//===----------------------------------------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//===----------------------------------------------------------------------===//

// The demangler does not pass all these tests with the system dylibs on macOS.
// XFAIL: stdlib=apple-libc++ && target={{.+}}-apple-macosx10.{{9|10|11|12|13|14|15}}

// This test is too big for most embedded devices.
// XFAIL: LIBCXX-PICOLIBC-FIXME

// https://llvm.org/PR51407 was not fixed in some previously-released
// demanglers, which causes them to run into the infinite loop.
// UNSUPPORTED: stdlib=apple-libc++ && target={{.+}}-apple-macosx10.{{9|10|11|12|13|14|15}}
// UNSUPPORTED: stdlib=apple-libc++ && target={{.+}}-apple-macosx11.0

// Android's long double on x86[-64] is (64/128)-bits instead of Linux's usual
// 80-bit format, and this demangling test is failing on it.
// XFAIL: LIBCXX-ANDROID-FIXME && target={{i686|x86_64}}-{{.+}}-android{{.*}}

#include "support/timer.h"
#include <algorithm>
#include <cassert>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cxxabi.h>
#include <string>

// Is long double fp80?  (Only x87 extended double has 64-bit mantissa)
#define LDBL_FP80 (__LDBL_MANT_DIG__ == 64)
// Is long double fp128?
#define LDBL_FP128 (__LDBL_MANT_DIG__ == 113)

// clang-format off
const char* cases[][2] =
{
    {"_Z1A", "A"},
    {"_Z1Av", "A()"},
    {"_Z1A1B1C", "A(B, C)"},
    {"_Z1fDB3_", "f(_BitInt(3))"},
    {"_Z1fDU10_", "f(unsigned _BitInt(10))"},
    {"_Z1fIfEvDUstPT__", "void f<float>(unsigned _BitInt(sizeof (float*)))"},
    {"_Z1fIiEvDBstPT__", "void f<int>(_BitInt(sizeof (int*)))"},
    {"_Z4testI1A1BE1Cv", "C test<A, B>()"},
    {"_Z4testI1A1BET0_T_S3_", "B test<A, B>(A, A)"},
    {"_ZN1SgtEi", "S::operator>(int)"},
    {"_ZrsI1QEiT_i", "int operator>><Q>(Q, int)"},
    {"_ZN13dyldbootstrap5startEPK12macho_headeriPPKcl", "dyldbootstrap::start(macho_header const*, int, char const**, long)"},
    {"_ZN4dyld17getExecutablePathEv", "dyld::getExecutablePath()"},
    {"_ZN4dyld22mainExecutablePreboundEv", "dyld::mainExecutablePrebound()"},
    {"_ZN4dyld14mainExecutableEv", "dyld::mainExecutable()"},
    {"_ZN4dyld21findImageByMachHeaderEPK11mach_header", "dyld::findImageByMachHeader(mach_header const*)"},
    {"_ZN4dyld26findImageContainingAddressEPKv", "dyld::findImageContainingAddress(void const*)"},
    {"_ZN4dyld17clearErrorMessageEv", "dyld::clearErrorMessage()"},
    {"_ZN4dyld15getErrorMessageEv", "dyld::getErrorMessage()"},
    {"_ZN4dyld24registerUndefinedHandlerEPFvPKcE", "dyld::registerUndefinedHandler(void (*)(char const*))"},
    {"_ZN4dyld19openSharedCacheFileEv", "dyld::openSharedCacheFile()"},
    {"_ZN4dyld15setErrorMessageEPKc", "dyld::setErrorMessage(char const*)"},
    {"_ZN4dyld22registerRemoveCallbackEPFvPK11mach_headerlE", "dyld::registerRemoveCallback(void (*)(mach_header const*, long))"},
    {"_ZN4dyld13inSharedCacheEPKc", "dyld::inSharedCache(char const*)"},
    {"_ZN4dyld15runInitializersEP11ImageLoader", "dyld::runInitializers(ImageLoader*)"},
    {"_ZN4dyld27findCoalescedExportedSymbolEPKcPPKN11ImageLoader6SymbolEPPKS2_", "dyld::findCoalescedExportedSymbol(char const*, ImageLoader::Symbol const**, ImageLoader const**)"},
    {"_ZN4dyld22flatFindExportedSymbolEPKcPPKN11ImageLoader6SymbolEPPKS2_", "dyld::flatFindExportedSymbol(char const*, ImageLoader::Symbol const**, ImageLoader const**)"},
    {"_ZN4dyld15findLoadedImageERK4stat", "dyld::findLoadedImage(stat const&)"},
    {"_ZN4dyld24initializeMainExecutableEv", "dyld::initializeMainExecutable()"},
    {"_ZN4dyld4warnEPKcz", "dyld::warn(char const*, ...)"},
    {"_ZN4dyld29processDyldEnvironmentVaribleEPKcS1_", "dyld::processDyldEnvironmentVarible(char const*, char const*)"},
    {"_ZN4dyld3logEPKcz", "dyld::log(char const*, ...)"},
    {"_ZN4dyld6throwfEPKcz", "dyld::throwf(char const*, ...)"},
    {"_ZN4dyld9mkstringfEPKcz", "dyld::mkstringf(char const*, ...)"},
    {"_ZN4dyld14addMappedRangeEP11ImageLoadermm", "dyld::addMappedRange(ImageLoader*, unsigned long, unsigned long)"},
    {"_Z28coresymbolication_load_imageP25CSCppDyldSharedMemoryPagePK11ImageLoadery", "coresymbolication_load_image(CSCppDyldSharedMemoryPage*, ImageLoader const*, unsigned long long)"},
    {"_Z30coresymbolication_unload_imageP25CSCppDyldSharedMemoryPagePK11ImageLoader", "coresymbolication_unload_image(CSCppDyldSharedMemoryPage*, ImageLoader const*)"},
    {"_ZN4dyld18getCoalescedImagesEPP11ImageLoader", "dyld::getCoalescedImages(ImageLoader**)"},
    {"_ZN4dyld25findImageContainingSymbolEPKv", "dyld::findImageContainingSymbol(void const*)"},
    {"_ZN4dyld19registerAddCallbackEPFvPK11mach_headerlE", "dyld::registerAddCallback(void (*)(mach_header const*, long))"},
    {"_ZN4dyld14forEachImageDoEPFvP11ImageLoaderPvES2_", "dyld::forEachImageDo(void (*)(ImageLoader*, void*), void*)"},
    {"_ZN4dyld15getIndexedImageEj", "dyld::getIndexedImage(unsigned int)"},
    {"_ZN4dyld13getImageCountEv", "dyld::getImageCount()"},
    {"_ZN4dyld10validImageEPK11ImageLoader", "dyld::validImage(ImageLoader const*)"},
    {"_ZN4dyld30flatFindExportedSymbolWithHintEPKcS1_PPKN11ImageLoader6SymbolEPPKS2_", "dyld::flatFindExportedSymbolWithHint(char const*, char const*, ImageLoader::Symbol const**, ImageLoader const**)"},
    {"_ZN4dyld14loadFromMemoryEPKhyPKc", "dyld::loadFromMemory(unsigned char const*, unsigned long long, char const*)"},
    {"_ZN4dyld36registerImageStateBatchChangeHandlerE17dyld_image_statesPFPKcS0_jPK15dyld_image_infoE", "dyld::registerImageStateBatchChangeHandler(dyld_image_states, char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*))"},
    {"_ZN4dyld37registerImageStateSingleChangeHandlerE17dyld_image_statesPFPKcS0_jPK15dyld_image_infoE", "dyld::registerImageStateSingleChangeHandler(dyld_image_states, char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*))"},
    {"_ZN4dyld4haltEPKc", "dyld::halt(char const*)"},
    {"_ZN4dyld18fastBindLazySymbolEPP11ImageLoaderm", "dyld::fastBindLazySymbol(ImageLoader**, unsigned long)"},
    {"_ZN4dyld14bindLazySymbolEPK11mach_headerPm", "dyld::bindLazySymbol(mach_header const*, unsigned long*)"},
    {"_ZN4dyld14runTerminatorsEPv", "dyld::runTerminators(void*)"},
    {"_ZN4dyld11removeImageEP11ImageLoader", "dyld::removeImage(ImageLoader*)"},
    {"_ZN4dyld20garbageCollectImagesEv", "dyld::garbageCollectImages()"},
    {"_ZN4dyld9preflightEP11ImageLoaderRKNS0_10RPathChainE", "dyld::preflight(ImageLoader*, ImageLoader::RPathChain const&)"},
    {"_ZN4dyld4linkEP11ImageLoaderbRKNS0_10RPathChainE", "dyld::link(ImageLoader*, bool, ImageLoader::RPathChain const&)"},
    {"_ZN4dyld10cloneImageEP11ImageLoader", "dyld::cloneImage(ImageLoader*)"},
    {"_ZN4dyld4loadEPKcRKNS_11LoadContextE", "dyld::load(char const*, dyld::LoadContext const&)"},
    {"_ZN4dyld5_mainEPK12macho_headermiPPKcS5_S5_", "dyld::_main(macho_header const*, unsigned long, int, char const**, char const**, char const**)"},
    {"_ZNSt6vectorIN4dyld13RegisteredDOFESaIS1_EE5eraseEN9__gnu_cxx17__normal_iteratorIPS1_S3_EE", "std::vector<dyld::RegisteredDOF, std::allocator<dyld::RegisteredDOF>>::erase(__gnu_cxx::__normal_iterator<dyld::RegisteredDOF*, std::vector<dyld::RegisteredDOF, std::allocator<dyld::RegisteredDOF>>>)"},
    {"_ZNSt12_Vector_baseIPKcSaIS1_EED2Ev", "std::_Vector_base<char const*, std::allocator<char const*>>::~_Vector_base()"},
    {"_ZNSt6vectorIPKcSaIS1_EED2Ev", "std::vector<char const*, std::allocator<char const*>>::~vector()"},
    {"_ZNSt12_Vector_baseIPFPKc17dyld_image_statesjPK15dyld_image_infoESaIS7_EED2Ev", "std::_Vector_base<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*), std::allocator<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*)>>::~_Vector_base()"},
    {"_ZNSt6vectorIPFPKc17dyld_image_statesjPK15dyld_image_infoESaIS7_EED2Ev", "std::vector<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*), std::allocator<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*)>>::~vector()"},
    {"_ZNSt12_Vector_baseIPFvPK11mach_headerlESaIS4_EED2Ev", "std::_Vector_base<void (*)(mach_header const*, long), std::allocator<void (*)(mach_header const*, long)>>::~_Vector_base()"},
    {"_ZNSt6vectorIPFvPK11mach_headerlESaIS4_EED2Ev", "std::vector<void (*)(mach_header const*, long), std::allocator<void (*)(mach_header const*, long)>>::~vector()"},
    {"_ZNSt12_Vector_baseIN4dyld13RegisteredDOFESaIS1_EED2Ev", "std::_Vector_base<dyld::RegisteredDOF, std::allocator<dyld::RegisteredDOF>>::~_Vector_base()"},
    {"_ZNSt6vectorIN4dyld13RegisteredDOFESaIS1_EED2Ev", "std::vector<dyld::RegisteredDOF, std::allocator<dyld::RegisteredDOF>>::~vector()"},
    {"_ZNSt12_Vector_baseIP11ImageLoaderSaIS1_EED2Ev", "std::_Vector_base<ImageLoader*, std::allocator<ImageLoader*>>::~_Vector_base()"},
    {"_ZNSt6vectorIP11ImageLoaderSaIS1_EED2Ev", "std::vector<ImageLoader*, std::allocator<ImageLoader*>>::~vector()"},
    {"_ZN9__gnu_cxx13new_allocatorIPFPKc17dyld_image_statesjPK15dyld_image_infoEE8allocateEmPKv", "__gnu_cxx::new_allocator<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*)>::allocate(unsigned long, void const*)"},
    {"_ZN9__gnu_cxx13new_allocatorIPFvPK11mach_headerlEE8allocateEmPKv", "__gnu_cxx::new_allocator<void (*)(mach_header const*, long)>::allocate(unsigned long, void const*)"},
    {"_ZN9__gnu_cxx13new_allocatorIPKcE8allocateEmPKv", "__gnu_cxx::new_allocator<char const*>::allocate(unsigned long, void const*)"},
    {"_ZN9__gnu_cxx13new_allocatorIP11ImageLoaderE8allocateEmPKv", "__gnu_cxx::new_allocator<ImageLoader*>::allocate(unsigned long, void const*)"},
    {"_ZN9__gnu_cxx13new_allocatorIN4dyld13RegisteredDOFEE8allocateEmPKv", "__gnu_cxx::new_allocator<dyld::RegisteredDOF>::allocate(unsigned long, void const*)"},
    {"_ZNSt6vectorIN4dyld13RegisteredDOFESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<dyld::RegisteredDOF, std::allocator<dyld::RegisteredDOF>>::_M_insert_aux(__gnu_cxx::__normal_iterator<dyld::RegisteredDOF*, std::vector<dyld::RegisteredDOF, std::allocator<dyld::RegisteredDOF>>>, dyld::RegisteredDOF const&)"},
    {"_ZNSt6vectorIN4dyld13RegisteredDOFESaIS1_EE9push_backERKS1_", "std::vector<dyld::RegisteredDOF, std::allocator<dyld::RegisteredDOF>>::push_back(dyld::RegisteredDOF const&)"},
    {"_ZSt18uninitialized_copyIPPFPKc17dyld_image_statesjPK15dyld_image_infoES8_ET0_T_SA_S9_", "char const* (**std::uninitialized_copy<char const* (**)(dyld_image_states, unsigned int, dyld_image_info const*), char const* (**)(dyld_image_states, unsigned int, dyld_image_info const*)>(char const* (**)(dyld_image_states, unsigned int, dyld_image_info const*), char const* (**)(dyld_image_states, unsigned int, dyld_image_info const*), char const* (**)(dyld_image_states, unsigned int, dyld_image_info const*)))(dyld_image_states, unsigned int, dyld_image_info const*)"},
    {"_ZSt18uninitialized_copyIPPFvPK11mach_headerlES5_ET0_T_S7_S6_", "void (**std::uninitialized_copy<void (**)(mach_header const*, long), void (**)(mach_header const*, long)>(void (**)(mach_header const*, long), void (**)(mach_header const*, long), void (**)(mach_header const*, long)))(mach_header const*, long)"},
    {"_ZSt18uninitialized_copyIPPKcS2_ET0_T_S4_S3_", "char const** std::uninitialized_copy<char const**, char const**>(char const**, char const**, char const**)"},
    {"_ZNSt15__copy_backwardILb1ESt26random_access_iterator_tagE8__copy_bIPFPKc17dyld_image_statesjPK15dyld_image_infoEEEPT_PKSB_SE_SC_", "char const* (**std::__copy_backward<true, std::random_access_iterator_tag>::__copy_b<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*)>(char const* (* const*)(dyld_image_states, unsigned int, dyld_image_info const*), char const* (* const*)(dyld_image_states, unsigned int, dyld_image_info const*), char const* (**)(dyld_image_states, unsigned int, dyld_image_info const*)))(dyld_image_states, unsigned int, dyld_image_info const*)"},
    {"_ZNSt6vectorIPFPKc17dyld_image_statesjPK15dyld_image_infoESaIS7_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS7_S9_EERKS7_", "std::vector<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*), std::allocator<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*)>>::_M_insert_aux(__gnu_cxx::__normal_iterator<char const* (**)(dyld_image_states, unsigned int, dyld_image_info const*), std::vector<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*), std::allocator<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*)>>>, char const* (* const&)(dyld_image_states, unsigned int, dyld_image_info const*))"},
    {"_ZNSt6vectorIPFPKc17dyld_image_statesjPK15dyld_image_infoESaIS7_EE6insertEN9__gnu_cxx17__normal_iteratorIPS7_S9_EERKS7_", "std::vector<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*), std::allocator<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*)>>::insert(__gnu_cxx::__normal_iterator<char const* (**)(dyld_image_states, unsigned int, dyld_image_info const*), std::vector<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*), std::allocator<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*)>>>, char const* (* const&)(dyld_image_states, unsigned int, dyld_image_info const*))"},
    {"_ZNSt6vectorIPFPKc17dyld_image_statesjPK15dyld_image_infoESaIS7_EE9push_backERKS7_", "std::vector<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*), std::allocator<char const* (*)(dyld_image_states, unsigned int, dyld_image_info const*)>>::push_back(char const* (* const&)(dyld_image_states, unsigned int, dyld_image_info const*))"},
    {"_ZNSt15__copy_backwardILb1ESt26random_access_iterator_tagE8__copy_bIPFvPK11mach_headerlEEEPT_PKS8_SB_S9_", "void (**std::__copy_backward<true, std::random_access_iterator_tag>::__copy_b<void (*)(mach_header const*, long)>(void (* const*)(mach_header const*, long), void (* const*)(mach_header const*, long), void (**)(mach_header const*, long)))(mach_header const*, long)"},
    {"_ZNSt6vectorIPFvPK11mach_headerlESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<void (*)(mach_header const*, long), std::allocator<void (*)(mach_header const*, long)>>::_M_insert_aux(__gnu_cxx::__normal_iterator<void (**)(mach_header const*, long), std::vector<void (*)(mach_header const*, long), std::allocator<void (*)(mach_header const*, long)>>>, void (* const&)(mach_header const*, long))"},
    {"_ZNSt6vectorIPFvPK11mach_headerlESaIS4_EE9push_backERKS4_", "std::vector<void (*)(mach_header const*, long), std::allocator<void (*)(mach_header const*, long)>>::push_back(void (* const&)(mach_header const*, long))"},
    {"_ZNSt15__copy_backwardILb1ESt26random_access_iterator_tagE8__copy_bIPKcEEPT_PKS5_S8_S6_", "char const** std::__copy_backward<true, std::random_access_iterator_tag>::__copy_b<char const*>(char const* const*, char const* const*, char const**)"},
    {"_ZNSt6vectorIPKcSaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<char const*, std::allocator<char const*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<char const**, std::vector<char const*, std::allocator<char const*>>>, char const* const&)"},
    {"_ZNSt6vectorIPKcSaIS1_EE9push_backERKS1_", "std::vector<char const*, std::allocator<char const*>>::push_back(char const* const&)"},
    {"_ZNSt15__copy_backwardILb1ESt26random_access_iterator_tagE8__copy_bIP11ImageLoaderEEPT_PKS5_S8_S6_", "ImageLoader** std::__copy_backward<true, std::random_access_iterator_tag>::__copy_b<ImageLoader*>(ImageLoader* const*, ImageLoader* const*, ImageLoader**)"},
    {"_ZNSt6vectorIPFvPK11mach_headerlESaIS4_EE20_M_allocate_and_copyIPS4_EES8_mT_S9_", "void (**std::vector<void (*)(mach_header const*, long), std::allocator<void (*)(mach_header const*, long)>>::_M_allocate_and_copy<void (**)(mach_header const*, long)>(unsigned long, void (**)(mach_header const*, long), void (**)(mach_header const*, long)))(mach_header const*, long)"},
    {"_ZNSt6vectorIPFvPK11mach_headerlESaIS4_EE7reserveEm", "std::vector<void (*)(mach_header const*, long), std::allocator<void (*)(mach_header const*, long)>>::reserve(unsigned long)"},
    {"_ZNSt6vectorIN4dyld13RegisteredDOFESaIS1_EE20_M_allocate_and_copyIPS1_EES5_mT_S6_", "dyld::RegisteredDOF* std::vector<dyld::RegisteredDOF, std::allocator<dyld::RegisteredDOF>>::_M_allocate_and_copy<dyld::RegisteredDOF*>(unsigned long, dyld::RegisteredDOF*, dyld::RegisteredDOF*)"},
    {"_ZNSt6vectorIN4dyld13RegisteredDOFESaIS1_EE7reserveEm", "std::vector<dyld::RegisteredDOF, std::allocator<dyld::RegisteredDOF>>::reserve(unsigned long)"},
    {"_ZSt18uninitialized_copyIPP11ImageLoaderS2_ET0_T_S4_S3_", "ImageLoader** std::uninitialized_copy<ImageLoader**, ImageLoader**>(ImageLoader**, ImageLoader**, ImageLoader**)"},
    {"_ZNSt6vectorIP11ImageLoaderSaIS1_EE20_M_allocate_and_copyIPS1_EES5_mT_S6_", "ImageLoader** std::vector<ImageLoader*, std::allocator<ImageLoader*>>::_M_allocate_and_copy<ImageLoader**>(unsigned long, ImageLoader**, ImageLoader**)"},
    {"_ZNSt6vectorIP11ImageLoaderSaIS1_EE7reserveEm", "std::vector<ImageLoader*, std::allocator<ImageLoader*>>::reserve(unsigned long)"},
    {"_ZNSt6vectorIP11ImageLoaderSaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<ImageLoader*, std::allocator<ImageLoader*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<ImageLoader**, std::vector<ImageLoader*, std::allocator<ImageLoader*>>>, ImageLoader* const&)"},
    {"_ZNSt6vectorIP11ImageLoaderSaIS1_EE9push_backERKS1_", "std::vector<ImageLoader*, std::allocator<ImageLoader*>>::push_back(ImageLoader* const&)"},
    {"_ZNSt6vectorIP11ImageLoaderSaIS1_EE5eraseEN9__gnu_cxx17__normal_iteratorIPS1_S3_EE", "std::vector<ImageLoader*, std::allocator<ImageLoader*>>::erase(__gnu_cxx::__normal_iterator<ImageLoader**, std::vector<ImageLoader*, std::allocator<ImageLoader*>>>)"},
    {"_Z18lookupDyldFunctionPKcPm", "lookupDyldFunction(char const*, unsigned long*)"},
    {"_ZNSt12_Vector_baseIP19__NSObjectFileImageSaIS1_EED2Ev", "std::_Vector_base<__NSObjectFileImage*, std::allocator<__NSObjectFileImage*>>::~_Vector_base()"},
    {"_ZNSt6vectorIP19__NSObjectFileImageSaIS1_EED2Ev", "std::vector<__NSObjectFileImage*, std::allocator<__NSObjectFileImage*>>::~vector()"},
    {"_ZNSt15__copy_backwardILb1ESt26random_access_iterator_tagE8__copy_bIP19__NSObjectFileImageEEPT_PKS5_S8_S6_", "__NSObjectFileImage** std::__copy_backward<true, std::random_access_iterator_tag>::__copy_b<__NSObjectFileImage*>(__NSObjectFileImage* const*, __NSObjectFileImage* const*, __NSObjectFileImage**)"},
    {"_ZN9__gnu_cxx13new_allocatorIP19__NSObjectFileImageE8allocateEmPKv", "__gnu_cxx::new_allocator<__NSObjectFileImage*>::allocate(unsigned long, void const*)"},
    {"_ZNSt6vectorIP19__NSObjectFileImageSaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<__NSObjectFileImage*, std::allocator<__NSObjectFileImage*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<__NSObjectFileImage**, std::vector<__NSObjectFileImage*, std::allocator<__NSObjectFileImage*>>>, __NSObjectFileImage* const&)"},
    {"_ZNSt6vectorIP19__NSObjectFileImageSaIS1_EE9push_backERKS1_", "std::vector<__NSObjectFileImage*, std::allocator<__NSObjectFileImage*>>::push_back(__NSObjectFileImage* const&)"},
    {"_ZNSt6vectorIP19__NSObjectFileImageSaIS1_EE5eraseEN9__gnu_cxx17__normal_iteratorIPS1_S3_EE", "std::vector<__NSObjectFileImage*, std::allocator<__NSObjectFileImage*>>::erase(__gnu_cxx::__normal_iterator<__NSObjectFileImage**, std::vector<__NSObjectFileImage*, std::allocator<__NSObjectFileImage*>>>)"},
    {"_Z19setAlImageInfosHaltPKcm", "setAlImageInfosHalt(char const*, unsigned long)"},
    {"_Z24removeImageFromAllImagesPK11mach_header", "removeImageFromAllImages(mach_header const*)"},
    {"_Z20addImagesToAllImagesjPK15dyld_image_info", "addImagesToAllImages(unsigned int, dyld_image_info const*)"},
    {"_ZNSt6vectorI15dyld_image_infoSaIS0_EE5eraseEN9__gnu_cxx17__normal_iteratorIPS0_S2_EE", "std::vector<dyld_image_info, std::allocator<dyld_image_info>>::erase(__gnu_cxx::__normal_iterator<dyld_image_info*, std::vector<dyld_image_info, std::allocator<dyld_image_info>>>)"},
    {"_ZNSt12_Vector_baseI15dyld_image_infoSaIS0_EED2Ev", "std::_Vector_base<dyld_image_info, std::allocator<dyld_image_info>>::~_Vector_base()"},
    {"_ZNSt6vectorI15dyld_image_infoSaIS0_EED2Ev", "std::vector<dyld_image_info, std::allocator<dyld_image_info>>::~vector()"},
    {"_ZN9__gnu_cxx13new_allocatorI15dyld_image_infoE8allocateEmPKv", "__gnu_cxx::new_allocator<dyld_image_info>::allocate(unsigned long, void const*)"},
    {"_ZNSt6vectorI15dyld_image_infoSaIS0_EE20_M_allocate_and_copyIPS0_EES4_mT_S5_", "dyld_image_info* std::vector<dyld_image_info, std::allocator<dyld_image_info>>::_M_allocate_and_copy<dyld_image_info*>(unsigned long, dyld_image_info*, dyld_image_info*)"},
    {"_ZNSt6vectorI15dyld_image_infoSaIS0_EE7reserveEm", "std::vector<dyld_image_info, std::allocator<dyld_image_info>>::reserve(unsigned long)"},
    {"_ZNSt6vectorI15dyld_image_infoSaIS0_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS0_S2_EERKS0_", "std::vector<dyld_image_info, std::allocator<dyld_image_info>>::_M_insert_aux(__gnu_cxx::__normal_iterator<dyld_image_info*, std::vector<dyld_image_info, std::allocator<dyld_image_info>>>, dyld_image_info const&)"},
    {"_ZNSt6vectorI15dyld_image_infoSaIS0_EE9push_backERKS0_", "std::vector<dyld_image_info, std::allocator<dyld_image_info>>::push_back(dyld_image_info const&)"},
    {"_ZN10__cxxabiv112__unexpectedEPFvvE", "__cxxabiv1::__unexpected(void (*)())"},
    {"_ZN10__cxxabiv111__terminateEPFvvE", "__cxxabiv1::__terminate(void (*)())"},
    {"_ZSt10unexpectedv", "std::unexpected()"},
    {"_ZSt9terminatev", "std::terminate()"},
    {"_ZN11ImageLoaderC2EPKcj", "ImageLoader::ImageLoader(char const*, unsigned int)"},
    {"_ZN11ImageLoader11deleteImageEPS_", "ImageLoader::deleteImage(ImageLoader*)"},
    {"_ZN11ImageLoader11setFileInfoEiyl", "ImageLoader::setFileInfo(int, unsigned long long, long)"},
    {"_ZN11ImageLoader9setMappedERKNS_11LinkContextE", "ImageLoader::setMapped(ImageLoader::LinkContext const&)"},
    {"_ZNK11ImageLoader7compareEPKS_", "ImageLoader::compare(ImageLoader const*) const"},
    {"_ZN11ImageLoader4hashEPKc", "ImageLoader::hash(char const*)"},
    {"_ZNK11ImageLoader16matchInstallPathEv", "ImageLoader::matchInstallPath() const"},
    {"_ZN11ImageLoader19setMatchInstallPathEb", "ImageLoader::setMatchInstallPath(bool)"},
    {"_ZNK11ImageLoader9statMatchERK4stat", "ImageLoader::statMatch(stat const&) const"},
    {"_ZN11ImageLoader14setLeaveMappedEv", "ImageLoader::setLeaveMapped()"},
    {"_ZN11ImageLoader14setHideExportsEb", "ImageLoader::setHideExports(bool)"},
    {"_ZNK11ImageLoader16hasHiddenExportsEv", "ImageLoader::hasHiddenExports() const"},
    {"_ZNK11ImageLoader8isLinkedEv", "ImageLoader::isLinked() const"},
    {"_ZNK11ImageLoader12lastModifiedEv", "ImageLoader::lastModified() const"},
    {"_ZNK11ImageLoader24overlapsWithAddressRangeEPKvS1_", "ImageLoader::overlapsWithAddressRange(void const*, void const*) const"},
    {"_ZNK11ImageLoader16getMappedRegionsERPNS_12MappedRegionE", "ImageLoader::getMappedRegions(ImageLoader::MappedRegion*&) const"},
    {"_ZNK11ImageLoader41findExportedSymbolInDependentImagesExceptEPKcPPKS_RS4_S4_S4_", "ImageLoader::findExportedSymbolInDependentImagesExcept(char const*, ImageLoader const**, ImageLoader const**&, ImageLoader const**, ImageLoader const**) const"},
    {"_ZN11ImageLoader29decrementDlopenReferenceCountEv", "ImageLoader::decrementDlopenReferenceCount()"},
    {"_ZN11ImageLoader19bindAllLazyPointersERKNS_11LinkContextEb", "ImageLoader::bindAllLazyPointers(ImageLoader::LinkContext const&, bool)"},
    {"_ZNK11ImageLoader35allDependentLibrariesAsWhenPreBoundEv", "ImageLoader::allDependentLibrariesAsWhenPreBound() const"},
    {"_ZN11ImageLoader20recursiveUpdateDepthEj", "ImageLoader::recursiveUpdateDepth(unsigned int)"},
    {"_ZN11ImageLoader23recursiveGetDOFSectionsERKNS_11LinkContextERSt6vectorINS_7DOFInfoESaIS4_EE", "ImageLoader::recursiveGetDOFSections(ImageLoader::LinkContext const&, std::vector<ImageLoader::DOFInfo, std::allocator<ImageLoader::DOFInfo>>&)"},
    {"_ZNK11ImageLoader12getShortNameEv", "ImageLoader::getShortName() const"},
    {"_ZN11ImageLoader9addSuffixEPKcS1_Pc", "ImageLoader::addSuffix(char const*, char const*, char*)"},
    {"_ZN11ImageLoader15printStatisticsEj", "ImageLoader::printStatistics(unsigned int)"},
    {"_ZN11ImageLoader13recursiveBindERKNS_11LinkContextEb", "ImageLoader::recursiveBind(ImageLoader::LinkContext const&, bool)"},
    {"_ZN11ImageLoader25recursiveApplyInterposingERKNS_11LinkContextE", "ImageLoader::recursiveApplyInterposing(ImageLoader::LinkContext const&)"},
    {"_ZN11ImageLoader16applyInterposingERKNS_11LinkContextE", "ImageLoader::applyInterposing(ImageLoader::LinkContext const&)"},
    {"_ZN11ImageLoader15recursiveRebaseERKNS_11LinkContextE", "ImageLoader::recursiveRebase(ImageLoader::LinkContext const&)"},
    {"_ZNK11ImageLoader42findExportedSymbolInImageOrDependentImagesEPKcRKNS_11LinkContextEPPKS_", "ImageLoader::findExportedSymbolInImageOrDependentImages(char const*, ImageLoader::LinkContext const&, ImageLoader const**) const"},
    {"_ZNK11ImageLoader35findExportedSymbolInDependentImagesEPKcRKNS_11LinkContextEPPKS_", "ImageLoader::findExportedSymbolInDependentImages(char const*, ImageLoader::LinkContext const&, ImageLoader const**) const"},
    {"_ZN11ImageLoader8reExportEPS_", "ImageLoader::reExport(ImageLoader*)"},
    {"_ZN11ImageLoader19addDynamicReferenceEPKS_", "ImageLoader::addDynamicReference(ImageLoader const*)"},
    {"_ZN11ImageLoader14setPathUnownedEPKc", "ImageLoader::setPathUnowned(char const*)"},
    {"_ZN11ImageLoader7setPathEPKc", "ImageLoader::setPath(char const*)"},
    {"_ZN11ImageLoaderD0Ev", "ImageLoader::~ImageLoader()"},
    {"_ZNK11ImageLoader15containsAddressEPKv", "ImageLoader::containsAddress(void const*) const"},
    {"_ZN11ImageLoaderD2Ev", "ImageLoader::~ImageLoader()"},
    {"_ZN11ImageLoaderD1Ev", "ImageLoader::~ImageLoader()"},
    {"_ZN11ImageLoader23recursiveInitializationERKNS_11LinkContextEj", "ImageLoader::recursiveInitialization(ImageLoader::LinkContext const&, unsigned int)"},
    {"_ZN11ImageLoader15runInitializersERKNS_11LinkContextE", "ImageLoader::runInitializers(ImageLoader::LinkContext const&)"},
    {"_ZN11ImageLoader8weakBindERKNS_11LinkContextE", "ImageLoader::weakBind(ImageLoader::LinkContext const&)"},
    {"_ZN11ImageLoader22recursiveLoadLibrariesERKNS_11LinkContextEbRKNS_10RPathChainE", "ImageLoader::recursiveLoadLibraries(ImageLoader::LinkContext const&, bool, ImageLoader::RPathChain const&)"},
    {"_ZN11ImageLoader4linkERKNS_11LinkContextEbbRKNS_10RPathChainE", "ImageLoader::link(ImageLoader::LinkContext const&, bool, bool, ImageLoader::RPathChain const&)"},
    {"_ZNSt12_Vector_baseIN11ImageLoader7DOFInfoESaIS1_EED2Ev", "std::_Vector_base<ImageLoader::DOFInfo, std::allocator<ImageLoader::DOFInfo>>::~_Vector_base()"},
    {"_ZNSt6vectorIN11ImageLoader7DOFInfoESaIS1_EED2Ev", "std::vector<ImageLoader::DOFInfo, std::allocator<ImageLoader::DOFInfo>>::~vector()"},
    {"_ZNSt8_Rb_treeIPK11ImageLoaderS2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE8_M_eraseEPSt13_Rb_tree_nodeIS2_E", "std::_Rb_tree<ImageLoader const*, ImageLoader const*, std::_Identity<ImageLoader const*>, std::less<ImageLoader const*>, std::allocator<ImageLoader const*>>::_M_erase(std::_Rb_tree_node<ImageLoader const*>*)"},
    {"_ZNSt12_Vector_baseIN11ImageLoader14InterposeTupleESaIS1_EED2Ev", "std::_Vector_base<ImageLoader::InterposeTuple, std::allocator<ImageLoader::InterposeTuple>>::~_Vector_base()"},
    {"_ZNSt6vectorIN11ImageLoader14InterposeTupleESaIS1_EED2Ev", "std::vector<ImageLoader::InterposeTuple, std::allocator<ImageLoader::InterposeTuple>>::~vector()"},
    {"_ZNSt12_Vector_baseISt4pairIP11ImageLoaderS2_ESaIS3_EED2Ev", "std::_Vector_base<std::pair<ImageLoader*, ImageLoader*>, std::allocator<std::pair<ImageLoader*, ImageLoader*>>>::~_Vector_base()"},
    {"_ZNSt6vectorISt4pairIP11ImageLoaderS2_ESaIS3_EED2Ev", "std::vector<std::pair<ImageLoader*, ImageLoader*>, std::allocator<std::pair<ImageLoader*, ImageLoader*>>>::~vector()"},
    {"_ZN9__gnu_cxx13new_allocatorISt13_Rb_tree_nodeIPK11ImageLoaderEE8allocateEmPKv", "__gnu_cxx::new_allocator<std::_Rb_tree_node<ImageLoader const*>>::allocate(unsigned long, void const*)"},
    {"_ZNSt8_Rb_treeIPK11ImageLoaderS2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE14_M_create_nodeERKS2_", "std::_Rb_tree<ImageLoader const*, ImageLoader const*, std::_Identity<ImageLoader const*>, std::less<ImageLoader const*>, std::allocator<ImageLoader const*>>::_M_create_node(ImageLoader const* const&)"},
    {"_ZN9__gnu_cxx13new_allocatorISt4pairIP11ImageLoaderS3_EE8allocateEmPKv", "__gnu_cxx::new_allocator<std::pair<ImageLoader*, ImageLoader*>>::allocate(unsigned long, void const*)"},
    {"_ZNSt6vectorISt4pairIP11ImageLoaderS2_ESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<std::pair<ImageLoader*, ImageLoader*>, std::allocator<std::pair<ImageLoader*, ImageLoader*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<ImageLoader*, ImageLoader*>*, std::vector<std::pair<ImageLoader*, ImageLoader*>, std::allocator<std::pair<ImageLoader*, ImageLoader*>>>>, std::pair<ImageLoader*, ImageLoader*> const&)"},
    {"_ZNSt6vectorISt4pairIP11ImageLoaderS2_ESaIS3_EE9push_backERKS3_", "std::vector<std::pair<ImageLoader*, ImageLoader*>, std::allocator<std::pair<ImageLoader*, ImageLoader*>>>::push_back(std::pair<ImageLoader*, ImageLoader*> const&)"},
    {"_ZNSt8_Rb_treeIPK11ImageLoaderS2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE9_M_insertEPSt18_Rb_tree_node_baseSA_RKS2_", "std::_Rb_tree<ImageLoader const*, ImageLoader const*, std::_Identity<ImageLoader const*>, std::less<ImageLoader const*>, std::allocator<ImageLoader const*>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, ImageLoader const* const&)"},
    {"_ZNSt8_Rb_treeIPK11ImageLoaderS2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE16_M_insert_uniqueERKS2_", "std::_Rb_tree<ImageLoader const*, ImageLoader const*, std::_Identity<ImageLoader const*>, std::less<ImageLoader const*>, std::allocator<ImageLoader const*>>::_M_insert_unique(ImageLoader const* const&)"},
    {"_ZNK16ImageLoaderMachO12segmentCountEv", "ImageLoaderMachO::segmentCount() const"},
    {"_ZN16ImageLoaderMachO22segHasTrailingZeroFillEj", "ImageLoaderMachO::segHasTrailingZeroFill(unsigned int)"},
    {"_ZNK16ImageLoaderMachO19segActualEndAddressEj", "ImageLoaderMachO::segActualEndAddress(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO25segmentsMustSlideTogetherEv", "ImageLoaderMachO::segmentsMustSlideTogether() const"},
    {"_ZNK16ImageLoaderMachO16segmentsCanSlideEv", "ImageLoaderMachO::segmentsCanSlide() const"},
    {"_ZNK16ImageLoaderMachO8isBundleEv", "ImageLoaderMachO::isBundle() const"},
    {"_ZNK16ImageLoaderMachO7isDylibEv", "ImageLoaderMachO::isDylib() const"},
    {"_ZNK16ImageLoaderMachO12isExecutableEv", "ImageLoaderMachO::isExecutable() const"},
    {"_ZNK16ImageLoaderMachO31isPositionIndependentExecutableEv", "ImageLoaderMachO::isPositionIndependentExecutable() const"},
    {"_ZNK16ImageLoaderMachO9forceFlatEv", "ImageLoaderMachO::forceFlat() const"},
    {"_ZNK16ImageLoaderMachO21usesTwoLevelNameSpaceEv", "ImageLoaderMachO::usesTwoLevelNameSpace() const"},
    {"_ZNK16ImageLoaderMachO13isPrebindableEv", "ImageLoaderMachO::isPrebindable() const"},
    {"_ZNK16ImageLoaderMachO19hasCoalescedExportsEv", "ImageLoaderMachO::hasCoalescedExports() const"},
    {"_ZN16ImageLoaderMachO8setSlideEl", "ImageLoaderMachO::setSlide(long)"},
    {"_ZNK16ImageLoaderMachO14getInstallPathEv", "ImageLoaderMachO::getInstallPath() const"},
    {"_ZNK16ImageLoaderMachO7getMainEv", "ImageLoaderMachO::getMain() const"},
    {"_ZN16ImageLoaderMachO16doGetLibraryInfoEv", "ImageLoaderMachO::doGetLibraryInfo()"},
    {"_ZNK16ImageLoaderMachO21getExportedSymbolInfoEPKN11ImageLoader6SymbolE", "ImageLoaderMachO::getExportedSymbolInfo(ImageLoader::Symbol const*) const"},
    {"_ZNK16ImageLoaderMachO21getExportedSymbolNameEPKN11ImageLoader6SymbolE", "ImageLoaderMachO::getExportedSymbolName(ImageLoader::Symbol const*) const"},
    {"_ZNK16ImageLoaderMachO22getExportedSymbolCountEv", "ImageLoaderMachO::getExportedSymbolCount() const"},
    {"_ZNK16ImageLoaderMachO24getIndexedExportedSymbolEj", "ImageLoaderMachO::getIndexedExportedSymbol(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO22getImportedSymbolCountEv", "ImageLoaderMachO::getImportedSymbolCount() const"},
    {"_ZNK16ImageLoaderMachO24getIndexedImportedSymbolEj", "ImageLoaderMachO::getIndexedImportedSymbol(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO21getImportedSymbolInfoEPKN11ImageLoader6SymbolE", "ImageLoaderMachO::getImportedSymbolInfo(ImageLoader::Symbol const*) const"},
    {"_ZNK16ImageLoaderMachO21getImportedSymbolNameEPKN11ImageLoader6SymbolE", "ImageLoaderMachO::getImportedSymbolName(ImageLoader::Symbol const*) const"},
    {"_ZN16ImageLoaderMachO13getUnwindInfoEP20dyld_unwind_sections", "ImageLoaderMachO::getUnwindInfo(dyld_unwind_sections*)"},
    {"_ZN16ImageLoaderMachO11findSectionEPKvPPKcS4_Pm", "ImageLoaderMachO::findSection(void const*, char const**, char const**, unsigned long*)"},
    {"_ZNK16ImageLoaderMachO10machHeaderEv", "ImageLoaderMachO::machHeader() const"},
    {"_ZNK16ImageLoaderMachO8getSlideEv", "ImageLoaderMachO::getSlide() const"},
    {"_ZNK16ImageLoaderMachO17lookupProgramVarsERKN11ImageLoader11LinkContextE", "ImageLoaderMachO::lookupProgramVars(ImageLoader::LinkContext const&) const"},
    {"_ZN16ImageLoaderMachO19needsInitializationEv", "ImageLoaderMachO::needsInitialization()"},
    {"_ZN16ImageLoaderMachO16needsTerminationEv", "ImageLoaderMachO::needsTermination()"},
    {"_ZN16ImageLoaderMachO10segProtectEjRKN11ImageLoader11LinkContextE", "ImageLoaderMachO::segProtect(unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO18doModInitFunctionsERKN11ImageLoader11LinkContextE", "ImageLoaderMachO::doModInitFunctions(ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO11doImageInitERKN11ImageLoader11LinkContextE", "ImageLoaderMachO::doImageInit(ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO16doInitializationERKN11ImageLoader11LinkContextE", "ImageLoaderMachO::doInitialization(ImageLoader::LinkContext const&)"},
    {"_ZNK16ImageLoaderMachO16getSymbolAddressEPKN11ImageLoader6SymbolEPKS0_RKNS0_11LinkContextE", "ImageLoaderMachO::getSymbolAddress(ImageLoader::Symbol const*, ImageLoader const*, ImageLoader::LinkContext const&) const"},
    {"_ZNK16ImageLoaderMachO24getExportedSymbolAddressEPKN11ImageLoader6SymbolERKNS0_11LinkContextEPKS0_", "ImageLoaderMachO::getExportedSymbolAddress(ImageLoader::Symbol const*, ImageLoader::LinkContext const&, ImageLoader const*) const"},
    {"_ZN16ImageLoaderMachO19throwSymbolNotFoundEPKcS1_S1_", "ImageLoaderMachO::throwSymbolNotFound(char const*, char const*, char const*)"},
    {"_ZN16ImageLoaderMachO21reserveAnAddressRangeEmRKN11ImageLoader11LinkContextE", "ImageLoaderMachO::reserveAnAddressRange(unsigned long, ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO23setupLazyPointerHandlerERKN11ImageLoader11LinkContextE", "ImageLoaderMachO::setupLazyPointerHandler(ImageLoader::LinkContext const&)"},
    {"_ZNK16ImageLoaderMachO6getEndEv", "ImageLoaderMachO::getEnd() const"},
    {"_ZN16ImageLoaderMachO17getSectionContentEPKcS1_PPvPm", "ImageLoaderMachO::getSectionContent(char const*, char const*, void**, unsigned long*)"},
    {"_ZN16ImageLoaderMachO13parseLoadCmdsEv", "ImageLoaderMachO::parseLoadCmds()"},
    {"_ZN16ImageLoaderMachO15printStatisticsEj", "ImageLoaderMachO::printStatistics(unsigned int)"},
    {"_ZN16ImageLoaderMachO12bindLocationERKN11ImageLoader11LinkContextEmmPKS0_hPKclS7_", "ImageLoaderMachO::bindLocation(ImageLoader::LinkContext const&, unsigned long, unsigned long, ImageLoader const*, unsigned char, char const*, long, char const*)"},
    {"_ZN16ImageLoaderMachO16doGetDOFSectionsERKN11ImageLoader11LinkContextERSt6vectorINS0_7DOFInfoESaIS5_EE", "ImageLoaderMachO::doGetDOFSections(ImageLoader::LinkContext const&, std::vector<ImageLoader::DOFInfo, std::allocator<ImageLoader::DOFInfo>>&)"},
    {"_ZNK16ImageLoaderMachO16usablePrebindingERKN11ImageLoader11LinkContextE", "ImageLoaderMachO::usablePrebinding(ImageLoader::LinkContext const&) const"},
    {"_ZNK16ImageLoaderMachO7getUUIDEPh", "ImageLoaderMachO::getUUID(unsigned char*) const"},
    {"_ZN16ImageLoaderMachO26needsAddedLibSystemDepencyEjPK12macho_header", "ImageLoaderMachO::needsAddedLibSystemDepency(unsigned int, macho_header const*)"},
    {"_ZN16ImageLoaderMachO23doGetDependentLibrariesEPN11ImageLoader20DependentLibraryInfoE", "ImageLoaderMachO::doGetDependentLibraries(ImageLoader::DependentLibraryInfo*)"},
    {"_ZN16ImageLoaderMachO17sniffLoadCommandsEPK12macho_headerPKcPbPjS6_", "ImageLoaderMachO::sniffLoadCommands(macho_header const*, char const*, bool*, unsigned int*, unsigned int*)"},
    {"_ZNK16ImageLoaderMachO24participatesInCoalescingEv", "ImageLoaderMachO::participatesInCoalescing() const"},
    {"_ZN16ImageLoaderMachO12preFetchDATAEiyRKN11ImageLoader11LinkContextE", "ImageLoaderMachO::preFetchDATA(int, unsigned long long, ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO13UnmapSegmentsEv", "ImageLoaderMachO::UnmapSegments()"},
    {"_ZN16ImageLoaderMachO7destroyEv", "ImageLoaderMachO::destroy()"},
    {"_ZN16ImageLoaderMachO21instantiateFromMemoryEPKcPK12macho_headeryRKN11ImageLoader11LinkContextE", "ImageLoaderMachO::instantiateFromMemory(char const*, macho_header const*, unsigned long long, ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO20instantiateFromCacheEPK12macho_headerPKcRK4statRKN11ImageLoader11LinkContextE", "ImageLoaderMachO::instantiateFromCache(macho_header const*, char const*, stat const&, ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO19instantiateFromFileEPKciPKhyyRK4statRKN11ImageLoader11LinkContextE", "ImageLoaderMachO::instantiateFromFile(char const*, int, unsigned char const*, unsigned long long, unsigned long long, stat const&, ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO25instantiateMainExecutableEPK12macho_headermPKcRKN11ImageLoader11LinkContextE", "ImageLoaderMachO::instantiateMainExecutable(macho_header const*, unsigned long, char const*, ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachOC2EPK12macho_headerPKcjPjj", "ImageLoaderMachO::ImageLoaderMachO(macho_header const*, char const*, unsigned int, unsigned int*, unsigned int)"},
    {"_ZN16ImageLoaderMachO13doTerminationERKN11ImageLoader11LinkContextE", "ImageLoaderMachO::doTermination(ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO8doRebaseERKN11ImageLoader11LinkContextE", "ImageLoaderMachO::doRebase(ImageLoader::LinkContext const&)"},
    {"_ZNK16ImageLoaderMachO9getRPathsERKN11ImageLoader11LinkContextERSt6vectorIPKcSaIS6_EE", "ImageLoaderMachO::getRPaths(ImageLoader::LinkContext const&, std::vector<char const*, std::allocator<char const*>>&) const"},
    {"_ZN16ImageLoaderMachO19registerInterposingEv", "ImageLoaderMachO::registerInterposing()"},
    {"_ZNK16ImageLoaderMachO18findExportedSymbolEPKcbPPK11ImageLoader", "ImageLoaderMachO::findExportedSymbol(char const*, bool, ImageLoader const**) const"},
    {"_ZN16ImageLoaderMachO22assignSegmentAddressesERKN11ImageLoader11LinkContextE", "ImageLoaderMachO::assignSegmentAddresses(ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO11mapSegmentsEPKvyRKN11ImageLoader11LinkContextE", "ImageLoaderMachO::mapSegments(void const*, unsigned long long, ImageLoader::LinkContext const&)"},
    {"_ZN16ImageLoaderMachO11mapSegmentsEiyyyRKN11ImageLoader11LinkContextE", "ImageLoaderMachO::mapSegments(int, unsigned long long, unsigned long long, unsigned long long, ImageLoader::LinkContext const&)"},
    {"_ZNK16ImageLoaderMachO23segPreferredLoadAddressEj", "ImageLoaderMachO::segPreferredLoadAddress(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO26segHasPreferredLoadAddressEj", "ImageLoaderMachO::segHasPreferredLoadAddress(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO15segUnaccessibleEj", "ImageLoaderMachO::segUnaccessible(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO13segExecutableEj", "ImageLoaderMachO::segExecutable(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO20segActualLoadAddressEj", "ImageLoaderMachO::segActualLoadAddress(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO7segSizeEj", "ImageLoaderMachO::segSize(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO7segNameEj", "ImageLoaderMachO::segName(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO12segWriteableEj", "ImageLoaderMachO::segWriteable(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO11segReadableEj", "ImageLoaderMachO::segReadable(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO13segFileOffsetEj", "ImageLoaderMachO::segFileOffset(unsigned int) const"},
    {"_ZNK16ImageLoaderMachO11segFileSizeEj", "ImageLoaderMachO::segFileSize(unsigned int) const"},
    {"_ZN16ImageLoaderMachOD2Ev", "ImageLoaderMachO::~ImageLoaderMachO()"},
    {"_ZN16ImageLoaderMachOD1Ev", "ImageLoaderMachO::~ImageLoaderMachO()"},
    {"_ZN16ImageLoaderMachOD0Ev", "ImageLoaderMachO::~ImageLoaderMachO()"},
    {"_ZN9__gnu_cxx13new_allocatorIN11ImageLoader7DOFInfoEE8allocateEmPKv", "__gnu_cxx::new_allocator<ImageLoader::DOFInfo>::allocate(unsigned long, void const*)"},
    {"_ZN9__gnu_cxx13new_allocatorIN11ImageLoader14InterposeTupleEE8allocateEmPKv", "__gnu_cxx::new_allocator<ImageLoader::InterposeTuple>::allocate(unsigned long, void const*)"},
    {"_ZNSt6vectorIN11ImageLoader7DOFInfoESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<ImageLoader::DOFInfo, std::allocator<ImageLoader::DOFInfo>>::_M_insert_aux(__gnu_cxx::__normal_iterator<ImageLoader::DOFInfo*, std::vector<ImageLoader::DOFInfo, std::allocator<ImageLoader::DOFInfo>>>, ImageLoader::DOFInfo const&)"},
    {"_ZNSt6vectorIN11ImageLoader7DOFInfoESaIS1_EE9push_backERKS1_", "std::vector<ImageLoader::DOFInfo, std::allocator<ImageLoader::DOFInfo>>::push_back(ImageLoader::DOFInfo const&)"},
    {"_ZNSt6vectorIN11ImageLoader14InterposeTupleESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<ImageLoader::InterposeTuple, std::allocator<ImageLoader::InterposeTuple>>::_M_insert_aux(__gnu_cxx::__normal_iterator<ImageLoader::InterposeTuple*, std::vector<ImageLoader::InterposeTuple, std::allocator<ImageLoader::InterposeTuple>>>, ImageLoader::InterposeTuple const&)"},
    {"_ZNSt6vectorIN11ImageLoader14InterposeTupleESaIS1_EE9push_backERKS1_", "std::vector<ImageLoader::InterposeTuple, std::allocator<ImageLoader::InterposeTuple>>::push_back(ImageLoader::InterposeTuple const&)"},
    {"_ZNK23ImageLoaderMachOClassic21segmentCommandOffsetsEv", "ImageLoaderMachOClassic::segmentCommandOffsets() const"},
    {"_ZNK23ImageLoaderMachOClassic8libImageEj", "ImageLoaderMachOClassic::libImage(unsigned int) const"},
    {"_ZNK23ImageLoaderMachOClassic13libReExportedEj", "ImageLoaderMachOClassic::libReExported(unsigned int) const"},
    {"_ZN23ImageLoaderMachOClassic11setLibImageEjP11ImageLoaderb", "ImageLoaderMachOClassic::setLibImage(unsigned int, ImageLoader*, bool)"},
    {"_ZN23ImageLoaderMachOClassic18setSymbolTableInfoEPK11macho_nlistPKcPK16dysymtab_command", "ImageLoaderMachOClassic::setSymbolTableInfo(macho_nlist const*, char const*, dysymtab_command const*)"},
    {"_ZNK23ImageLoaderMachOClassic14containsSymbolEPKv", "ImageLoaderMachOClassic::containsSymbol(void const*) const"},
    {"_ZNK23ImageLoaderMachOClassic21exportedSymbolAddressEPKN11ImageLoader6SymbolE", "ImageLoaderMachOClassic::exportedSymbolAddress(ImageLoader::Symbol const*) const"},
    {"_ZNK23ImageLoaderMachOClassic29exportedSymbolIsWeakDefintionEPKN11ImageLoader6SymbolE", "ImageLoaderMachOClassic::exportedSymbolIsWeakDefintion(ImageLoader::Symbol const*) const"},
    {"_ZNK23ImageLoaderMachOClassic18exportedSymbolNameEPKN11ImageLoader6SymbolE", "ImageLoaderMachOClassic::exportedSymbolName(ImageLoader::Symbol const*) const"},
    {"_ZNK23ImageLoaderMachOClassic19exportedSymbolCountEv", "ImageLoaderMachOClassic::exportedSymbolCount() const"},
    {"_ZNK23ImageLoaderMachOClassic21exportedSymbolIndexedEj", "ImageLoaderMachOClassic::exportedSymbolIndexed(unsigned int) const"},
    {"_ZNK23ImageLoaderMachOClassic19importedSymbolCountEv", "ImageLoaderMachOClassic::importedSymbolCount() const"},
    {"_ZNK23ImageLoaderMachOClassic21importedSymbolIndexedEj", "ImageLoaderMachOClassic::importedSymbolIndexed(unsigned int) const"},
    {"_ZNK23ImageLoaderMachOClassic18importedSymbolNameEPKN11ImageLoader6SymbolE", "ImageLoaderMachOClassic::importedSymbolName(ImageLoader::Symbol const*) const"},
    {"_ZN23ImageLoaderMachOClassic22initializeCoalIteratorERN11ImageLoader12CoalIteratorEj", "ImageLoaderMachOClassic::initializeCoalIterator(ImageLoader::CoalIterator&, unsigned int)"},
    {"_ZN23ImageLoaderMachOClassic21incrementCoalIteratorERN11ImageLoader12CoalIteratorE", "ImageLoaderMachOClassic::incrementCoalIterator(ImageLoader::CoalIterator&)"},
    {"_ZN23ImageLoaderMachOClassic22getAddressCoalIteratorERN11ImageLoader12CoalIteratorERKNS0_11LinkContextE", "ImageLoaderMachOClassic::getAddressCoalIterator(ImageLoader::CoalIterator&, ImageLoader::LinkContext const&)"},
    {"_ZNK23ImageLoaderMachOClassic17findClosestSymbolEPKvPS1_", "ImageLoaderMachOClassic::findClosestSymbol(void const*, void const**) const"},
    {"_ZN23ImageLoaderMachOClassic20doBindFastLazySymbolEjRKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::doBindFastLazySymbol(unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic30getFirstWritableSegmentAddressEv", "ImageLoaderMachOClassic::getFirstWritableSegmentAddress()"},
    {"_ZN23ImageLoaderMachOClassic18bindIndirectSymbolEPmPK13macho_sectionPKcmPK11ImageLoaderRKNS6_11LinkContextE", "ImageLoaderMachOClassic::bindIndirectSymbol(unsigned long*, macho_section const*, char const*, unsigned long, ImageLoader const*, ImageLoader::LinkContext const&)"},
    {"_ZNK23ImageLoaderMachOClassic12binarySearchEPKcS1_PK11macho_nlistj", "ImageLoaderMachOClassic::binarySearch(char const*, char const*, macho_nlist const*, unsigned int) const"},
    {"_ZNK23ImageLoaderMachOClassic19binarySearchWithTocEPKcS1_PK11macho_nlistPK23dylib_table_of_contentsjj", "ImageLoaderMachOClassic::binarySearchWithToc(char const*, char const*, macho_nlist const*, dylib_table_of_contents const*, unsigned int, unsigned int) const"},
    {"_ZNK23ImageLoaderMachOClassic18findExportedSymbolEPKcPPK11ImageLoader", "ImageLoaderMachOClassic::findExportedSymbol(char const*, ImageLoader const**) const"},
    {"_ZNK23ImageLoaderMachOClassic13hasSubLibraryERKN11ImageLoader11LinkContextEPKS0_", "ImageLoaderMachOClassic::hasSubLibrary(ImageLoader::LinkContext const&, ImageLoader const*) const"},
    {"_ZNK23ImageLoaderMachOClassic16isSubframeworkOfERKN11ImageLoader11LinkContextEPKS0_", "ImageLoaderMachOClassic::isSubframeworkOf(ImageLoader::LinkContext const&, ImageLoader const*) const"},
    {"_ZN23ImageLoaderMachOClassic18mapSegmentsClassicEiyyyRKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::mapSegmentsClassic(int, unsigned long long, unsigned long long, unsigned long long, ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic16prefetchLINKEDITERKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::prefetchLINKEDIT(ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassicD2Ev", "ImageLoaderMachOClassic::~ImageLoaderMachOClassic()"},
    {"_ZN23ImageLoaderMachOClassicD1Ev", "ImageLoaderMachOClassic::~ImageLoaderMachOClassic()"},
    {"_ZN23ImageLoaderMachOClassicD0Ev", "ImageLoaderMachOClassic::~ImageLoaderMachOClassic()"},
    {"_ZN23ImageLoaderMachOClassic17instantiateFinishERKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::instantiateFinish(ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic6rebaseERKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::rebase(ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic11doInterposeERKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::doInterpose(ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic16resolveUndefinedERKN11ImageLoader11LinkContextEPK11macho_nlistbbPPKS0_", "ImageLoaderMachOClassic::resolveUndefined(ImageLoader::LinkContext const&, macho_nlist const*, bool, bool, ImageLoader const**)"},
    {"_ZN23ImageLoaderMachOClassic26bindIndirectSymbolPointersERKN11ImageLoader11LinkContextEbb", "ImageLoaderMachOClassic::bindIndirectSymbolPointers(ImageLoader::LinkContext const&, bool, bool)"},
    {"_ZN23ImageLoaderMachOClassic16doBindJustLaziesERKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::doBindJustLazies(ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic16doBindLazySymbolEPmRKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::doBindLazySymbol(unsigned long*, ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic16instantiateStartEPK12macho_headerPKcjj", "ImageLoaderMachOClassic::instantiateStart(macho_header const*, char const*, unsigned int, unsigned int)"},
    {"_ZN23ImageLoaderMachOClassic21instantiateFromMemoryEPKcPK12macho_headeryjjRKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::instantiateFromMemory(char const*, macho_header const*, unsigned long long, unsigned int, unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic20instantiateFromCacheEPK12macho_headerPKcRK4statjjRKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::instantiateFromCache(macho_header const*, char const*, stat const&, unsigned int, unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic19instantiateFromFileEPKciPKhyyRK4statjjRKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::instantiateFromFile(char const*, int, unsigned char const*, unsigned long long, unsigned long long, stat const&, unsigned int, unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic25instantiateMainExecutableEPK12macho_headermPKcjjRKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::instantiateMainExecutable(macho_header const*, unsigned long, char const*, unsigned int, unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic22updateUsesCoalIteratorERN11ImageLoader12CoalIteratorEmPS0_RKNS0_11LinkContextE", "ImageLoaderMachOClassic::updateUsesCoalIterator(ImageLoader::CoalIterator&, unsigned long, ImageLoader*, ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic25doBindExternalRelocationsERKN11ImageLoader11LinkContextE", "ImageLoaderMachOClassic::doBindExternalRelocations(ImageLoader::LinkContext const&)"},
    {"_ZN23ImageLoaderMachOClassic6doBindERKN11ImageLoader11LinkContextEb", "ImageLoaderMachOClassic::doBind(ImageLoader::LinkContext const&, bool)"},
    {"_ZN23ImageLoaderMachOClassic11setDyldInfoEPK17dyld_info_command", "ImageLoaderMachOClassic::setDyldInfo(dyld_info_command const*)"},
    {"_ZNK26ImageLoaderMachOCompressed21segmentCommandOffsetsEv", "ImageLoaderMachOCompressed::segmentCommandOffsets() const"},
    {"_ZNK26ImageLoaderMachOCompressed8libImageEj", "ImageLoaderMachOCompressed::libImage(unsigned int) const"},
    {"_ZNK26ImageLoaderMachOCompressed13libReExportedEj", "ImageLoaderMachOCompressed::libReExported(unsigned int) const"},
    {"_ZN26ImageLoaderMachOCompressed11setLibImageEjP11ImageLoaderb", "ImageLoaderMachOCompressed::setLibImage(unsigned int, ImageLoader*, bool)"},
    {"_ZNK26ImageLoaderMachOCompressed14containsSymbolEPKv", "ImageLoaderMachOCompressed::containsSymbol(void const*) const"},
    {"_ZN26ImageLoaderMachOCompressed22initializeCoalIteratorERN11ImageLoader12CoalIteratorEj", "ImageLoaderMachOCompressed::initializeCoalIterator(ImageLoader::CoalIterator&, unsigned int)"},
    {"_ZN26ImageLoaderMachOCompressed22getAddressCoalIteratorERN11ImageLoader12CoalIteratorERKNS0_11LinkContextE", "ImageLoaderMachOCompressed::getAddressCoalIterator(ImageLoader::CoalIterator&, ImageLoader::LinkContext const&)"},
    {"_ZNK26ImageLoaderMachOCompressed17findClosestSymbolEPKvPS1_", "ImageLoaderMachOCompressed::findClosestSymbol(void const*, void const**) const"},
    {"_ZNK26ImageLoaderMachOCompressed18importedSymbolNameEPKN11ImageLoader6SymbolE", "ImageLoaderMachOCompressed::importedSymbolName(ImageLoader::Symbol const*) const"},
    {"_ZNK26ImageLoaderMachOCompressed21importedSymbolIndexedEj", "ImageLoaderMachOCompressed::importedSymbolIndexed(unsigned int) const"},
    {"_ZNK26ImageLoaderMachOCompressed19importedSymbolCountEv", "ImageLoaderMachOCompressed::importedSymbolCount() const"},
    {"_ZNK26ImageLoaderMachOCompressed21exportedSymbolIndexedEj", "ImageLoaderMachOCompressed::exportedSymbolIndexed(unsigned int) const"},
    {"_ZNK26ImageLoaderMachOCompressed19exportedSymbolCountEv", "ImageLoaderMachOCompressed::exportedSymbolCount() const"},
    {"_ZNK26ImageLoaderMachOCompressed18exportedSymbolNameEPKN11ImageLoader6SymbolE", "ImageLoaderMachOCompressed::exportedSymbolName(ImageLoader::Symbol const*) const"},
    {"_ZN26ImageLoaderMachOCompressed15resolveTwolevelERKN11ImageLoader11LinkContextEPKS0_bPKcPS5_", "ImageLoaderMachOCompressed::resolveTwolevel(ImageLoader::LinkContext const&, ImageLoader const*, bool, char const*, ImageLoader const**)"},
    {"_ZN26ImageLoaderMachOCompressed11resolveFlatERKN11ImageLoader11LinkContextEPKcbPPKS0_", "ImageLoaderMachOCompressed::resolveFlat(ImageLoader::LinkContext const&, char const*, bool, ImageLoader const**)"},
    {"_ZN26ImageLoaderMachOCompressed7resolveERKN11ImageLoader11LinkContextEPKchiPPKS0_PNS_10LastLookupE", "ImageLoaderMachOCompressed::resolve(ImageLoader::LinkContext const&, char const*, unsigned char, int, ImageLoader const**, ImageLoaderMachOCompressed::LastLookup*)"},
    {"_ZN26ImageLoaderMachOCompressed6bindAtERKN11ImageLoader11LinkContextEmhPKchliS5_PNS_10LastLookupE", "ImageLoaderMachOCompressed::bindAt(ImageLoader::LinkContext const&, unsigned long, unsigned char, char const*, unsigned char, long, int, char const*, ImageLoaderMachOCompressed::LastLookup*)"},
    {"_ZN26ImageLoaderMachOCompressed11interposeAtERKN11ImageLoader11LinkContextEmhPKchliS5_PNS_10LastLookupE", "ImageLoaderMachOCompressed::interposeAt(ImageLoader::LinkContext const&, unsigned long, unsigned char, char const*, unsigned char, long, int, char const*, ImageLoaderMachOCompressed::LastLookup*)"},
    {"_ZN26ImageLoaderMachOCompressed16instantiateStartEPK12macho_headerPKcjj", "ImageLoaderMachOCompressed::instantiateStart(macho_header const*, char const*, unsigned int, unsigned int)"},
    {"_ZN26ImageLoaderMachOCompressed16doBindLazySymbolEPmRKN11ImageLoader11LinkContextE", "ImageLoaderMachOCompressed::doBindLazySymbol(unsigned long*, ImageLoader::LinkContext const&)"},
    {"_ZN26ImageLoaderMachOCompressed20instantiateFromCacheEPK12macho_headerPKcRK4statjjRKN11ImageLoader11LinkContextE", "ImageLoaderMachOCompressed::instantiateFromCache(macho_header const*, char const*, stat const&, unsigned int, unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZN26ImageLoaderMachOCompressed21instantiateFromMemoryEPKcPK12macho_headeryjjRKN11ImageLoader11LinkContextE", "ImageLoaderMachOCompressed::instantiateFromMemory(char const*, macho_header const*, unsigned long long, unsigned int, unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZN26ImageLoaderMachOCompressed25instantiateMainExecutableEPK12macho_headermPKcjjRKN11ImageLoader11LinkContextE", "ImageLoaderMachOCompressed::instantiateMainExecutable(macho_header const*, unsigned long, char const*, unsigned int, unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZN26ImageLoaderMachOCompressedD0Ev", "ImageLoaderMachOCompressed::~ImageLoaderMachOCompressed()"},
    {"_ZN26ImageLoaderMachOCompressedD1Ev", "ImageLoaderMachOCompressed::~ImageLoaderMachOCompressed()"},
    {"_ZN26ImageLoaderMachOCompressed19instantiateFromFileEPKciPKhyyRK4statjjRKN11ImageLoader11LinkContextE", "ImageLoaderMachOCompressed::instantiateFromFile(char const*, int, unsigned char const*, unsigned long long, unsigned long long, stat const&, unsigned int, unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZNK26ImageLoaderMachOCompressed29exportedSymbolIsWeakDefintionEPKN11ImageLoader6SymbolE", "ImageLoaderMachOCompressed::exportedSymbolIsWeakDefintion(ImageLoader::Symbol const*) const"},
    {"_ZNK26ImageLoaderMachOCompressed21exportedSymbolAddressEPKN11ImageLoader6SymbolE", "ImageLoaderMachOCompressed::exportedSymbolAddress(ImageLoader::Symbol const*) const"},
    {"_ZNK26ImageLoaderMachOCompressed18findExportedSymbolEPKcPPK11ImageLoader", "ImageLoaderMachOCompressed::findExportedSymbol(char const*, ImageLoader const**) const"},
    {"_ZN26ImageLoaderMachOCompressed6rebaseERKN11ImageLoader11LinkContextE", "ImageLoaderMachOCompressed::rebase(ImageLoader::LinkContext const&)"},
    {"_ZN26ImageLoaderMachOCompressed22updateUsesCoalIteratorERN11ImageLoader12CoalIteratorEmPS0_RKNS0_11LinkContextE", "ImageLoaderMachOCompressed::updateUsesCoalIterator(ImageLoader::CoalIterator&, unsigned long, ImageLoader*, ImageLoader::LinkContext const&)"},
    {"_ZN26ImageLoaderMachOCompressed21incrementCoalIteratorERN11ImageLoader12CoalIteratorE", "ImageLoaderMachOCompressed::incrementCoalIterator(ImageLoader::CoalIterator&)"},
    {"_ZN26ImageLoaderMachOCompressed20doBindFastLazySymbolEjRKN11ImageLoader11LinkContextE", "ImageLoaderMachOCompressed::doBindFastLazySymbol(unsigned int, ImageLoader::LinkContext const&)"},
    {"_ZN26ImageLoaderMachOCompressed12eachLazyBindERKN11ImageLoader11LinkContextEMS_FmS3_mhPKchliS5_PNS_10LastLookupEE", "ImageLoaderMachOCompressed::eachLazyBind(ImageLoader::LinkContext const&, unsigned long (ImageLoaderMachOCompressed::*)(ImageLoader::LinkContext const&, unsigned long, unsigned char, char const*, unsigned char, long, int, char const*, ImageLoaderMachOCompressed::LastLookup*))"},
    {"_ZN26ImageLoaderMachOCompressed16doBindJustLaziesERKN11ImageLoader11LinkContextE", "ImageLoaderMachOCompressed::doBindJustLazies(ImageLoader::LinkContext const&)"},
    {"_ZN26ImageLoaderMachOCompressed8eachBindERKN11ImageLoader11LinkContextEMS_FmS3_mhPKchliS5_PNS_10LastLookupEE", "ImageLoaderMachOCompressed::eachBind(ImageLoader::LinkContext const&, unsigned long (ImageLoaderMachOCompressed::*)(ImageLoader::LinkContext const&, unsigned long, unsigned char, char const*, unsigned char, long, int, char const*, ImageLoaderMachOCompressed::LastLookup*))"},
    {"_ZN26ImageLoaderMachOCompressed11doInterposeERKN11ImageLoader11LinkContextE", "ImageLoaderMachOCompressed::doInterpose(ImageLoader::LinkContext const&)"},
    {"_ZN26ImageLoaderMachOCompressed6doBindERKN11ImageLoader11LinkContextEb", "ImageLoaderMachOCompressed::doBind(ImageLoader::LinkContext const&, bool)"},
    {"_ZN26ImageLoaderMachOCompressed11setDyldInfoEPK17dyld_info_command", "ImageLoaderMachOCompressed::setDyldInfo(dyld_info_command const*)"},
    {"_ZN26ImageLoaderMachOCompressed18setSymbolTableInfoEPK11macho_nlistPKcPK16dysymtab_command", "ImageLoaderMachOCompressed::setSymbolTableInfo(macho_nlist const*, char const*, dysymtab_command const*)"},
    {"_ZNK26ImageLoaderMachOCompressed16isSubframeworkOfERKN11ImageLoader11LinkContextEPKS0_", "ImageLoaderMachOCompressed::isSubframeworkOf(ImageLoader::LinkContext const&, ImageLoader const*) const"},
    {"_ZNK26ImageLoaderMachOCompressed13hasSubLibraryERKN11ImageLoader11LinkContextEPKS0_", "ImageLoaderMachOCompressed::hasSubLibrary(ImageLoader::LinkContext const&, ImageLoader const*) const"},
    {"_ZSt17__throw_bad_allocv", "std::__throw_bad_alloc()"},
    {"_ZSt20__throw_length_errorPKc", "std::__throw_length_error(char const*)"},
    {"_ZSt19__throw_logic_errorPKc", "std::__throw_logic_error(char const*)"},
    {"_ZNSt12length_errorD0Ev", "std::length_error::~length_error()"},
    {"_ZNSt12length_errorD2Ev", "std::length_error::~length_error()"},
    {"_ZNSt12length_errorD1Ev", "std::length_error::~length_error()"},
    {"_ZNKSt11logic_error4whatEv", "std::logic_error::what() const"},
    {"_ZNSt11logic_errorC2ERKSs", "std::logic_error::logic_error(std::string const&)"},
    {"_ZNSt11logic_errorC1ERKSs", "std::logic_error::logic_error(std::string const&)"},
    {"_ZNSt12length_errorC1ERKSs", "std::length_error::length_error(std::string const&)"},
    {"_ZNSt11logic_errorD0Ev", "std::logic_error::~logic_error()"},
    {"_ZNSt11logic_errorD2Ev", "std::logic_error::~logic_error()"},
    {"_ZNSt11logic_errorD1Ev", "std::logic_error::~logic_error()"},
    {"_ZSt18_Rb_tree_decrementPSt18_Rb_tree_node_base", "std::_Rb_tree_decrement(std::_Rb_tree_node_base*)"},
    {"_ZSt29_Rb_tree_insert_and_rebalancebPSt18_Rb_tree_node_baseS0_RS_", "std::_Rb_tree_insert_and_rebalance(bool, std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::_Rb_tree_node_base&)"},
    {"_ZSt18_Rb_tree_incrementPKSt18_Rb_tree_node_base", "std::_Rb_tree_increment(std::_Rb_tree_node_base const*)"},
    {"_ZNSs4_Rep10_M_disposeERKSaIcE", "std::string::_Rep::_M_dispose(std::allocator<char> const&)"},
    {"_ZNSs4_Rep9_S_createEmmRKSaIcE", "std::string::_Rep::_S_create(unsigned long, unsigned long, std::allocator<char> const&)"},
    {"_ZNSs4_Rep8_M_cloneERKSaIcEm", "std::string::_Rep::_M_clone(std::allocator<char> const&, unsigned long)"},
    {"_ZNSs4_Rep7_M_grabERKSaIcES2_", "std::string::_Rep::_M_grab(std::allocator<char> const&, std::allocator<char> const&)"},
    {"_ZNSsC2ERKSs", "std::basic_string<char, std::char_traits<char>, std::allocator<char>>::basic_string(std::string const&)"},
    {"_ZNSsC1ERKSs", "std::basic_string<char, std::char_traits<char>, std::allocator<char>>::basic_string(std::string const&)"},
    {"_ZNSs12_S_constructIPKcEEPcT_S3_RKSaIcESt20forward_iterator_tag", "char* std::string::_S_construct<char const*>(char const*, char const*, std::allocator<char> const&, std::forward_iterator_tag)"},
    {"_ZNSsC2EPKcRKSaIcE", "std::basic_string<char, std::char_traits<char>, std::allocator<char>>::basic_string(char const*, std::allocator<char> const&)"},
    {"_ZNSsC1EPKcRKSaIcE", "std::basic_string<char, std::char_traits<char>, std::allocator<char>>::basic_string(char const*, std::allocator<char> const&)"},
    {"_ZN9__gnu_cxx13new_allocatorIcE8allocateEmPKv", "__gnu_cxx::new_allocator<char>::allocate(unsigned long, void const*)"},
    {"_ZdlPv", "operator delete(void*)"},
    {"_ZdaPv", "operator delete[](void*)"},
    {"_ZNK9__gnu_cxx24__concurrence_lock_error4whatEv", "__gnu_cxx::__concurrence_lock_error::what() const"},
    {"_ZNK9__gnu_cxx26__concurrence_unlock_error4whatEv", "__gnu_cxx::__concurrence_unlock_error::what() const"},
    {"_ZN9__gnu_cxx32__throw_concurrence_unlock_errorEv", "__gnu_cxx::__throw_concurrence_unlock_error()"},
    {"_ZN9__gnu_cxx30__throw_concurrence_lock_errorEv", "__gnu_cxx::__throw_concurrence_lock_error()"},
    {"_ZN9__gnu_cxx7__mutex4lockEv", "__gnu_cxx::__mutex::lock()"},
    {"_ZN9__gnu_cxx26__concurrence_unlock_errorD0Ev", "__gnu_cxx::__concurrence_unlock_error::~__concurrence_unlock_error()"},
    {"_ZN9__gnu_cxx26__concurrence_unlock_errorD2Ev", "__gnu_cxx::__concurrence_unlock_error::~__concurrence_unlock_error()"},
    {"_ZN9__gnu_cxx26__concurrence_unlock_errorD1Ev", "__gnu_cxx::__concurrence_unlock_error::~__concurrence_unlock_error()"},
    {"_ZN9__gnu_cxx24__concurrence_lock_errorD0Ev", "__gnu_cxx::__concurrence_lock_error::~__concurrence_lock_error()"},
    {"_ZN9__gnu_cxx24__concurrence_lock_errorD2Ev", "__gnu_cxx::__concurrence_lock_error::~__concurrence_lock_error()"},
    {"_ZN9__gnu_cxx24__concurrence_lock_errorD1Ev", "__gnu_cxx::__concurrence_lock_error::~__concurrence_lock_error()"},
    {"_ZN9__gnu_cxx7__mutex6unlockEv", "__gnu_cxx::__mutex::unlock()"},
    {"_ZN9__gnu_cxx13__scoped_lockD2Ev", "__gnu_cxx::__scoped_lock::~__scoped_lock()"},
    {"_ZNKSt9exception4whatEv", "std::exception::what() const"},
    {"_ZNKSt13bad_exception4whatEv", "std::bad_exception::what() const"},
    {"_ZNSt13bad_exceptionD0Ev", "std::bad_exception::~bad_exception()"},
    {"_ZNSt9exceptionD0Ev", "std::exception::~exception()"},
    {"_ZNSt9exceptionD2Ev", "std::exception::~exception()"},
    {"_ZNSt13bad_exceptionD1Ev", "std::bad_exception::~bad_exception()"},
    {"_ZNSt9exceptionD1Ev", "std::exception::~exception()"},
    {"_ZNKSt9bad_alloc4whatEv", "std::bad_alloc::what() const"},
    {"_ZNSt9bad_allocD0Ev", "std::bad_alloc::~bad_alloc()"},
    {"_ZNSt9bad_allocD2Ev", "std::bad_alloc::~bad_alloc()"},
    {"_ZNSt9bad_allocD1Ev", "std::bad_alloc::~bad_alloc()"},
    {"_Znwm", "operator new(unsigned long)"},
    {"_Znam", "operator new[](unsigned long)"},
    {"_ZNKSt9type_info14__is_pointer_pEv", "std::type_info::__is_pointer_p() const"},
    {"_ZNKSt9type_info15__is_function_pEv", "std::type_info::__is_function_p() const"},
    {"_ZNKSt9type_info11__do_upcastEPKN10__cxxabiv117__class_type_infoEPPv", "std::type_info::__do_upcast(__cxxabiv1::__class_type_info const*, void**) const"},
    {"_ZNK10__cxxabiv117__class_type_info10__do_catchEPKSt9type_infoPPvj", "__cxxabiv1::__class_type_info::__do_catch(std::type_info const*, void**, unsigned int) const"},
    {"_ZNK10__cxxabiv117__class_type_info11__do_upcastEPKS0_PPv", "__cxxabiv1::__class_type_info::__do_upcast(__cxxabiv1::__class_type_info const*, void**) const"},
    {"_ZNK10__cxxabiv117__class_type_info20__do_find_public_srcElPKvPKS0_S2_", "__cxxabiv1::__class_type_info::__do_find_public_src(long, void const*, __cxxabiv1::__class_type_info const*, void const*) const"},
    {"_ZNK10__cxxabiv117__class_type_info11__do_upcastEPKS0_PKvRNS0_15__upcast_resultE", "__cxxabiv1::__class_type_info::__do_upcast(__cxxabiv1::__class_type_info const*, void const*, __cxxabiv1::__class_type_info::__upcast_result&) const"},
    {"_ZN10__cxxabiv117__class_type_infoD0Ev", "__cxxabiv1::__class_type_info::~__class_type_info()"},
    {"_ZN10__cxxabiv117__class_type_infoD1Ev", "__cxxabiv1::__class_type_info::~__class_type_info()"},
    {"_ZNSt9type_infoD0Ev", "std::type_info::~type_info()"},
    {"_ZNSt9type_infoD1Ev", "std::type_info::~type_info()"},
    {"_ZNSt9type_infoD2Ev", "std::type_info::~type_info()"},
    {"_ZNKSt9type_info10__do_catchEPKS_PPvj", "std::type_info::__do_catch(std::type_info const*, void**, unsigned int) const"},
    {"_ZNK10__cxxabiv117__class_type_info12__do_dyncastElNS0_10__sub_kindEPKS0_PKvS3_S5_RNS0_16__dyncast_resultE", "__cxxabiv1::__class_type_info::__do_dyncast(long, __cxxabiv1::__class_type_info::__sub_kind, __cxxabiv1::__class_type_info const*, void const*, __cxxabiv1::__class_type_info const*, void const*, __cxxabiv1::__class_type_info::__dyncast_result&) const"},
    {"_ZNK10__cxxabiv120__si_class_type_info20__do_find_public_srcElPKvPKNS_17__class_type_infoES2_", "__cxxabiv1::__si_class_type_info::__do_find_public_src(long, void const*, __cxxabiv1::__class_type_info const*, void const*) const"},
    {"_ZNK10__cxxabiv120__si_class_type_info12__do_dyncastElNS_17__class_type_info10__sub_kindEPKS1_PKvS4_S6_RNS1_16__dyncast_resultE", "__cxxabiv1::__si_class_type_info::__do_dyncast(long, __cxxabiv1::__class_type_info::__sub_kind, __cxxabiv1::__class_type_info const*, void const*, __cxxabiv1::__class_type_info const*, void const*, __cxxabiv1::__class_type_info::__dyncast_result&) const"},
    {"_ZNK10__cxxabiv120__si_class_type_info11__do_upcastEPKNS_17__class_type_infoEPKvRNS1_15__upcast_resultE", "__cxxabiv1::__si_class_type_info::__do_upcast(__cxxabiv1::__class_type_info const*, void const*, __cxxabiv1::__class_type_info::__upcast_result&) const"},
    {"_ZN10__cxxabiv120__si_class_type_infoD0Ev", "__cxxabiv1::__si_class_type_info::~__si_class_type_info()"},
    {"_ZN10__cxxabiv120__si_class_type_infoD2Ev", "__cxxabiv1::__si_class_type_info::~__si_class_type_info()"},
    {"_ZN10__cxxabiv120__si_class_type_infoD1Ev", "__cxxabiv1::__si_class_type_info::~__si_class_type_info()"},
    {"_ZNK10__cxxabiv119__pointer_type_info14__is_pointer_pEv", "__cxxabiv1::__pointer_type_info::__is_pointer_p() const"},
    {"_ZN10__cxxabiv117__pbase_type_infoD0Ev", "__cxxabiv1::__pbase_type_info::~__pbase_type_info()"},
    {"_ZN10__cxxabiv117__pbase_type_infoD2Ev", "__cxxabiv1::__pbase_type_info::~__pbase_type_info()"},
    {"_ZN10__cxxabiv119__pointer_type_infoD0Ev", "__cxxabiv1::__pointer_type_info::~__pointer_type_info()"},
    {"_ZN10__cxxabiv119__pointer_type_infoD2Ev", "__cxxabiv1::__pointer_type_info::~__pointer_type_info()"},
    {"_ZN10__cxxabiv119__pointer_type_infoD1Ev", "__cxxabiv1::__pointer_type_info::~__pointer_type_info()"},
    {"_ZN10__cxxabiv117__pbase_type_infoD1Ev", "__cxxabiv1::__pbase_type_info::~__pbase_type_info()"},
    {"_ZN10__cxxabiv123__fundamental_type_infoD0Ev", "__cxxabiv1::__fundamental_type_info::~__fundamental_type_info()"},
    {"_ZN10__cxxabiv123__fundamental_type_infoD2Ev", "__cxxabiv1::__fundamental_type_info::~__fundamental_type_info()"},
    {"_ZN10__cxxabiv123__fundamental_type_infoD1Ev", "__cxxabiv1::__fundamental_type_info::~__fundamental_type_info()"},
    {"_ZNK10__cxxabiv117__pbase_type_info10__do_catchEPKSt9type_infoPPvj", "__cxxabiv1::__pbase_type_info::__do_catch(std::type_info const*, void**, unsigned int) const"},
    {"_ZNK10__cxxabiv119__pointer_type_info15__pointer_catchEPKNS_17__pbase_type_infoEPPvj", "__cxxabiv1::__pointer_type_info::__pointer_catch(__cxxabiv1::__pbase_type_info const*, void**, unsigned int) const"},
    {"_ZNK10__cxxabiv117__pbase_type_info15__pointer_catchEPKS0_PPvj", "__cxxabiv1::__pbase_type_info::__pointer_catch(__cxxabiv1::__pbase_type_info const*, void**, unsigned int) const"},
    {"_ZN16CSCppTimeoutLockD1Ev", "CSCppTimeoutLock::~CSCppTimeoutLock()"},
    {"_ZN16CSCppTimeoutLockC2EPjj", "CSCppTimeoutLock::CSCppTimeoutLock(unsigned int*, unsigned int)"},
    {"_ZN16CSCppTimeoutLockC1EPjj", "CSCppTimeoutLock::CSCppTimeoutLock(unsigned int*, unsigned int)"},
    {"_ZN25CSCppDyldSharedMemoryPage11send_noticeEjRjS0_", "CSCppDyldSharedMemoryPage::send_notice(unsigned int, unsigned int&, unsigned int&)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE8validRegEi", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::validReg(int)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE13validFloatRegEi", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::validFloatReg(int)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE7getInfoEP15unw_proc_info_t", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::getInfo(unw_proc_info_t*)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE15getRegisterNameEi", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::getRegisterName(int)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE13isSignalFrameEv", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::isSignalFrame()"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EED0Ev", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::~UnwindCursor()"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE33getInfoFromCompactEncodingSectionEyyy", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::getInfoFromCompactEncodingSection(unsigned long long, unsigned long long, unsigned long long)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE24setInfoBasedOnIPRegisterEb", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::setInfoBasedOnIPRegister(bool)"},
    {"_ZN9libunwind17LocalAddressSpace16findFunctionNameEyPcmPy", "libunwind::LocalAddressSpace::findFunctionName(unsigned long long, char*, unsigned long, unsigned long long*)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE15getFunctionNameEPcmPy", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::getFunctionName(char*, unsigned long, unsigned long long*)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE6jumptoEv", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::jumpto()"},
    {"_ZN9libunwind22CompactUnwinder_x86_64INS_17LocalAddressSpaceEE32stepWithCompactEncodingFramelessEjyRS1_RNS_16Registers_x86_64Eb", "libunwind::CompactUnwinder_x86_64<libunwind::LocalAddressSpace>::stepWithCompactEncodingFrameless(unsigned int, unsigned long long, libunwind::LocalAddressSpace&, libunwind::Registers_x86_64&, bool)"},
    {"_ZN9libunwind22CompactUnwinder_x86_64INS_17LocalAddressSpaceEE31stepWithCompactEncodingRBPFrameEjyRS1_RNS_16Registers_x86_64E", "libunwind::CompactUnwinder_x86_64<libunwind::LocalAddressSpace>::stepWithCompactEncodingRBPFrame(unsigned int, unsigned long long, libunwind::LocalAddressSpace&, libunwind::Registers_x86_64&)"},
    {"_ZN9libunwind22CompactUnwinder_x86_64INS_17LocalAddressSpaceEE23stepWithCompactEncodingEjyRS1_RNS_16Registers_x86_64E", "libunwind::CompactUnwinder_x86_64<libunwind::LocalAddressSpace>::stepWithCompactEncoding(unsigned int, unsigned long long, libunwind::LocalAddressSpace&, libunwind::Registers_x86_64&)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE23stepWithCompactEncodingEv", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::stepWithCompactEncoding()"},
    {"_ZN9libunwind16Registers_x86_6411setRegisterEiy", "libunwind::Registers_x86_64::setRegister(int, unsigned long long)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE6setRegEiy", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::setReg(int, unsigned long long)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE6getRegEi", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::getReg(int)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EED1Ev", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::~UnwindCursor()"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE4stepEv", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::step()"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE11setFloatRegEid", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::setFloatReg(int, double)"},
    {"_ZN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EE11getFloatRegEi", "libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>::getFloatReg(int)"},
    {"_ZN9libunwind16Registers_x86_646jumptoEv", "libunwind::Registers_x86_64::jumpto()"},
    {"_Z41__static_initialization_and_destruction_0ii", "__static_initialization_and_destruction_0(int, int)"},
    {"_Z41__static_initialization_and_destruction_0ii", "__static_initialization_and_destruction_0(int, int)"},
    {"_Z41__static_initialization_and_destruction_0ii", "__static_initialization_and_destruction_0(int, int)"},
    {"_Z41__static_initialization_and_destruction_0ii", "__static_initialization_and_destruction_0(int, int)"},
    {"_Z41__static_initialization_and_destruction_0ii", "__static_initialization_and_destruction_0(int, int)"},
    {"_ZZ34dyld_image_path_containing_addressE8__func__", "dyld_image_path_containing_address::__func__"},
    {"_ZZ40dyld_register_image_state_change_handlerE8__func__", "dyld_register_image_state_change_handler::__func__"},
    {"_ZZ5dlsymE8__func__", "dlsym::__func__"},
    {"_ZZ7dlerrorE8__func__", "dlerror::__func__"},
    {"_ZZ6dladdrE8__func__", "dladdr::__func__"},
    {"_ZZ7dlcloseE8__func__", "dlclose::__func__"},
    {"_ZZ6dlopenE8__func__", "dlopen::__func__"},
    {"_ZZ16dlopen_preflightE8__func__", "dlopen_preflight::__func__"},
    {"_ZZ23_dyld_launched_preboundE8__func__", "_dyld_launched_prebound::__func__"},
    {"_ZZ14NSUnLinkModuleE8__func__", "NSUnLinkModule::__func__"},
    {"_ZZ22NSLibraryNameForModuleE8__func__", "NSLibraryNameForModule::__func__"},
    {"_ZZ14NSNameOfModuleE8__func__", "NSNameOfModule::__func__"},
    {"_ZZ22NSLookupSymbolInModuleE8__func__", "NSLookupSymbolInModule::__func__"},
    {"_ZZ12NSLinkModuleE8__func__", "NSLinkModule::__func__"},
    {"_ZZ34NSIsSymbolDefinedInObjectFileImageE8__func__", "NSIsSymbolDefinedInObjectFileImage::__func__"},
    {"_ZZ33NSGetSectionDataInObjectFileImageE8__func__", "NSGetSectionDataInObjectFileImage::__func__"},
    {"_ZZ38NSSymbolReferenceNameInObjectFileImageE8__func__", "NSSymbolReferenceNameInObjectFileImage::__func__"},
    {"_ZZ39NSSymbolReferenceCountInObjectFileImageE8__func__", "NSSymbolReferenceCountInObjectFileImage::__func__"},
    {"_ZZ39NSSymbolDefinitionNameInObjectFileImageE8__func__", "NSSymbolDefinitionNameInObjectFileImage::__func__"},
    {"_ZZ40NSSymbolDefinitionCountInObjectFileImageE8__func__", "NSSymbolDefinitionCountInObjectFileImage::__func__"},
    {"_ZZ27NSHasModInitObjectFileImageE8__func__", "NSHasModInitObjectFileImage::__func__"},
    {"_ZZ24NSDestroyObjectFileImageE8__func__", "NSDestroyObjectFileImage::__func__"},
    {"_ZZ33NSCreateObjectFileImageFromMemoryE8__func__", "NSCreateObjectFileImageFromMemory::__func__"},
    {"_ZZ31NSCreateObjectFileImageFromFileE8__func__", "NSCreateObjectFileImageFromFile::__func__"},
    {"_ZZ30_dyld_image_containing_addressE8__func__", "_dyld_image_containing_address::__func__"},
    {"_ZZ41_dyld_bind_fully_image_containing_addressE8__func__", "_dyld_bind_fully_image_containing_address::__func__"},
    {"_ZZ22_dyld_bind_objc_moduleE8__func__", "_dyld_bind_objc_module::__func__"},
    {"_ZZ35_dyld_all_twolevel_modules_preboundE8__func__", "_dyld_all_twolevel_modules_prebound::__func__"},
    {"_ZZ17NSModuleForSymbolE8__func__", "NSModuleForSymbol::__func__"},
    {"_ZZ17NSAddressOfSymbolE8__func__", "NSAddressOfSymbol::__func__"},
    {"_ZZ14NSNameOfSymbolE8__func__", "NSNameOfSymbol::__func__"},
    {"_ZZ29NSIsSymbolNameDefinedWithHintE8__func__", "NSIsSymbolNameDefinedWithHint::__func__"},
    {"_ZZ21NSLookupSymbolInImageE8__func__", "NSLookupSymbolInImage::__func__"},
    {"_ZZ28NSIsSymbolNameDefinedInImageE8__func__", "NSIsSymbolNameDefinedInImage::__func__"},
    {"_ZZ25NSAddLibraryWithSearchingE8__func__", "NSAddLibraryWithSearching::__func__"},
    {"_ZZ12NSAddLibraryE8__func__", "NSAddLibrary::__func__"},
    {"_ZZ10NSAddImageE8__func__", "NSAddImage::__func__"},
    {"_ZZ29NSLookupAndBindSymbolWithHintE8__func__", "NSLookupAndBindSymbolWithHint::__func__"},
    {"_ZZ21NSLookupAndBindSymbolE8__func__", "NSLookupAndBindSymbol::__func__"},
    {"_ZZ31_dyld_lookup_and_bind_with_hintE8__func__", "_dyld_lookup_and_bind_with_hint::__func__"},
    {"_ZZ27_dyld_lookup_and_bind_fullyE8__func__", "_dyld_lookup_and_bind_fully::__func__"},
    {"_ZZ36_dyld_register_func_for_remove_imageE8__func__", "_dyld_register_func_for_remove_image::__func__"},
    {"_ZZ33_dyld_register_func_for_add_imageE8__func__", "_dyld_register_func_for_add_image::__func__"},
    {"_ZZ41_dyld_get_image_header_containing_addressE8__func__", "_dyld_get_image_header_containing_address::__func__"},
    {"_ZZ20_dyld_get_image_nameE8__func__", "_dyld_get_image_name::__func__"},
    {"_ZZ21_dyld_get_image_slideE8__func__", "_dyld_get_image_slide::__func__"},
    {"_ZZ28_dyld_get_image_vmaddr_slideE8__func__", "_dyld_get_image_vmaddr_slide::__func__"},
    {"_ZZ22_dyld_get_image_headerE8__func__", "_dyld_get_image_header::__func__"},
    {"_ZZ17_dyld_image_countE8__func__", "_dyld_image_count::__func__"},
    {"_ZZ20_NSGetExecutablePathE8__func__", "_NSGetExecutablePath::__func__"},
    {"_ZTSSt11logic_error", "typeinfo name for std::logic_error"},
    {"_ZTSSt13bad_exception", "typeinfo name for std::bad_exception"},
    {"_ZTSSt9exception", "typeinfo name for std::exception"},
    {"_ZTSSt9bad_alloc", "typeinfo name for std::bad_alloc"},
    {"_ZTSN10__cxxabiv120__si_class_type_infoE", "typeinfo name for __cxxabiv1::__si_class_type_info"},
    {"_ZTSN10__cxxabiv117__class_type_infoE", "typeinfo name for __cxxabiv1::__class_type_info"},
    {"_ZTSSt9type_info", "typeinfo name for std::type_info"},
    {"_ZTSPKc", "typeinfo name for char const*"},
    {"_ZTSPc", "typeinfo name for char*"},
    {"_ZTSc", "typeinfo name for char"},
    {"_ZTSv", "typeinfo name for void"},
    {"_ZTSN10__cxxabiv119__pointer_type_infoE", "typeinfo name for __cxxabiv1::__pointer_type_info"},
    {"_ZTSN10__cxxabiv117__pbase_type_infoE", "typeinfo name for __cxxabiv1::__pbase_type_info"},
    {"_ZTSN10__cxxabiv123__fundamental_type_infoE", "typeinfo name for __cxxabiv1::__fundamental_type_info"},
    {"_ZTSSt12length_error", "typeinfo name for std::length_error"},
    {"_ZTSN9__gnu_cxx24__concurrence_lock_errorE", "typeinfo name for __gnu_cxx::__concurrence_lock_error"},
    {"_ZTSN9__gnu_cxx26__concurrence_unlock_errorE", "typeinfo name for __gnu_cxx::__concurrence_unlock_error"},
    {"_ZTV11ImageLoader", "vtable for ImageLoader"},
    {"_ZTV16ImageLoaderMachO", "vtable for ImageLoaderMachO"},
    {"_ZTV23ImageLoaderMachOClassic", "vtable for ImageLoaderMachOClassic"},
    {"_ZTV26ImageLoaderMachOCompressed", "vtable for ImageLoaderMachOCompressed"},
    {"_ZTISt12length_error", "typeinfo for std::length_error"},
    {"_ZTVSt12length_error", "vtable for std::length_error"},
    {"_ZTVSt11logic_error", "vtable for std::logic_error"},
    {"_ZTISt11logic_error", "typeinfo for std::logic_error"},
    {"_ZTIN9__gnu_cxx24__concurrence_lock_errorE", "typeinfo for __gnu_cxx::__concurrence_lock_error"},
    {"_ZTVN9__gnu_cxx24__concurrence_lock_errorE", "vtable for __gnu_cxx::__concurrence_lock_error"},
    {"_ZTIN9__gnu_cxx26__concurrence_unlock_errorE", "typeinfo for __gnu_cxx::__concurrence_unlock_error"},
    {"_ZTVN9__gnu_cxx26__concurrence_unlock_errorE", "vtable for __gnu_cxx::__concurrence_unlock_error"},
    {"_ZTVSt13bad_exception", "vtable for std::bad_exception"},
    {"_ZTVSt9exception", "vtable for std::exception"},
    {"_ZTISt13bad_exception", "typeinfo for std::bad_exception"},
    {"_ZTISt9exception", "typeinfo for std::exception"},
    {"_ZTVSt9bad_alloc", "vtable for std::bad_alloc"},
    {"_ZTISt9bad_alloc", "typeinfo for std::bad_alloc"},
    {"_ZTVN10__cxxabiv120__si_class_type_infoE", "vtable for __cxxabiv1::__si_class_type_info"},
    {"_ZTVN10__cxxabiv117__class_type_infoE", "vtable for __cxxabiv1::__class_type_info"},
    {"_ZTVSt9type_info", "vtable for std::type_info"},
    {"_ZTIN10__cxxabiv120__si_class_type_infoE", "typeinfo for __cxxabiv1::__si_class_type_info"},
    {"_ZTIN10__cxxabiv117__class_type_infoE", "typeinfo for __cxxabiv1::__class_type_info"},
    {"_ZTISt9type_info", "typeinfo for std::type_info"},
    {"_ZTVN10__cxxabiv119__pointer_type_infoE", "vtable for __cxxabiv1::__pointer_type_info"},
    {"_ZTVN10__cxxabiv117__pbase_type_infoE", "vtable for __cxxabiv1::__pbase_type_info"},
    {"_ZTVN10__cxxabiv123__fundamental_type_infoE", "vtable for __cxxabiv1::__fundamental_type_info"},
    {"_ZTIPKc", "typeinfo for char const*"},
    {"_ZTIPc", "typeinfo for char*"},
    {"_ZTIc", "typeinfo for char"},
    {"_ZTIv", "typeinfo for void"},
    {"_ZTIN10__cxxabiv119__pointer_type_infoE", "typeinfo for __cxxabiv1::__pointer_type_info"},
    {"_ZTIN10__cxxabiv117__pbase_type_infoE", "typeinfo for __cxxabiv1::__pbase_type_info"},
    {"_ZTIN10__cxxabiv123__fundamental_type_infoE", "typeinfo for __cxxabiv1::__fundamental_type_info"},
    {"_ZTVN9libunwind12UnwindCursorINS_17LocalAddressSpaceENS_16Registers_x86_64EEE", "vtable for libunwind::UnwindCursor<libunwind::LocalAddressSpace, libunwind::Registers_x86_64>"},
    {"_ZN4dyld8gLogAPIsE", "dyld::gLogAPIs"},
    {"_ZN4dyld17gLibSystemHelpersE", "dyld::gLibSystemHelpers"},
    {"_ZN10__cxxabiv119__terminate_handlerE", "__cxxabiv1::__terminate_handler"},
    {"_ZN10__cxxabiv120__unexpected_handlerE", "__cxxabiv1::__unexpected_handler"},
    {"_ZN11ImageLoader27fgImagesUsedFromSharedCacheE", "ImageLoader::fgImagesUsedFromSharedCache"},
    {"_ZN11ImageLoader26fgImagesWithUsedPrebindingE", "ImageLoader::fgImagesWithUsedPrebinding"},
    {"_ZN11ImageLoader25fgImagesRequiringNoFixupsE", "ImageLoader::fgImagesRequiringNoFixups"},
    {"_ZN11ImageLoader27fgImagesRequiringCoalescingE", "ImageLoader::fgImagesRequiringCoalescing"},
    {"_ZN11ImageLoader26fgImagesHasWeakDefinitionsE", "ImageLoader::fgImagesHasWeakDefinitions"},
    {"_ZN11ImageLoader19fgTotalRebaseFixupsE", "ImageLoader::fgTotalRebaseFixups"},
    {"_ZN11ImageLoader17fgTotalBindFixupsE", "ImageLoader::fgTotalBindFixups"},
    {"_ZN11ImageLoader26fgTotalBindSymbolsResolvedE", "ImageLoader::fgTotalBindSymbolsResolved"},
    {"_ZN11ImageLoader24fgTotalBindImageSearchesE", "ImageLoader::fgTotalBindImageSearches"},
    {"_ZN11ImageLoader21fgTotalLazyBindFixupsE", "ImageLoader::fgTotalLazyBindFixups"},
    {"_ZN11ImageLoader29fgTotalPossibleLazyBindFixupsE", "ImageLoader::fgTotalPossibleLazyBindFixups"},
    {"_ZN11ImageLoader21fgTotalSegmentsMappedE", "ImageLoader::fgTotalSegmentsMapped"},
    {"_ZN11ImageLoader18fgTotalBytesMappedE", "ImageLoader::fgTotalBytesMapped"},
    {"_ZN11ImageLoader22fgTotalBytesPreFetchedE", "ImageLoader::fgTotalBytesPreFetched"},
    {"_ZN11ImageLoader21fgNextPIEDylibAddressE", "ImageLoader::fgNextPIEDylibAddress"},
    {"_ZN16ImageLoaderMachO26fgSymbolTableBinarySearchsE", "ImageLoaderMachO::fgSymbolTableBinarySearchs"},
    {"_ZN16ImageLoaderMachO19fgSymbolTrieSearchsE", "ImageLoaderMachO::fgSymbolTrieSearchs"},
    {"_ZN4dyld12gLinkContextE", "dyld::gLinkContext"},
    {"_ZN11ImageLoader24fgTotalLoadLibrariesTimeE", "ImageLoader::fgTotalLoadLibrariesTime"},
    {"_ZN11ImageLoader17fgTotalRebaseTimeE", "ImageLoader::fgTotalRebaseTime"},
    {"_ZN11ImageLoader15fgTotalBindTimeE", "ImageLoader::fgTotalBindTime"},
    {"_ZN11ImageLoader19fgTotalWeakBindTimeE", "ImageLoader::fgTotalWeakBindTime"},
    {"_ZN11ImageLoader10fgTotalDOFE", "ImageLoader::fgTotalDOF"},
    {"_ZN11ImageLoader15fgTotalInitTimeE", "ImageLoader::fgTotalInitTime"},
    {"_ZN11ImageLoader23fgDynamicImageReExportsE", "ImageLoader::fgDynamicImageReExports"},
    {"_ZN11ImageLoader19fgInterposingTuplesE", "ImageLoader::fgInterposingTuples"},
    {"_ZNSs4_Rep20_S_empty_rep_storageE", "std::string::_Rep::_S_empty_rep_storage"},
    {"_ZZN23ImageLoaderMachOClassic26bindIndirectSymbolPointersERKN11ImageLoader11LinkContextEbbE13alreadyWarned", "ImageLoaderMachOClassic::bindIndirectSymbolPointers(ImageLoader::LinkContext const&, bool, bool)::alreadyWarned"},
    {"_ZN12_GLOBAL__N_115emergency_mutexE", "(anonymous namespace)::emergency_mutex"},
    {"_Z1fIDnLDn0EEvv", "void f<std::nullptr_t, nullptr>()"},

    // clang

    {"_ZN4llvm8DenseMapIjcNS_12DenseMapInfoIjEENS1_IcEEE6insertERKSt4pairIjcE", "llvm::DenseMap<unsigned int, char, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<char>>::insert(std::pair<unsigned int, char> const&)"},
    {"_ZN4llvm8DenseMapIjcNS_12DenseMapInfoIjEENS1_IcEEE16InsertIntoBucketERKjRKcPSt4pairIjcE", "llvm::DenseMap<unsigned int, char, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<char>>::InsertIntoBucket(unsigned int const&, char const&, std::pair<unsigned int, char>*)"},
    {"_ZN4llvm8DenseMapIjcNS_12DenseMapInfoIjEENS1_IcEEE4growEj", "llvm::DenseMap<unsigned int, char, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZN4llvm19MachinePassRegistry3AddEPNS_23MachinePassRegistryNodeE", "llvm::MachinePassRegistry::Add(llvm::MachinePassRegistryNode*)"},
    {"_ZN4llvm2cl6valuesIiEENS0_11ValuesClassIT_EEPKcS3_S6_z", "llvm::cl::ValuesClass<int> llvm::cl::values<int>(char const*, int, char const*, ...)"},
    {"_ZN4llvm2cl11ValuesClassIiEC2EPKciS4_P13__va_list_tag", "llvm::cl::ValuesClass<int>::ValuesClass(char const*, int, char const*, __va_list_tag*)"},
    {"_ZN4llvm24PassRegistrationListenerC2Ev", "llvm::PassRegistrationListener::PassRegistrationListener()"},
    {"_ZN4llvm24PassRegistrationListener15enumeratePassesEv", "llvm::PassRegistrationListener::enumeratePasses()"},
    {"_ZN4llvm12PassRegistry15getPassRegistryEv", "llvm::PassRegistry::getPassRegistry()"},
    {"_ZNK4llvm12PassRegistry7getImplEv", "llvm::PassRegistry::getImpl() const"},
    {"_ZN4llvm12PassRegistry13enumerateWithEPNS_24PassRegistrationListenerE", "llvm::PassRegistry::enumerateWith(llvm::PassRegistrationListener*)"},
    {"_ZN4llvm12PassRegistry23addRegistrationListenerEPNS_24PassRegistrationListenerE", "llvm::PassRegistry::addRegistrationListener(llvm::PassRegistrationListener*)"},
    {"_ZNSt6vectorIPN4llvm24PassRegistrationListenerESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::PassRegistrationListener*, std::allocator<llvm::PassRegistrationListener*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::PassRegistrationListener**, std::vector<llvm::PassRegistrationListener*, std::allocator<llvm::PassRegistrationListener*>>>, llvm::PassRegistrationListener* const&)"},
    {"_ZN4llvm3sys11MemoryFenceEv", "llvm::sys::MemoryFence()"},
    {"_ZN4llvm2cl6Option11addArgumentEv", "llvm::cl::Option::addArgument()"},
    {"_ZN4llvm2cl18MarkOptionsChangedEv", "llvm::cl::MarkOptionsChanged()"},
    {"_ZNK4llvm17ManagedStaticBase21RegisterManagedStaticEPFPvvEPFvS1_E", "llvm::ManagedStaticBase::RegisterManagedStatic(void* (*)(), void (*)(void*)) const"},
    {"_ZN4llvm3sys9MutexImplC2Eb", "llvm::sys::MutexImpl::MutexImpl(bool)"},
    {"_ZN4llvm3sys9MutexImpl7acquireEv", "llvm::sys::MutexImpl::acquire()"},
    {"_ZN4llvm3sys9MutexImpl7releaseEv", "llvm::sys::MutexImpl::release()"},
    {"_ZN4llvm15SmallVectorBase8grow_podEmm", "llvm::SmallVectorBase::grow_pod(unsigned long, unsigned long)"},
    {"_ZN4llvm3sys15ThreadLocalImplC2Ev", "llvm::sys::ThreadLocalImpl::ThreadLocalImpl()"},
    {"_ZN4llvm21llvm_is_multithreadedEv", "llvm::llvm_is_multithreaded()"},
    {"_ZN4llvm24llvm_acquire_global_lockEv", "llvm::llvm_acquire_global_lock()"},
    {"_ZN4llvm24llvm_release_global_lockEv", "llvm::llvm_release_global_lock()"},
    {"_ZN4llvm15system_categoryEv", "llvm::system_category()"},
    {"_Z8cc1_mainPPKcS1_S0_Pv", "cc1_main(char const**, char const**, char const*, void*)"},
    {"_Z16LLVMErrorHandlerPvRKSs", "LLVMErrorHandler(void*, std::string const&)"},
    {"_ZNK5clang17DiagnosticBuilder9AddStringEN4llvm9StringRefE", "clang::DiagnosticBuilder::AddString(llvm::StringRef) const"},
    {"_ZNK4llvm18IntrusiveRefCntPtrIN5clang10DiagnosticEE6getPtrEv", "llvm::IntrusiveRefCntPtr<clang::Diagnostic>::getPtr() const"},
    {"_ZN5clang16DiagnosticClient15BeginSourceFileERKNS_11LangOptionsEPKNS_12PreprocessorE", "clang::DiagnosticClient::BeginSourceFile(clang::LangOptions const&, clang::Preprocessor const*)"},
    {"_ZN5clang16DiagnosticClient13EndSourceFileEv", "clang::DiagnosticClient::EndSourceFile()"},
    {"_ZN5clang18CompilerInvocationD2Ev", "clang::CompilerInvocation::~CompilerInvocation()"},
    {"_ZN5clang14CodeGenOptionsD2Ev", "clang::CodeGenOptions::~CodeGenOptions()"},
    {"_ZN5clang23DependencyOutputOptionsD2Ev", "clang::DependencyOutputOptions::~DependencyOutputOptions()"},
    {"_ZN5clang15FrontendOptionsD2Ev", "clang::FrontendOptions::~FrontendOptions()"},
    {"_ZNSt6vectorIS_ISsSaISsEESaIS1_EED2Ev", "std::vector<std::vector<std::string, std::allocator<std::string>>, std::allocator<std::vector<std::string, std::allocator<std::string>>>>::~vector()"},
    {"_ZN5clang19HeaderSearchOptionsD2Ev", "clang::HeaderSearchOptions::~HeaderSearchOptions()"},
    {"_ZN5clang19PreprocessorOptionsD2Ev", "clang::PreprocessorOptions::~PreprocessorOptions()"},
    {"_ZNSt8_Rb_treeISsSsSt9_IdentityISsESt4lessISsESaISsEE8_M_eraseEPSt13_Rb_tree_nodeISsE", "std::_Rb_tree<std::string, std::string, std::_Identity<std::string>, std::less<std::string>, std::allocator<std::string>>::_M_erase(std::_Rb_tree_node<std::string>*)"},
    {"_ZNSt6vectorISt4pairISsSsESaIS1_EED2Ev", "std::vector<std::pair<std::string, std::string>, std::allocator<std::pair<std::string, std::string>>>::~vector()"},
    {"_ZN5clang13TargetOptionsD2Ev", "clang::TargetOptions::~TargetOptions()"},
    {"_ZN5clang18CompilerInvocationC2Ev", "clang::CompilerInvocation::CompilerInvocation()"},
    {"_Z10cc1as_mainPPKcS1_S0_Pv", "cc1as_main(char const**, char const**, char const*, void*)"},
    {"_Z16LLVMErrorHandlerPvRKSs", "LLVMErrorHandler(void*, std::string const&)"},
    {"_ZN4llvm23PrettyStackTraceProgramD1Ev", "llvm::PrettyStackTraceProgram::~PrettyStackTraceProgram()"},
    {"_ZN4llvm23PrettyStackTraceProgramD0Ev", "llvm::PrettyStackTraceProgram::~PrettyStackTraceProgram()"},
    {"_ZN4llvm21formatted_raw_ostream9setStreamERNS_11raw_ostreamEb", "llvm::formatted_raw_ostream::setStream(llvm::raw_ostream&, bool)"},
    {"_ZN4llvm21formatted_raw_ostreamD1Ev", "llvm::formatted_raw_ostream::~formatted_raw_ostream()"},
    {"_ZN4llvm21formatted_raw_ostreamD0Ev", "llvm::formatted_raw_ostream::~formatted_raw_ostream()"},
    {"_ZN4llvm11raw_ostream11changeColorENS0_6ColorsEbb", "llvm::raw_ostream::changeColor(llvm::raw_ostream::Colors, bool, bool)"},
    {"_ZN4llvm11raw_ostream10resetColorEv", "llvm::raw_ostream::resetColor()"},
    {"_ZNK4llvm11raw_ostream12is_displayedEv", "llvm::raw_ostream::is_displayed() const"},
    {"_ZNK4llvm21formatted_raw_ostream11current_posEv", "llvm::formatted_raw_ostream::current_pos() const"},
    {"_ZN4llvm21formatted_raw_ostream13releaseStreamEv", "llvm::formatted_raw_ostream::releaseStream()"},
    {"_ZNSt6vectorISsSaISsEEaSERKS1_", "std::vector<std::string, std::allocator<std::string>>::operator=(std::vector<std::string, std::allocator<std::string>> const&)"},
    {"_ZNSt6vectorIN4llvm9SourceMgr9SrcBufferESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::SourceMgr::SrcBuffer, std::allocator<llvm::SourceMgr::SrcBuffer>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::SourceMgr::SrcBuffer*, std::vector<llvm::SourceMgr::SrcBuffer, std::allocator<llvm::SourceMgr::SrcBuffer>>>, llvm::SourceMgr::SrcBuffer const&)"},
    {"_ZN4llvm10error_code21unspecified_bool_trueEv", "llvm::error_code::unspecified_bool_true()"},
    {"_Z17GetExecutablePathPKcb", "GetExecutablePath(char const*, bool)"},
    {"_Z17ExpandArgsFromBufPKcRN4llvm15SmallVectorImplIS0_EERSt3setISsSt4lessISsESaISsEE", "ExpandArgsFromBuf(char const*, llvm::SmallVectorImpl<char const*>&, std::set<std::string, std::less<std::string>, std::allocator<std::string>>&)"},
    {"_ZN4llvm15SmallVectorImplIPKcE6insertIN9__gnu_cxx17__normal_iteratorIPS2_St6vectorIS2_SaIS2_EEEEEES7_S7_T_SC_", "char const** llvm::SmallVectorImpl<char const*>::insert<__gnu_cxx::__normal_iterator<char const**, std::vector<char const*, std::allocator<char const*>>>>(char const**, __gnu_cxx::__normal_iterator<char const**, std::vector<char const*, std::allocator<char const*>>>, __gnu_cxx::__normal_iterator<char const**, std::vector<char const*, std::allocator<char const*>>>)"},
    {"_ZNSt6vectorIPKcSaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<char const*, std::allocator<char const*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<char const**, std::vector<char const*, std::allocator<char const*>>>, char const* const&)"},
    {"_ZNSt8_Rb_treeISsSsSt9_IdentityISsESt4lessISsESaISsEE16_M_insert_uniqueERKSs", "std::_Rb_tree<std::string, std::string, std::_Identity<std::string>, std::less<std::string>, std::allocator<std::string>>::_M_insert_unique(std::string const&)"},
    {"_ZNSt8_Rb_treeISsSsSt9_IdentityISsESt4lessISsESaISsEE9_M_insertEPSt18_Rb_tree_node_baseS7_RKSs", "std::_Rb_tree<std::string, std::string, std::_Identity<std::string>, std::less<std::string>, std::allocator<std::string>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::string const&)"},
    {"_ZN4llvm15SmallVectorImplIPKcE6insertEPS2_RKS2_", "llvm::SmallVectorImpl<char const*>::insert(char const**, char const* const&)"},
    {"_ZN5clang25ExecuteCompilerInvocationEPNS_16CompilerInstanceE", "clang::ExecuteCompilerInvocation(clang::CompilerInstance*)"},
    {"_ZN5clang14FrontendAction21BeginSourceFileActionERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::FrontendAction::BeginSourceFileAction(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang14FrontendAction19EndSourceFileActionEv", "clang::FrontendAction::EndSourceFileAction()"},
    {"_ZNK5clang26PreprocessorFrontendAction20usesPreprocessorOnlyEv", "clang::PreprocessorFrontendAction::usesPreprocessorOnly() const"},
    {"_ZN5clang14FrontendAction27usesCompleteTranslationUnitEv", "clang::FrontendAction::usesCompleteTranslationUnit()"},
    {"_ZNK5clang14FrontendAction13hasPCHSupportEv", "clang::FrontendAction::hasPCHSupport() const"},
    {"_ZNK5clang14FrontendAction17hasASTFileSupportEv", "clang::FrontendAction::hasASTFileSupport() const"},
    {"_ZNK5clang14FrontendAction12hasIRSupportEv", "clang::FrontendAction::hasIRSupport() const"},
    {"_ZNK5clang14FrontendAction24hasCodeCompletionSupportEv", "clang::FrontendAction::hasCodeCompletionSupport() const"},
    {"_ZN5clang26PreprocessorFrontendActionD1Ev", "clang::PreprocessorFrontendAction::~PreprocessorFrontendAction()"},
    {"_ZN5clang26PreprocessorFrontendActionD0Ev", "clang::PreprocessorFrontendAction::~PreprocessorFrontendAction()"},
    {"_ZNK5clang17ASTFrontendAction20usesPreprocessorOnlyEv", "clang::ASTFrontendAction::usesPreprocessorOnly() const"},
    {"_ZN5clang17ASTFrontendActionD1Ev", "clang::ASTFrontendAction::~ASTFrontendAction()"},
    {"_ZN5clang17ASTFrontendActionD0Ev", "clang::ASTFrontendAction::~ASTFrontendAction()"},
    {"_ZNK5clang23PrintPreprocessedAction13hasPCHSupportEv", "clang::PrintPreprocessedAction::hasPCHSupport() const"},
    {"_ZN5clang19PrintPreambleAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::PrintPreambleAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZNK5clang19PrintPreambleAction20usesPreprocessorOnlyEv", "clang::PrintPreambleAction::usesPreprocessorOnly() const"},
    {"_ZN5clang16SyntaxOnlyActionD1Ev", "clang::SyntaxOnlyAction::~SyntaxOnlyAction()"},
    {"_ZN5clang16SyntaxOnlyActionD0Ev", "clang::SyntaxOnlyAction::~SyntaxOnlyAction()"},
    {"_ZNK5clang16SyntaxOnlyAction24hasCodeCompletionSupportEv", "clang::SyntaxOnlyAction::hasCodeCompletionSupport() const"},
    {"_ZNK5clang14InitOnlyAction20usesPreprocessorOnlyEv", "clang::InitOnlyAction::usesPreprocessorOnly() const"},
    {"_ZN5clang17GeneratePCHAction27usesCompleteTranslationUnitEv", "clang::GeneratePCHAction::usesCompleteTranslationUnit()"},
    {"_ZNK5clang17GeneratePCHAction17hasASTFileSupportEv", "clang::GeneratePCHAction::hasASTFileSupport() const"},
    {"_ZN5clang16CreateASTPrinterEPN4llvm11raw_ostreamE", "clang::CreateASTPrinter(llvm::raw_ostream*)"},
    {"_ZN5clang19CreateASTPrinterXMLEPN4llvm11raw_ostreamE", "clang::CreateASTPrinterXML(llvm::raw_ostream*)"},
    {"_ZN5clang15CreateASTDumperEv", "clang::CreateASTDumper()"},
    {"_ZN5clang15CreateASTViewerEv", "clang::CreateASTViewer()"},
    {"_ZN5clang24CreateDeclContextPrinterEv", "clang::CreateDeclContextPrinter()"},
    {"_ZN5clang23CreateInheritanceViewerERKSs", "clang::CreateInheritanceViewer(std::string const&)"},
    {"_ZN5clang18CreateASTDumperXMLERN4llvm11raw_ostreamE", "clang::CreateASTDumperXML(llvm::raw_ostream&)"},
    {"_ZN12_GLOBAL__N_110ASTDumpXMLD1Ev", "(anonymous namespace)::ASTDumpXML::~ASTDumpXML()"},
    {"_ZN12_GLOBAL__N_110ASTDumpXMLD0Ev", "(anonymous namespace)::ASTDumpXML::~ASTDumpXML()"},
    {"_ZN12_GLOBAL__N_110ASTDumpXML21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::ASTDumpXML::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_117InheritanceViewerD1Ev", "(anonymous namespace)::InheritanceViewer::~InheritanceViewer()"},
    {"_ZN12_GLOBAL__N_117InheritanceViewerD0Ev", "(anonymous namespace)::InheritanceViewer::~InheritanceViewer()"},
    {"_ZN12_GLOBAL__N_117InheritanceViewer21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::InheritanceViewer::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_118DeclContextPrinterD1Ev", "(anonymous namespace)::DeclContextPrinter::~DeclContextPrinter()"},
    {"_ZN12_GLOBAL__N_118DeclContextPrinterD0Ev", "(anonymous namespace)::DeclContextPrinter::~DeclContextPrinter()"},
    {"_ZN12_GLOBAL__N_118DeclContextPrinter21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::DeclContextPrinter::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_118DeclContextPrinter16PrintDeclContextEPKN5clang11DeclContextEj", "(anonymous namespace)::DeclContextPrinter::PrintDeclContext(clang::DeclContext const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_19ASTViewerD1Ev", "(anonymous namespace)::ASTViewer::~ASTViewer()"},
    {"_ZN12_GLOBAL__N_19ASTViewerD0Ev", "(anonymous namespace)::ASTViewer::~ASTViewer()"},
    {"_ZN12_GLOBAL__N_19ASTViewer10InitializeERN5clang10ASTContextE", "(anonymous namespace)::ASTViewer::Initialize(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_19ASTViewer18HandleTopLevelDeclEN5clang12DeclGroupRefE", "(anonymous namespace)::ASTViewer::HandleTopLevelDecl(clang::DeclGroupRef)"},
    {"_ZN12_GLOBAL__N_113ASTPrinterXMLD1Ev", "(anonymous namespace)::ASTPrinterXML::~ASTPrinterXML()"},
    {"_ZN12_GLOBAL__N_113ASTPrinterXMLD0Ev", "(anonymous namespace)::ASTPrinterXML::~ASTPrinterXML()"},
    {"_ZN12_GLOBAL__N_113ASTPrinterXML10InitializeERN5clang10ASTContextE", "(anonymous namespace)::ASTPrinterXML::Initialize(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_113ASTPrinterXML21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::ASTPrinterXML::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_110ASTPrinterD1Ev", "(anonymous namespace)::ASTPrinter::~ASTPrinter()"},
    {"_ZN12_GLOBAL__N_110ASTPrinterD0Ev", "(anonymous namespace)::ASTPrinter::~ASTPrinter()"},
    {"_ZN12_GLOBAL__N_110ASTPrinter21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::ASTPrinter::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZNSt5dequeISsSaISsEED2Ev", "std::deque<std::string, std::allocator<std::string>>::~deque()"},
    {"_ZNSt5dequeISsSaISsEE19_M_destroy_data_auxESt15_Deque_iteratorISsRSsPSsES5_", "std::deque<std::string, std::allocator<std::string>>::_M_destroy_data_aux(std::_Deque_iterator<std::string, std::string&, std::string*>, std::_Deque_iterator<std::string, std::string&, std::string*>)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_jESt10_Select1stIS4_ENS0_16QualTypeOrderingESaIS4_EE8_M_eraseEPSt13_Rb_tree_nodeIS4_E", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, unsigned int>, std::_Select1st<std::pair<clang::QualType const, unsigned int>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, unsigned int>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::QualType const, unsigned int>>*)"},
    {"_ZN5clang14ASTMergeAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::ASTMergeAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang14ASTMergeAction21BeginSourceFileActionERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::ASTMergeAction::BeginSourceFileAction(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang14ASTMergeAction13ExecuteActionEv", "clang::ASTMergeAction::ExecuteAction()"},
    {"_ZN5clang14ASTMergeAction19EndSourceFileActionEv", "clang::ASTMergeAction::EndSourceFileAction()"},
    {"_ZN5clang14ASTMergeActionC1EPNS_14FrontendActionEPSsj", "clang::ASTMergeAction::ASTMergeAction(clang::FrontendAction*, std::string*, unsigned int)"},
    {"_ZN5clang14ASTMergeActionC2EPNS_14FrontendActionEPSsj", "clang::ASTMergeAction::ASTMergeAction(clang::FrontendAction*, std::string*, unsigned int)"},
    {"_ZN5clang14ASTMergeActionD0Ev", "clang::ASTMergeAction::~ASTMergeAction()"},
    {"_ZN5clang14ASTMergeActionD1Ev", "clang::ASTMergeAction::~ASTMergeAction()"},
    {"_ZN5clang14ASTMergeActionD2Ev", "clang::ASTMergeAction::~ASTMergeAction()"},
    {"_ZNK5clang14ASTMergeAction20usesPreprocessorOnlyEv", "clang::ASTMergeAction::usesPreprocessorOnly() const"},
    {"_ZN5clang14ASTMergeAction27usesCompleteTranslationUnitEv", "clang::ASTMergeAction::usesCompleteTranslationUnit()"},
    {"_ZNK5clang14ASTMergeAction13hasPCHSupportEv", "clang::ASTMergeAction::hasPCHSupport() const"},
    {"_ZNK5clang14ASTMergeAction17hasASTFileSupportEv", "clang::ASTMergeAction::hasASTFileSupport() const"},
    {"_ZNK5clang14ASTMergeAction24hasCodeCompletionSupportEv", "clang::ASTMergeAction::hasCodeCompletionSupport() const"},
    {"_ZN5clang7ASTUnitC1Eb", "clang::ASTUnit::ASTUnit(bool)"},
    {"_ZN5clang7ASTUnitC2Eb", "clang::ASTUnit::ASTUnit(bool)"},
    {"_ZN5clang7ASTUnitC3Eb", "clang::ASTUnit::ASTUnit(bool)"},
    {"_ZN5clang7ASTUnitC4Eb", "clang::ASTUnit::ASTUnit(bool)"},
    {"_ZN5clang7ASTUnitC5Eb", "clang::ASTUnit::ASTUnit(bool)"},
    {"_ZN5clang7ASTUnitD0Ev", "clang::ASTUnit::~ASTUnit()"},
    {"_ZN5clang7ASTUnitD1Ev", "clang::ASTUnit::~ASTUnit()"},
    {"_ZN5clang7ASTUnitD2Ev", "clang::ASTUnit::~ASTUnit()"},
    {"_ZN5clang7ASTUnitD4Ev", "clang::ASTUnit::~ASTUnit()"},
    {"_ZN5clang7ASTUnitD5Ev", "clang::ASTUnit::~ASTUnit()"},
    {"_ZN5clang7ASTUnit19CleanTemporaryFilesEv", "clang::ASTUnit::CleanTemporaryFiles()"},
    {"_ZN5clang7ASTUnit28ClearCachedCompletionResultsEv", "clang::ASTUnit::ClearCachedCompletionResults()"},
    {"_ZN5clang7ASTUnit26CacheCodeCompletionResultsEv", "clang::ASTUnit::CacheCodeCompletionResults()"},
    {"_ZNK5clang7ASTUnit15getMainFileNameEv", "clang::ASTUnit::getMainFileName() const"},
    {"_ZN12_GLOBAL__N_111SimpleTimerD1Ev", "(anonymous namespace)::SimpleTimer::~SimpleTimer()"},
    {"_ZN5clang7ASTUnit25getOriginalSourceFileNameEv", "clang::ASTUnit::getOriginalSourceFileName()"},
    {"_ZN5clang7ASTUnit14getASTFileNameEv", "clang::ASTUnit::getASTFileName()"},
    {"_ZN5clang7ASTUnit16getBufferForFileEN4llvm9StringRefEPSs", "clang::ASTUnit::getBufferForFile(llvm::StringRef, std::string*)"},
    {"_ZN5clang7ASTUnit14ConfigureDiagsERN4llvm18IntrusiveRefCntPtrINS_10DiagnosticEEEPPKcS8_RS0_b", "clang::ASTUnit::ConfigureDiags(llvm::IntrusiveRefCntPtr<clang::Diagnostic>&, char const**, char const**, clang::ASTUnit&, bool)"},
    {"_ZN5clang7ASTUnit15LoadFromASTFileERKSsN4llvm18IntrusiveRefCntPtrINS_10DiagnosticEEERKNS_17FileSystemOptionsEbPSt4pairISsPKNS3_12MemoryBufferEEjb", "clang::ASTUnit::LoadFromASTFile(std::string const&, llvm::IntrusiveRefCntPtr<clang::Diagnostic>, clang::FileSystemOptions const&, bool, std::pair<std::string, llvm::MemoryBuffer const*>*, unsigned int, bool)"},
    {"_ZN5clang7ASTUnit5ParseEPN4llvm12MemoryBufferE", "clang::ASTUnit::Parse(llvm::MemoryBuffer*)"},
    {"_ZN5clang7ASTUnit15ComputePreambleERNS_18CompilerInvocationEjRb", "clang::ASTUnit::ComputePreamble(clang::CompilerInvocation&, unsigned int, bool&)"},
    {"_ZN5clang7ASTUnit36getMainBufferWithPrecompiledPreambleENS_18CompilerInvocationEbj", "clang::ASTUnit::getMainBufferWithPrecompiledPreamble(clang::CompilerInvocation, bool, unsigned int)"},
    {"_ZN5clang7ASTUnit32RealizeTopLevelDeclsFromPreambleEv", "clang::ASTUnit::RealizeTopLevelDeclsFromPreamble()"},
    {"_ZN5clang7ASTUnit39RealizePreprocessedEntitiesFromPreambleEv", "clang::ASTUnit::RealizePreprocessedEntitiesFromPreamble()"},
    {"_ZN5clang7ASTUnit15pp_entity_beginEv", "clang::ASTUnit::pp_entity_begin()"},
    {"_ZN5clang7ASTUnit13pp_entity_endEv", "clang::ASTUnit::pp_entity_end()"},
    {"_ZNK5clang7ASTUnit14getMaxPCHLevelEv", "clang::ASTUnit::getMaxPCHLevel() const"},
    {"_ZN5clang7ASTUnit26LoadFromCompilerInvocationEb", "clang::ASTUnit::LoadFromCompilerInvocation(bool)"},
    {"_ZN5clang7ASTUnit26LoadFromCompilerInvocationEPNS_18CompilerInvocationEN4llvm18IntrusiveRefCntPtrINS_10DiagnosticEEEbbbbb", "clang::ASTUnit::LoadFromCompilerInvocation(clang::CompilerInvocation*, llvm::IntrusiveRefCntPtr<clang::Diagnostic>, bool, bool, bool, bool, bool)"},
    {"_ZN5clang7ASTUnit19LoadFromCommandLineEPPKcS3_N4llvm18IntrusiveRefCntPtrINS_10DiagnosticEEENS4_9StringRefEbbPSt4pairISsPKNS4_12MemoryBufferEEjbbbbb", "clang::ASTUnit::LoadFromCommandLine(char const**, char const**, llvm::IntrusiveRefCntPtr<clang::Diagnostic>, llvm::StringRef, bool, bool, std::pair<std::string, llvm::MemoryBuffer const*>*, unsigned int, bool, bool, bool, bool, bool)"},
    {"_ZN5clang7ASTUnit7ReparseEPSt4pairISsPKN4llvm12MemoryBufferEEj", "clang::ASTUnit::Reparse(std::pair<std::string, llvm::MemoryBuffer const*>*, unsigned int)"},
    {"_ZN5clang7ASTUnit12CodeCompleteEN4llvm9StringRefEjjPSt4pairISsPKNS1_12MemoryBufferEEjbbRNS_20CodeCompleteConsumerERNS_10DiagnosticERNS_11LangOptionsERNS_13SourceManagerERNS_11FileManagerERNS1_15SmallVectorImplINS_16StoredDiagnosticEEERNSJ_IS6_EE", "clang::ASTUnit::CodeComplete(llvm::StringRef, unsigned int, unsigned int, std::pair<std::string, llvm::MemoryBuffer const*>*, unsigned int, bool, bool, clang::CodeCompleteConsumer&, clang::Diagnostic&, clang::LangOptions&, clang::SourceManager&, clang::FileManager&, llvm::SmallVectorImpl<clang::StoredDiagnostic>&, llvm::SmallVectorImpl<llvm::MemoryBuffer const*>&)"},
    {"_ZN5clang7ASTUnit4SaveEN4llvm9StringRefE", "clang::ASTUnit::Save(llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_129AugmentedCodeCompleteConsumerD1Ev", "(anonymous namespace)::AugmentedCodeCompleteConsumer::~AugmentedCodeCompleteConsumer()"},
    {"_ZN12_GLOBAL__N_129AugmentedCodeCompleteConsumerD0Ev", "(anonymous namespace)::AugmentedCodeCompleteConsumer::~AugmentedCodeCompleteConsumer()"},
    {"_ZN12_GLOBAL__N_129AugmentedCodeCompleteConsumer26ProcessCodeCompleteResultsERN5clang4SemaENS1_21CodeCompletionContextEPNS1_20CodeCompletionResultEj", "(anonymous namespace)::AugmentedCodeCompleteConsumer::ProcessCodeCompleteResults(clang::Sema&, clang::CodeCompletionContext, clang::CodeCompletionResult*, unsigned int)"},
    {"_ZN12_GLOBAL__N_129AugmentedCodeCompleteConsumer25ProcessOverloadCandidatesERN5clang4SemaEjPNS1_20CodeCompleteConsumer17OverloadCandidateEj", "(anonymous namespace)::AugmentedCodeCompleteConsumer::ProcessOverloadCandidates(clang::Sema&, unsigned int, clang::CodeCompleteConsumer::OverloadCandidate*, unsigned int)"},
    {"_ZN12_GLOBAL__N_129AugmentedCodeCompleteConsumer12getAllocatorEv", "(anonymous namespace)::AugmentedCodeCompleteConsumer::getAllocator()"},
    {"_ZN12_GLOBAL__N_122StoredDiagnosticClientD1Ev", "(anonymous namespace)::StoredDiagnosticClient::~StoredDiagnosticClient()"},
    {"_ZN12_GLOBAL__N_122StoredDiagnosticClientD0Ev", "(anonymous namespace)::StoredDiagnosticClient::~StoredDiagnosticClient()"},
    {"_ZN12_GLOBAL__N_122StoredDiagnosticClient16HandleDiagnosticEN5clang10Diagnostic5LevelERKNS1_14DiagnosticInfoE", "(anonymous namespace)::StoredDiagnosticClient::HandleDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_ZN12_GLOBAL__N_124PrecompilePreambleAction17CreateASTConsumerERN5clang16CompilerInstanceEN4llvm9StringRefE", "(anonymous namespace)::PrecompilePreambleAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_124PrecompilePreambleActionD1Ev", "(anonymous namespace)::PrecompilePreambleAction::~PrecompilePreambleAction()"},
    {"_ZN12_GLOBAL__N_124PrecompilePreambleActionD0Ev", "(anonymous namespace)::PrecompilePreambleAction::~PrecompilePreambleAction()"},
    {"_ZN12_GLOBAL__N_124PrecompilePreambleAction27usesCompleteTranslationUnitEv", "(anonymous namespace)::PrecompilePreambleAction::usesCompleteTranslationUnit()"},
    {"_ZNK12_GLOBAL__N_124PrecompilePreambleAction17hasASTFileSupportEv", "(anonymous namespace)::PrecompilePreambleAction::hasASTFileSupport() const"},
    {"_ZNK12_GLOBAL__N_124PrecompilePreambleAction24hasCodeCompletionSupportEv", "(anonymous namespace)::PrecompilePreambleAction::hasCodeCompletionSupport() const"},
    {"_ZN12_GLOBAL__N_126PrecompilePreambleConsumerD1Ev", "(anonymous namespace)::PrecompilePreambleConsumer::~PrecompilePreambleConsumer()"},
    {"_ZN12_GLOBAL__N_126PrecompilePreambleConsumerD0Ev", "(anonymous namespace)::PrecompilePreambleConsumer::~PrecompilePreambleConsumer()"},
    {"_ZN12_GLOBAL__N_126PrecompilePreambleConsumer18HandleTopLevelDeclEN5clang12DeclGroupRefE", "(anonymous namespace)::PrecompilePreambleConsumer::HandleTopLevelDecl(clang::DeclGroupRef)"},
    {"_ZN12_GLOBAL__N_126PrecompilePreambleConsumer21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::PrecompilePreambleConsumer::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_126PrecompilePreambleConsumer27GetASTSerializationListenerEv", "(anonymous namespace)::PrecompilePreambleConsumer::GetASTSerializationListener()"},
    {"_ZN12_GLOBAL__N_126PrecompilePreambleConsumer28SerializedPreprocessedEntityEPN5clang18PreprocessedEntityEy", "(anonymous namespace)::PrecompilePreambleConsumer::SerializedPreprocessedEntity(clang::PreprocessedEntity*, unsigned long long)"},
    {"_ZThn1912_N12_GLOBAL__N_126PrecompilePreambleConsumerD1Ev", "non-virtual thunk to (anonymous namespace)::PrecompilePreambleConsumer::~PrecompilePreambleConsumer()"},
    {"_ZThn1912_N12_GLOBAL__N_126PrecompilePreambleConsumerD0Ev", "non-virtual thunk to (anonymous namespace)::PrecompilePreambleConsumer::~PrecompilePreambleConsumer()"},
    {"_ZThn1912_N12_GLOBAL__N_126PrecompilePreambleConsumer28SerializedPreprocessedEntityEPN5clang18PreprocessedEntityEy", "non-virtual thunk to (anonymous namespace)::PrecompilePreambleConsumer::SerializedPreprocessedEntity(clang::PreprocessedEntity*, unsigned long long)"},
    {"_ZN12_GLOBAL__N_125TopLevelDeclTrackerAction17CreateASTConsumerERN5clang16CompilerInstanceEN4llvm9StringRefE", "(anonymous namespace)::TopLevelDeclTrackerAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_125TopLevelDeclTrackerActionD1Ev", "(anonymous namespace)::TopLevelDeclTrackerAction::~TopLevelDeclTrackerAction()"},
    {"_ZN12_GLOBAL__N_125TopLevelDeclTrackerActionD0Ev", "(anonymous namespace)::TopLevelDeclTrackerAction::~TopLevelDeclTrackerAction()"},
    {"_ZN12_GLOBAL__N_125TopLevelDeclTrackerAction27usesCompleteTranslationUnitEv", "(anonymous namespace)::TopLevelDeclTrackerAction::usesCompleteTranslationUnit()"},
    {"_ZNK12_GLOBAL__N_125TopLevelDeclTrackerAction24hasCodeCompletionSupportEv", "(anonymous namespace)::TopLevelDeclTrackerAction::hasCodeCompletionSupport() const"},
    {"_ZN12_GLOBAL__N_127TopLevelDeclTrackerConsumerD1Ev", "(anonymous namespace)::TopLevelDeclTrackerConsumer::~TopLevelDeclTrackerConsumer()"},
    {"_ZN12_GLOBAL__N_127TopLevelDeclTrackerConsumerD0Ev", "(anonymous namespace)::TopLevelDeclTrackerConsumer::~TopLevelDeclTrackerConsumer()"},
    {"_ZN12_GLOBAL__N_127TopLevelDeclTrackerConsumer18HandleTopLevelDeclEN5clang12DeclGroupRefE", "(anonymous namespace)::TopLevelDeclTrackerConsumer::HandleTopLevelDecl(clang::DeclGroupRef)"},
    {"_ZN12_GLOBAL__N_127TopLevelDeclTrackerConsumer21HandleInterestingDeclEN5clang12DeclGroupRefE", "(anonymous namespace)::TopLevelDeclTrackerConsumer::HandleInterestingDecl(clang::DeclGroupRef)"},
    {"_ZN12_GLOBAL__N_116ASTInfoCollectorD1Ev", "(anonymous namespace)::ASTInfoCollector::~ASTInfoCollector()"},
    {"_ZN12_GLOBAL__N_116ASTInfoCollectorD0Ev", "(anonymous namespace)::ASTInfoCollector::~ASTInfoCollector()"},
    {"_ZN12_GLOBAL__N_116ASTInfoCollector19ReadLanguageOptionsERKN5clang11LangOptionsE", "(anonymous namespace)::ASTInfoCollector::ReadLanguageOptions(clang::LangOptions const&)"},
    {"_ZN12_GLOBAL__N_116ASTInfoCollector16ReadTargetTripleEN4llvm9StringRefE", "(anonymous namespace)::ASTInfoCollector::ReadTargetTriple(llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_116ASTInfoCollector20ReadPredefinesBufferERKN4llvm11SmallVectorIN5clang18PCHPredefinesBlockELj2EEENS1_9StringRefERSs", "(anonymous namespace)::ASTInfoCollector::ReadPredefinesBuffer(llvm::SmallVector<clang::PCHPredefinesBlock, 2u> const&, llvm::StringRef, std::string&)"},
    {"_ZN12_GLOBAL__N_116ASTInfoCollector18ReadHeaderFileInfoERKN5clang14HeaderFileInfoEj", "(anonymous namespace)::ASTInfoCollector::ReadHeaderFileInfo(clang::HeaderFileInfo const&, unsigned int)"},
    {"_ZN12_GLOBAL__N_116ASTInfoCollector11ReadCounterEj", "(anonymous namespace)::ASTInfoCollector::ReadCounter(unsigned int)"},
    {"_ZN5clang19PreprocessorOptions15addRemappedFileEN4llvm9StringRefEPKNS1_12MemoryBufferE", "clang::PreprocessorOptions::addRemappedFile(llvm::StringRef, llvm::MemoryBuffer const*)"},
    {"_ZN4llvm15SmallVectorImplIPKcE6insertIPS2_EES5_S5_T_S6_", "char const** llvm::SmallVectorImpl<char const*>::insert<char const**>(char const**, char const**, char const**)"},
    {"_ZN4llvm15SmallVectorImplIN5clang16StoredDiagnosticEE4swapERS3_", "llvm::SmallVectorImpl<clang::StoredDiagnostic>::swap(llvm::SmallVectorImpl<clang::StoredDiagnostic>&)"},
    {"_ZN5clang11LangOptionsaSERKS0_", "clang::LangOptions::operator=(clang::LangOptions const&)"},
    {"_ZN4llvm15SmallVectorImplIN5clang16StoredDiagnosticEE6insertIPS2_EES5_S5_T_S6_", "clang::StoredDiagnostic* llvm::SmallVectorImpl<clang::StoredDiagnostic>::insert<clang::StoredDiagnostic*>(clang::StoredDiagnostic*, clang::StoredDiagnostic*, clang::StoredDiagnostic*)"},
    {"_ZN4llvm15SmallVectorImplIN5clang16StoredDiagnosticEE9push_backERKS2_", "llvm::SmallVectorImpl<clang::StoredDiagnostic>::push_back(clang::StoredDiagnostic const&)"},
    {"_ZN5clang9ASTWriterD1Ev", "clang::ASTWriter::~ASTWriter()"},
    {"_ZN4llvm15SmallVectorImplIN5clang16StoredDiagnosticEE6appendIPS2_EEvT_S6_", "void llvm::SmallVectorImpl<clang::StoredDiagnostic>::append<clang::StoredDiagnostic*>(clang::StoredDiagnostic*, clang::StoredDiagnostic*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang16StoredDiagnosticELb0EE18uninitialized_copyIPS2_S5_EEvT_S6_T0_", "void llvm::SmallVectorTemplateBase<clang::StoredDiagnostic, false>::uninitialized_copy<clang::StoredDiagnostic*, clang::StoredDiagnostic*>(clang::StoredDiagnostic*, clang::StoredDiagnostic*, clang::StoredDiagnostic*)"},
    {"_ZNSt6vectorIN5clang15CharSourceRangeESaIS1_EEaSERKS3_", "std::vector<clang::CharSourceRange, std::allocator<clang::CharSourceRange>>::operator=(std::vector<clang::CharSourceRange, std::allocator<clang::CharSourceRange>> const&)"},
    {"_ZNSt6vectorIN5clang9FixItHintESaIS1_EEaSERKS3_", "std::vector<clang::FixItHint, std::allocator<clang::FixItHint>>::operator=(std::vector<clang::FixItHint, std::allocator<clang::FixItHint>> const&)"},
    {"_ZNSt6vectorIN5clang9FixItHintESaIS1_EEC2ERKS3_", "std::vector<clang::FixItHint, std::allocator<clang::FixItHint>>::vector(std::vector<clang::FixItHint, std::allocator<clang::FixItHint>> const&)"},
    {"_ZNSt6vectorIN5clang15CharSourceRangeESaIS1_EEC2ERKS3_", "std::vector<clang::CharSourceRange, std::allocator<clang::CharSourceRange>>::vector(std::vector<clang::CharSourceRange, std::allocator<clang::CharSourceRange>> const&)"},
    {"_ZNSt6__copyILb0ESt26random_access_iterator_tagE4copyIPN5clang16StoredDiagnosticES5_EET0_T_S7_S6_", "clang::StoredDiagnostic* std::__copy<false, std::random_access_iterator_tag>::copy<clang::StoredDiagnostic*, clang::StoredDiagnostic*>(clang::StoredDiagnostic*, clang::StoredDiagnostic*, clang::StoredDiagnostic*)"},
    {"_ZNSt15__copy_backwardILb0ESt26random_access_iterator_tagE8__copy_bIPN5clang16StoredDiagnosticES5_EET0_T_S7_S6_", "clang::StoredDiagnostic* std::__copy_backward<false, std::random_access_iterator_tag>::__copy_b<clang::StoredDiagnostic*, clang::StoredDiagnostic*>(clang::StoredDiagnostic*, clang::StoredDiagnostic*, clang::StoredDiagnostic*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang16StoredDiagnosticELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::StoredDiagnostic, false>::grow(unsigned long)"},
    {"_ZNSt6vectorIPN5clang18PreprocessedEntityESaIS2_EE15_M_range_insertIN9__gnu_cxx17__normal_iteratorIPS2_S4_EEEEvS9_T_SA_St20forward_iterator_tag", "void std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>::_M_range_insert<__gnu_cxx::__normal_iterator<clang::PreprocessedEntity**, std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>>>(__gnu_cxx::__normal_iterator<clang::PreprocessedEntity**, std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>>, __gnu_cxx::__normal_iterator<clang::PreprocessedEntity**, std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>>, __gnu_cxx::__normal_iterator<clang::PreprocessedEntity**, std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>>, std::forward_iterator_tag)"},
    {"_ZNSt6vectorIPN5clang18PreprocessedEntityESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::PreprocessedEntity**, std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>>, clang::PreprocessedEntity* const&)"},
    {"_ZNSt6vectorIPN5clang4DeclESaIS2_EE15_M_range_insertIN9__gnu_cxx17__normal_iteratorIPS2_S4_EEEEvS9_T_SA_St20forward_iterator_tag", "void std::vector<clang::Decl*, std::allocator<clang::Decl*>>::_M_range_insert<__gnu_cxx::__normal_iterator<clang::Decl**, std::vector<clang::Decl*, std::allocator<clang::Decl*>>>>(__gnu_cxx::__normal_iterator<clang::Decl**, std::vector<clang::Decl*, std::allocator<clang::Decl*>>>, __gnu_cxx::__normal_iterator<clang::Decl**, std::vector<clang::Decl*, std::allocator<clang::Decl*>>>, __gnu_cxx::__normal_iterator<clang::Decl**, std::vector<clang::Decl*, std::allocator<clang::Decl*>>>, std::forward_iterator_tag)"},
    {"_ZN4llvm9StringMapISt4pairIxlENS_15MallocAllocatorEE16GetOrCreateValueIS2_EERNS_14StringMapEntryIS2_EENS_9StringRefET_", "llvm::StringMapEntry<std::pair<long long, long>>& llvm::StringMap<std::pair<long long, long>, llvm::MallocAllocator>::GetOrCreateValue<std::pair<long long, long>>(llvm::StringRef, std::pair<long long, long>)"},
    {"_ZNSt8_Rb_treeIN5clang6FileIDESt4pairIKS1_St6vectorIPNS0_18PreprocessedEntityESaIS6_EEESt10_Select1stIS9_ESt4lessIS1_ESaIS9_EE8_M_eraseEPSt13_Rb_tree_nodeIS9_E", "std::_Rb_tree<clang::FileID, std::pair<clang::FileID const, std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>>, std::_Select1st<std::pair<clang::FileID const, std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>>>, std::less<clang::FileID>, std::allocator<std::pair<clang::FileID const, std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::FileID const, std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>>>*)"},
    {"_ZNSt6vectorIN5clang7ASTUnit26CachedCodeCompletionResultESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::ASTUnit::CachedCodeCompletionResult, std::allocator<clang::ASTUnit::CachedCodeCompletionResult>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::ASTUnit::CachedCodeCompletionResult*, std::vector<clang::ASTUnit::CachedCodeCompletionResult, std::allocator<clang::ASTUnit::CachedCodeCompletionResult>>>, clang::ASTUnit::CachedCodeCompletionResult const&)"},
    {"_ZN4llvm8DenseMapIN5clang7CanQualINS1_4TypeEEEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::CanQual<clang::Type>, unsigned int, llvm::DenseMapInfo<clang::CanQual<clang::Type>>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::CanQual<clang::Type> const&, unsigned int const&, std::pair<clang::CanQual<clang::Type>, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIN5clang7CanQualINS1_4TypeEEEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::CanQual<clang::Type>, unsigned int, llvm::DenseMapInfo<clang::CanQual<clang::Type>>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZNSt6vectorIPN5clang4DeclESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::Decl*, std::allocator<clang::Decl*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::Decl**, std::vector<clang::Decl*, std::allocator<clang::Decl*>>>, clang::Decl* const&)"},
    {"_ZN4llvm15BitstreamWriterD2Ev", "llvm::BitstreamWriter::~BitstreamWriter()"},
    {"_ZThn8_N5clang9ASTWriterD1Ev", "non-virtual thunk to clang::ASTWriter::~ASTWriter()"},
    {"_ZN5clang9ASTWriterD2Ev", "clang::ASTWriter::~ASTWriter()"},
    {"_ZN5clang9ASTWriterD0Ev", "clang::ASTWriter::~ASTWriter()"},
    {"_ZThn8_N5clang9ASTWriterD0Ev", "non-virtual thunk to clang::ASTWriter::~ASTWriter()"},
    {"_ZNSt8_Rb_treeIPN5clang10SwitchCaseESt4pairIKS2_jESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<clang::SwitchCase*, std::pair<clang::SwitchCase* const, unsigned int>, std::_Select1st<std::pair<clang::SwitchCase* const, unsigned int>>, std::less<clang::SwitchCase*>, std::allocator<std::pair<clang::SwitchCase* const, unsigned int>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::SwitchCase* const, unsigned int>>*)"},
    {"_ZNSt8_Rb_treeIPN5clang9LabelStmtESt4pairIKS2_jESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<clang::LabelStmt*, std::pair<clang::LabelStmt* const, unsigned int>, std::_Select1st<std::pair<clang::LabelStmt* const, unsigned int>>, std::less<clang::LabelStmt*>, std::allocator<std::pair<clang::LabelStmt* const, unsigned int>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::LabelStmt* const, unsigned int>>*)"},
    {"_ZN4llvm15SmallVectorImplIN5clang20CodeCompletionResultEE6insertIPS2_EES5_S5_T_S6_", "clang::CodeCompletionResult* llvm::SmallVectorImpl<clang::CodeCompletionResult>::insert<clang::CodeCompletionResult*>(clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang20CodeCompletionResultELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::CodeCompletionResult, false>::grow(unsigned long)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang20CodeCompletionString5ChunkELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::CodeCompletionString::Chunk, false>::grow(unsigned long)"},
    {"_ZN4llvm9StringSetINS_16BumpPtrAllocatorEE6insertENS_9StringRefE", "llvm::StringSet<llvm::BumpPtrAllocator>::insert(llvm::StringRef)"},
    {"_ZNSt6vectorISt4pairISsSsESaIS1_EE5clearEv", "std::vector<std::pair<std::string, std::string>, std::allocator<std::pair<std::string, std::string>>>::clear()"},
    {"_ZN5clang18CompilerInvocationC2ERKS0_", "clang::CompilerInvocation::CompilerInvocation(clang::CompilerInvocation const&)"},
    {"_ZN5clang19PreprocessorOptionsC2ERKS0_", "clang::PreprocessorOptions::PreprocessorOptions(clang::PreprocessorOptions const&)"},
    {"_ZNSt6vectorISt4pairISsPKN4llvm12MemoryBufferEESaIS5_EEC2ERKS7_", "std::vector<std::pair<std::string, llvm::MemoryBuffer const*>, std::allocator<std::pair<std::string, llvm::MemoryBuffer const*>>>::vector(std::vector<std::pair<std::string, llvm::MemoryBuffer const*>, std::allocator<std::pair<std::string, llvm::MemoryBuffer const*>>> const&)"},
    {"_ZNSt6vectorISt4pairISsSsESaIS1_EEC2ERKS3_", "std::vector<std::pair<std::string, std::string>, std::allocator<std::pair<std::string, std::string>>>::vector(std::vector<std::pair<std::string, std::string>, std::allocator<std::pair<std::string, std::string>>> const&)"},
    {"_ZNSt6vectorISt4pairISsbESaIS1_EEC2ERKS3_", "std::vector<std::pair<std::string, bool>, std::allocator<std::pair<std::string, bool>>>::vector(std::vector<std::pair<std::string, bool>, std::allocator<std::pair<std::string, bool>>> const&)"},
    {"_ZNSt6vectorIN5clang19HeaderSearchOptions5EntryESaIS2_EEC2ERKS4_", "std::vector<clang::HeaderSearchOptions::Entry, std::allocator<clang::HeaderSearchOptions::Entry>>::vector(std::vector<clang::HeaderSearchOptions::Entry, std::allocator<clang::HeaderSearchOptions::Entry>> const&)"},
    {"_ZN5clang15FrontendOptionsC2ERKS0_", "clang::FrontendOptions::FrontendOptions(clang::FrontendOptions const&)"},
    {"_ZNSt6vectorIS_ISsSaISsEESaIS1_EEC2ERKS3_", "std::vector<std::vector<std::string, std::allocator<std::string>>, std::allocator<std::vector<std::string, std::allocator<std::string>>>>::vector(std::vector<std::vector<std::string, std::allocator<std::string>>, std::allocator<std::vector<std::string, std::allocator<std::string>>>> const&)"},
    {"_ZNSt6vectorISt4pairIN5clang9InputKindESsESaIS3_EEC2ERKS5_", "std::vector<std::pair<clang::InputKind, std::string>, std::allocator<std::pair<clang::InputKind, std::string>>>::vector(std::vector<std::pair<clang::InputKind, std::string>, std::allocator<std::pair<clang::InputKind, std::string>>> const&)"},
    {"_ZN5clang17DiagnosticOptionsC2ERKS0_", "clang::DiagnosticOptions::DiagnosticOptions(clang::DiagnosticOptions const&)"},
    {"_ZN5clang14CodeGenOptionsC2ERKS0_", "clang::CodeGenOptions::CodeGenOptions(clang::CodeGenOptions const&)"},
    {"_ZN5clang15AnalyzerOptionsC2ERKS0_", "clang::AnalyzerOptions::AnalyzerOptions(clang::AnalyzerOptions const&)"},
    {"_ZNSt6vectorIN5clang8AnalysesESaIS1_EEC2ERKS3_", "std::vector<clang::Analyses, std::allocator<clang::Analyses>>::vector(std::vector<clang::Analyses, std::allocator<clang::Analyses>> const&)"},
    {"_ZN5clang12PCHGenerator14InitializeSemaERNS_4SemaE", "clang::PCHGenerator::InitializeSema(clang::Sema&)"},
    {"_ZNSt6vectorIySaIyEE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPyS1_EERKy", "std::vector<unsigned long long, std::allocator<unsigned long long>>::_M_insert_aux(__gnu_cxx::__normal_iterator<unsigned long long*, std::vector<unsigned long long, std::allocator<unsigned long long>>>, unsigned long long const&)"},
    {"_ZN5clang12PCHGeneratorD1Ev", "clang::PCHGenerator::~PCHGenerator()"},
    {"_ZN5clang12PCHGeneratorD0Ev", "clang::PCHGenerator::~PCHGenerator()"},
    {"_ZNSt6vectorISt4pairISsPKN4llvm12MemoryBufferEESaIS5_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS5_S7_EERKS5_", "std::vector<std::pair<std::string, llvm::MemoryBuffer const*>, std::allocator<std::pair<std::string, llvm::MemoryBuffer const*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<std::string, llvm::MemoryBuffer const*>*, std::vector<std::pair<std::string, llvm::MemoryBuffer const*>, std::allocator<std::pair<std::string, llvm::MemoryBuffer const*>>>>, std::pair<std::string, llvm::MemoryBuffer const*> const&)"},
    {"_ZN5clang14BoostConAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::BoostConAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_119BoostConASTConsumerD1Ev", "(anonymous namespace)::BoostConASTConsumer::~BoostConASTConsumer()"},
    {"_ZN12_GLOBAL__N_119BoostConASTConsumerD0Ev", "(anonymous namespace)::BoostConASTConsumer::~BoostConASTConsumer()"},
    {"_ZN12_GLOBAL__N_119BoostConASTConsumer21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::BoostConASTConsumer::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE12TraverseDeclEPNS_4DeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::TraverseDecl(clang::Decl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE12TraverseStmtEPNS_4StmtE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::TraverseStmt(clang::Stmt*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE15TraverseTypeLocENS_7TypeLocE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::TraverseTypeLoc(clang::TypeLoc)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE27TraverseNestedNameSpecifierEPNS_19NestedNameSpecifierE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::TraverseNestedNameSpecifier(clang::NestedNameSpecifier*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE27TraverseTemplateArgumentLocERKNS_19TemplateArgumentLocE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::TraverseTemplateArgumentLoc(clang::TemplateArgumentLoc const&)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE24TraverseTemplateArgumentERKNS_16TemplateArgumentE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::TraverseTemplateArgument(clang::TemplateArgument const&)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE12TraverseTypeENS_8QualTypeE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::TraverseType(clang::QualType)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE24TraverseDeclaratorHelperEPNS_14DeclaratorDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::TraverseDeclaratorHelper(clang::DeclaratorDecl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE22TraverseFunctionHelperEPNS_12FunctionDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::TraverseFunctionHelper(clang::FunctionDecl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE23TraverseCXXRecordHelperEPNS_13CXXRecordDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::TraverseCXXRecordHelper(clang::CXXRecordDecl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119BoostConASTConsumerEE23WalkUpFromCXXRecordDeclEPNS_13CXXRecordDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::BoostConASTConsumer>::WalkUpFromCXXRecordDecl(clang::CXXRecordDecl*)"},
    {"_ZN5clang14BoostConActionD1Ev", "clang::BoostConAction::~BoostConAction()"},
    {"_ZN5clang14BoostConActionD0Ev", "clang::BoostConAction::~BoostConAction()"},
    {"_ZNK5clang38DependentTemplateSpecializationTypeLoc9getArgLocEj", "clang::DependentTemplateSpecializationTypeLoc::getArgLoc(unsigned int) const"},
    {"_ZNK5clang29TemplateSpecializationTypeLoc9getArgLocEj", "clang::TemplateSpecializationTypeLoc::getArgLoc(unsigned int) const"},
    {"_ZN5clang11CacheTokensERNS_12PreprocessorEPN4llvm14raw_fd_ostreamE", "clang::CacheTokens(clang::Preprocessor&, llvm::raw_fd_ostream*)"},
    {"_ZN5clang31OnDiskChainedHashTableGeneratorIN12_GLOBAL__N_121FileEntryPTHEntryInfoEE6insertENS1_18PTHEntryKeyVariantERKNS1_8PTHEntryE", "clang::OnDiskChainedHashTableGenerator<(anonymous namespace)::FileEntryPTHEntryInfo>::insert((anonymous namespace)::PTHEntryKeyVariant, (anonymous namespace)::PTHEntry const&)"},
    {"_ZN12_GLOBAL__N_19PTHWriter9EmitTokenERKN5clang5TokenE", "(anonymous namespace)::PTHWriter::EmitToken(clang::Token const&)"},
    {"_ZN12_GLOBAL__N_112StatListenerD1Ev", "(anonymous namespace)::StatListener::~StatListener()"},
    {"_ZN12_GLOBAL__N_112StatListenerD0Ev", "(anonymous namespace)::StatListener::~StatListener()"},
    {"_ZN12_GLOBAL__N_112StatListener7getStatEPKcR4statPi", "(anonymous namespace)::StatListener::getStat(char const*, stat&, int*)"},
    {"_ZN5clang2io6Emit32ERN4llvm11raw_ostreamEj", "clang::io::Emit32(llvm::raw_ostream&, unsigned int)"},
    {"_ZN5clang2io6Emit64ERN4llvm11raw_ostreamEy", "clang::io::Emit64(llvm::raw_ostream&, unsigned long long)"},
    {"_ZN4llvm8DenseMapIPKN5clang14IdentifierInfoEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::IdentifierInfo const*, unsigned int, llvm::DenseMapInfo<clang::IdentifierInfo const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::IdentifierInfo const* const&, unsigned int const&, std::pair<clang::IdentifierInfo const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang14IdentifierInfoEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::IdentifierInfo const*, unsigned int, llvm::DenseMapInfo<clang::IdentifierInfo const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN5clang16CompilerInstanceC1Ev", "clang::CompilerInstance::CompilerInstance()"},
    {"_ZN5clang16CompilerInstanceC2Ev", "clang::CompilerInstance::CompilerInstance()"},
    {"_ZN5clang16CompilerInstanceD1Ev", "clang::CompilerInstance::~CompilerInstance()"},
    {"_ZN5clang16CompilerInstanceD2Ev", "clang::CompilerInstance::~CompilerInstance()"},
    {"_ZN5clang16CompilerInstance14setLLVMContextEPN4llvm11LLVMContextE", "clang::CompilerInstance::setLLVMContext(llvm::LLVMContext*)"},
    {"_ZN5clang16CompilerInstance13setInvocationEPNS_18CompilerInvocationE", "clang::CompilerInstance::setInvocation(clang::CompilerInvocation*)"},
    {"_ZN5clang16CompilerInstance14setDiagnosticsEPNS_10DiagnosticE", "clang::CompilerInstance::setDiagnostics(clang::Diagnostic*)"},
    {"_ZN5clang16CompilerInstance9setTargetEPNS_10TargetInfoE", "clang::CompilerInstance::setTarget(clang::TargetInfo*)"},
    {"_ZN5clang16CompilerInstance14setFileManagerEPNS_11FileManagerE", "clang::CompilerInstance::setFileManager(clang::FileManager*)"},
    {"_ZN5clang16CompilerInstance16setSourceManagerEPNS_13SourceManagerE", "clang::CompilerInstance::setSourceManager(clang::SourceManager*)"},
    {"_ZN5clang16CompilerInstance15setPreprocessorEPNS_12PreprocessorE", "clang::CompilerInstance::setPreprocessor(clang::Preprocessor*)"},
    {"_ZN5clang16CompilerInstance13setASTContextEPNS_10ASTContextE", "clang::CompilerInstance::setASTContext(clang::ASTContext*)"},
    {"_ZN5clang16CompilerInstance7setSemaEPNS_4SemaE", "clang::CompilerInstance::setSema(clang::Sema*)"},
    {"_ZN5clang16CompilerInstance14setASTConsumerEPNS_11ASTConsumerE", "clang::CompilerInstance::setASTConsumer(clang::ASTConsumer*)"},
    {"_ZN5clang16CompilerInstance25setCodeCompletionConsumerEPNS_20CodeCompleteConsumerE", "clang::CompilerInstance::setCodeCompletionConsumer(clang::CodeCompleteConsumer*)"},
    {"_ZN5clang16CompilerInstance17createDiagnosticsEiPKPKcPNS_16DiagnosticClientE", "clang::CompilerInstance::createDiagnostics(int, char const* const*, clang::DiagnosticClient*)"},
    {"_ZN5clang16CompilerInstance17createDiagnosticsERKNS_17DiagnosticOptionsEiPKPKcPNS_16DiagnosticClientE", "clang::CompilerInstance::createDiagnostics(clang::DiagnosticOptions const&, int, char const* const*, clang::DiagnosticClient*)"},
    {"_ZN5clang16CompilerInstance17createFileManagerEv", "clang::CompilerInstance::createFileManager()"},
    {"_ZN5clang16CompilerInstance19createSourceManagerERNS_11FileManagerE", "clang::CompilerInstance::createSourceManager(clang::FileManager&)"},
    {"_ZN5clang16CompilerInstance18createPreprocessorEv", "clang::CompilerInstance::createPreprocessor()"},
    {"_ZN5clang16CompilerInstance18createPreprocessorERNS_10DiagnosticERKNS_11LangOptionsERKNS_19PreprocessorOptionsERKNS_19HeaderSearchOptionsERKNS_23DependencyOutputOptionsERKNS_10TargetInfoERKNS_15FrontendOptionsERNS_13SourceManagerERNS_11FileManagerE", "clang::CompilerInstance::createPreprocessor(clang::Diagnostic&, clang::LangOptions const&, clang::PreprocessorOptions const&, clang::HeaderSearchOptions const&, clang::DependencyOutputOptions const&, clang::TargetInfo const&, clang::FrontendOptions const&, clang::SourceManager&, clang::FileManager&)"},
    {"_ZN5clang16CompilerInstance16createASTContextEv", "clang::CompilerInstance::createASTContext()"},
    {"_ZN5clang16CompilerInstance26createPCHExternalASTSourceEN4llvm9StringRefEbbPv", "clang::CompilerInstance::createPCHExternalASTSource(llvm::StringRef, bool, bool, void*)"},
    {"_ZN5clang16CompilerInstance26createPCHExternalASTSourceEN4llvm9StringRefERKSsbbRNS_12PreprocessorERNS_10ASTContextEPvb", "clang::CompilerInstance::createPCHExternalASTSource(llvm::StringRef, std::string const&, bool, bool, clang::Preprocessor&, clang::ASTContext&, void*, bool)"},
    {"_ZN5clang16CompilerInstance28createCodeCompletionConsumerEv", "clang::CompilerInstance::createCodeCompletionConsumer()"},
    {"_ZN5clang16CompilerInstance28createCodeCompletionConsumerERNS_12PreprocessorERKSsjjbbbRN4llvm11raw_ostreamE", "clang::CompilerInstance::createCodeCompletionConsumer(clang::Preprocessor&, std::string const&, unsigned int, unsigned int, bool, bool, bool, llvm::raw_ostream&)"},
    {"_Z20EnableCodeCompletionRN5clang12PreprocessorERKSsjj", "EnableCodeCompletion(clang::Preprocessor&, std::string const&, unsigned int, unsigned int)"},
    {"_ZN5clang16CompilerInstance19createFrontendTimerEv", "clang::CompilerInstance::createFrontendTimer()"},
    {"_ZN5clang16CompilerInstance10createSemaEbPNS_20CodeCompleteConsumerE", "clang::CompilerInstance::createSema(bool, clang::CodeCompleteConsumer*)"},
    {"_ZN5clang16CompilerInstance13addOutputFileERKNS0_10OutputFileE", "clang::CompilerInstance::addOutputFile(clang::CompilerInstance::OutputFile const&)"},
    {"_ZN5clang16CompilerInstance16clearOutputFilesEb", "clang::CompilerInstance::clearOutputFiles(bool)"},
    {"_ZN5clang16CompilerInstance23createDefaultOutputFileEbN4llvm9StringRefES2_", "clang::CompilerInstance::createDefaultOutputFile(bool, llvm::StringRef, llvm::StringRef)"},
    {"_ZN5clang16CompilerInstance16createOutputFileEN4llvm9StringRefEbbS2_S2_", "clang::CompilerInstance::createOutputFile(llvm::StringRef, bool, bool, llvm::StringRef, llvm::StringRef)"},
    {"_ZN5clang16CompilerInstance16createOutputFileEN4llvm9StringRefERSsbbS2_S2_PSsS4_", "clang::CompilerInstance::createOutputFile(llvm::StringRef, std::string&, bool, bool, llvm::StringRef, llvm::StringRef, std::string*, std::string*)"},
    {"_ZN5clang16CompilerInstance23InitializeSourceManagerEN4llvm9StringRefE", "clang::CompilerInstance::InitializeSourceManager(llvm::StringRef)"},
    {"_ZN5clang16CompilerInstance23InitializeSourceManagerEN4llvm9StringRefERNS_10DiagnosticERNS_11FileManagerERNS_13SourceManagerERKNS_15FrontendOptionsE", "clang::CompilerInstance::InitializeSourceManager(llvm::StringRef, clang::Diagnostic&, clang::FileManager&, clang::SourceManager&, clang::FrontendOptions const&)"},
    {"_ZN5clang16CompilerInstance13ExecuteActionERNS_14FrontendActionE", "clang::CompilerInstance::ExecuteAction(clang::FrontendAction&)"},
    {"_ZNSt10_List_baseIN5clang16CompilerInstance10OutputFileESaIS2_EE8_M_clearEv", "std::_List_base<clang::CompilerInstance::OutputFile, std::allocator<clang::CompilerInstance::OutputFile>>::_M_clear()"},
    {"_ZN5clang28PrintingCodeCompleteConsumer12getAllocatorEv", "clang::PrintingCodeCompleteConsumer::getAllocator()"},
    {"_ZN5clang20CodeCompleteConsumer26ProcessCodeCompleteResultsERNS_4SemaENS_21CodeCompletionContextEPNS_20CodeCompletionResultEj", "clang::CodeCompleteConsumer::ProcessCodeCompleteResults(clang::Sema&, clang::CodeCompletionContext, clang::CodeCompletionResult*, unsigned int)"},
    {"_ZN5clang20CodeCompleteConsumer25ProcessOverloadCandidatesERNS_4SemaEjPNS0_17OverloadCandidateEj", "clang::CodeCompleteConsumer::ProcessOverloadCandidates(clang::Sema&, unsigned int, clang::CodeCompleteConsumer::OverloadCandidate*, unsigned int)"},
    {"_ZN5clang23ChainedDiagnosticClientD1Ev", "clang::ChainedDiagnosticClient::~ChainedDiagnosticClient()"},
    {"_ZN5clang23ChainedDiagnosticClientD0Ev", "clang::ChainedDiagnosticClient::~ChainedDiagnosticClient()"},
    {"_ZN5clang23ChainedDiagnosticClient15BeginSourceFileERKNS_11LangOptionsEPKNS_12PreprocessorE", "clang::ChainedDiagnosticClient::BeginSourceFile(clang::LangOptions const&, clang::Preprocessor const*)"},
    {"_ZN5clang23ChainedDiagnosticClient13EndSourceFileEv", "clang::ChainedDiagnosticClient::EndSourceFile()"},
    {"_ZNK5clang23ChainedDiagnosticClient25IncludeInDiagnosticCountsEv", "clang::ChainedDiagnosticClient::IncludeInDiagnosticCounts() const"},
    {"_ZN5clang23ChainedDiagnosticClient16HandleDiagnosticENS_10Diagnostic5LevelERKNS_14DiagnosticInfoE", "clang::ChainedDiagnosticClient::HandleDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_ZN5clang18CompilerInvocation6toArgsERSt6vectorISsSaISsEE", "clang::CompilerInvocation::toArgs(std::vector<std::string, std::allocator<std::string>>&)"},
    {"_ZN5clang18CompilerInvocation16GetResourcesPathEPKcPv", "clang::CompilerInvocation::GetResourcesPath(char const*, void*)"},
    {"_ZN5clang18CompilerInvocation15setLangDefaultsERNS_11LangOptionsENS_9InputKindENS_12LangStandard4KindE", "clang::CompilerInvocation::setLangDefaults(clang::LangOptions&, clang::InputKind, clang::LangStandard::Kind)"},
    {"_ZN5clang18CompilerInvocation14CreateFromArgsERS0_PKPKcS5_RNS_10DiagnosticE", "clang::CompilerInvocation::CreateFromArgs(clang::CompilerInvocation&, char const* const*, char const* const*, clang::Diagnostic&)"},
    {"_ZN5clang19PreprocessorOptions11addMacroDefEN4llvm9StringRefE", "clang::PreprocessorOptions::addMacroDef(llvm::StringRef)"},
    {"_ZN5clang19PreprocessorOptions13addMacroUndefEN4llvm9StringRefE", "clang::PreprocessorOptions::addMacroUndef(llvm::StringRef)"},
    {"_ZN5clang19PreprocessorOptions15addRemappedFileEN4llvm9StringRefES2_", "clang::PreprocessorOptions::addRemappedFile(llvm::StringRef, llvm::StringRef)"},
    {"_ZNSt6vectorISt4pairISsSsESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<std::pair<std::string, std::string>, std::allocator<std::pair<std::string, std::string>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<std::string, std::string>*, std::vector<std::pair<std::string, std::string>, std::allocator<std::pair<std::string, std::string>>>>, std::pair<std::string, std::string> const&)"},
    {"_ZNSt6vectorISsSaISsEE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSsS1_EERKSs", "std::vector<std::string, std::allocator<std::string>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::string*, std::vector<std::string, std::allocator<std::string>>>, std::string const&)"},
    {"_ZNSt6vectorISt4pairISsbESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<std::pair<std::string, bool>, std::allocator<std::pair<std::string, bool>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<std::string, bool>*, std::vector<std::pair<std::string, bool>, std::allocator<std::pair<std::string, bool>>>>, std::pair<std::string, bool> const&)"},
    {"_ZN5clang19HeaderSearchOptions7AddPathEN4llvm9StringRefENS_8frontend15IncludeDirGroupEbbb", "clang::HeaderSearchOptions::AddPath(llvm::StringRef, clang::frontend::IncludeDirGroup, bool, bool, bool)"},
    {"_ZNSt6vectorIN5clang19HeaderSearchOptions5EntryESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::HeaderSearchOptions::Entry, std::allocator<clang::HeaderSearchOptions::Entry>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::HeaderSearchOptions::Entry*, std::vector<clang::HeaderSearchOptions::Entry, std::allocator<clang::HeaderSearchOptions::Entry>>>, clang::HeaderSearchOptions::Entry const&)"},
    {"_ZN5clang20ParsedSourceLocation10FromStringEN4llvm9StringRefE", "clang::ParsedSourceLocation::FromString(llvm::StringRef)"},
    {"_ZNSt6vectorISt4pairIN5clang9InputKindESsESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<std::pair<clang::InputKind, std::string>, std::allocator<std::pair<clang::InputKind, std::string>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<clang::InputKind, std::string>*, std::vector<std::pair<clang::InputKind, std::string>, std::allocator<std::pair<clang::InputKind, std::string>>>>, std::pair<clang::InputKind, std::string> const&)"},
    {"_ZNSt6vectorIS_ISsSaISsEESaIS1_EE15_M_erase_at_endEPS1_", "std::vector<std::vector<std::string, std::allocator<std::string>>, std::allocator<std::vector<std::string, std::allocator<std::string>>>>::_M_erase_at_end(std::vector<std::string, std::allocator<std::string>>*)"},
    {"_ZNSt6vectorIS_ISsSaISsEESaIS1_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS1_S3_EEmRKS1_", "std::vector<std::vector<std::string, std::allocator<std::string>>, std::allocator<std::vector<std::string, std::allocator<std::string>>>>::_M_fill_insert(__gnu_cxx::__normal_iterator<std::vector<std::string, std::allocator<std::string>>*, std::vector<std::vector<std::string, std::allocator<std::string>>, std::allocator<std::vector<std::string, std::allocator<std::string>>>>>, unsigned long, std::vector<std::string, std::allocator<std::string>> const&)"},
    {"_ZNSt6vectorISsSaISsEEC2ERKS1_", "std::vector<std::string, std::allocator<std::string>>::vector(std::vector<std::string, std::allocator<std::string>> const&)"},
    {"_ZNSt6vectorIN5clang8AnalysesESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<clang::Analyses, std::allocator<clang::Analyses>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::Analyses*, std::vector<clang::Analyses, std::allocator<clang::Analyses>>>, clang::Analyses const&)"},
    {"_ZN5clang11DocumentXML14writeDeclToXMLEPNS_4DeclE", "clang::DocumentXML::writeDeclToXML(clang::Decl*)"},
    {"_ZN5clang11DeclVisitorINS_11DocumentXML11DeclPrinterEvE5VisitEPNS_4DeclE", "clang::DeclVisitor<clang::DocumentXML::DeclPrinter, void>::Visit(clang::Decl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter20VisitLinkageSpecDeclEPNS_15LinkageSpecDeclE", "clang::DocumentXML::DeclPrinter::VisitLinkageSpecDecl(clang::LinkageSpecDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter18VisitNamespaceDeclEPNS_13NamespaceDeclE", "clang::DocumentXML::DeclPrinter::VisitNamespaceDecl(clang::NamespaceDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter23VisitNamespaceAliasDeclEPNS_18NamespaceAliasDeclE", "clang::DocumentXML::DeclPrinter::VisitNamespaceAliasDecl(clang::NamespaceAliasDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter13VisitEnumDeclEPNS_8EnumDeclE", "clang::DocumentXML::DeclPrinter::VisitEnumDecl(clang::EnumDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter15VisitRecordDeclEPNS_10RecordDeclE", "clang::DocumentXML::DeclPrinter::VisitRecordDecl(clang::RecordDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter18VisitCXXRecordDeclEPNS_13CXXRecordDeclE", "clang::DocumentXML::DeclPrinter::VisitCXXRecordDecl(clang::CXXRecordDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter25VisitTemplateTypeParmDeclEPNS_20TemplateTypeParmDeclE", "clang::DocumentXML::DeclPrinter::VisitTemplateTypeParmDecl(clang::TemplateTypeParmDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter16VisitTypedefDeclEPNS_11TypedefDeclE", "clang::DocumentXML::DeclPrinter::VisitTypedefDecl(clang::TypedefDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter14VisitUsingDeclEPNS_9UsingDeclE", "clang::DocumentXML::DeclPrinter::VisitUsingDecl(clang::UsingDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter23VisitUsingDirectiveDeclEPNS_18UsingDirectiveDeclE", "clang::DocumentXML::DeclPrinter::VisitUsingDirectiveDecl(clang::UsingDirectiveDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter20VisitUsingShadowDeclEPNS_15UsingShadowDeclE", "clang::DocumentXML::DeclPrinter::VisitUsingShadowDecl(clang::UsingShadowDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter14VisitFieldDeclEPNS_9FieldDeclE", "clang::DocumentXML::DeclPrinter::VisitFieldDecl(clang::FieldDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter17VisitFunctionDeclEPNS_12FunctionDeclE", "clang::DocumentXML::DeclPrinter::VisitFunctionDecl(clang::FunctionDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter18VisitCXXMethodDeclEPNS_13CXXMethodDeclE", "clang::DocumentXML::DeclPrinter::VisitCXXMethodDecl(clang::CXXMethodDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter23VisitCXXConstructorDeclEPNS_18CXXConstructorDeclE", "clang::DocumentXML::DeclPrinter::VisitCXXConstructorDecl(clang::CXXConstructorDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter22VisitCXXConversionDeclEPNS_17CXXConversionDeclE", "clang::DocumentXML::DeclPrinter::VisitCXXConversionDecl(clang::CXXConversionDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter22VisitCXXDestructorDeclEPNS_17CXXDestructorDeclE", "clang::DocumentXML::DeclPrinter::VisitCXXDestructorDecl(clang::CXXDestructorDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter12VisitVarDeclEPNS_7VarDeclE", "clang::DocumentXML::DeclPrinter::VisitVarDecl(clang::VarDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter16VisitParmVarDeclEPNS_11ParmVarDeclE", "clang::DocumentXML::DeclPrinter::VisitParmVarDecl(clang::ParmVarDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter21VisitEnumConstantDeclEPNS_16EnumConstantDeclE", "clang::DocumentXML::DeclPrinter::VisitEnumConstantDecl(clang::EnumConstantDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter9VisitDeclEPNS_4DeclE", "clang::DocumentXML::DeclPrinter::VisitDecl(clang::Decl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter15addFunctionBodyEPNS_12FunctionDeclE", "clang::DocumentXML::DeclPrinter::addFunctionBody(clang::FunctionDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter11addSubNodesEPNS_13CXXRecordDeclE", "clang::DocumentXML::DeclPrinter::addSubNodes(clang::CXXRecordDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter11addSubNodesEPNS_10RecordDeclE", "clang::DocumentXML::DeclPrinter::addSubNodes(clang::RecordDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter11addSubNodesEPNS_8EnumDeclE", "clang::DocumentXML::DeclPrinter::addSubNodes(clang::EnumDecl*)"},
    {"_ZN5clang11DocumentXML11DeclPrinter17VisitTemplateDeclEPNS_12TemplateDeclE", "clang::DocumentXML::DeclPrinter::VisitTemplateDecl(clang::TemplateDecl*)"},
    {"_ZN5clang23AttachDependencyFileGenERNS_12PreprocessorERKNS_23DependencyOutputOptionsE", "clang::AttachDependencyFileGen(clang::Preprocessor&, clang::DependencyOutputOptions const&)"},
    {"_ZN12_GLOBAL__N_122DependencyFileCallbackD1Ev", "(anonymous namespace)::DependencyFileCallback::~DependencyFileCallback()"},
    {"_ZN12_GLOBAL__N_122DependencyFileCallbackD0Ev", "(anonymous namespace)::DependencyFileCallback::~DependencyFileCallback()"},
    {"_ZN12_GLOBAL__N_122DependencyFileCallback11FileChangedEN5clang14SourceLocationENS1_11PPCallbacks16FileChangeReasonENS1_6SrcMgr18CharacteristicKindE", "(anonymous namespace)::DependencyFileCallback::FileChanged(clang::SourceLocation, clang::PPCallbacks::FileChangeReason, clang::SrcMgr::CharacteristicKind)"},
    {"_ZN12_GLOBAL__N_122DependencyFileCallback13EndOfMainFileEv", "(anonymous namespace)::DependencyFileCallback::EndOfMainFile()"},
    {"_ZN5clang11DocumentXMLC1ERKSsRN4llvm11raw_ostreamE", "clang::DocumentXML::DocumentXML(std::string const&, llvm::raw_ostream&)"},
    {"_ZN5clang11DocumentXMLC2ERKSsRN4llvm11raw_ostreamE", "clang::DocumentXML::DocumentXML(std::string const&, llvm::raw_ostream&)"},
    {"_ZN5clang11DocumentXML10addSubNodeERKSs", "clang::DocumentXML::addSubNode(std::string const&)"},
    {"_ZN5clang11DocumentXML6IndentEv", "clang::DocumentXML::Indent()"},
    {"_ZN5clang11DocumentXML8toParentEv", "clang::DocumentXML::toParent()"},
    {"_ZN5clang11DocumentXML12escapeStringEPKcm", "clang::DocumentXML::escapeString(char const*, unsigned long)"},
    {"_ZN5clang11DocumentXML8finalizeEv", "clang::DocumentXML::finalize()"},
    {"_ZN5clang11DocumentXML12addAttributeEPKcRKNS_8QualTypeE", "clang::DocumentXML::addAttribute(char const*, clang::QualType const&)"},
    {"_ZN5clang11DocumentXML18addTypeRecursivelyERKNS_8QualTypeE", "clang::DocumentXML::addTypeRecursively(clang::QualType const&)"},
    {"_ZN5clang11DocumentXML15addPtrAttributeEPKcPKNS_4TypeE", "clang::DocumentXML::addPtrAttribute(char const*, clang::Type const*)"},
    {"_ZN5clang11DocumentXML18addTypeRecursivelyEPKNS_4TypeE", "clang::DocumentXML::addTypeRecursively(clang::Type const*)"},
    {"_ZN5clang11DocumentXML15addPtrAttributeEPKcPKNS_19NestedNameSpecifierE", "clang::DocumentXML::addPtrAttribute(char const*, clang::NestedNameSpecifier const*)"},
    {"_ZN5clang11DocumentXML15addPtrAttributeEPKcPKNS_13NamespaceDeclE", "clang::DocumentXML::addPtrAttribute(char const*, clang::NamespaceDecl const*)"},
    {"_ZN5clang11DocumentXML15addPtrAttributeEPKcPKNS_11DeclContextE", "clang::DocumentXML::addPtrAttribute(char const*, clang::DeclContext const*)"},
    {"_ZN5clang11DocumentXML22addContextsRecursivelyEPKNS_11DeclContextE", "clang::DocumentXML::addContextsRecursively(clang::DeclContext const*)"},
    {"_ZN5clang11DocumentXML15addPtrAttributeEPKcPKNS_9NamedDeclE", "clang::DocumentXML::addPtrAttribute(char const*, clang::NamedDecl const*)"},
    {"_ZN5clang11DocumentXML22addSourceFileAttributeERKSs", "clang::DocumentXML::addSourceFileAttribute(std::string const&)"},
    {"_ZN5clang11DocumentXML15addPtrAttributeEPKcPKNS_9LabelStmtE", "clang::DocumentXML::addPtrAttribute(char const*, clang::LabelStmt const*)"},
    {"_ZN5clang11DocumentXML11addLocationERKNS_14SourceLocationE", "clang::DocumentXML::addLocation(clang::SourceLocation const&)"},
    {"_ZN5clang11DocumentXML16addLocationRangeERKNS_11SourceRangeE", "clang::DocumentXML::addLocationRange(clang::SourceRange const&)"},
    {"_ZN5clang11DocumentXML9PrintDeclEPNS_4DeclE", "clang::DocumentXML::PrintDecl(clang::Decl*)"},
    {"_ZN5clang11DocumentXML12addAttributeISsEEvPKcRKT_", "void clang::DocumentXML::addAttribute<std::string>(char const*, std::string const&)"},
    {"_ZN5clang11DocumentXML15addPtrAttributeEPKcS2_", "clang::DocumentXML::addPtrAttribute(char const*, char const*)"},
    {"_ZN5clang11DocumentXML12addAttributeIjEEvPKcRKT_", "void clang::DocumentXML::addAttribute<unsigned int>(char const*, unsigned int const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang9LabelStmtEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::LabelStmt const*, unsigned int, llvm::DenseMapInfo<clang::LabelStmt const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::LabelStmt const* const&, unsigned int const&, std::pair<clang::LabelStmt const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang9LabelStmtEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::LabelStmt const*, unsigned int, llvm::DenseMapInfo<clang::LabelStmt const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang9LabelStmtEjNS_12DenseMapInfoIS4_EENS5_IjEEE6insertERKSt4pairIS4_jE", "llvm::DenseMap<clang::LabelStmt const*, unsigned int, llvm::DenseMapInfo<clang::LabelStmt const*>, llvm::DenseMapInfo<unsigned int>>::insert(std::pair<clang::LabelStmt const*, unsigned int> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang11DeclContextEjNS_12DenseMapInfoIS4_EENS5_IjEEE6insertERKSt4pairIS4_jE", "llvm::DenseMap<clang::DeclContext const*, unsigned int, llvm::DenseMapInfo<clang::DeclContext const*>, llvm::DenseMapInfo<unsigned int>>::insert(std::pair<clang::DeclContext const*, unsigned int> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang11DeclContextEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::DeclContext const*, unsigned int, llvm::DenseMapInfo<clang::DeclContext const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::DeclContext const* const&, unsigned int const&, std::pair<clang::DeclContext const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang11DeclContextEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::DeclContext const*, unsigned int, llvm::DenseMapInfo<clang::DeclContext const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang9NamedDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE6insertERKSt4pairIS4_jE", "llvm::DenseMap<clang::NamedDecl const*, unsigned int, llvm::DenseMapInfo<clang::NamedDecl const*>, llvm::DenseMapInfo<unsigned int>>::insert(std::pair<clang::NamedDecl const*, unsigned int> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeEjNS_12DenseMapInfoIS4_EENS5_IjEEE6insertERKSt4pairIS4_jE", "llvm::DenseMap<clang::Type const*, unsigned int, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<unsigned int>>::insert(std::pair<clang::Type const*, unsigned int> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::Type const*, unsigned int, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::Type const* const&, unsigned int const&, std::pair<clang::Type const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::Type const*, unsigned int, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_jESt10_Select1stIS4_ENS0_16QualTypeOrderingESaIS4_EE16_M_insert_uniqueERKS4_", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, unsigned int>, std::_Select1st<std::pair<clang::QualType const, unsigned int>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, unsigned int>>>::_M_insert_unique(std::pair<clang::QualType const, unsigned int> const&)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_jESt10_Select1stIS4_ENS0_16QualTypeOrderingESaIS4_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS4_ERKS4_", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, unsigned int>, std::_Select1st<std::pair<clang::QualType const, unsigned int>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, unsigned int>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::QualType const, unsigned int>>, std::pair<clang::QualType const, unsigned int> const&)"},
    {"_ZNSt5dequeISsSaISsEE8pop_backEv", "std::deque<std::string, std::allocator<std::string>>::pop_back()"},
    {"_ZNSt11_Deque_baseISsSaISsEE17_M_initialize_mapEm", "std::_Deque_base<std::string, std::allocator<std::string>>::_M_initialize_map(unsigned long)"},
    {"_ZNSt5dequeISsSaISsEEC2ERKS1_", "std::deque<std::string, std::allocator<std::string>>::deque(std::deque<std::string, std::allocator<std::string>> const&)"},
    {"_ZN5clang14FrontendActionC1Ev", "clang::FrontendAction::FrontendAction()"},
    {"_ZN5clang14FrontendActionC2Ev", "clang::FrontendAction::FrontendAction()"},
    {"_ZN5clang14FrontendActionD0Ev", "clang::FrontendAction::~FrontendAction()"},
    {"_ZN5clang14FrontendActionD1Ev", "clang::FrontendAction::~FrontendAction()"},
    {"_ZN5clang14FrontendActionD2Ev", "clang::FrontendAction::~FrontendAction()"},
    {"_ZN5clang14FrontendAction14setCurrentFileEN4llvm9StringRefENS_9InputKindEPNS_7ASTUnitE", "clang::FrontendAction::setCurrentFile(llvm::StringRef, clang::InputKind, clang::ASTUnit*)"},
    {"_ZN5clang14FrontendAction24CreateWrappedASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::FrontendAction::CreateWrappedASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang14FrontendAction15BeginSourceFileERNS_16CompilerInstanceEN4llvm9StringRefENS_9InputKindE", "clang::FrontendAction::BeginSourceFile(clang::CompilerInstance&, llvm::StringRef, clang::InputKind)"},
    {"_ZN5clang14FrontendAction7ExecuteEv", "clang::FrontendAction::Execute()"},
    {"_ZN5clang14FrontendAction13EndSourceFileEv", "clang::FrontendAction::EndSourceFile()"},
    {"_ZN5clang17ASTFrontendAction13ExecuteActionEv", "clang::ASTFrontendAction::ExecuteAction()"},
    {"_ZN5clang26PreprocessorFrontendAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::PreprocessorFrontendAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_124DeserializedDeclsCheckerD1Ev", "(anonymous namespace)::DeserializedDeclsChecker::~DeserializedDeclsChecker()"},
    {"_ZN12_GLOBAL__N_124DeserializedDeclsCheckerD0Ev", "(anonymous namespace)::DeserializedDeclsChecker::~DeserializedDeclsChecker()"},
    {"_ZN12_GLOBAL__N_124DeserializedDeclsChecker8DeclReadEjPKN5clang4DeclE", "(anonymous namespace)::DeserializedDeclsChecker::DeclRead(unsigned int, clang::Decl const*)"},
    {"_ZN12_GLOBAL__N_123DeserializedDeclsDumperD1Ev", "(anonymous namespace)::DeserializedDeclsDumper::~DeserializedDeclsDumper()"},
    {"_ZN12_GLOBAL__N_123DeserializedDeclsDumperD0Ev", "(anonymous namespace)::DeserializedDeclsDumper::~DeserializedDeclsDumper()"},
    {"_ZN12_GLOBAL__N_123DeserializedDeclsDumper8DeclReadEjPKN5clang4DeclE", "(anonymous namespace)::DeserializedDeclsDumper::DeclRead(unsigned int, clang::Decl const*)"},
    {"_ZNSt6vectorIPN5clang11ASTConsumerESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::ASTConsumer*, std::allocator<clang::ASTConsumer*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::ASTConsumer**, std::vector<clang::ASTConsumer*, std::allocator<clang::ASTConsumer*>>>, clang::ASTConsumer* const&)"},
    {"_ZN5clang26ASTDeserializationListener17ReaderInitializedEPNS_9ASTReaderE", "clang::ASTDeserializationListener::ReaderInitialized(clang::ASTReader*)"},
    {"_ZN5clang26ASTDeserializationListener14IdentifierReadEjPNS_14IdentifierInfoE", "clang::ASTDeserializationListener::IdentifierRead(unsigned int, clang::IdentifierInfo*)"},
    {"_ZN5clang26ASTDeserializationListener8TypeReadENS_13serialization7TypeIdxENS_8QualTypeE", "clang::ASTDeserializationListener::TypeRead(clang::serialization::TypeIdx, clang::QualType)"},
    {"_ZN5clang26ASTDeserializationListener12SelectorReadEjNS_8SelectorE", "clang::ASTDeserializationListener::SelectorRead(unsigned int, clang::Selector)"},
    {"_ZN5clang26ASTDeserializationListener19MacroDefinitionReadEjPNS_15MacroDefinitionE", "clang::ASTDeserializationListener::MacroDefinitionRead(unsigned int, clang::MacroDefinition*)"},
    {"_ZNSt8_Rb_treeISsSsSt9_IdentityISsESt4lessISsESaISsEE4findERKSs", "std::_Rb_tree<std::string, std::string, std::_Identity<std::string>, std::less<std::string>, std::allocator<std::string>>::find(std::string const&)"},
    {"_ZNSt8_Rb_treeISsSsSt9_IdentityISsESt4lessISsESaISsEE7_M_copyEPKSt13_Rb_tree_nodeISsEPS7_", "std::_Rb_tree<std::string, std::string, std::_Identity<std::string>, std::less<std::string>, std::allocator<std::string>>::_M_copy(std::_Rb_tree_node<std::string> const*, std::_Rb_tree_node<std::string>*)"},
    {"_ZN5clang26ASTDeserializationListener8DeclReadEjPKNS_4DeclE", "clang::ASTDeserializationListener::DeclRead(unsigned int, clang::Decl const*)"},
    {"_ZN5clang14InitOnlyAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::InitOnlyAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang14InitOnlyAction13ExecuteActionEv", "clang::InitOnlyAction::ExecuteAction()"},
    {"_ZN5clang14ASTPrintAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::ASTPrintAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang17ASTPrintXMLAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::ASTPrintXMLAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang13ASTDumpAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::ASTDumpAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang16ASTDumpXMLAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::ASTDumpXMLAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang13ASTViewAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::ASTViewAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang22DeclContextPrintAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::DeclContextPrintAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang17GeneratePCHAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::GeneratePCHAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang17GeneratePCHAction27ComputeASTConsumerArgumentsERNS_16CompilerInstanceEN4llvm9StringRefERSsRPNS3_11raw_ostreamERb", "clang::GeneratePCHAction::ComputeASTConsumerArguments(clang::CompilerInstance&, llvm::StringRef, std::string&, llvm::raw_ostream*&, bool&)"},
    {"_ZN5clang21InheritanceViewAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::InheritanceViewAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang16SyntaxOnlyAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::SyntaxOnlyAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang19DumpRawTokensAction13ExecuteActionEv", "clang::DumpRawTokensAction::ExecuteAction()"},
    {"_ZN5clang16DumpTokensAction13ExecuteActionEv", "clang::DumpTokensAction::ExecuteAction()"},
    {"_ZN5clang17GeneratePTHAction13ExecuteActionEv", "clang::GeneratePTHAction::ExecuteAction()"},
    {"_ZN5clang20PreprocessOnlyAction13ExecuteActionEv", "clang::PreprocessOnlyAction::ExecuteAction()"},
    {"_ZN5clang23PrintPreprocessedAction13ExecuteActionEv", "clang::PrintPreprocessedAction::ExecuteAction()"},
    {"_ZN5clang19PrintPreambleAction13ExecuteActionEv", "clang::PrintPreambleAction::ExecuteAction()"},
    {"_ZN5clang5LexerD1Ev", "clang::Lexer::~Lexer()"},
    {"_ZN5clang12Preprocessor3LexERNS_5TokenE", "clang::Preprocessor::Lex(clang::Token&)"},
    {"_ZN5clang14InitOnlyActionD1Ev", "clang::InitOnlyAction::~InitOnlyAction()"},
    {"_ZN5clang14InitOnlyActionD0Ev", "clang::InitOnlyAction::~InitOnlyAction()"},
    {"_ZN5clang14ASTPrintActionD1Ev", "clang::ASTPrintAction::~ASTPrintAction()"},
    {"_ZN5clang14ASTPrintActionD0Ev", "clang::ASTPrintAction::~ASTPrintAction()"},
    {"_ZN5clang17ASTPrintXMLActionD1Ev", "clang::ASTPrintXMLAction::~ASTPrintXMLAction()"},
    {"_ZN5clang17ASTPrintXMLActionD0Ev", "clang::ASTPrintXMLAction::~ASTPrintXMLAction()"},
    {"_ZN5clang13ASTDumpActionD1Ev", "clang::ASTDumpAction::~ASTDumpAction()"},
    {"_ZN5clang13ASTDumpActionD0Ev", "clang::ASTDumpAction::~ASTDumpAction()"},
    {"_ZN5clang16ASTDumpXMLActionD1Ev", "clang::ASTDumpXMLAction::~ASTDumpXMLAction()"},
    {"_ZN5clang16ASTDumpXMLActionD0Ev", "clang::ASTDumpXMLAction::~ASTDumpXMLAction()"},
    {"_ZN5clang13ASTViewActionD1Ev", "clang::ASTViewAction::~ASTViewAction()"},
    {"_ZN5clang13ASTViewActionD0Ev", "clang::ASTViewAction::~ASTViewAction()"},
    {"_ZN5clang22DeclContextPrintActionD1Ev", "clang::DeclContextPrintAction::~DeclContextPrintAction()"},
    {"_ZN5clang22DeclContextPrintActionD0Ev", "clang::DeclContextPrintAction::~DeclContextPrintAction()"},
    {"_ZN5clang17GeneratePCHActionD1Ev", "clang::GeneratePCHAction::~GeneratePCHAction()"},
    {"_ZN5clang17GeneratePCHActionD0Ev", "clang::GeneratePCHAction::~GeneratePCHAction()"},
    {"_ZN5clang21InheritanceViewActionD1Ev", "clang::InheritanceViewAction::~InheritanceViewAction()"},
    {"_ZN5clang21InheritanceViewActionD0Ev", "clang::InheritanceViewAction::~InheritanceViewAction()"},
    {"_ZN5clang19PrintPreambleActionD1Ev", "clang::PrintPreambleAction::~PrintPreambleAction()"},
    {"_ZN5clang19PrintPreambleActionD0Ev", "clang::PrintPreambleAction::~PrintPreambleAction()"},
    {"_ZN5clang19DumpRawTokensActionD1Ev", "clang::DumpRawTokensAction::~DumpRawTokensAction()"},
    {"_ZN5clang19DumpRawTokensActionD0Ev", "clang::DumpRawTokensAction::~DumpRawTokensAction()"},
    {"_ZN5clang16DumpTokensActionD1Ev", "clang::DumpTokensAction::~DumpTokensAction()"},
    {"_ZN5clang16DumpTokensActionD0Ev", "clang::DumpTokensAction::~DumpTokensAction()"},
    {"_ZN5clang17GeneratePTHActionD1Ev", "clang::GeneratePTHAction::~GeneratePTHAction()"},
    {"_ZN5clang17GeneratePTHActionD0Ev", "clang::GeneratePTHAction::~GeneratePTHAction()"},
    {"_ZN5clang20PreprocessOnlyActionD1Ev", "clang::PreprocessOnlyAction::~PreprocessOnlyAction()"},
    {"_ZN5clang20PreprocessOnlyActionD0Ev", "clang::PreprocessOnlyAction::~PreprocessOnlyAction()"},
    {"_ZN5clang23PrintPreprocessedActionD1Ev", "clang::PrintPreprocessedAction::~PrintPreprocessedAction()"},
    {"_ZN5clang23PrintPreprocessedActionD0Ev", "clang::PrintPreprocessedAction::~PrintPreprocessedAction()"},
    {"_ZN5clang5LexerD0Ev", "clang::Lexer::~Lexer()"},
    {"_ZN5clang5Lexer11IndirectLexERNS_5TokenE", "clang::Lexer::IndirectLex(clang::Token&)"},
    {"_ZN5clang5Lexer17getSourceLocationEv", "clang::Lexer::getSourceLocation()"},
    {"_ZN5clang17PreprocessorLexerD1Ev", "clang::PreprocessorLexer::~PreprocessorLexer()"},
    {"_ZN5clang17PreprocessorLexerD0Ev", "clang::PreprocessorLexer::~PreprocessorLexer()"},
    {"_ZN5clang11ASTConsumerD1Ev", "clang::ASTConsumer::~ASTConsumer()"},
    {"_ZN5clang11ASTConsumerD0Ev", "clang::ASTConsumer::~ASTConsumer()"},
    {"_ZN5clang11ASTConsumer10InitializeERNS_10ASTContextE", "clang::ASTConsumer::Initialize(clang::ASTContext&)"},
    {"_ZN5clang11ASTConsumer21HandleTranslationUnitERNS_10ASTContextE", "clang::ASTConsumer::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN5clang11ASTConsumer23HandleTagDeclDefinitionEPNS_7TagDeclE", "clang::ASTConsumer::HandleTagDeclDefinition(clang::TagDecl*)"},
    {"_ZN5clang11ASTConsumer27CompleteTentativeDefinitionEPNS_7VarDeclE", "clang::ASTConsumer::CompleteTentativeDefinition(clang::VarDecl*)"},
    {"_ZN5clang11ASTConsumer12HandleVTableEPNS_13CXXRecordDeclEb", "clang::ASTConsumer::HandleVTable(clang::CXXRecordDecl*, bool)"},
    {"_ZN5clang11ASTConsumer22GetASTMutationListenerEv", "clang::ASTConsumer::GetASTMutationListener()"},
    {"_ZN5clang11ASTConsumer29GetASTDeserializationListenerEv", "clang::ASTConsumer::GetASTDeserializationListener()"},
    {"_ZN5clang11ASTConsumer10PrintStatsEv", "clang::ASTConsumer::PrintStats()"},
    {"_ZN5clang15FrontendOptions24getInputKindForExtensionEN4llvm9StringRefE", "clang::FrontendOptions::getInputKindForExtension(llvm::StringRef)"},
    {"_ZN4llvm12StringSwitchIN5clang9InputKindES2_E5CasesILj4ELj4ELj4ELj4ELj4EEERS3_RAT__KcRAT0__S6_RAT1__S6_RAT2__S6_RAT3__S6_RKS2_", "llvm::StringSwitch<clang::InputKind, clang::InputKind>& llvm::StringSwitch<clang::InputKind, clang::InputKind>::Cases<4u, 4u, 4u, 4u, 4u>(char const (&) [4u], char const (&) [4u], char const (&) [4u], char const (&) [4u], char const (&) [4u], clang::InputKind const&)"},
    {"_ZN5clang22AttachHeaderIncludeGenERNS_12PreprocessorEbN4llvm9StringRefE", "clang::AttachHeaderIncludeGen(clang::Preprocessor&, bool, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_122HeaderIncludesCallbackD1Ev", "(anonymous namespace)::HeaderIncludesCallback::~HeaderIncludesCallback()"},
    {"_ZN12_GLOBAL__N_122HeaderIncludesCallbackD0Ev", "(anonymous namespace)::HeaderIncludesCallback::~HeaderIncludesCallback()"},
    {"_ZN12_GLOBAL__N_122HeaderIncludesCallback11FileChangedEN5clang14SourceLocationENS1_11PPCallbacks16FileChangeReasonENS1_6SrcMgr18CharacteristicKindE", "(anonymous namespace)::HeaderIncludesCallback::FileChanged(clang::SourceLocation, clang::PPCallbacks::FileChangeReason, clang::SrcMgr::CharacteristicKind)"},
    {"_ZN5clang24ApplyHeaderSearchOptionsERNS_12HeaderSearchERKNS_19HeaderSearchOptionsERKNS_11LangOptionsERKN4llvm6TripleE", "clang::ApplyHeaderSearchOptions(clang::HeaderSearch&, clang::HeaderSearchOptions const&, clang::LangOptions const&, llvm::Triple const&)"},
    {"_ZN12_GLOBAL__N_116InitHeaderSearch7AddPathERKN4llvm5TwineEN5clang8frontend15IncludeDirGroupEbbbb", "(anonymous namespace)::InitHeaderSearch::AddPath(llvm::Twine const&, clang::frontend::IncludeDirGroup, bool, bool, bool, bool)"},
    {"_ZN12_GLOBAL__N_116InitHeaderSearch17AddDelimitedPathsEN4llvm9StringRefE", "(anonymous namespace)::InitHeaderSearch::AddDelimitedPaths(llvm::StringRef)"},
    {"_Z16RemoveDuplicatesRSt6vectorIN5clang15DirectoryLookupESaIS1_EEb", "RemoveDuplicates(std::vector<clang::DirectoryLookup, std::allocator<clang::DirectoryLookup>>&, bool)"},
    {"_ZN12_GLOBAL__N_116InitHeaderSearch27AddGnuCPlusPlusIncludePathsEN4llvm9StringRefES2_S2_S2_RKNS1_6TripleE", "(anonymous namespace)::InitHeaderSearch::AddGnuCPlusPlusIncludePaths(llvm::StringRef, llvm::StringRef, llvm::StringRef, llvm::StringRef, llvm::Triple const&)"},
    {"_ZN12_GLOBAL__N_116InitHeaderSearch29AddMinGWCPlusPlusIncludePathsEN4llvm9StringRefES2_S2_", "(anonymous namespace)::InitHeaderSearch::AddMinGWCPlusPlusIncludePaths(llvm::StringRef, llvm::StringRef, llvm::StringRef)"},
    {"_ZNSt6vectorIN5clang15DirectoryLookupESaIS1_EEaSERKS3_", "std::vector<clang::DirectoryLookup, std::allocator<clang::DirectoryLookup>>::operator=(std::vector<clang::DirectoryLookup, std::allocator<clang::DirectoryLookup>> const&)"},
    {"_ZNSt6vectorIN5clang15DirectoryLookupESaIS1_EE15_M_range_insertIN9__gnu_cxx17__normal_iteratorIPS1_S3_EEEEvS8_T_S9_St20forward_iterator_tag", "void std::vector<clang::DirectoryLookup, std::allocator<clang::DirectoryLookup>>::_M_range_insert<__gnu_cxx::__normal_iterator<clang::DirectoryLookup*, std::vector<clang::DirectoryLookup, std::allocator<clang::DirectoryLookup>>>>(__gnu_cxx::__normal_iterator<clang::DirectoryLookup*, std::vector<clang::DirectoryLookup, std::allocator<clang::DirectoryLookup>>>, __gnu_cxx::__normal_iterator<clang::DirectoryLookup*, std::vector<clang::DirectoryLookup, std::allocator<clang::DirectoryLookup>>>, __gnu_cxx::__normal_iterator<clang::DirectoryLookup*, std::vector<clang::DirectoryLookup, std::allocator<clang::DirectoryLookup>>>, std::forward_iterator_tag)"},
    {"_ZNSt6vectorIN5clang15DirectoryLookupESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<clang::DirectoryLookup, std::allocator<clang::DirectoryLookup>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::DirectoryLookup*, std::vector<clang::DirectoryLookup, std::allocator<clang::DirectoryLookup>>>, clang::DirectoryLookup const&)"},
    {"_ZN5clang24NormalizeDashIncludePathEN4llvm9StringRefE", "clang::NormalizeDashIncludePath(llvm::StringRef)"},
    {"_ZN5clang22InitializePreprocessorERNS_12PreprocessorERKNS_19PreprocessorOptionsERKNS_19HeaderSearchOptionsERKNS_15FrontendOptionsE", "clang::InitializePreprocessor(clang::Preprocessor&, clang::PreprocessorOptions const&, clang::HeaderSearchOptions const&, clang::FrontendOptions const&)"},
    {"_Z18AddImplicitIncludeRN5clang12MacroBuilderEN4llvm9StringRefE", "AddImplicitInclude(clang::MacroBuilder&, llvm::StringRef)"},
    {"_Z17DefineFloatMacrosRN5clang12MacroBuilderEN4llvm9StringRefEPKNS2_12fltSemanticsE", "DefineFloatMacros(clang::MacroBuilder&, llvm::StringRef, llvm::fltSemantics const*)"},
    {"_Z23DefineExactWidthIntTypeN5clang10TargetInfo7IntTypeERKS0_RNS_12MacroBuilderE", "DefineExactWidthIntType(clang::TargetInfo::IntType, clang::TargetInfo const&, clang::MacroBuilder&)"},
    {"_ZN5clang12LangStandard22getLangStandardForKindENS0_4KindE", "clang::LangStandard::getLangStandardForKind(clang::LangStandard::Kind)"},
    {"_ZN5clang12LangStandard22getLangStandardForNameEN4llvm9StringRefE", "clang::LangStandard::getLangStandardForName(llvm::StringRef)"},
    {"_ZN5clang35MultiplexASTDeserializationListenerC1ERKSt6vectorIPNS_26ASTDeserializationListenerESaIS3_EE", "clang::MultiplexASTDeserializationListener::MultiplexASTDeserializationListener(std::vector<clang::ASTDeserializationListener*, std::allocator<clang::ASTDeserializationListener*>> const&)"},
    {"_ZN5clang35MultiplexASTDeserializationListenerC2ERKSt6vectorIPNS_26ASTDeserializationListenerESaIS3_EE", "clang::MultiplexASTDeserializationListener::MultiplexASTDeserializationListener(std::vector<clang::ASTDeserializationListener*, std::allocator<clang::ASTDeserializationListener*>> const&)"},
    {"_ZN5clang35MultiplexASTDeserializationListener17ReaderInitializedEPNS_9ASTReaderE", "clang::MultiplexASTDeserializationListener::ReaderInitialized(clang::ASTReader*)"},
    {"_ZN5clang35MultiplexASTDeserializationListener14IdentifierReadEjPNS_14IdentifierInfoE", "clang::MultiplexASTDeserializationListener::IdentifierRead(unsigned int, clang::IdentifierInfo*)"},
    {"_ZN5clang35MultiplexASTDeserializationListener8TypeReadENS_13serialization7TypeIdxENS_8QualTypeE", "clang::MultiplexASTDeserializationListener::TypeRead(clang::serialization::TypeIdx, clang::QualType)"},
    {"_ZN5clang35MultiplexASTDeserializationListener8DeclReadEjPKNS_4DeclE", "clang::MultiplexASTDeserializationListener::DeclRead(unsigned int, clang::Decl const*)"},
    {"_ZN5clang35MultiplexASTDeserializationListener12SelectorReadEjNS_8SelectorE", "clang::MultiplexASTDeserializationListener::SelectorRead(unsigned int, clang::Selector)"},
    {"_ZN5clang35MultiplexASTDeserializationListener19MacroDefinitionReadEjPNS_15MacroDefinitionE", "clang::MultiplexASTDeserializationListener::MacroDefinitionRead(unsigned int, clang::MacroDefinition*)"},
    {"_ZN5clang28MultiplexASTMutationListenerC1ERKSt6vectorIPNS_19ASTMutationListenerESaIS3_EE", "clang::MultiplexASTMutationListener::MultiplexASTMutationListener(std::vector<clang::ASTMutationListener*, std::allocator<clang::ASTMutationListener*>> const&)"},
    {"_ZN5clang28MultiplexASTMutationListenerC2ERKSt6vectorIPNS_19ASTMutationListenerESaIS3_EE", "clang::MultiplexASTMutationListener::MultiplexASTMutationListener(std::vector<clang::ASTMutationListener*, std::allocator<clang::ASTMutationListener*>> const&)"},
    {"_ZN5clang28MultiplexASTMutationListener22CompletedTagDefinitionEPKNS_7TagDeclE", "clang::MultiplexASTMutationListener::CompletedTagDefinition(clang::TagDecl const*)"},
    {"_ZN5clang28MultiplexASTMutationListener16AddedVisibleDeclEPKNS_11DeclContextEPKNS_4DeclE", "clang::MultiplexASTMutationListener::AddedVisibleDecl(clang::DeclContext const*, clang::Decl const*)"},
    {"_ZN5clang28MultiplexASTMutationListener22AddedCXXImplicitMemberEPKNS_13CXXRecordDeclEPKNS_4DeclE", "clang::MultiplexASTMutationListener::AddedCXXImplicitMember(clang::CXXRecordDecl const*, clang::Decl const*)"},
    {"_ZN5clang28MultiplexASTMutationListener30AddedCXXTemplateSpecializationEPKNS_17ClassTemplateDeclEPKNS_31ClassTemplateSpecializationDeclE", "clang::MultiplexASTMutationListener::AddedCXXTemplateSpecialization(clang::ClassTemplateDecl const*, clang::ClassTemplateSpecializationDecl const*)"},
    {"_ZN5clang17MultiplexConsumerC1ERKSt6vectorIPNS_11ASTConsumerESaIS3_EE", "clang::MultiplexConsumer::MultiplexConsumer(std::vector<clang::ASTConsumer*, std::allocator<clang::ASTConsumer*>> const&)"},
    {"_ZN5clang17MultiplexConsumerC2ERKSt6vectorIPNS_11ASTConsumerESaIS3_EE", "clang::MultiplexConsumer::MultiplexConsumer(std::vector<clang::ASTConsumer*, std::allocator<clang::ASTConsumer*>> const&)"},
    {"_ZN5clang17MultiplexConsumerD0Ev", "clang::MultiplexConsumer::~MultiplexConsumer()"},
    {"_ZN5clang17MultiplexConsumerD1Ev", "clang::MultiplexConsumer::~MultiplexConsumer()"},
    {"_ZN5clang17MultiplexConsumerD2Ev", "clang::MultiplexConsumer::~MultiplexConsumer()"},
    {"_ZN5clang17MultiplexConsumer10InitializeERNS_10ASTContextE", "clang::MultiplexConsumer::Initialize(clang::ASTContext&)"},
    {"_ZN5clang17MultiplexConsumer18HandleTopLevelDeclENS_12DeclGroupRefE", "clang::MultiplexConsumer::HandleTopLevelDecl(clang::DeclGroupRef)"},
    {"_ZN5clang17MultiplexConsumer21HandleInterestingDeclENS_12DeclGroupRefE", "clang::MultiplexConsumer::HandleInterestingDecl(clang::DeclGroupRef)"},
    {"_ZN5clang17MultiplexConsumer21HandleTranslationUnitERNS_10ASTContextE", "clang::MultiplexConsumer::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN5clang17MultiplexConsumer23HandleTagDeclDefinitionEPNS_7TagDeclE", "clang::MultiplexConsumer::HandleTagDeclDefinition(clang::TagDecl*)"},
    {"_ZN5clang17MultiplexConsumer27CompleteTentativeDefinitionEPNS_7VarDeclE", "clang::MultiplexConsumer::CompleteTentativeDefinition(clang::VarDecl*)"},
    {"_ZN5clang17MultiplexConsumer12HandleVTableEPNS_13CXXRecordDeclEb", "clang::MultiplexConsumer::HandleVTable(clang::CXXRecordDecl*, bool)"},
    {"_ZN5clang17MultiplexConsumer22GetASTMutationListenerEv", "clang::MultiplexConsumer::GetASTMutationListener()"},
    {"_ZN5clang17MultiplexConsumer29GetASTDeserializationListenerEv", "clang::MultiplexConsumer::GetASTDeserializationListener()"},
    {"_ZN5clang17MultiplexConsumer10PrintStatsEv", "clang::MultiplexConsumer::PrintStats()"},
    {"_ZN5clang17MultiplexConsumer14InitializeSemaERNS_4SemaE", "clang::MultiplexConsumer::InitializeSema(clang::Sema&)"},
    {"_ZN5clang17MultiplexConsumer10ForgetSemaEv", "clang::MultiplexConsumer::ForgetSema()"},
    {"_ZN5clang35MultiplexASTDeserializationListenerD1Ev", "clang::MultiplexASTDeserializationListener::~MultiplexASTDeserializationListener()"},
    {"_ZN5clang35MultiplexASTDeserializationListenerD0Ev", "clang::MultiplexASTDeserializationListener::~MultiplexASTDeserializationListener()"},
    {"_ZN5clang28MultiplexASTMutationListenerD1Ev", "clang::MultiplexASTMutationListener::~MultiplexASTMutationListener()"},
    {"_ZN5clang28MultiplexASTMutationListenerD0Ev", "clang::MultiplexASTMutationListener::~MultiplexASTMutationListener()"},
    {"_ZNSt6vectorIPN5clang26ASTDeserializationListenerESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::ASTDeserializationListener*, std::allocator<clang::ASTDeserializationListener*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::ASTDeserializationListener**, std::vector<clang::ASTDeserializationListener*, std::allocator<clang::ASTDeserializationListener*>>>, clang::ASTDeserializationListener* const&)"},
    {"_ZNSt6vectorIPN5clang19ASTMutationListenerESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::ASTMutationListener*, std::allocator<clang::ASTMutationListener*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::ASTMutationListener**, std::vector<clang::ASTMutationListener*, std::allocator<clang::ASTMutationListener*>>>, clang::ASTMutationListener* const&)"},
    {"_ZN5clang12SemaConsumerD1Ev", "clang::SemaConsumer::~SemaConsumer()"},
    {"_ZN5clang12SemaConsumerD0Ev", "clang::SemaConsumer::~SemaConsumer()"},
    {"_ZN5clang12SemaConsumer14InitializeSemaERNS_4SemaE", "clang::SemaConsumer::InitializeSema(clang::Sema&)"},
    {"_ZN5clang12SemaConsumer10ForgetSemaEv", "clang::SemaConsumer::ForgetSema()"},
    {"_ZN5clang24DoPrintPreprocessedInputERNS_12PreprocessorEPN4llvm11raw_ostreamERKNS_25PreprocessorOutputOptionsE", "clang::DoPrintPreprocessedInput(clang::Preprocessor&, llvm::raw_ostream*, clang::PreprocessorOutputOptions const&)"},
    {"_ZN12_GLOBAL__N_124PrintPPOutputPPCallbacks10MoveToLineEj", "(anonymous namespace)::PrintPPOutputPPCallbacks::MoveToLine(unsigned int)"},
    {"_ZN12_GLOBAL__N_124PrintPPOutputPPCallbacks13WriteLineInfoEjPKcj", "(anonymous namespace)::PrintPPOutputPPCallbacks::WriteLineInfo(unsigned int, char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_120UnknownPragmaHandlerD1Ev", "(anonymous namespace)::UnknownPragmaHandler::~UnknownPragmaHandler()"},
    {"_ZN12_GLOBAL__N_120UnknownPragmaHandlerD0Ev", "(anonymous namespace)::UnknownPragmaHandler::~UnknownPragmaHandler()"},
    {"_ZN12_GLOBAL__N_120UnknownPragmaHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::UnknownPragmaHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_124PrintPPOutputPPCallbacksD1Ev", "(anonymous namespace)::PrintPPOutputPPCallbacks::~PrintPPOutputPPCallbacks()"},
    {"_ZN12_GLOBAL__N_124PrintPPOutputPPCallbacksD0Ev", "(anonymous namespace)::PrintPPOutputPPCallbacks::~PrintPPOutputPPCallbacks()"},
    {"_ZN12_GLOBAL__N_124PrintPPOutputPPCallbacks11FileChangedEN5clang14SourceLocationENS1_11PPCallbacks16FileChangeReasonENS1_6SrcMgr18CharacteristicKindE", "(anonymous namespace)::PrintPPOutputPPCallbacks::FileChanged(clang::SourceLocation, clang::PPCallbacks::FileChangeReason, clang::SrcMgr::CharacteristicKind)"},
    {"_ZN12_GLOBAL__N_124PrintPPOutputPPCallbacks5IdentEN5clang14SourceLocationERKSs", "(anonymous namespace)::PrintPPOutputPPCallbacks::Ident(clang::SourceLocation, std::string const&)"},
    {"_ZN12_GLOBAL__N_124PrintPPOutputPPCallbacks13PragmaCommentEN5clang14SourceLocationEPKNS1_14IdentifierInfoERKSs", "(anonymous namespace)::PrintPPOutputPPCallbacks::PragmaComment(clang::SourceLocation, clang::IdentifierInfo const*, std::string const&)"},
    {"_ZN12_GLOBAL__N_124PrintPPOutputPPCallbacks13PragmaMessageEN5clang14SourceLocationEN4llvm9StringRefE", "(anonymous namespace)::PrintPPOutputPPCallbacks::PragmaMessage(clang::SourceLocation, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_124PrintPPOutputPPCallbacks12MacroDefinedERKN5clang5TokenEPKNS1_9MacroInfoE", "(anonymous namespace)::PrintPPOutputPPCallbacks::MacroDefined(clang::Token const&, clang::MacroInfo const*)"},
    {"_ZN12_GLOBAL__N_124PrintPPOutputPPCallbacks14MacroUndefinedERKN5clang5TokenEPKNS1_9MacroInfoE", "(anonymous namespace)::PrintPPOutputPPCallbacks::MacroUndefined(clang::Token const&, clang::MacroInfo const*)"},
    {"_Z20PrintMacroDefinitionRKN5clang14IdentifierInfoERKNS_9MacroInfoERNS_12PreprocessorERN4llvm11raw_ostreamE", "PrintMacroDefinition(clang::IdentifierInfo const&, clang::MacroInfo const&, clang::Preprocessor&, llvm::raw_ostream&)"},
    {"_Z14MacroIDComparePKvS0_", "MacroIDCompare(void const*, void const*)"},
    {"_ZN4llvm15SmallVectorImplISt4pairIPN5clang14IdentifierInfoEPNS2_9MacroInfoEEE6appendINS_16DenseMapIteratorIS4_S6_NS_12DenseMapInfoIS4_EENSB_IS6_EELb1EEEEEvT_SF_", "void llvm::SmallVectorImpl<std::pair<clang::IdentifierInfo*, clang::MacroInfo*>>::append<llvm::DenseMapIterator<clang::IdentifierInfo*, clang::MacroInfo*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::MacroInfo*>, true>>(llvm::DenseMapIterator<clang::IdentifierInfo*, clang::MacroInfo*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::MacroInfo*>, true>, llvm::DenseMapIterator<clang::IdentifierInfo*, clang::MacroInfo*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::MacroInfo*>, true>)"},
    {"_ZN5clang11DocumentXML9PrintStmtEPKNS_4StmtE", "clang::DocumentXML::PrintStmt(clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_17StmtXML11DumpSubTreeEPN5clang4StmtE", "(anonymous namespace)::StmtXML::DumpSubTree(clang::Stmt*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_17StmtXMLEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::StmtXML, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_17StmtXML19VisitBinaryOperatorEPN5clang14BinaryOperatorE", "(anonymous namespace)::StmtXML::VisitBinaryOperator(clang::BinaryOperator*)"},
    {"_ZN12_GLOBAL__N_17StmtXML21VisitCXXConstructExprEPN5clang16CXXConstructExprE", "(anonymous namespace)::StmtXML::VisitCXXConstructExpr(clang::CXXConstructExpr*)"},
    {"_ZN12_GLOBAL__N_17StmtXML13VisitCallExprEPN5clang8CallExprE", "(anonymous namespace)::StmtXML::VisitCallExpr(clang::CallExpr*)"},
    {"_ZN12_GLOBAL__N_17StmtXML18VisitUnaryOperatorEPN5clang13UnaryOperatorE", "(anonymous namespace)::StmtXML::VisitUnaryOperator(clang::UnaryOperator*)"},
    {"_ZN12_GLOBAL__N_17StmtXML9VisitStmtEPN5clang4StmtE", "(anonymous namespace)::StmtXML::VisitStmt(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_17StmtXML21VisitCXXNamedCastExprEPN5clang16CXXNamedCastExprE", "(anonymous namespace)::StmtXML::VisitCXXNamedCastExpr(clang::CXXNamedCastExpr*)"},
    {"_ZN5clang20TextDiagnosticBuffer16HandleDiagnosticENS_10Diagnostic5LevelERKNS_14DiagnosticInfoE", "clang::TextDiagnosticBuffer::HandleDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_ZNK5clang20TextDiagnosticBuffer16FlushDiagnosticsERNS_10DiagnosticE", "clang::TextDiagnosticBuffer::FlushDiagnostics(clang::Diagnostic&) const"},
    {"_ZN5clang20TextDiagnosticBufferD1Ev", "clang::TextDiagnosticBuffer::~TextDiagnosticBuffer()"},
    {"_ZN5clang20TextDiagnosticBufferD0Ev", "clang::TextDiagnosticBuffer::~TextDiagnosticBuffer()"},
    {"_ZNSt6vectorISt4pairIN5clang14SourceLocationESsESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<std::pair<clang::SourceLocation, std::string>, std::allocator<std::pair<clang::SourceLocation, std::string>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<clang::SourceLocation, std::string>*, std::vector<std::pair<clang::SourceLocation, std::string>, std::allocator<std::pair<clang::SourceLocation, std::string>>>>, std::pair<clang::SourceLocation, std::string> const&)"},
    {"_ZN5clang20TextDiagnosticBufferD2Ev", "clang::TextDiagnosticBuffer::~TextDiagnosticBuffer()"},
    {"_ZN5clang21TextDiagnosticPrinterC1ERN4llvm11raw_ostreamERKNS_17DiagnosticOptionsEb", "clang::TextDiagnosticPrinter::TextDiagnosticPrinter(llvm::raw_ostream&, clang::DiagnosticOptions const&, bool)"},
    {"_ZN5clang21TextDiagnosticPrinterC2ERN4llvm11raw_ostreamERKNS_17DiagnosticOptionsEb", "clang::TextDiagnosticPrinter::TextDiagnosticPrinter(llvm::raw_ostream&, clang::DiagnosticOptions const&, bool)"},
    {"_ZN5clang21TextDiagnosticPrinterD0Ev", "clang::TextDiagnosticPrinter::~TextDiagnosticPrinter()"},
    {"_ZN5clang21TextDiagnosticPrinterD1Ev", "clang::TextDiagnosticPrinter::~TextDiagnosticPrinter()"},
    {"_ZN5clang21TextDiagnosticPrinterD2Ev", "clang::TextDiagnosticPrinter::~TextDiagnosticPrinter()"},
    {"_ZN5clang21TextDiagnosticPrinter17PrintIncludeStackENS_14SourceLocationERKNS_13SourceManagerE", "clang::TextDiagnosticPrinter::PrintIncludeStack(clang::SourceLocation, clang::SourceManager const&)"},
    {"_ZN5clang21TextDiagnosticPrinter14HighlightRangeERKNS_15CharSourceRangeERKNS_13SourceManagerEjNS_6FileIDERSsRKSs", "clang::TextDiagnosticPrinter::HighlightRange(clang::CharSourceRange const&, clang::SourceManager const&, unsigned int, clang::FileID, std::string&, std::string const&)"},
    {"_ZN5clang21TextDiagnosticPrinter19EmitCaretDiagnosticENS_14SourceLocationEPNS_15CharSourceRangeEjRKNS_13SourceManagerEPKNS_9FixItHintEjjjjj", "clang::TextDiagnosticPrinter::EmitCaretDiagnostic(clang::SourceLocation, clang::CharSourceRange*, unsigned int, clang::SourceManager const&, clang::FixItHint const*, unsigned int, unsigned int, unsigned int, unsigned int, unsigned int)"},
    {"_ZN5clang21TextDiagnosticPrinter16HandleDiagnosticENS_10Diagnostic5LevelERKNS_14DiagnosticInfoE", "clang::TextDiagnosticPrinter::HandleDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_Z13findEndOfWordjRKN4llvm15SmallVectorImplIcEEjjj", "findEndOfWord(unsigned int, llvm::SmallVectorImpl<char> const&, unsigned int, unsigned int, unsigned int)"},
    {"_ZNK5clang13SourceManager16getDecomposedLocENS_14SourceLocationE", "clang::SourceManager::getDecomposedLoc(clang::SourceLocation) const"},
    {"_ZNK5clang13SourceManager29getDecomposedInstantiationLocENS_14SourceLocationE", "clang::SourceManager::getDecomposedInstantiationLoc(clang::SourceLocation) const"},
    {"_ZN5clang21TextDiagnosticPrinter15BeginSourceFileERKNS_11LangOptionsEPKNS_12PreprocessorE", "clang::TextDiagnosticPrinter::BeginSourceFile(clang::LangOptions const&, clang::Preprocessor const*)"},
    {"_ZN5clang21TextDiagnosticPrinter13EndSourceFileEv", "clang::TextDiagnosticPrinter::EndSourceFile()"},
    {"_ZNK5clang13SourceManager16isOffsetInFileIDENS_6FileIDEj", "clang::SourceManager::isOffsetInFileID(clang::FileID, unsigned int) const"},
    {"_ZN5clang11DocumentXML14addParentTypesEPKNS_4TypeE", "clang::DocumentXML::addParentTypes(clang::Type const*)"},
    {"_ZN5clang11DocumentXML14writeTypeToXMLEPKNS_4TypeE", "clang::DocumentXML::writeTypeToXML(clang::Type const*)"},
    {"_ZN5clang11DocumentXML14writeTypeToXMLERKNS_8QualTypeE", "clang::DocumentXML::writeTypeToXML(clang::QualType const&)"},
    {"_ZN5clang3XML12_GLOBAL__N_110TypeWriter9VisitTypeEPKNS_4TypeE", "clang::XML::(anonymous namespace)::TypeWriter::VisitType(clang::Type const*)"},
    {"_ZN5clang11TypeVisitorINS_11DocumentXML9TypeAdderEvE5VisitEPKNS_4TypeE", "clang::TypeVisitor<clang::DocumentXML::TypeAdder, void>::Visit(clang::Type const*)"},
    {"_ZN5clang11DocumentXML12addAttributeIN4llvm5APIntEEEvPKcRKT_", "void clang::DocumentXML::addAttribute<llvm::APInt>(char const*, llvm::APInt const&)"},
    {"_ZN5clang11DocumentXML12addAttributeINS_10Qualifiers2GCEEEvPKcRKT_", "void clang::DocumentXML::addAttribute<clang::Qualifiers::GC>(char const*, clang::Qualifiers::GC const&)"},
    {"_ZN5clang23VerifyDiagnosticsClientC1ERNS_10DiagnosticEPNS_16DiagnosticClientE", "clang::VerifyDiagnosticsClient::VerifyDiagnosticsClient(clang::Diagnostic&, clang::DiagnosticClient*)"},
    {"_ZN5clang23VerifyDiagnosticsClientC2ERNS_10DiagnosticEPNS_16DiagnosticClientE", "clang::VerifyDiagnosticsClient::VerifyDiagnosticsClient(clang::Diagnostic&, clang::DiagnosticClient*)"},
    {"_ZN5clang23VerifyDiagnosticsClientD0Ev", "clang::VerifyDiagnosticsClient::~VerifyDiagnosticsClient()"},
    {"_ZN5clang23VerifyDiagnosticsClientD1Ev", "clang::VerifyDiagnosticsClient::~VerifyDiagnosticsClient()"},
    {"_ZN5clang23VerifyDiagnosticsClientD2Ev", "clang::VerifyDiagnosticsClient::~VerifyDiagnosticsClient()"},
    {"_ZN5clang23VerifyDiagnosticsClient16CheckDiagnosticsEv", "clang::VerifyDiagnosticsClient::CheckDiagnostics()"},
    {"_ZN5clang23VerifyDiagnosticsClient15BeginSourceFileERKNS_11LangOptionsEPKNS_12PreprocessorE", "clang::VerifyDiagnosticsClient::BeginSourceFile(clang::LangOptions const&, clang::Preprocessor const*)"},
    {"_ZN5clang23VerifyDiagnosticsClient13EndSourceFileEv", "clang::VerifyDiagnosticsClient::EndSourceFile()"},
    {"_ZN5clang23VerifyDiagnosticsClient16HandleDiagnosticENS_10Diagnostic5LevelERKNS_14DiagnosticInfoE", "clang::VerifyDiagnosticsClient::HandleDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_Z12PrintProblemRN5clang10DiagnosticEPNS_13SourceManagerEN9__gnu_cxx17__normal_iteratorIPKSt4pairINS_14SourceLocationESsESt6vectorIS8_SaIS8_EEEESE_PKcb", "PrintProblem(clang::Diagnostic&, clang::SourceManager*, __gnu_cxx::__normal_iterator<std::pair<clang::SourceLocation, std::string> const*, std::vector<std::pair<clang::SourceLocation, std::string>, std::allocator<std::pair<clang::SourceLocation, std::string>>>>, __gnu_cxx::__normal_iterator<std::pair<clang::SourceLocation, std::string> const*, std::vector<std::pair<clang::SourceLocation, std::string>, std::allocator<std::pair<clang::SourceLocation, std::string>>>>, char const*, bool)"},
    {"_Z10CheckListsRN5clang10DiagnosticERNS_13SourceManagerEPKcRSt6vectorIPN12_GLOBAL__N_19DirectiveESaIS9_EEN9__gnu_cxx17__normal_iteratorIPKSt4pairINS_14SourceLocationESsES6_ISH_SaISH_EEEESM_", "CheckLists(clang::Diagnostic&, clang::SourceManager&, char const*, std::vector<(anonymous namespace)::Directive*, std::allocator<(anonymous namespace)::Directive*>>&, __gnu_cxx::__normal_iterator<std::pair<clang::SourceLocation, std::string> const*, std::vector<std::pair<clang::SourceLocation, std::string>, std::allocator<std::pair<clang::SourceLocation, std::string>>>>, __gnu_cxx::__normal_iterator<std::pair<clang::SourceLocation, std::string> const*, std::vector<std::pair<clang::SourceLocation, std::string>, std::allocator<std::pair<clang::SourceLocation, std::string>>>>)"},
    {"_ZNSt6vectorIPN12_GLOBAL__N_19DirectiveESaIS2_EE9push_backERKS2_", "std::vector<(anonymous namespace)::Directive*, std::allocator<(anonymous namespace)::Directive*>>::push_back((anonymous namespace)::Directive* const&)"},
    {"_ZN12_GLOBAL__N_117StandardDirectiveD1Ev", "(anonymous namespace)::StandardDirective::~StandardDirective()"},
    {"_ZN12_GLOBAL__N_117StandardDirectiveD0Ev", "(anonymous namespace)::StandardDirective::~StandardDirective()"},
    {"_ZN12_GLOBAL__N_117StandardDirective7isValidERSs", "(anonymous namespace)::StandardDirective::isValid(std::string&)"},
    {"_ZN12_GLOBAL__N_117StandardDirective5MatchERKSs", "(anonymous namespace)::StandardDirective::Match(std::string const&)"},
    {"_ZN12_GLOBAL__N_19DirectiveD1Ev", "(anonymous namespace)::Directive::~Directive()"},
    {"_ZN12_GLOBAL__N_19DirectiveD0Ev", "(anonymous namespace)::Directive::~Directive()"},
    {"_ZN12_GLOBAL__N_114RegexDirectiveD1Ev", "(anonymous namespace)::RegexDirective::~RegexDirective()"},
    {"_ZN12_GLOBAL__N_114RegexDirectiveD0Ev", "(anonymous namespace)::RegexDirective::~RegexDirective()"},
    {"_ZN12_GLOBAL__N_114RegexDirective7isValidERSs", "(anonymous namespace)::RegexDirective::isValid(std::string&)"},
    {"_ZN12_GLOBAL__N_114RegexDirective5MatchERKSs", "(anonymous namespace)::RegexDirective::Match(std::string const&)"},
    {"_ZNSt6vectorISt4pairIN5clang14SourceLocationESsESaIS3_EE19_M_range_initializeIN9__gnu_cxx17__normal_iteratorIPKS3_S5_EEEEvT_SC_St20forward_iterator_tag", "void std::vector<std::pair<clang::SourceLocation, std::string>, std::allocator<std::pair<clang::SourceLocation, std::string>>>::_M_range_initialize<__gnu_cxx::__normal_iterator<std::pair<clang::SourceLocation, std::string> const*, std::vector<std::pair<clang::SourceLocation, std::string>, std::allocator<std::pair<clang::SourceLocation, std::string>>>>>(__gnu_cxx::__normal_iterator<std::pair<clang::SourceLocation, std::string> const*, std::vector<std::pair<clang::SourceLocation, std::string>, std::allocator<std::pair<clang::SourceLocation, std::string>>>>, __gnu_cxx::__normal_iterator<std::pair<clang::SourceLocation, std::string> const*, std::vector<std::pair<clang::SourceLocation, std::string>, std::allocator<std::pair<clang::SourceLocation, std::string>>>>, std::forward_iterator_tag)"},
    {"_ZSt6searchIPKcS1_ET_S2_S2_T0_S3_", "char const* std::search<char const*, char const*>(char const*, char const*, char const*, char const*)"},
    {"_ZN5clang21ProcessWarningOptionsERNS_10DiagnosticERKNS_17DiagnosticOptionsE", "clang::ProcessWarningOptions(clang::Diagnostic&, clang::DiagnosticOptions const&)"},
    {"_ZN5clang6driver6ActionD0Ev", "clang::driver::Action::~Action()"},
    {"_ZN5clang6driver6ActionD1Ev", "clang::driver::Action::~Action()"},
    {"_ZN5clang6driver6ActionD2Ev", "clang::driver::Action::~Action()"},
    {"_ZN5clang6driver6Action12getClassNameENS1_11ActionClassE", "clang::driver::Action::getClassName(clang::driver::Action::ActionClass)"},
    {"_ZN5clang6driver11InputActionC1ERKNS0_3ArgENS0_5types2IDE", "clang::driver::InputAction::InputAction(clang::driver::Arg const&, clang::driver::types::ID)"},
    {"_ZN5clang6driver11InputActionC2ERKNS0_3ArgENS0_5types2IDE", "clang::driver::InputAction::InputAction(clang::driver::Arg const&, clang::driver::types::ID)"},
    {"_ZN5clang6driver14BindArchActionC1EPNS0_6ActionEPKc", "clang::driver::BindArchAction::BindArchAction(clang::driver::Action*, char const*)"},
    {"_ZN5clang6driver14BindArchActionC2EPNS0_6ActionEPKc", "clang::driver::BindArchAction::BindArchAction(clang::driver::Action*, char const*)"},
    {"_ZN5clang6driver9JobActionC1ENS0_6Action11ActionClassEPS2_NS0_5types2IDE", "clang::driver::JobAction::JobAction(clang::driver::Action::ActionClass, clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver9JobActionC2ENS0_6Action11ActionClassEPS2_NS0_5types2IDE", "clang::driver::JobAction::JobAction(clang::driver::Action::ActionClass, clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver9JobActionC1ENS0_6Action11ActionClassERKN4llvm11SmallVectorIPS2_Lj3EEENS0_5types2IDE", "clang::driver::JobAction::JobAction(clang::driver::Action::ActionClass, llvm::SmallVector<clang::driver::Action*, 3u> const&, clang::driver::types::ID)"},
    {"_ZN5clang6driver9JobActionC2ENS0_6Action11ActionClassERKN4llvm11SmallVectorIPS2_Lj3EEENS0_5types2IDE", "clang::driver::JobAction::JobAction(clang::driver::Action::ActionClass, llvm::SmallVector<clang::driver::Action*, 3u> const&, clang::driver::types::ID)"},
    {"_ZN5clang6driver19PreprocessJobActionC1EPNS0_6ActionENS0_5types2IDE", "clang::driver::PreprocessJobAction::PreprocessJobAction(clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver19PreprocessJobActionC2EPNS0_6ActionENS0_5types2IDE", "clang::driver::PreprocessJobAction::PreprocessJobAction(clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver19PrecompileJobActionC1EPNS0_6ActionENS0_5types2IDE", "clang::driver::PrecompileJobAction::PrecompileJobAction(clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver19PrecompileJobActionC2EPNS0_6ActionENS0_5types2IDE", "clang::driver::PrecompileJobAction::PrecompileJobAction(clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver16AnalyzeJobActionC1EPNS0_6ActionENS0_5types2IDE", "clang::driver::AnalyzeJobAction::AnalyzeJobAction(clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver16AnalyzeJobActionC2EPNS0_6ActionENS0_5types2IDE", "clang::driver::AnalyzeJobAction::AnalyzeJobAction(clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver16CompileJobActionC1EPNS0_6ActionENS0_5types2IDE", "clang::driver::CompileJobAction::CompileJobAction(clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver16CompileJobActionC2EPNS0_6ActionENS0_5types2IDE", "clang::driver::CompileJobAction::CompileJobAction(clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver17AssembleJobActionC1EPNS0_6ActionENS0_5types2IDE", "clang::driver::AssembleJobAction::AssembleJobAction(clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver17AssembleJobActionC2EPNS0_6ActionENS0_5types2IDE", "clang::driver::AssembleJobAction::AssembleJobAction(clang::driver::Action*, clang::driver::types::ID)"},
    {"_ZN5clang6driver13LinkJobActionC1ERN4llvm11SmallVectorIPNS0_6ActionELj3EEENS0_5types2IDE", "clang::driver::LinkJobAction::LinkJobAction(llvm::SmallVector<clang::driver::Action*, 3u>&, clang::driver::types::ID)"},
    {"_ZN5clang6driver13LinkJobActionC2ERN4llvm11SmallVectorIPNS0_6ActionELj3EEENS0_5types2IDE", "clang::driver::LinkJobAction::LinkJobAction(llvm::SmallVector<clang::driver::Action*, 3u>&, clang::driver::types::ID)"},
    {"_ZN5clang6driver13LipoJobActionC1ERN4llvm11SmallVectorIPNS0_6ActionELj3EEENS0_5types2IDE", "clang::driver::LipoJobAction::LipoJobAction(llvm::SmallVector<clang::driver::Action*, 3u>&, clang::driver::types::ID)"},
    {"_ZN5clang6driver13LipoJobActionC2ERN4llvm11SmallVectorIPNS0_6ActionELj3EEENS0_5types2IDE", "clang::driver::LipoJobAction::LipoJobAction(llvm::SmallVector<clang::driver::Action*, 3u>&, clang::driver::types::ID)"},
    {"_ZN5clang6driver17DsymutilJobActionC1ERN4llvm11SmallVectorIPNS0_6ActionELj3EEENS0_5types2IDE", "clang::driver::DsymutilJobAction::DsymutilJobAction(llvm::SmallVector<clang::driver::Action*, 3u>&, clang::driver::types::ID)"},
    {"_ZN5clang6driver17DsymutilJobActionC2ERN4llvm11SmallVectorIPNS0_6ActionELj3EEENS0_5types2IDE", "clang::driver::DsymutilJobAction::DsymutilJobAction(llvm::SmallVector<clang::driver::Action*, 3u>&, clang::driver::types::ID)"},
    {"_ZN5clang6driver17DsymutilJobActionD1Ev", "clang::driver::DsymutilJobAction::~DsymutilJobAction()"},
    {"_ZN5clang6driver17DsymutilJobActionD0Ev", "clang::driver::DsymutilJobAction::~DsymutilJobAction()"},
    {"_ZN5clang6driver13LipoJobActionD1Ev", "clang::driver::LipoJobAction::~LipoJobAction()"},
    {"_ZN5clang6driver13LipoJobActionD0Ev", "clang::driver::LipoJobAction::~LipoJobAction()"},
    {"_ZN5clang6driver13LinkJobActionD1Ev", "clang::driver::LinkJobAction::~LinkJobAction()"},
    {"_ZN5clang6driver13LinkJobActionD0Ev", "clang::driver::LinkJobAction::~LinkJobAction()"},
    {"_ZN5clang6driver17AssembleJobActionD1Ev", "clang::driver::AssembleJobAction::~AssembleJobAction()"},
    {"_ZN5clang6driver17AssembleJobActionD0Ev", "clang::driver::AssembleJobAction::~AssembleJobAction()"},
    {"_ZN5clang6driver16CompileJobActionD1Ev", "clang::driver::CompileJobAction::~CompileJobAction()"},
    {"_ZN5clang6driver16CompileJobActionD0Ev", "clang::driver::CompileJobAction::~CompileJobAction()"},
    {"_ZN5clang6driver16AnalyzeJobActionD1Ev", "clang::driver::AnalyzeJobAction::~AnalyzeJobAction()"},
    {"_ZN5clang6driver16AnalyzeJobActionD0Ev", "clang::driver::AnalyzeJobAction::~AnalyzeJobAction()"},
    {"_ZN5clang6driver19PrecompileJobActionD1Ev", "clang::driver::PrecompileJobAction::~PrecompileJobAction()"},
    {"_ZN5clang6driver19PrecompileJobActionD0Ev", "clang::driver::PrecompileJobAction::~PrecompileJobAction()"},
    {"_ZN5clang6driver19PreprocessJobActionD1Ev", "clang::driver::PreprocessJobAction::~PreprocessJobAction()"},
    {"_ZN5clang6driver19PreprocessJobActionD0Ev", "clang::driver::PreprocessJobAction::~PreprocessJobAction()"},
    {"_ZN5clang6driver9JobActionD1Ev", "clang::driver::JobAction::~JobAction()"},
    {"_ZN5clang6driver9JobActionD0Ev", "clang::driver::JobAction::~JobAction()"},
    {"_ZN5clang6driver14BindArchActionD1Ev", "clang::driver::BindArchAction::~BindArchAction()"},
    {"_ZN5clang6driver14BindArchActionD0Ev", "clang::driver::BindArchAction::~BindArchAction()"},
    {"_ZN5clang6driver11InputActionD1Ev", "clang::driver::InputAction::~InputAction()"},
    {"_ZN5clang6driver11InputActionD0Ev", "clang::driver::InputAction::~InputAction()"},
    {"_ZN4llvm15SmallVectorImplIPN5clang6driver6ActionEEaSERKS5_", "llvm::SmallVectorImpl<clang::driver::Action*>::operator=(llvm::SmallVectorImpl<clang::driver::Action*> const&)"},
    {"_ZN5clang6driver3ArgC1EPKNS0_6OptionEjPKS1_", "clang::driver::Arg::Arg(clang::driver::Option const*, unsigned int, clang::driver::Arg const*)"},
    {"_ZN5clang6driver3ArgC2EPKNS0_6OptionEjPKS1_", "clang::driver::Arg::Arg(clang::driver::Option const*, unsigned int, clang::driver::Arg const*)"},
    {"_ZN5clang6driver3ArgC1EPKNS0_6OptionEjPKcPKS1_", "clang::driver::Arg::Arg(clang::driver::Option const*, unsigned int, char const*, clang::driver::Arg const*)"},
    {"_ZN5clang6driver3ArgC2EPKNS0_6OptionEjPKcPKS1_", "clang::driver::Arg::Arg(clang::driver::Option const*, unsigned int, char const*, clang::driver::Arg const*)"},
    {"_ZN5clang6driver3ArgC1EPKNS0_6OptionEjPKcS6_PKS1_", "clang::driver::Arg::Arg(clang::driver::Option const*, unsigned int, char const*, char const*, clang::driver::Arg const*)"},
    {"_ZN5clang6driver3ArgC2EPKNS0_6OptionEjPKcS6_PKS1_", "clang::driver::Arg::Arg(clang::driver::Option const*, unsigned int, char const*, char const*, clang::driver::Arg const*)"},
    {"_ZN5clang6driver3ArgD1Ev", "clang::driver::Arg::~Arg()"},
    {"_ZN5clang6driver3ArgD2Ev", "clang::driver::Arg::~Arg()"},
    {"_ZNK5clang6driver3Arg4dumpEv", "clang::driver::Arg::dump() const"},
    {"_ZNK5clang6driver3Arg11getAsStringERKNS0_7ArgListE", "clang::driver::Arg::getAsString(clang::driver::ArgList const&) const"},
    {"_ZNK5clang6driver3Arg6renderERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::Arg::render(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver3Arg13renderAsInputERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::Arg::renderAsInput(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZN5clang6driver12arg_iterator13SkipToNextArgEv", "clang::driver::arg_iterator::SkipToNextArg()"},
    {"_ZN5clang6driver7ArgListC1Ev", "clang::driver::ArgList::ArgList()"},
    {"_ZN5clang6driver7ArgListC2Ev", "clang::driver::ArgList::ArgList()"},
    {"_ZN5clang6driver7ArgListD0Ev", "clang::driver::ArgList::~ArgList()"},
    {"_ZN5clang6driver7ArgListD1Ev", "clang::driver::ArgList::~ArgList()"},
    {"_ZN5clang6driver7ArgListD2Ev", "clang::driver::ArgList::~ArgList()"},
    {"_ZN5clang6driver7ArgList6appendEPNS0_3ArgE", "clang::driver::ArgList::append(clang::driver::Arg*)"},
    {"_ZNK5clang6driver7ArgList17getLastArgNoClaimENS0_12OptSpecifierE", "clang::driver::ArgList::getLastArgNoClaim(clang::driver::OptSpecifier) const"},
    {"_ZNK5clang6driver7ArgList10getLastArgENS0_12OptSpecifierE", "clang::driver::ArgList::getLastArg(clang::driver::OptSpecifier) const"},
    {"_ZNK5clang6driver7ArgList10getLastArgENS0_12OptSpecifierES2_", "clang::driver::ArgList::getLastArg(clang::driver::OptSpecifier, clang::driver::OptSpecifier) const"},
    {"_ZNK5clang6driver7ArgList10getLastArgENS0_12OptSpecifierES2_S2_", "clang::driver::ArgList::getLastArg(clang::driver::OptSpecifier, clang::driver::OptSpecifier, clang::driver::OptSpecifier) const"},
    {"_ZNK5clang6driver7ArgList10getLastArgENS0_12OptSpecifierES2_S2_S2_", "clang::driver::ArgList::getLastArg(clang::driver::OptSpecifier, clang::driver::OptSpecifier, clang::driver::OptSpecifier, clang::driver::OptSpecifier) const"},
    {"_ZNK5clang6driver7ArgList7hasFlagENS0_12OptSpecifierES2_b", "clang::driver::ArgList::hasFlag(clang::driver::OptSpecifier, clang::driver::OptSpecifier, bool) const"},
    {"_ZNK5clang6driver7ArgList15getLastArgValueENS0_12OptSpecifierEN4llvm9StringRefE", "clang::driver::ArgList::getLastArgValue(clang::driver::OptSpecifier, llvm::StringRef) const"},
    {"_ZNK5clang6driver7ArgList18getLastArgIntValueENS0_12OptSpecifierEiRNS_10DiagnosticE", "clang::driver::ArgList::getLastArgIntValue(clang::driver::OptSpecifier, int, clang::Diagnostic&) const"},
    {"_ZNK5clang6driver7ArgList15getAllArgValuesENS0_12OptSpecifierE", "clang::driver::ArgList::getAllArgValues(clang::driver::OptSpecifier) const"},
    {"_ZNK5clang6driver7ArgList15AddAllArgValuesERN4llvm11SmallVectorIPKcLj16EEENS0_12OptSpecifierES8_S8_", "clang::driver::ArgList::AddAllArgValues(llvm::SmallVector<char const*, 16u>&, clang::driver::OptSpecifier, clang::driver::OptSpecifier, clang::driver::OptSpecifier) const"},
    {"_ZNK5clang6driver7ArgList10AddLastArgERN4llvm11SmallVectorIPKcLj16EEENS0_12OptSpecifierE", "clang::driver::ArgList::AddLastArg(llvm::SmallVector<char const*, 16u>&, clang::driver::OptSpecifier) const"},
    {"_ZNK5clang6driver7ArgList10AddAllArgsERN4llvm11SmallVectorIPKcLj16EEENS0_12OptSpecifierES8_S8_", "clang::driver::ArgList::AddAllArgs(llvm::SmallVector<char const*, 16u>&, clang::driver::OptSpecifier, clang::driver::OptSpecifier, clang::driver::OptSpecifier) const"},
    {"_ZNK5clang6driver7ArgList20AddAllArgsTranslatedERN4llvm11SmallVectorIPKcLj16EEENS0_12OptSpecifierES5_b", "clang::driver::ArgList::AddAllArgsTranslated(llvm::SmallVector<char const*, 16u>&, clang::driver::OptSpecifier, char const*, bool) const"},
    {"_ZNK5clang6driver7ArgList13MakeArgStringERKN4llvm5TwineE", "clang::driver::ArgList::MakeArgString(llvm::Twine const&) const"},
    {"_ZNK5clang6driver7ArgList12ClaimAllArgsENS0_12OptSpecifierE", "clang::driver::ArgList::ClaimAllArgs(clang::driver::OptSpecifier) const"},
    {"_ZNK5clang6driver7ArgList24GetOrMakeJoinedArgStringEjN4llvm9StringRefES3_", "clang::driver::ArgList::GetOrMakeJoinedArgString(unsigned int, llvm::StringRef, llvm::StringRef) const"},
    {"_ZN5clang6driver12InputArgListC1EPKPKcS5_", "clang::driver::InputArgList::InputArgList(char const* const*, char const* const*)"},
    {"_ZN5clang6driver12InputArgListC2EPKPKcS5_", "clang::driver::InputArgList::InputArgList(char const* const*, char const* const*)"},
    {"_ZN5clang6driver12InputArgListD0Ev", "clang::driver::InputArgList::~InputArgList()"},
    {"_ZN5clang6driver12InputArgListD1Ev", "clang::driver::InputArgList::~InputArgList()"},
    {"_ZN5clang6driver12InputArgListD2Ev", "clang::driver::InputArgList::~InputArgList()"},
    {"_ZNK5clang6driver12InputArgList9MakeIndexEN4llvm9StringRefE", "clang::driver::InputArgList::MakeIndex(llvm::StringRef) const"},
    {"_ZNK5clang6driver12InputArgList9MakeIndexEN4llvm9StringRefES3_", "clang::driver::InputArgList::MakeIndex(llvm::StringRef, llvm::StringRef) const"},
    {"_ZNK5clang6driver12InputArgList13MakeArgStringEN4llvm9StringRefE", "clang::driver::InputArgList::MakeArgString(llvm::StringRef) const"},
    {"_ZN5clang6driver14DerivedArgListC1ERKNS0_12InputArgListE", "clang::driver::DerivedArgList::DerivedArgList(clang::driver::InputArgList const&)"},
    {"_ZN5clang6driver14DerivedArgListC2ERKNS0_12InputArgListE", "clang::driver::DerivedArgList::DerivedArgList(clang::driver::InputArgList const&)"},
    {"_ZN5clang6driver14DerivedArgListD0Ev", "clang::driver::DerivedArgList::~DerivedArgList()"},
    {"_ZN5clang6driver14DerivedArgListD1Ev", "clang::driver::DerivedArgList::~DerivedArgList()"},
    {"_ZN5clang6driver14DerivedArgListD2Ev", "clang::driver::DerivedArgList::~DerivedArgList()"},
    {"_ZNK5clang6driver14DerivedArgList13MakeArgStringEN4llvm9StringRefE", "clang::driver::DerivedArgList::MakeArgString(llvm::StringRef) const"},
    {"_ZNK5clang6driver14DerivedArgList11MakeFlagArgEPKNS0_3ArgEPKNS0_6OptionE", "clang::driver::DerivedArgList::MakeFlagArg(clang::driver::Arg const*, clang::driver::Option const*) const"},
    {"_ZNK5clang6driver14DerivedArgList17MakePositionalArgEPKNS0_3ArgEPKNS0_6OptionEN4llvm9StringRefE", "clang::driver::DerivedArgList::MakePositionalArg(clang::driver::Arg const*, clang::driver::Option const*, llvm::StringRef) const"},
    {"_ZNK5clang6driver14DerivedArgList15MakeSeparateArgEPKNS0_3ArgEPKNS0_6OptionEN4llvm9StringRefE", "clang::driver::DerivedArgList::MakeSeparateArg(clang::driver::Arg const*, clang::driver::Option const*, llvm::StringRef) const"},
    {"_ZNK5clang6driver14DerivedArgList13MakeJoinedArgEPKNS0_3ArgEPKNS0_6OptionEN4llvm9StringRefE", "clang::driver::DerivedArgList::MakeJoinedArg(clang::driver::Arg const*, clang::driver::Option const*, llvm::StringRef) const"},
    {"_ZNK5clang6driver12InputArgList12getArgStringEj", "clang::driver::InputArgList::getArgString(unsigned int) const"},
    {"_ZNK5clang6driver12InputArgList21getNumInputArgStringsEv", "clang::driver::InputArgList::getNumInputArgStrings() const"},
    {"_ZNK5clang6driver14DerivedArgList12getArgStringEj", "clang::driver::DerivedArgList::getArgString(unsigned int) const"},
    {"_ZNK5clang6driver14DerivedArgList21getNumInputArgStringsEv", "clang::driver::DerivedArgList::getNumInputArgStrings() const"},
    {"_ZNSt6vectorISsSaISsEE22_M_initialize_dispatchIPPKcEEvT_S6_St12__false_type", "void std::vector<std::string, std::allocator<std::string>>::_M_initialize_dispatch<char const**>(char const**, char const**, std::__false_type)"},
    {"_ZN5clang6driver19createCC1AsOptTableEv", "clang::driver::createCC1AsOptTable()"},
    {"_ZN5clang6driver17createCC1OptTableEv", "clang::driver::createCC1OptTable()"},
    {"_ZN5clang6driver11CompilationC1ERKNS0_6DriverERKNS0_9ToolChainEPNS0_12InputArgListEPNS0_14DerivedArgListE", "clang::driver::Compilation::Compilation(clang::driver::Driver const&, clang::driver::ToolChain const&, clang::driver::InputArgList*, clang::driver::DerivedArgList*)"},
    {"_ZN5clang6driver11CompilationC2ERKNS0_6DriverERKNS0_9ToolChainEPNS0_12InputArgListEPNS0_14DerivedArgListE", "clang::driver::Compilation::Compilation(clang::driver::Driver const&, clang::driver::ToolChain const&, clang::driver::InputArgList*, clang::driver::DerivedArgList*)"},
    {"_ZN5clang6driver11CompilationD1Ev", "clang::driver::Compilation::~Compilation()"},
    {"_ZN5clang6driver11CompilationD2Ev", "clang::driver::Compilation::~Compilation()"},
    {"_ZN5clang6driver11Compilation19getArgsForToolChainEPKNS0_9ToolChainEPKc", "clang::driver::Compilation::getArgsForToolChain(clang::driver::ToolChain const*, char const*)"},
    {"_ZNK5clang6driver11Compilation8PrintJobERN4llvm11raw_ostreamERKNS0_3JobEPKcb", "clang::driver::Compilation::PrintJob(llvm::raw_ostream&, clang::driver::Job const&, char const*, bool) const"},
    {"_ZNK5clang6driver11Compilation15CleanupFileListERKN4llvm11SmallVectorIPKcLj16EEEb", "clang::driver::Compilation::CleanupFileList(llvm::SmallVector<char const*, 16u> const&, bool) const"},
    {"_ZNK5clang6driver11Compilation14ExecuteCommandERKNS0_7CommandERPS3_", "clang::driver::Compilation::ExecuteCommand(clang::driver::Command const&, clang::driver::Command const*&) const"},
    {"_ZNK5clang6driver11Compilation10ExecuteJobERKNS0_3JobERPKNS0_7CommandE", "clang::driver::Compilation::ExecuteJob(clang::driver::Job const&, clang::driver::Command const*&) const"},
    {"_ZNK4llvm8DenseMapISt4pairIPKN5clang6driver9ToolChainEPKcEPNS3_14DerivedArgListENS_12DenseMapInfoIS9_EENSC_ISB_EEE15LookupBucketForERKS9_RPS1_IS9_SB_E", "llvm::DenseMap<std::pair<clang::driver::ToolChain const*, char const*>, clang::driver::DerivedArgList*, llvm::DenseMapInfo<std::pair<clang::driver::ToolChain const*, char const*>>, llvm::DenseMapInfo<clang::driver::DerivedArgList*>>::LookupBucketFor(std::pair<clang::driver::ToolChain const*, char const*> const&, std::pair<std::pair<clang::driver::ToolChain const*, char const*>, clang::driver::DerivedArgList*>*&) const"},
    {"_ZN4llvm8DenseMapISt4pairIPKN5clang6driver9ToolChainEPKcEPNS3_14DerivedArgListENS_12DenseMapInfoIS9_EENSC_ISB_EEE16InsertIntoBucketERKS9_RKSB_PS1_IS9_SB_E", "llvm::DenseMap<std::pair<clang::driver::ToolChain const*, char const*>, clang::driver::DerivedArgList*, llvm::DenseMapInfo<std::pair<clang::driver::ToolChain const*, char const*>>, llvm::DenseMapInfo<clang::driver::DerivedArgList*>>::InsertIntoBucket(std::pair<clang::driver::ToolChain const*, char const*> const&, clang::driver::DerivedArgList* const&, std::pair<std::pair<clang::driver::ToolChain const*, char const*>, clang::driver::DerivedArgList*>*)"},
    {"_ZN4llvm8DenseMapISt4pairIPKN5clang6driver9ToolChainEPKcEPNS3_14DerivedArgListENS_12DenseMapInfoIS9_EENSC_ISB_EEE4growEj", "llvm::DenseMap<std::pair<clang::driver::ToolChain const*, char const*>, clang::driver::DerivedArgList*, llvm::DenseMapInfo<std::pair<clang::driver::ToolChain const*, char const*>>, llvm::DenseMapInfo<clang::driver::DerivedArgList*>>::grow(unsigned int)"},
    {"_ZN5clang6driver6DriverC1EN4llvm9StringRefES3_S3_bbRNS_10DiagnosticE", "clang::driver::Driver::Driver(llvm::StringRef, llvm::StringRef, llvm::StringRef, bool, bool, clang::Diagnostic&)"},
    {"_ZN5clang6driver6DriverC2EN4llvm9StringRefES3_S3_bbRNS_10DiagnosticE", "clang::driver::Driver::Driver(llvm::StringRef, llvm::StringRef, llvm::StringRef, bool, bool, clang::Diagnostic&)"},
    {"_ZN5clang6driver6DriverD1Ev", "clang::driver::Driver::~Driver()"},
    {"_ZN5clang6driver6DriverD2Ev", "clang::driver::Driver::~Driver()"},
    {"_ZN5clang6driver6Driver15ParseArgStringsEPPKcS4_", "clang::driver::Driver::ParseArgStrings(char const**, char const**)"},
    {"_ZNK5clang6driver6Driver18TranslateInputArgsERKNS0_12InputArgListE", "clang::driver::Driver::TranslateInputArgs(clang::driver::InputArgList const&) const"},
    {"_ZN5clang6driver6Driver16BuildCompilationEiPPKc", "clang::driver::Driver::BuildCompilation(int, char const**)"},
    {"_ZNK5clang6driver6Driver11GetHostInfoEPKc", "clang::driver::Driver::GetHostInfo(char const*) const"},
    {"_ZNK5clang6driver6Driver12PrintOptionsERKNS0_7ArgListE", "clang::driver::Driver::PrintOptions(clang::driver::ArgList const&) const"},
    {"_ZN5clang6driver6Driver19HandleImmediateArgsERKNS0_11CompilationE", "clang::driver::Driver::HandleImmediateArgs(clang::driver::Compilation const&)"},
    {"_ZNK5clang6driver6Driver21BuildUniversalActionsERKNS0_9ToolChainERKNS0_7ArgListERN4llvm11SmallVectorIPNS0_6ActionELj3EEE", "clang::driver::Driver::BuildUniversalActions(clang::driver::ToolChain const&, clang::driver::ArgList const&, llvm::SmallVector<clang::driver::Action*, 3u>&) const"},
    {"_ZNK5clang6driver6Driver12BuildActionsERKNS0_9ToolChainERKNS0_7ArgListERN4llvm11SmallVectorIPNS0_6ActionELj3EEE", "clang::driver::Driver::BuildActions(clang::driver::ToolChain const&, clang::driver::ArgList const&, llvm::SmallVector<clang::driver::Action*, 3u>&) const"},
    {"_ZNK5clang6driver6Driver12PrintActionsERKNS0_11CompilationE", "clang::driver::Driver::PrintActions(clang::driver::Compilation const&) const"},
    {"_ZNK5clang6driver6Driver9BuildJobsERNS0_11CompilationE", "clang::driver::Driver::BuildJobs(clang::driver::Compilation&) const"},
    {"_ZNK5clang6driver6Driver18ExecuteCompilationERKNS0_11CompilationE", "clang::driver::Driver::ExecuteCompilation(clang::driver::Compilation const&) const"},
    {"_ZNK5clang6driver6Driver9PrintHelpEb", "clang::driver::Driver::PrintHelp(bool) const"},
    {"_ZNK5clang6driver6Driver12PrintVersionERKNS0_11CompilationERN4llvm11raw_ostreamE", "clang::driver::Driver::PrintVersion(clang::driver::Compilation const&, llvm::raw_ostream&) const"},
    {"_ZNK5clang6driver6Driver11GetFilePathEPKcRKNS0_9ToolChainE", "clang::driver::Driver::GetFilePath(char const*, clang::driver::ToolChain const&) const"},
    {"_ZNK5clang6driver6Driver14GetProgramPathEPKcRKNS0_9ToolChainEb", "clang::driver::Driver::GetProgramPath(char const*, clang::driver::ToolChain const&, bool) const"},
    {"_Z13PrintActions1RKN5clang6driver11CompilationEPNS0_6ActionERSt3mapIS5_jSt4lessIS5_ESaISt4pairIKS5_jEEE", "PrintActions1(clang::driver::Compilation const&, clang::driver::Action*, std::map<clang::driver::Action*, unsigned int, std::less<clang::driver::Action*>, std::allocator<std::pair<clang::driver::Action* const, unsigned int>>>&)"},
    {"_Z21ContainsCompileActionPKN5clang6driver6ActionE", "ContainsCompileAction(clang::driver::Action const*)"},
    {"_ZNK5clang6driver6Driver20ConstructPhaseActionERKNS0_7ArgListENS0_6phases2IDEPNS0_6ActionE", "clang::driver::Driver::ConstructPhaseAction(clang::driver::ArgList const&, clang::driver::phases::ID, clang::driver::Action*) const"},
    {"_ZNK5clang6driver6Driver18BuildJobsForActionERNS0_11CompilationEPKNS0_6ActionEPKNS0_9ToolChainEPKcbSB_RNS0_9InputInfoE", "clang::driver::Driver::BuildJobsForAction(clang::driver::Compilation&, clang::driver::Action const*, clang::driver::ToolChain const*, char const*, bool, char const*, clang::driver::InputInfo&) const"},
    {"_ZNK5clang6driver6Driver18GetNamedOutputPathERNS0_11CompilationERKNS0_9JobActionEPKcb", "clang::driver::Driver::GetNamedOutputPath(clang::driver::Compilation&, clang::driver::JobAction const&, char const*, bool) const"},
    {"_ZNK5clang6driver6Driver16GetTemporaryPathEPKc", "clang::driver::Driver::GetTemporaryPath(char const*) const"},
    {"_ZNK5clang6driver6Driver22ShouldUseClangCompilerERKNS0_11CompilationERKNS0_9JobActionERKN4llvm6TripleE", "clang::driver::Driver::ShouldUseClangCompiler(clang::driver::Compilation const&, clang::driver::JobAction const&, llvm::Triple const&) const"},
    {"_ZN5clang6driver6Driver17GetReleaseVersionEPKcRjS4_S4_Rb", "clang::driver::Driver::GetReleaseVersion(char const*, unsigned int&, unsigned int&, unsigned int&, bool&)"},
    {"_ZN4llvm22PrettyStackTraceStringD1Ev", "llvm::PrettyStackTraceString::~PrettyStackTraceString()"},
    {"_ZN4llvm9StringSetINS_15MallocAllocatorEE6insertENS_9StringRefE", "llvm::StringSet<llvm::MallocAllocator>::insert(llvm::StringRef)"},
    {"_ZNK5clang6driver9InputInfo11getAsStringEv", "clang::driver::InputInfo::getAsString() const"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang6driver9InputInfoELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::driver::InputInfo, false>::grow(unsigned long)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISsLb0EE4growEm", "llvm::SmallVectorTemplateBase<std::string, false>::grow(unsigned long)"},
    {"_ZNSt8_Rb_treeIN4llvm6Triple8ArchTypeES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE8_M_eraseEPSt13_Rb_tree_nodeIS2_E", "std::_Rb_tree<llvm::Triple::ArchType, llvm::Triple::ArchType, std::_Identity<llvm::Triple::ArchType>, std::less<llvm::Triple::ArchType>, std::allocator<llvm::Triple::ArchType>>::_M_erase(std::_Rb_tree_node<llvm::Triple::ArchType>*)"},
    {"_ZNSt8_Rb_treeIN4llvm6Triple8ArchTypeES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE16_M_insert_uniqueERKS2_", "std::_Rb_tree<llvm::Triple::ArchType, llvm::Triple::ArchType, std::_Identity<llvm::Triple::ArchType>, std::less<llvm::Triple::ArchType>, std::allocator<llvm::Triple::ArchType>>::_M_insert_unique(llvm::Triple::ArchType const&)"},
    {"_ZNSt8_Rb_treeIPN5clang6driver6ActionESt4pairIKS3_jESt10_Select1stIS6_ESt4lessIS3_ESaIS6_EE8_M_eraseEPSt13_Rb_tree_nodeIS6_E", "std::_Rb_tree<clang::driver::Action*, std::pair<clang::driver::Action* const, unsigned int>, std::_Select1st<std::pair<clang::driver::Action* const, unsigned int>>, std::less<clang::driver::Action*>, std::allocator<std::pair<clang::driver::Action* const, unsigned int>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::driver::Action* const, unsigned int>>*)"},
    {"_ZNK4llvm18raw_string_ostream11current_posEv", "llvm::raw_string_ostream::current_pos() const"},
    {"_ZNSt8_Rb_treeIPN5clang6driver6ActionESt4pairIKS3_jESt10_Select1stIS6_ESt4lessIS3_ESaIS6_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS6_ERKS6_", "std::_Rb_tree<clang::driver::Action*, std::pair<clang::driver::Action* const, unsigned int>, std::_Select1st<std::pair<clang::driver::Action* const, unsigned int>>, std::less<clang::driver::Action*>, std::allocator<std::pair<clang::driver::Action* const, unsigned int>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::driver::Action* const, unsigned int>>, std::pair<clang::driver::Action* const, unsigned int> const&)"},
    {"_ZNSt8_Rb_treeIPN5clang6driver6ActionESt4pairIKS3_jESt10_Select1stIS6_ESt4lessIS3_ESaIS6_EE16_M_insert_uniqueERKS6_", "std::_Rb_tree<clang::driver::Action*, std::pair<clang::driver::Action* const, unsigned int>, std::_Select1st<std::pair<clang::driver::Action* const, unsigned int>>, std::less<clang::driver::Action*>, std::allocator<std::pair<clang::driver::Action* const, unsigned int>>>::_M_insert_unique(std::pair<clang::driver::Action* const, unsigned int> const&)"},
    {"_ZN4llvm6TripleC2ENS_9StringRefES1_S1_", "llvm::Triple::Triple(llvm::StringRef, llvm::StringRef, llvm::StringRef)"},
    {"_ZN4llvm22PrettyStackTraceStringD0Ev", "llvm::PrettyStackTraceString::~PrettyStackTraceString()"},
    {"_ZN5clang6driver20createDriverOptTableEv", "clang::driver::createDriverOptTable()"},
    {"_ZN5clang6driver8HostInfoC1ERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::HostInfo::HostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver8HostInfoC2ERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::HostInfo::HostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver8HostInfoD0Ev", "clang::driver::HostInfo::~HostInfo()"},
    {"_ZN5clang6driver8HostInfoD1Ev", "clang::driver::HostInfo::~HostInfo()"},
    {"_ZN5clang6driver8HostInfoD2Ev", "clang::driver::HostInfo::~HostInfo()"},
    {"_ZN5clang6driver22createAuroraUXHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createAuroraUXHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver20createDarwinHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createDarwinHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver21createOpenBSDHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createOpenBSDHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver21createFreeBSDHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createFreeBSDHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver20createNetBSDHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createNetBSDHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver19createMinixHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createMinixHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver23createDragonFlyHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createDragonFlyHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver19createLinuxHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createLinuxHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver17createTCEHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createTCEHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver21createWindowsHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createWindowsHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver19createMinGWHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createMinGWHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN5clang6driver21createUnknownHostInfoERKNS0_6DriverERKN4llvm6TripleE", "clang::driver::createUnknownHostInfo(clang::driver::Driver const&, llvm::Triple const&)"},
    {"_ZN12_GLOBAL__N_115UnknownHostInfoD1Ev", "(anonymous namespace)::UnknownHostInfo::~UnknownHostInfo()"},
    {"_ZN12_GLOBAL__N_115UnknownHostInfoD0Ev", "(anonymous namespace)::UnknownHostInfo::~UnknownHostInfo()"},
    {"_ZNK12_GLOBAL__N_115UnknownHostInfo15useDriverDriverEv", "(anonymous namespace)::UnknownHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_115UnknownHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::UnknownHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZN12_GLOBAL__N_115UnknownHostInfoD2Ev", "(anonymous namespace)::UnknownHostInfo::~UnknownHostInfo()"},
    {"_ZN12_GLOBAL__N_113MinGWHostInfoD1Ev", "(anonymous namespace)::MinGWHostInfo::~MinGWHostInfo()"},
    {"_ZN12_GLOBAL__N_113MinGWHostInfoD0Ev", "(anonymous namespace)::MinGWHostInfo::~MinGWHostInfo()"},
    {"_ZN12_GLOBAL__N_115WindowsHostInfoD1Ev", "(anonymous namespace)::WindowsHostInfo::~WindowsHostInfo()"},
    {"_ZN12_GLOBAL__N_115WindowsHostInfoD0Ev", "(anonymous namespace)::WindowsHostInfo::~WindowsHostInfo()"},
    {"_ZNK12_GLOBAL__N_115WindowsHostInfo15useDriverDriverEv", "(anonymous namespace)::WindowsHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_115WindowsHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::WindowsHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZNK12_GLOBAL__N_115WindowsHostInfo22lookupTypeForExtensionEPKc", "(anonymous namespace)::WindowsHostInfo::lookupTypeForExtension(char const*) const"},
    {"_ZN12_GLOBAL__N_111TCEHostInfoD1Ev", "(anonymous namespace)::TCEHostInfo::~TCEHostInfo()"},
    {"_ZN12_GLOBAL__N_111TCEHostInfoD0Ev", "(anonymous namespace)::TCEHostInfo::~TCEHostInfo()"},
    {"_ZNK12_GLOBAL__N_111TCEHostInfo15useDriverDriverEv", "(anonymous namespace)::TCEHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_111TCEHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::TCEHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZN12_GLOBAL__N_113LinuxHostInfoD1Ev", "(anonymous namespace)::LinuxHostInfo::~LinuxHostInfo()"},
    {"_ZN12_GLOBAL__N_113LinuxHostInfoD0Ev", "(anonymous namespace)::LinuxHostInfo::~LinuxHostInfo()"},
    {"_ZNK12_GLOBAL__N_113LinuxHostInfo15useDriverDriverEv", "(anonymous namespace)::LinuxHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_113LinuxHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::LinuxHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZN12_GLOBAL__N_117DragonFlyHostInfoD1Ev", "(anonymous namespace)::DragonFlyHostInfo::~DragonFlyHostInfo()"},
    {"_ZN12_GLOBAL__N_117DragonFlyHostInfoD0Ev", "(anonymous namespace)::DragonFlyHostInfo::~DragonFlyHostInfo()"},
    {"_ZNK12_GLOBAL__N_117DragonFlyHostInfo15useDriverDriverEv", "(anonymous namespace)::DragonFlyHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_117DragonFlyHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::DragonFlyHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZN12_GLOBAL__N_113MinixHostInfoD1Ev", "(anonymous namespace)::MinixHostInfo::~MinixHostInfo()"},
    {"_ZN12_GLOBAL__N_113MinixHostInfoD0Ev", "(anonymous namespace)::MinixHostInfo::~MinixHostInfo()"},
    {"_ZNK12_GLOBAL__N_113MinixHostInfo15useDriverDriverEv", "(anonymous namespace)::MinixHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_113MinixHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::MinixHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZN12_GLOBAL__N_114NetBSDHostInfoD1Ev", "(anonymous namespace)::NetBSDHostInfo::~NetBSDHostInfo()"},
    {"_ZN12_GLOBAL__N_114NetBSDHostInfoD0Ev", "(anonymous namespace)::NetBSDHostInfo::~NetBSDHostInfo()"},
    {"_ZNK12_GLOBAL__N_114NetBSDHostInfo15useDriverDriverEv", "(anonymous namespace)::NetBSDHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_114NetBSDHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::NetBSDHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZN12_GLOBAL__N_115FreeBSDHostInfoD1Ev", "(anonymous namespace)::FreeBSDHostInfo::~FreeBSDHostInfo()"},
    {"_ZN12_GLOBAL__N_115FreeBSDHostInfoD0Ev", "(anonymous namespace)::FreeBSDHostInfo::~FreeBSDHostInfo()"},
    {"_ZNK12_GLOBAL__N_115FreeBSDHostInfo15useDriverDriverEv", "(anonymous namespace)::FreeBSDHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_115FreeBSDHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::FreeBSDHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZN12_GLOBAL__N_115OpenBSDHostInfoD1Ev", "(anonymous namespace)::OpenBSDHostInfo::~OpenBSDHostInfo()"},
    {"_ZN12_GLOBAL__N_115OpenBSDHostInfoD0Ev", "(anonymous namespace)::OpenBSDHostInfo::~OpenBSDHostInfo()"},
    {"_ZNK12_GLOBAL__N_115OpenBSDHostInfo15useDriverDriverEv", "(anonymous namespace)::OpenBSDHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_115OpenBSDHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::OpenBSDHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZN12_GLOBAL__N_114DarwinHostInfoD1Ev", "(anonymous namespace)::DarwinHostInfo::~DarwinHostInfo()"},
    {"_ZN12_GLOBAL__N_114DarwinHostInfoD0Ev", "(anonymous namespace)::DarwinHostInfo::~DarwinHostInfo()"},
    {"_ZNK12_GLOBAL__N_114DarwinHostInfo15useDriverDriverEv", "(anonymous namespace)::DarwinHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_114DarwinHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::DarwinHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZN12_GLOBAL__N_116AuroraUXHostInfoD1Ev", "(anonymous namespace)::AuroraUXHostInfo::~AuroraUXHostInfo()"},
    {"_ZN12_GLOBAL__N_116AuroraUXHostInfoD0Ev", "(anonymous namespace)::AuroraUXHostInfo::~AuroraUXHostInfo()"},
    {"_ZNK12_GLOBAL__N_116AuroraUXHostInfo15useDriverDriverEv", "(anonymous namespace)::AuroraUXHostInfo::useDriverDriver() const"},
    {"_ZNK12_GLOBAL__N_116AuroraUXHostInfo15CreateToolChainERKN5clang6driver7ArgListEPKc", "(anonymous namespace)::AuroraUXHostInfo::CreateToolChain(clang::driver::ArgList const&, char const*) const"},
    {"_ZN4llvm9StringMapIPN5clang6driver9ToolChainENS_15MallocAllocatorEE16GetOrCreateValueIS4_EERNS_14StringMapEntryIS4_EENS_9StringRefET_", "llvm::StringMapEntry<clang::driver::ToolChain*>& llvm::StringMap<clang::driver::ToolChain*, llvm::MallocAllocator>::GetOrCreateValue<clang::driver::ToolChain*>(llvm::StringRef, clang::driver::ToolChain*)"},
    {"_ZNK5clang6driver9ToolChain13TranslateArgsERKNS0_14DerivedArgListEPKc", "clang::driver::ToolChain::TranslateArgs(clang::driver::DerivedArgList const&, char const*) const"},
    {"_ZNK5clang6driver9ToolChain15IsBlocksDefaultEv", "clang::driver::ToolChain::IsBlocksDefault() const"},
    {"_ZNK5clang6driver9ToolChain28IsIntegratedAssemblerDefaultEv", "clang::driver::ToolChain::IsIntegratedAssemblerDefault() const"},
    {"_ZNK5clang6driver9ToolChain23IsStrictAliasingDefaultEv", "clang::driver::ToolChain::IsStrictAliasingDefault() const"},
    {"_ZNK5clang6driver9ToolChain35IsObjCDefaultSynthPropertiesDefaultEv", "clang::driver::ToolChain::IsObjCDefaultSynthPropertiesDefault() const"},
    {"_ZNK5clang6driver9ToolChain26IsObjCNonFragileABIDefaultEv", "clang::driver::ToolChain::IsObjCNonFragileABIDefault() const"},
    {"_ZNK5clang6driver9ToolChain27IsObjCLegacyDispatchDefaultEv", "clang::driver::ToolChain::IsObjCLegacyDispatchDefault() const"},
    {"_ZNK5clang6driver9ToolChain20UseObjCMixedDispatchEv", "clang::driver::ToolChain::UseObjCMixedDispatch() const"},
    {"_ZNK5clang6driver9ToolChain29GetDefaultStackProtectorLevelEv", "clang::driver::ToolChain::GetDefaultStackProtectorLevel() const"},
    {"_ZNK5clang6driver10toolchains18Darwin_Generic_GCC25GetDefaultRelocationModelEv", "clang::driver::toolchains::Darwin_Generic_GCC::GetDefaultRelocationModel() const"},
    {"_ZNK5clang6driver9ToolChain14SupportsObjCGCEv", "clang::driver::ToolChain::SupportsObjCGC() const"},
    {"_ZNK5clang6driver9ToolChain18UseDwarfDebugFlagsEv", "clang::driver::ToolChain::UseDwarfDebugFlags() const"},
    {"_ZNK5clang6driver9ToolChain17UseSjLjExceptionsEv", "clang::driver::ToolChain::UseSjLjExceptions() const"},
    {"_ZN4llvm8DenseMapIjPN5clang6driver9ToolChainENS_12DenseMapInfoIjEENS5_IS4_EEE16InsertIntoBucketERKjRKS4_PSt4pairIjS4_E", "llvm::DenseMap<unsigned int, clang::driver::ToolChain*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<clang::driver::ToolChain*>>::InsertIntoBucket(unsigned int const&, clang::driver::ToolChain* const&, std::pair<unsigned int, clang::driver::ToolChain*>*)"},
    {"_ZN4llvm8DenseMapIjPN5clang6driver9ToolChainENS_12DenseMapInfoIjEENS5_IS4_EEE4growEj", "llvm::DenseMap<unsigned int, clang::driver::ToolChain*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<clang::driver::ToolChain*>>::grow(unsigned int)"},
    {"_ZN5clang6driver3JobD0Ev", "clang::driver::Job::~Job()"},
    {"_ZN5clang6driver3JobD1Ev", "clang::driver::Job::~Job()"},
    {"_ZN5clang6driver3JobD2Ev", "clang::driver::Job::~Job()"},
    {"_ZN5clang6driver7CommandC1ERKNS0_6ActionERKNS0_4ToolEPKcRKN4llvm11SmallVectorIS9_Lj16EEE", "clang::driver::Command::Command(clang::driver::Action const&, clang::driver::Tool const&, char const*, llvm::SmallVector<char const*, 16u> const&)"},
    {"_ZN5clang6driver7CommandC2ERKNS0_6ActionERKNS0_4ToolEPKcRKN4llvm11SmallVectorIS9_Lj16EEE", "clang::driver::Command::Command(clang::driver::Action const&, clang::driver::Tool const&, char const*, llvm::SmallVector<char const*, 16u> const&)"},
    {"_ZN5clang6driver7JobListC1Ev", "clang::driver::JobList::JobList()"},
    {"_ZN5clang6driver7JobListC2Ev", "clang::driver::JobList::JobList()"},
    {"_ZN5clang6driver7JobListD0Ev", "clang::driver::JobList::~JobList()"},
    {"_ZN5clang6driver7JobListD1Ev", "clang::driver::JobList::~JobList()"},
    {"_ZN5clang6driver7JobListD2Ev", "clang::driver::JobList::~JobList()"},
    {"_ZN5clang6driver3Job10addCommandEPNS0_7CommandE", "clang::driver::Job::addCommand(clang::driver::Command*)"},
    {"_ZN5clang6driver7CommandD1Ev", "clang::driver::Command::~Command()"},
    {"_ZN5clang6driver7CommandD0Ev", "clang::driver::Command::~Command()"},
    {"_ZN4llvm15SmallVectorImplIPKcEaSERKS3_", "llvm::SmallVectorImpl<char const*>::operator=(llvm::SmallVectorImpl<char const*> const&)"},
    {"_ZN5clang6driver12OptSpecifierC1EPKNS0_6OptionE", "clang::driver::OptSpecifier::OptSpecifier(clang::driver::Option const*)"},
    {"_ZN5clang6driver12OptSpecifierC2EPKNS0_6OptionE", "clang::driver::OptSpecifier::OptSpecifier(clang::driver::Option const*)"},
    {"_ZN5clang6driver8OptTableC1EPKNS1_4InfoEj", "clang::driver::OptTable::OptTable(clang::driver::OptTable::Info const*, unsigned int)"},
    {"_ZN5clang6driver8OptTableC2EPKNS1_4InfoEj", "clang::driver::OptTable::OptTable(clang::driver::OptTable::Info const*, unsigned int)"},
    {"_ZN5clang6driver8OptTableD1Ev", "clang::driver::OptTable::~OptTable()"},
    {"_ZN5clang6driver8OptTableD2Ev", "clang::driver::OptTable::~OptTable()"},
    {"_ZNK5clang6driver8OptTable12CreateOptionEj", "clang::driver::OptTable::CreateOption(unsigned int) const"},
    {"_ZNK5clang6driver8OptTable11ParseOneArgERKNS0_7ArgListERj", "clang::driver::OptTable::ParseOneArg(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZNK5clang6driver8OptTable9ParseArgsEPKPKcS5_RjS6_", "clang::driver::OptTable::ParseArgs(char const* const*, char const* const*, unsigned int&, unsigned int&) const"},
    {"_ZNK5clang6driver8OptTable9PrintHelpERN4llvm11raw_ostreamEPKcS6_b", "clang::driver::OptTable::PrintHelp(llvm::raw_ostream&, char const*, char const*, bool) const"},
    {"_ZNSt3mapISsSt6vectorISt4pairISsPKcESaIS4_EESt4lessISsESaIS1_IKSsS6_EEEixERS9_", "std::map<std::string, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>>::operator[](std::string const&)"},
    {"_ZNSt6vectorISt4pairISsPKcESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<std::string, char const*>*, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>, std::pair<std::string, char const*> const&)"},
    {"_ZNSt6vectorISt4pairISsPKcESaIS3_EEC2ERKS5_", "std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>::vector(std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsSt6vectorIS0_ISsPKcESaIS5_EEESt10_Select1stIS8_ESt4lessISsESaIS8_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS8_ERKS8_", "std::_Rb_tree<std::string, std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>, std::_Select1st<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>, std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsSt6vectorIS0_ISsPKcESaIS5_EEESt10_Select1stIS8_ESt4lessISsESaIS8_EE9_M_insertEPSt18_Rb_tree_node_baseSG_RKS8_", "std::_Rb_tree<std::string, std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>, std::_Select1st<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsSt6vectorIS0_ISsPKcESaIS5_EEESt10_Select1stIS8_ESt4lessISsESaIS8_EE16_M_insert_uniqueERKS8_", "std::_Rb_tree<std::string, std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>, std::_Select1st<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>>::_M_insert_unique(std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsSt6vectorIS0_ISsPKcESaIS5_EEESt10_Select1stIS8_ESt4lessISsESaIS8_EE8_M_eraseEPSt13_Rb_tree_nodeIS8_E", "std::_Rb_tree<std::string, std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>, std::_Select1st<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>>::_M_erase(std::_Rb_tree_node<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>*)"},
    {"_ZN9__gnu_cxx13new_allocatorISt4pairIKSsSt6vectorIS1_ISsPKcESaIS6_EEEE7destroyEPS9_", "__gnu_cxx::new_allocator<std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>>::destroy(std::pair<std::string const, std::vector<std::pair<std::string, char const*>, std::allocator<std::pair<std::string, char const*>>>>*)"},
    {"_ZN5clang6driver6OptionC1ENS1_11OptionClassENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKS1_", "clang::driver::Option::Option(clang::driver::Option::OptionClass, clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZN5clang6driver6OptionC2ENS1_11OptionClassENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKS1_", "clang::driver::Option::Option(clang::driver::Option::OptionClass, clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZN5clang6driver6OptionD0Ev", "clang::driver::Option::~Option()"},
    {"_ZN5clang6driver6OptionD1Ev", "clang::driver::Option::~Option()"},
    {"_ZN5clang6driver6OptionD2Ev", "clang::driver::Option::~Option()"},
    {"_ZNK5clang6driver6Option4dumpEv", "clang::driver::Option::dump() const"},
    {"_ZNK5clang6driver6Option7matchesENS0_12OptSpecifierE", "clang::driver::Option::matches(clang::driver::OptSpecifier) const"},
    {"_ZN5clang6driver11OptionGroupC1ENS0_12OptSpecifierEPKcPKS1_", "clang::driver::OptionGroup::OptionGroup(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*)"},
    {"_ZN5clang6driver11OptionGroupC2ENS0_12OptSpecifierEPKcPKS1_", "clang::driver::OptionGroup::OptionGroup(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*)"},
    {"_ZNK5clang6driver11OptionGroup6acceptERKNS0_7ArgListERj", "clang::driver::OptionGroup::accept(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZN5clang6driver11InputOptionC1ENS0_12OptSpecifierE", "clang::driver::InputOption::InputOption(clang::driver::OptSpecifier)"},
    {"_ZN5clang6driver11InputOptionC2ENS0_12OptSpecifierE", "clang::driver::InputOption::InputOption(clang::driver::OptSpecifier)"},
    {"_ZNK5clang6driver11InputOption6acceptERKNS0_7ArgListERj", "clang::driver::InputOption::accept(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZN5clang6driver13UnknownOptionC1ENS0_12OptSpecifierE", "clang::driver::UnknownOption::UnknownOption(clang::driver::OptSpecifier)"},
    {"_ZN5clang6driver13UnknownOptionC2ENS0_12OptSpecifierE", "clang::driver::UnknownOption::UnknownOption(clang::driver::OptSpecifier)"},
    {"_ZNK5clang6driver13UnknownOption6acceptERKNS0_7ArgListERj", "clang::driver::UnknownOption::accept(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZN5clang6driver10FlagOptionC1ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::FlagOption::FlagOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZN5clang6driver10FlagOptionC2ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::FlagOption::FlagOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZNK5clang6driver10FlagOption6acceptERKNS0_7ArgListERj", "clang::driver::FlagOption::accept(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZN5clang6driver12JoinedOptionC1ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::JoinedOption::JoinedOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZN5clang6driver12JoinedOptionC2ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::JoinedOption::JoinedOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZNK5clang6driver12JoinedOption6acceptERKNS0_7ArgListERj", "clang::driver::JoinedOption::accept(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZN5clang6driver17CommaJoinedOptionC1ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::CommaJoinedOption::CommaJoinedOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZN5clang6driver17CommaJoinedOptionC2ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::CommaJoinedOption::CommaJoinedOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZNK5clang6driver17CommaJoinedOption6acceptERKNS0_7ArgListERj", "clang::driver::CommaJoinedOption::accept(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZN5clang6driver14SeparateOptionC1ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::SeparateOption::SeparateOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZN5clang6driver14SeparateOptionC2ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::SeparateOption::SeparateOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZNK5clang6driver14SeparateOption6acceptERKNS0_7ArgListERj", "clang::driver::SeparateOption::accept(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZN5clang6driver14MultiArgOptionC1ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionEj", "clang::driver::MultiArgOption::MultiArgOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*, unsigned int)"},
    {"_ZN5clang6driver14MultiArgOptionC2ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionEj", "clang::driver::MultiArgOption::MultiArgOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*, unsigned int)"},
    {"_ZNK5clang6driver14MultiArgOption6acceptERKNS0_7ArgListERj", "clang::driver::MultiArgOption::accept(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZN5clang6driver22JoinedOrSeparateOptionC1ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::JoinedOrSeparateOption::JoinedOrSeparateOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZN5clang6driver22JoinedOrSeparateOptionC2ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::JoinedOrSeparateOption::JoinedOrSeparateOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZNK5clang6driver22JoinedOrSeparateOption6acceptERKNS0_7ArgListERj", "clang::driver::JoinedOrSeparateOption::accept(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZN5clang6driver23JoinedAndSeparateOptionC1ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::JoinedAndSeparateOption::JoinedAndSeparateOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZN5clang6driver23JoinedAndSeparateOptionC2ENS0_12OptSpecifierEPKcPKNS0_11OptionGroupEPKNS0_6OptionE", "clang::driver::JoinedAndSeparateOption::JoinedAndSeparateOption(clang::driver::OptSpecifier, char const*, clang::driver::OptionGroup const*, clang::driver::Option const*)"},
    {"_ZNK5clang6driver23JoinedAndSeparateOption6acceptERKNS0_7ArgListERj", "clang::driver::JoinedAndSeparateOption::accept(clang::driver::ArgList const&, unsigned int&) const"},
    {"_ZN5clang6driver11OptionGroupD1Ev", "clang::driver::OptionGroup::~OptionGroup()"},
    {"_ZN5clang6driver11OptionGroupD0Ev", "clang::driver::OptionGroup::~OptionGroup()"},
    {"_ZN5clang6driver11InputOptionD1Ev", "clang::driver::InputOption::~InputOption()"},
    {"_ZN5clang6driver11InputOptionD0Ev", "clang::driver::InputOption::~InputOption()"},
    {"_ZN5clang6driver13UnknownOptionD1Ev", "clang::driver::UnknownOption::~UnknownOption()"},
    {"_ZN5clang6driver13UnknownOptionD0Ev", "clang::driver::UnknownOption::~UnknownOption()"},
    {"_ZN5clang6driver10FlagOptionD1Ev", "clang::driver::FlagOption::~FlagOption()"},
    {"_ZN5clang6driver10FlagOptionD0Ev", "clang::driver::FlagOption::~FlagOption()"},
    {"_ZN5clang6driver12JoinedOptionD1Ev", "clang::driver::JoinedOption::~JoinedOption()"},
    {"_ZN5clang6driver12JoinedOptionD0Ev", "clang::driver::JoinedOption::~JoinedOption()"},
    {"_ZN5clang6driver17CommaJoinedOptionD1Ev", "clang::driver::CommaJoinedOption::~CommaJoinedOption()"},
    {"_ZN5clang6driver17CommaJoinedOptionD0Ev", "clang::driver::CommaJoinedOption::~CommaJoinedOption()"},
    {"_ZN5clang6driver14SeparateOptionD1Ev", "clang::driver::SeparateOption::~SeparateOption()"},
    {"_ZN5clang6driver14SeparateOptionD0Ev", "clang::driver::SeparateOption::~SeparateOption()"},
    {"_ZN5clang6driver14MultiArgOptionD1Ev", "clang::driver::MultiArgOption::~MultiArgOption()"},
    {"_ZN5clang6driver14MultiArgOptionD0Ev", "clang::driver::MultiArgOption::~MultiArgOption()"},
    {"_ZN5clang6driver22JoinedOrSeparateOptionD1Ev", "clang::driver::JoinedOrSeparateOption::~JoinedOrSeparateOption()"},
    {"_ZN5clang6driver22JoinedOrSeparateOptionD0Ev", "clang::driver::JoinedOrSeparateOption::~JoinedOrSeparateOption()"},
    {"_ZN5clang6driver23JoinedAndSeparateOptionD1Ev", "clang::driver::JoinedAndSeparateOption::~JoinedAndSeparateOption()"},
    {"_ZN5clang6driver23JoinedAndSeparateOptionD0Ev", "clang::driver::JoinedAndSeparateOption::~JoinedAndSeparateOption()"},
    {"_ZN5clang6driver6phases12getPhaseNameENS1_2IDE", "clang::driver::phases::getPhaseName(clang::driver::phases::ID)"},
    {"_ZN5clang6driver4ToolC1EPKcS3_RKNS0_9ToolChainE", "clang::driver::Tool::Tool(char const*, char const*, clang::driver::ToolChain const&)"},
    {"_ZN5clang6driver4ToolC2EPKcS3_RKNS0_9ToolChainE", "clang::driver::Tool::Tool(char const*, char const*, clang::driver::ToolChain const&)"},
    {"_ZN5clang6driver4ToolD0Ev", "clang::driver::Tool::~Tool()"},
    {"_ZN5clang6driver4ToolD1Ev", "clang::driver::Tool::~Tool()"},
    {"_ZN5clang6driver4ToolD2Ev", "clang::driver::Tool::~Tool()"},
    {"_ZN5clang6driver9ToolChainC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::ToolChain::ToolChain(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver9ToolChainC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::ToolChain::ToolChain(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver9ToolChainD0Ev", "clang::driver::ToolChain::~ToolChain()"},
    {"_ZN5clang6driver9ToolChainD1Ev", "clang::driver::ToolChain::~ToolChain()"},
    {"_ZN5clang6driver9ToolChainD2Ev", "clang::driver::ToolChain::~ToolChain()"},
    {"_ZNK5clang6driver9ToolChain9getDriverEv", "clang::driver::ToolChain::getDriver() const"},
    {"_ZNK5clang6driver9ToolChain11GetFilePathEPKc", "clang::driver::ToolChain::GetFilePath(char const*) const"},
    {"_ZNK5clang6driver9ToolChain14GetProgramPathEPKcb", "clang::driver::ToolChain::GetProgramPath(char const*, bool) const"},
    {"_ZNK5clang6driver9ToolChain22LookupTypeForExtensionEPKc", "clang::driver::ToolChain::LookupTypeForExtension(char const*) const"},
    {"_ZNK5clang6driver9ToolChain20HasNativeLLVMSupportEv", "clang::driver::ToolChain::HasNativeLLVMSupport() const"},
    {"_ZNK5clang6driver9ToolChain17ComputeLLVMTripleERKNS0_7ArgListE", "clang::driver::ToolChain::ComputeLLVMTriple(clang::driver::ArgList const&) const"},
    {"_ZNK5clang6driver9ToolChain27ComputeEffectiveClangTripleERKNS0_7ArgListE", "clang::driver::ToolChain::ComputeEffectiveClangTriple(clang::driver::ArgList const&) const"},
    {"_ZNK5clang6driver9ToolChain16GetCXXStdlibTypeERKNS0_7ArgListE", "clang::driver::ToolChain::GetCXXStdlibType(clang::driver::ArgList const&) const"},
    {"_ZNK5clang6driver9ToolChain28AddClangCXXStdlibIncludeArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::ToolChain::AddClangCXXStdlibIncludeArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver9ToolChain19AddCXXStdlibLibArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::ToolChain::AddCXXStdlibLibArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver9ToolChain16AddCCKextLibArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::ToolChain::AddCCKextLibArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZN5clang6driver10toolchains6DarwinC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::Darwin::Darwin(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains6DarwinC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::Darwin::Darwin(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver10toolchains6Darwin22LookupTypeForExtensionEPKc", "clang::driver::toolchains::Darwin::LookupTypeForExtension(char const*) const"},
    {"_ZNK5clang6driver10toolchains6Darwin20HasNativeLLVMSupportEv", "clang::driver::toolchains::Darwin::HasNativeLLVMSupport() const"},
    {"_ZNK5clang6driver10toolchains6Darwin17getDarwinArchNameERKNS0_7ArgListE", "clang::driver::toolchains::Darwin::getDarwinArchName(clang::driver::ArgList const&) const"},
    {"_ZN5clang6driver10toolchains9DarwinGCCC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::DarwinGCC::DarwinGCC(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains9DarwinGCCC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::DarwinGCC::DarwinGCC(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains6DarwinD0Ev", "clang::driver::toolchains::Darwin::~Darwin()"},
    {"_ZN5clang6driver10toolchains6DarwinD1Ev", "clang::driver::toolchains::Darwin::~Darwin()"},
    {"_ZN5clang6driver10toolchains6DarwinD2Ev", "clang::driver::toolchains::Darwin::~Darwin()"},
    {"_ZNK5clang6driver10toolchains6Darwin27ComputeEffectiveClangTripleERKNS0_7ArgListE", "clang::driver::toolchains::Darwin::ComputeEffectiveClangTriple(clang::driver::ArgList const&) const"},
    {"_ZNK5clang6driver10toolchains6Darwin10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::Darwin::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZNK5clang6driver10toolchains9DarwinGCC21AddLinkSearchPathArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::toolchains::DarwinGCC::AddLinkSearchPathArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver10toolchains9DarwinGCC21AddLinkRuntimeLibArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::toolchains::DarwinGCC::AddLinkRuntimeLibArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZN5clang6driver10toolchains11DarwinClangC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::DarwinClang::DarwinClang(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains11DarwinClangC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::DarwinClang::DarwinClang(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver10toolchains11DarwinClang21AddLinkSearchPathArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::toolchains::DarwinClang::AddLinkSearchPathArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver10toolchains11DarwinClang21AddLinkRuntimeLibArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::toolchains::DarwinClang::AddLinkRuntimeLibArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver10toolchains6Darwin19AddDeploymentTargetERNS0_14DerivedArgListE", "clang::driver::toolchains::Darwin::AddDeploymentTarget(clang::driver::DerivedArgList&) const"},
    {"_ZNK5clang6driver10toolchains11DarwinClang19AddCXXStdlibLibArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::toolchains::DarwinClang::AddCXXStdlibLibArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver10toolchains11DarwinClang16AddCCKextLibArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::toolchains::DarwinClang::AddCCKextLibArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver10toolchains6Darwin13TranslateArgsERKNS0_14DerivedArgListEPKc", "clang::driver::toolchains::Darwin::TranslateArgs(clang::driver::DerivedArgList const&, char const*) const"},
    {"_ZNK5clang6driver10toolchains6Darwin21IsUnwindTablesDefaultEv", "clang::driver::toolchains::Darwin::IsUnwindTablesDefault() const"},
    {"_ZNK5clang6driver10toolchains6Darwin18UseDwarfDebugFlagsEv", "clang::driver::toolchains::Darwin::UseDwarfDebugFlags() const"},
    {"_ZNK5clang6driver10toolchains6Darwin17UseSjLjExceptionsEv", "clang::driver::toolchains::Darwin::UseSjLjExceptions() const"},
    {"_ZNK5clang6driver10toolchains6Darwin25GetDefaultRelocationModelEv", "clang::driver::toolchains::Darwin::GetDefaultRelocationModel() const"},
    {"_ZNK5clang6driver10toolchains6Darwin17GetForcedPicModelEv", "clang::driver::toolchains::Darwin::GetForcedPicModel() const"},
    {"_ZNK5clang6driver10toolchains6Darwin14SupportsObjCGCEv", "clang::driver::toolchains::Darwin::SupportsObjCGC() const"},
    {"_ZNK5clang6driver10toolchains18Darwin_Generic_GCC27ComputeEffectiveClangTripleERKNS0_7ArgListE", "clang::driver::toolchains::Darwin_Generic_GCC::ComputeEffectiveClangTriple(clang::driver::ArgList const&) const"},
    {"_ZN5clang6driver10toolchains11Generic_GCCC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::Generic_GCC::Generic_GCC(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains11Generic_GCCC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::Generic_GCC::Generic_GCC(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains11Generic_GCCD0Ev", "clang::driver::toolchains::Generic_GCC::~Generic_GCC()"},
    {"_ZN5clang6driver10toolchains11Generic_GCCD1Ev", "clang::driver::toolchains::Generic_GCC::~Generic_GCC()"},
    {"_ZN5clang6driver10toolchains11Generic_GCCD2Ev", "clang::driver::toolchains::Generic_GCC::~Generic_GCC()"},
    {"_ZNK5clang6driver10toolchains11Generic_GCC10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::Generic_GCC::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZNK5clang6driver10toolchains11Generic_GCC21IsUnwindTablesDefaultEv", "clang::driver::toolchains::Generic_GCC::IsUnwindTablesDefault() const"},
    {"_ZNK5clang6driver10toolchains11Generic_GCC25GetDefaultRelocationModelEv", "clang::driver::toolchains::Generic_GCC::GetDefaultRelocationModel() const"},
    {"_ZNK5clang6driver10toolchains11Generic_GCC17GetForcedPicModelEv", "clang::driver::toolchains::Generic_GCC::GetForcedPicModel() const"},
    {"_ZN5clang6driver10toolchains12TCEToolChainC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::TCEToolChain::TCEToolChain(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains12TCEToolChainC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::TCEToolChain::TCEToolChain(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains12TCEToolChainD0Ev", "clang::driver::toolchains::TCEToolChain::~TCEToolChain()"},
    {"_ZN5clang6driver10toolchains12TCEToolChainD1Ev", "clang::driver::toolchains::TCEToolChain::~TCEToolChain()"},
    {"_ZN5clang6driver10toolchains12TCEToolChainD2Ev", "clang::driver::toolchains::TCEToolChain::~TCEToolChain()"},
    {"_ZNK5clang6driver10toolchains12TCEToolChain18IsMathErrnoDefaultEv", "clang::driver::toolchains::TCEToolChain::IsMathErrnoDefault() const"},
    {"_ZNK5clang6driver10toolchains12TCEToolChain21IsUnwindTablesDefaultEv", "clang::driver::toolchains::TCEToolChain::IsUnwindTablesDefault() const"},
    {"_ZNK5clang6driver10toolchains12TCEToolChain25GetDefaultRelocationModelEv", "clang::driver::toolchains::TCEToolChain::GetDefaultRelocationModel() const"},
    {"_ZNK5clang6driver10toolchains12TCEToolChain17GetForcedPicModelEv", "clang::driver::toolchains::TCEToolChain::GetForcedPicModel() const"},
    {"_ZNK5clang6driver10toolchains12TCEToolChain10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::TCEToolChain::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZN5clang6driver10toolchains7OpenBSDC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::OpenBSD::OpenBSD(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains7OpenBSDC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::OpenBSD::OpenBSD(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver10toolchains7OpenBSD10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::OpenBSD::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZN5clang6driver10toolchains7FreeBSDC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::FreeBSD::FreeBSD(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains7FreeBSDC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::FreeBSD::FreeBSD(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver10toolchains7FreeBSD10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::FreeBSD::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZN5clang6driver10toolchains6NetBSDC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::NetBSD::NetBSD(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains6NetBSDC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::NetBSD::NetBSD(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver10toolchains6NetBSD10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::NetBSD::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZN5clang6driver10toolchains5MinixC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::Minix::Minix(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains5MinixC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::Minix::Minix(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver10toolchains5Minix10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::Minix::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZN5clang6driver10toolchains8AuroraUXC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::AuroraUX::AuroraUX(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains8AuroraUXC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::AuroraUX::AuroraUX(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver10toolchains8AuroraUX10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::AuroraUX::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZN5clang6driver10toolchains5LinuxC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::Linux::Linux(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains5LinuxC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::Linux::Linux(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver10toolchains5Linux20HasNativeLLVMSupportEv", "clang::driver::toolchains::Linux::HasNativeLLVMSupport() const"},
    {"_ZNK5clang6driver10toolchains5Linux10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::Linux::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZN5clang6driver10toolchains9DragonFlyC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::DragonFly::DragonFly(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains9DragonFlyC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::DragonFly::DragonFly(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver10toolchains9DragonFly10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::DragonFly::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZN5clang6driver10toolchains7WindowsC1ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::Windows::Windows(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZN5clang6driver10toolchains7WindowsC2ERKNS0_8HostInfoERKN4llvm6TripleE", "clang::driver::toolchains::Windows::Windows(clang::driver::HostInfo const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver10toolchains7Windows10SelectToolERKNS0_11CompilationERKNS0_9JobActionE", "clang::driver::toolchains::Windows::SelectTool(clang::driver::Compilation const&, clang::driver::JobAction const&) const"},
    {"_ZNK5clang6driver10toolchains7Windows28IsIntegratedAssemblerDefaultEv", "clang::driver::toolchains::Windows::IsIntegratedAssemblerDefault() const"},
    {"_ZNK5clang6driver10toolchains7Windows21IsUnwindTablesDefaultEv", "clang::driver::toolchains::Windows::IsUnwindTablesDefault() const"},
    {"_ZNK5clang6driver10toolchains7Windows25GetDefaultRelocationModelEv", "clang::driver::toolchains::Windows::GetDefaultRelocationModel() const"},
    {"_ZNK5clang6driver10toolchains7Windows17GetForcedPicModelEv", "clang::driver::toolchains::Windows::GetForcedPicModel() const"},
    {"_ZN5clang6driver10toolchains18Darwin_Generic_GCCD1Ev", "clang::driver::toolchains::Darwin_Generic_GCC::~Darwin_Generic_GCC()"},
    {"_ZN5clang6driver10toolchains18Darwin_Generic_GCCD0Ev", "clang::driver::toolchains::Darwin_Generic_GCC::~Darwin_Generic_GCC()"},
    {"_ZNK5clang6driver10toolchains6Darwin15IsBlocksDefaultEv", "clang::driver::toolchains::Darwin::IsBlocksDefault() const"},
    {"_ZNK5clang6driver10toolchains6Darwin28IsIntegratedAssemblerDefaultEv", "clang::driver::toolchains::Darwin::IsIntegratedAssemblerDefault() const"},
    {"_ZNK5clang6driver10toolchains6Darwin23IsStrictAliasingDefaultEv", "clang::driver::toolchains::Darwin::IsStrictAliasingDefault() const"},
    {"_ZNK5clang6driver10toolchains6Darwin35IsObjCDefaultSynthPropertiesDefaultEv", "clang::driver::toolchains::Darwin::IsObjCDefaultSynthPropertiesDefault() const"},
    {"_ZNK5clang6driver10toolchains6Darwin26IsObjCNonFragileABIDefaultEv", "clang::driver::toolchains::Darwin::IsObjCNonFragileABIDefault() const"},
    {"_ZNK5clang6driver10toolchains6Darwin27IsObjCLegacyDispatchDefaultEv", "clang::driver::toolchains::Darwin::IsObjCLegacyDispatchDefault() const"},
    {"_ZNK5clang6driver10toolchains6Darwin20UseObjCMixedDispatchEv", "clang::driver::toolchains::Darwin::UseObjCMixedDispatch() const"},
    {"_ZNK5clang6driver10toolchains6Darwin29GetDefaultStackProtectorLevelEv", "clang::driver::toolchains::Darwin::GetDefaultStackProtectorLevel() const"},
    {"_ZN5clang6driver10toolchains9DarwinGCCD1Ev", "clang::driver::toolchains::DarwinGCC::~DarwinGCC()"},
    {"_ZN5clang6driver10toolchains9DarwinGCCD0Ev", "clang::driver::toolchains::DarwinGCC::~DarwinGCC()"},
    {"_ZN5clang6driver10toolchains11DarwinClangD1Ev", "clang::driver::toolchains::DarwinClang::~DarwinClang()"},
    {"_ZN5clang6driver10toolchains11DarwinClangD0Ev", "clang::driver::toolchains::DarwinClang::~DarwinClang()"},
    {"_ZN5clang6driver10toolchains7OpenBSDD1Ev", "clang::driver::toolchains::OpenBSD::~OpenBSD()"},
    {"_ZN5clang6driver10toolchains7OpenBSDD0Ev", "clang::driver::toolchains::OpenBSD::~OpenBSD()"},
    {"_ZNK5clang6driver10toolchains11Generic_ELF28IsIntegratedAssemblerDefaultEv", "clang::driver::toolchains::Generic_ELF::IsIntegratedAssemblerDefault() const"},
    {"_ZN5clang6driver10toolchains7FreeBSDD1Ev", "clang::driver::toolchains::FreeBSD::~FreeBSD()"},
    {"_ZN5clang6driver10toolchains7FreeBSDD0Ev", "clang::driver::toolchains::FreeBSD::~FreeBSD()"},
    {"_ZN5clang6driver10toolchains6NetBSDD1Ev", "clang::driver::toolchains::NetBSD::~NetBSD()"},
    {"_ZN5clang6driver10toolchains6NetBSDD0Ev", "clang::driver::toolchains::NetBSD::~NetBSD()"},
    {"_ZN5clang6driver10toolchains5MinixD1Ev", "clang::driver::toolchains::Minix::~Minix()"},
    {"_ZN5clang6driver10toolchains5MinixD0Ev", "clang::driver::toolchains::Minix::~Minix()"},
    {"_ZN5clang6driver10toolchains8AuroraUXD1Ev", "clang::driver::toolchains::AuroraUX::~AuroraUX()"},
    {"_ZN5clang6driver10toolchains8AuroraUXD0Ev", "clang::driver::toolchains::AuroraUX::~AuroraUX()"},
    {"_ZN5clang6driver10toolchains5LinuxD1Ev", "clang::driver::toolchains::Linux::~Linux()"},
    {"_ZN5clang6driver10toolchains5LinuxD0Ev", "clang::driver::toolchains::Linux::~Linux()"},
    {"_ZN5clang6driver10toolchains9DragonFlyD1Ev", "clang::driver::toolchains::DragonFly::~DragonFly()"},
    {"_ZN5clang6driver10toolchains9DragonFlyD0Ev", "clang::driver::toolchains::DragonFly::~DragonFly()"},
    {"_ZN5clang6driver10toolchains7WindowsD1Ev", "clang::driver::toolchains::Windows::~Windows()"},
    {"_ZN5clang6driver10toolchains7WindowsD0Ev", "clang::driver::toolchains::Windows::~Windows()"},
    {"_ZN4llvm8DenseMapIjPN5clang6driver4ToolENS_12DenseMapInfoIjEENS5_IS4_EEE16InsertIntoBucketERKjRKS4_PSt4pairIjS4_E", "llvm::DenseMap<unsigned int, clang::driver::Tool*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<clang::driver::Tool*>>::InsertIntoBucket(unsigned int const&, clang::driver::Tool* const&, std::pair<unsigned int, clang::driver::Tool*>*)"},
    {"_ZN4llvm8DenseMapIjPN5clang6driver4ToolENS_12DenseMapInfoIjEENS5_IS4_EEE4growEj", "llvm::DenseMap<unsigned int, clang::driver::Tool*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<clang::driver::Tool*>>::grow(unsigned int)"},
    {"_ZN5clang6driver10toolchains11Generic_ELFD1Ev", "clang::driver::toolchains::Generic_ELF::~Generic_ELF()"},
    {"_ZN5clang6driver10toolchains11Generic_ELFD0Ev", "clang::driver::toolchains::Generic_ELF::~Generic_ELF()"},
    {"_ZN5clang6driver10toolchains5LinuxD2Ev", "clang::driver::toolchains::Linux::~Linux()"},
    {"_ZNK5clang6driver4Tool22hasIntegratedAssemblerEv", "clang::driver::Tool::hasIntegratedAssembler() const"},
    {"_ZNK5clang6driver5tools12visualstudio4Link16hasIntegratedCPPEv", "clang::driver::tools::visualstudio::Link::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver4Tool18hasGoodDiagnosticsEv", "clang::driver::Tool::hasGoodDiagnostics() const"},
    {"_ZNK5clang6driver5tools9dragonfly4Link16hasIntegratedCPPEv", "clang::driver::tools::dragonfly::Link::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools9dragonfly8Assemble16hasIntegratedCPPEv", "clang::driver::tools::dragonfly::Assemble::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools10linuxtools4Link16hasIntegratedCPPEv", "clang::driver::tools::linuxtools::Link::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools10linuxtools8Assemble16hasIntegratedCPPEv", "clang::driver::tools::linuxtools::Assemble::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools8auroraux4Link16hasIntegratedCPPEv", "clang::driver::tools::auroraux::Link::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools8auroraux8Assemble16hasIntegratedCPPEv", "clang::driver::tools::auroraux::Assemble::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools5minix4Link16hasIntegratedCPPEv", "clang::driver::tools::minix::Link::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools5minix8Assemble16hasIntegratedCPPEv", "clang::driver::tools::minix::Assemble::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools6netbsd4Link16hasIntegratedCPPEv", "clang::driver::tools::netbsd::Link::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools6netbsd8Assemble16hasIntegratedCPPEv", "clang::driver::tools::netbsd::Assemble::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools7freebsd4Link16hasIntegratedCPPEv", "clang::driver::tools::freebsd::Link::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools7freebsd8Assemble16hasIntegratedCPPEv", "clang::driver::tools::freebsd::Assemble::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools7openbsd4Link16hasIntegratedCPPEv", "clang::driver::tools::openbsd::Link::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools7openbsd8Assemble16hasIntegratedCPPEv", "clang::driver::tools::openbsd::Assemble::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools3gcc4Link16hasIntegratedCPPEv", "clang::driver::tools::gcc::Link::hasIntegratedCPP() const"},
    {"_ZN5clang6driver5tools3gcc6CommonD1Ev", "clang::driver::tools::gcc::Common::~Common()"},
    {"_ZN5clang6driver5tools3gcc6CommonD0Ev", "clang::driver::tools::gcc::Common::~Common()"},
    {"_ZNK5clang6driver5tools3gcc8Assemble16hasIntegratedCPPEv", "clang::driver::tools::gcc::Assemble::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools3gcc7Compile16hasIntegratedCPPEv", "clang::driver::tools::gcc::Compile::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools3gcc7Compile18hasGoodDiagnosticsEv", "clang::driver::tools::gcc::Compile::hasGoodDiagnostics() const"},
    {"_ZNK5clang6driver5tools3gcc10Precompile16hasIntegratedCPPEv", "clang::driver::tools::gcc::Precompile::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools3gcc10Precompile18hasGoodDiagnosticsEv", "clang::driver::tools::gcc::Precompile::hasGoodDiagnostics() const"},
    {"_ZNK5clang6driver5tools3gcc10Preprocess16hasIntegratedCPPEv", "clang::driver::tools::gcc::Preprocess::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools3gcc10Preprocess18hasGoodDiagnosticsEv", "clang::driver::tools::gcc::Preprocess::hasGoodDiagnostics() const"},
    {"_ZNK5clang6driver5tools6darwin8Dsymutil16hasIntegratedCPPEv", "clang::driver::tools::darwin::Dsymutil::hasIntegratedCPP() const"},
    {"_ZN5clang6driver5tools6darwin10DarwinToolD1Ev", "clang::driver::tools::darwin::DarwinTool::~DarwinTool()"},
    {"_ZN5clang6driver5tools6darwin10DarwinToolD0Ev", "clang::driver::tools::darwin::DarwinTool::~DarwinTool()"},
    {"_ZNK5clang6driver5tools6darwin4Lipo16hasIntegratedCPPEv", "clang::driver::tools::darwin::Lipo::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools6darwin4Link16hasIntegratedCPPEv", "clang::driver::tools::darwin::Link::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools6darwin8Assemble16hasIntegratedCPPEv", "clang::driver::tools::darwin::Assemble::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools7ClangAs22hasIntegratedAssemblerEv", "clang::driver::tools::ClangAs::hasIntegratedAssembler() const"},
    {"_ZNK5clang6driver5tools7ClangAs16hasIntegratedCPPEv", "clang::driver::tools::ClangAs::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools7ClangAs18hasGoodDiagnosticsEv", "clang::driver::tools::ClangAs::hasGoodDiagnostics() const"},
    {"_ZNK5clang6driver5tools6darwin3CC116hasIntegratedCPPEv", "clang::driver::tools::darwin::CC1::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools6darwin3CC118hasGoodDiagnosticsEv", "clang::driver::tools::darwin::CC1::hasGoodDiagnostics() const"},
    {"_ZN5clang6driver5tools6darwin3CC1D1Ev", "clang::driver::tools::darwin::CC1::~CC1()"},
    {"_ZN5clang6driver5tools6darwin3CC1D0Ev", "clang::driver::tools::darwin::CC1::~CC1()"},
    {"_ZNK5clang6driver5tools5Clang22hasIntegratedAssemblerEv", "clang::driver::tools::Clang::hasIntegratedAssembler() const"},
    {"_ZNK5clang6driver5tools5Clang16hasIntegratedCPPEv", "clang::driver::tools::Clang::hasIntegratedCPP() const"},
    {"_ZNK5clang6driver5tools5Clang18hasGoodDiagnosticsEv", "clang::driver::tools::Clang::hasGoodDiagnostics() const"},
    {"_ZNK5clang6driver5tools5Clang23AddPreprocessingOptionsERKNS0_6DriverERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEERKNS0_9InputInfoERKNSA_ISF_Lj4EEE", "clang::driver::tools::Clang::AddPreprocessingOptions(clang::driver::Driver const&, clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&) const"},
    {"_Z25CheckPreprocessingOptionsRKN5clang6driver6DriverERKNS0_7ArgListE", "CheckPreprocessingOptions(clang::driver::Driver const&, clang::driver::ArgList const&)"},
    {"_ZN5clang6driver5tools6darwin3CC121getDependencyFileNameERKNS0_7ArgListERKN4llvm11SmallVectorINS0_9InputInfoELj4EEE", "clang::driver::tools::darwin::CC1::getDependencyFileName(clang::driver::ArgList const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&)"},
    {"_Z11QuoteTargetN4llvm9StringRefERNS_15SmallVectorImplIcEE", "QuoteTarget(llvm::StringRef, llvm::SmallVectorImpl<char>&)"},
    {"_ZNK5clang6driver5tools5Clang16AddARMTargetArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::Clang::AddARMTargetArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_Z15getARMTargetCPURKN5clang6driver7ArgListERKN4llvm6TripleE", "getARMTargetCPU(clang::driver::ArgList const&, llvm::Triple const&)"},
    {"_ZNK5clang6driver5tools5Clang17AddMIPSTargetArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::Clang::AddMIPSTargetArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools5Clang18AddSparcTargetArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::Clang::AddSparcTargetArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools5Clang16AddX86TargetArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::Clang::AddX86TargetArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools5Clang12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS8_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::Clang::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZN5clang6driver5tools6darwin3CC116getBaseInputNameERKNS0_7ArgListERKN4llvm11SmallVectorINS0_9InputInfoELj4EEE", "clang::driver::tools::darwin::CC1::getBaseInputName(clang::driver::ArgList const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&)"},
    {"_Z26CheckCodeGenerationOptionsRKN5clang6driver6DriverERKNS0_7ArgListE", "CheckCodeGenerationOptions(clang::driver::Driver const&, clang::driver::ArgList const&)"},
    {"_ZNK5clang6driver5tools7ClangAs12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS8_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::ClangAs::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools3gcc6Common12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::gcc::Common::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools3gcc10Preprocess19RenderExtraToolArgsERKNS0_9JobActionERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::gcc::Preprocess::RenderExtraToolArgs(clang::driver::JobAction const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools3gcc10Precompile19RenderExtraToolArgsERKNS0_9JobActionERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::gcc::Precompile::RenderExtraToolArgs(clang::driver::JobAction const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools3gcc7Compile19RenderExtraToolArgsERKNS0_9JobActionERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::gcc::Compile::RenderExtraToolArgs(clang::driver::JobAction const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools3gcc8Assemble19RenderExtraToolArgsERKNS0_9JobActionERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::gcc::Assemble::RenderExtraToolArgs(clang::driver::JobAction const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools3gcc4Link19RenderExtraToolArgsERKNS0_9JobActionERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::gcc::Link::RenderExtraToolArgs(clang::driver::JobAction const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools6darwin3CC110getCC1NameENS0_5types2IDE", "clang::driver::tools::darwin::CC1::getCC1Name(clang::driver::types::ID) const"},
    {"_ZN5clang6driver5tools6darwin3CC116getBaseInputStemERKNS0_7ArgListERKN4llvm11SmallVectorINS0_9InputInfoELj4EEE", "clang::driver::tools::darwin::CC1::getBaseInputStem(clang::driver::ArgList const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&)"},
    {"_ZNK5clang6driver5tools6darwin3CC110AddCC1ArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::darwin::CC1::AddCC1Args(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools6darwin3CC117AddCC1OptionsArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEERKNS8_INS0_9InputInfoELj4EEERKSB_", "clang::driver::tools::darwin::CC1::AddCC1OptionsArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, llvm::SmallVector<char const*, 16u> const&) const"},
    {"_ZNK5clang6driver5tools6darwin3CC117AddCPPOptionsArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEERKNS8_INS0_9InputInfoELj4EEERKSB_", "clang::driver::tools::darwin::CC1::AddCPPOptionsArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, llvm::SmallVector<char const*, 16u> const&) const"},
    {"_ZNK5clang6driver5tools6darwin3CC123AddCPPUniqueOptionsArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEERKNS8_INS0_9InputInfoELj4EEE", "clang::driver::tools::darwin::CC1::AddCPPUniqueOptionsArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&) const"},
    {"_ZNK5clang6driver5tools6darwin3CC110AddCPPArgsERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::darwin::CC1::AddCPPArgs(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools6darwin10Preprocess12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::darwin::Preprocess::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools6darwin7Compile12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::darwin::Compile::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools6darwin8Assemble12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::darwin::Assemble::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools6darwin10DarwinTool13AddDarwinArchERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::darwin::DarwinTool::AddDarwinArch(clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools6darwin4Link11AddLinkArgsERNS0_11CompilationERKNS0_7ArgListERN4llvm11SmallVectorIPKcLj16EEE", "clang::driver::tools::darwin::Link::AddLinkArgs(clang::driver::Compilation&, clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&) const"},
    {"_ZNK5clang6driver5tools6darwin4Link12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::darwin::Link::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_Z15AddLinkerInputsRKN5clang6driver9ToolChainERKN4llvm11SmallVectorINS0_9InputInfoELj4EEERKNS0_7ArgListERNS5_IPKcLj16EEE", "AddLinkerInputs(clang::driver::ToolChain const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, llvm::SmallVector<char const*, 16u>&)"},
    {"_ZNK5clang6driver5tools6darwin4Lipo12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::darwin::Lipo::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools6darwin8Dsymutil12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::darwin::Dsymutil::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools8auroraux8Assemble12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::auroraux::Assemble::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools8auroraux4Link12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::auroraux::Link::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools7openbsd8Assemble12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::openbsd::Assemble::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools7openbsd4Link12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::openbsd::Link::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools7freebsd8Assemble12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::freebsd::Assemble::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools7freebsd4Link12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::freebsd::Link::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools6netbsd8Assemble12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::netbsd::Assemble::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools6netbsd4Link12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::netbsd::Link::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools10linuxtools8Assemble12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::linuxtools::Assemble::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools10linuxtools4Link12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::linuxtools::Link::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools5minix8Assemble12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::minix::Assemble::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools5minix4Link12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::minix::Link::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools9dragonfly8Assemble12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::dragonfly::Assemble::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools9dragonfly4Link12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::dragonfly::Link::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZNK5clang6driver5tools12visualstudio4Link12ConstructJobERNS0_11CompilationERKNS0_9JobActionERKNS0_9InputInfoERKN4llvm11SmallVectorIS9_Lj4EEERKNS0_7ArgListEPKc", "clang::driver::tools::visualstudio::Link::ConstructJob(clang::driver::Compilation&, clang::driver::JobAction const&, clang::driver::InputInfo const&, llvm::SmallVector<clang::driver::InputInfo, 4u> const&, clang::driver::ArgList const&, char const*) const"},
    {"_ZN5clang6driver5tools5ClangD1Ev", "clang::driver::tools::Clang::~Clang()"},
    {"_ZN5clang6driver5tools5ClangD0Ev", "clang::driver::tools::Clang::~Clang()"},
    {"_ZN5clang6driver5tools7ClangAsD1Ev", "clang::driver::tools::ClangAs::~ClangAs()"},
    {"_ZN5clang6driver5tools7ClangAsD0Ev", "clang::driver::tools::ClangAs::~ClangAs()"},
    {"_ZN5clang6driver5tools3gcc10PreprocessD1Ev", "clang::driver::tools::gcc::Preprocess::~Preprocess()"},
    {"_ZN5clang6driver5tools3gcc10PreprocessD0Ev", "clang::driver::tools::gcc::Preprocess::~Preprocess()"},
    {"_ZN5clang6driver5tools3gcc10PrecompileD1Ev", "clang::driver::tools::gcc::Precompile::~Precompile()"},
    {"_ZN5clang6driver5tools3gcc10PrecompileD0Ev", "clang::driver::tools::gcc::Precompile::~Precompile()"},
    {"_ZN5clang6driver5tools3gcc7CompileD1Ev", "clang::driver::tools::gcc::Compile::~Compile()"},
    {"_ZN5clang6driver5tools3gcc7CompileD0Ev", "clang::driver::tools::gcc::Compile::~Compile()"},
    {"_ZN5clang6driver5tools3gcc8AssembleD1Ev", "clang::driver::tools::gcc::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools3gcc8AssembleD0Ev", "clang::driver::tools::gcc::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools3gcc4LinkD1Ev", "clang::driver::tools::gcc::Link::~Link()"},
    {"_ZN5clang6driver5tools3gcc4LinkD0Ev", "clang::driver::tools::gcc::Link::~Link()"},
    {"_ZN5clang6driver5tools6darwin10PreprocessD1Ev", "clang::driver::tools::darwin::Preprocess::~Preprocess()"},
    {"_ZN5clang6driver5tools6darwin10PreprocessD0Ev", "clang::driver::tools::darwin::Preprocess::~Preprocess()"},
    {"_ZN5clang6driver5tools6darwin7CompileD1Ev", "clang::driver::tools::darwin::Compile::~Compile()"},
    {"_ZN5clang6driver5tools6darwin7CompileD0Ev", "clang::driver::tools::darwin::Compile::~Compile()"},
    {"_ZN5clang6driver5tools6darwin8AssembleD1Ev", "clang::driver::tools::darwin::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools6darwin8AssembleD0Ev", "clang::driver::tools::darwin::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools6darwin4LinkD1Ev", "clang::driver::tools::darwin::Link::~Link()"},
    {"_ZN5clang6driver5tools6darwin4LinkD0Ev", "clang::driver::tools::darwin::Link::~Link()"},
    {"_ZN5clang6driver5tools6darwin4LipoD1Ev", "clang::driver::tools::darwin::Lipo::~Lipo()"},
    {"_ZN5clang6driver5tools6darwin4LipoD0Ev", "clang::driver::tools::darwin::Lipo::~Lipo()"},
    {"_ZN5clang6driver5tools6darwin8DsymutilD1Ev", "clang::driver::tools::darwin::Dsymutil::~Dsymutil()"},
    {"_ZN5clang6driver5tools6darwin8DsymutilD0Ev", "clang::driver::tools::darwin::Dsymutil::~Dsymutil()"},
    {"_ZN5clang6driver5tools7openbsd8AssembleD1Ev", "clang::driver::tools::openbsd::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools7openbsd8AssembleD0Ev", "clang::driver::tools::openbsd::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools7openbsd4LinkD1Ev", "clang::driver::tools::openbsd::Link::~Link()"},
    {"_ZN5clang6driver5tools7openbsd4LinkD0Ev", "clang::driver::tools::openbsd::Link::~Link()"},
    {"_ZN5clang6driver5tools7freebsd8AssembleD1Ev", "clang::driver::tools::freebsd::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools7freebsd8AssembleD0Ev", "clang::driver::tools::freebsd::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools7freebsd4LinkD1Ev", "clang::driver::tools::freebsd::Link::~Link()"},
    {"_ZN5clang6driver5tools7freebsd4LinkD0Ev", "clang::driver::tools::freebsd::Link::~Link()"},
    {"_ZN5clang6driver5tools6netbsd8AssembleD1Ev", "clang::driver::tools::netbsd::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools6netbsd8AssembleD0Ev", "clang::driver::tools::netbsd::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools6netbsd4LinkD1Ev", "clang::driver::tools::netbsd::Link::~Link()"},
    {"_ZN5clang6driver5tools6netbsd4LinkD0Ev", "clang::driver::tools::netbsd::Link::~Link()"},
    {"_ZN5clang6driver5tools10linuxtools8AssembleD1Ev", "clang::driver::tools::linuxtools::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools10linuxtools8AssembleD0Ev", "clang::driver::tools::linuxtools::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools10linuxtools4LinkD1Ev", "clang::driver::tools::linuxtools::Link::~Link()"},
    {"_ZN5clang6driver5tools10linuxtools4LinkD0Ev", "clang::driver::tools::linuxtools::Link::~Link()"},
    {"_ZN5clang6driver5tools5minix8AssembleD1Ev", "clang::driver::tools::minix::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools5minix8AssembleD0Ev", "clang::driver::tools::minix::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools5minix4LinkD1Ev", "clang::driver::tools::minix::Link::~Link()"},
    {"_ZN5clang6driver5tools5minix4LinkD0Ev", "clang::driver::tools::minix::Link::~Link()"},
    {"_ZN5clang6driver5tools8auroraux8AssembleD1Ev", "clang::driver::tools::auroraux::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools8auroraux8AssembleD0Ev", "clang::driver::tools::auroraux::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools8auroraux4LinkD1Ev", "clang::driver::tools::auroraux::Link::~Link()"},
    {"_ZN5clang6driver5tools8auroraux4LinkD0Ev", "clang::driver::tools::auroraux::Link::~Link()"},
    {"_ZN5clang6driver5tools9dragonfly8AssembleD1Ev", "clang::driver::tools::dragonfly::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools9dragonfly8AssembleD0Ev", "clang::driver::tools::dragonfly::Assemble::~Assemble()"},
    {"_ZN5clang6driver5tools9dragonfly4LinkD1Ev", "clang::driver::tools::dragonfly::Link::~Link()"},
    {"_ZN5clang6driver5tools9dragonfly4LinkD0Ev", "clang::driver::tools::dragonfly::Link::~Link()"},
    {"_ZN5clang6driver5tools12visualstudio4LinkD1Ev", "clang::driver::tools::visualstudio::Link::~Link()"},
    {"_ZN5clang6driver5tools12visualstudio4LinkD0Ev", "clang::driver::tools::visualstudio::Link::~Link()"},
    {"_ZN4llvm15SmallVectorImplISsEaSERKS1_", "llvm::SmallVectorImpl<std::string>::operator=(llvm::SmallVectorImpl<std::string> const&)"},
    {"_ZN5clang6driver5types11getTypeNameENS1_2IDE", "clang::driver::types::getTypeName(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types19getPreprocessedTypeENS1_2IDE", "clang::driver::types::getPreprocessedType(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types17getTypeTempSuffixENS1_2IDE", "clang::driver::types::getTypeTempSuffix(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types16onlyAssembleTypeENS1_2IDE", "clang::driver::types::onlyAssembleType(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types18onlyPrecompileTypeENS1_2IDE", "clang::driver::types::onlyPrecompileType(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types22canTypeBeUserSpecifiedENS1_2IDE", "clang::driver::types::canTypeBeUserSpecified(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types19appendSuffixForTypeENS1_2IDE", "clang::driver::types::appendSuffixForType(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types11canLipoTypeENS1_2IDE", "clang::driver::types::canLipoType(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types17isAcceptedByClangENS1_2IDE", "clang::driver::types::isAcceptedByClang(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types21isOnlyAcceptedByClangENS1_2IDE", "clang::driver::types::isOnlyAcceptedByClang(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types6isObjCENS1_2IDE", "clang::driver::types::isObjC(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types5isCXXENS1_2IDE", "clang::driver::types::isCXX(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types22lookupTypeForExtensionEPKc", "clang::driver::types::lookupTypeForExtension(char const*)"},
    {"_ZN5clang6driver5types26lookupTypeForTypeSpecifierEPKc", "clang::driver::types::lookupTypeForTypeSpecifier(char const*)"},
    {"_ZN5clang6driver5types23getNumCompilationPhasesENS1_2IDE", "clang::driver::types::getNumCompilationPhases(clang::driver::types::ID)"},
    {"_ZN5clang6driver5types19getCompilationPhaseENS1_2IDEj", "clang::driver::types::getCompilationPhase(clang::driver::types::ID, unsigned int)"},
    {"_ZN5clang6driver5types21lookupCXXTypeForCTypeENS1_2IDE", "clang::driver::types::lookupCXXTypeForCType(clang::driver::types::ID)"},
    {"_ZN5clang26ASTDeserializationListenerD0Ev", "clang::ASTDeserializationListener::~ASTDeserializationListener()"},
    {"_ZN5clang26ASTDeserializationListenerD1Ev", "clang::ASTDeserializationListener::~ASTDeserializationListener()"},
    {"_ZN5clang26ASTDeserializationListenerD2Ev", "clang::ASTDeserializationListener::~ASTDeserializationListener()"},
    {"_ZN5clang13serialization18TypeIdxFromBuiltinEPKNS_11BuiltinTypeE", "clang::serialization::TypeIdxFromBuiltin(clang::BuiltinType const*)"},
    {"_ZN5clang13serialization11ComputeHashENS_8SelectorE", "clang::serialization::ComputeHash(clang::Selector)"},
    {"_ZN5clang17ASTReaderListenerD0Ev", "clang::ASTReaderListener::~ASTReaderListener()"},
    {"_ZN5clang17ASTReaderListenerD1Ev", "clang::ASTReaderListener::~ASTReaderListener()"},
    {"_ZN5clang17ASTReaderListenerD2Ev", "clang::ASTReaderListener::~ASTReaderListener()"},
    {"_ZN5clang12PCHValidator19ReadLanguageOptionsERKNS_11LangOptionsE", "clang::PCHValidator::ReadLanguageOptions(clang::LangOptions const&)"},
    {"_ZN5clang9ASTReader4DiagEj", "clang::ASTReader::Diag(unsigned int)"},
    {"_ZN5clang12PCHValidator16ReadTargetTripleEN4llvm9StringRefE", "clang::PCHValidator::ReadTargetTriple(llvm::StringRef)"},
    {"_ZN5clang12PCHValidator20ReadPredefinesBufferERKN4llvm11SmallVectorINS_18PCHPredefinesBlockELj2EEENS1_9StringRefERSs", "clang::PCHValidator::ReadPredefinesBuffer(llvm::SmallVector<clang::PCHPredefinesBlock, 2u> const&, llvm::StringRef, std::string&)"},
    {"_ZN5clang9ASTReader4DiagENS_14SourceLocationEj", "clang::ASTReader::Diag(clang::SourceLocation, unsigned int)"},
    {"_ZN5clang12PCHValidator18ReadHeaderFileInfoERKNS_14HeaderFileInfoEj", "clang::PCHValidator::ReadHeaderFileInfo(clang::HeaderFileInfo const&, unsigned int)"},
    {"_ZN5clang12PCHValidator11ReadCounterEj", "clang::PCHValidator::ReadCounter(unsigned int)"},
    {"_ZN5clang9ASTReader26setDeserializationListenerEPNS_26ASTDeserializationListenerE", "clang::ASTReader::setDeserializationListener(clang::ASTDeserializationListener*)"},
    {"_ZN5clang9ASTReader22ReadDeclContextStorageERN4llvm15BitstreamCursorERKSt4pairIyyERNS0_15DeclContextInfoE", "clang::ASTReader::ReadDeclContextStorage(llvm::BitstreamCursor&, std::pair<unsigned long long, unsigned long long> const&, clang::ASTReader::DeclContextInfo&)"},
    {"_ZN5clang9ASTReader5ErrorEPKc", "clang::ASTReader::Error(char const*)"},
    {"_ZN5clang9ASTReader22CheckPredefinesBuffersEv", "clang::ASTReader::CheckPredefinesBuffers()"},
    {"_ZN5clang9ASTReader14ParseLineTableERNS0_11PerFileDataERN4llvm15SmallVectorImplIyEE", "clang::ASTReader::ParseLineTable(clang::ASTReader::PerFileData&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTReader28MaybeAddSystemRootToFilenameERSs", "clang::ASTReader::MaybeAddSystemRootToFilename(std::string&)"},
    {"_ZN5clang9ASTReader22ReadSourceManagerBlockERNS0_11PerFileDataE", "clang::ASTReader::ReadSourceManagerBlock(clang::ASTReader::PerFileData&)"},
    {"_ZN5clang9ASTReader15SLocCursorForIDEj", "clang::ASTReader::SLocCursorForID(unsigned int)"},
    {"_ZN5clang9ASTReader19ReadSLocEntryRecordEj", "clang::ASTReader::ReadSLocEntryRecord(unsigned int)"},
    {"_ZN5clang9ASTReader16ReadBlockAbbrevsERN4llvm15BitstreamCursorEj", "clang::ASTReader::ReadBlockAbbrevs(llvm::BitstreamCursor&, unsigned int)"},
    {"_ZN5clang9ASTReader15ReadMacroRecordERNS0_11PerFileDataEy", "clang::ASTReader::ReadMacroRecord(clang::ASTReader::PerFileData&, unsigned long long)"},
    {"_ZN5clang9ASTReader20DecodeIdentifierInfoEj", "clang::ASTReader::DecodeIdentifierInfo(unsigned int)"},
    {"_ZN5clang9ASTReader18getMacroDefinitionEj", "clang::ASTReader::getMacroDefinition(unsigned int)"},
    {"_ZN5clang9ASTReader22LoadPreprocessedEntityERNS0_11PerFileDataE", "clang::ASTReader::LoadPreprocessedEntity(clang::ASTReader::PerFileData&)"},
    {"_ZN5clang9ASTReader20SetIdentifierIsMacroEPNS_14IdentifierInfoERNS0_11PerFileDataEy", "clang::ASTReader::SetIdentifierIsMacro(clang::IdentifierInfo*, clang::ASTReader::PerFileData&, unsigned long long)"},
    {"_ZN5clang9ASTReader17ReadDefinedMacrosEv", "clang::ASTReader::ReadDefinedMacros()"},
    {"_ZN5clang9ASTReader19LoadMacroDefinitionEN4llvm16DenseMapIteratorIPNS_14IdentifierInfoEyNS1_12DenseMapInfoIS4_EENS5_IyEELb0EEE", "clang::ASTReader::LoadMacroDefinition(llvm::DenseMapIterator<clang::IdentifierInfo*, unsigned long long, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<unsigned long long>, false>)"},
    {"_ZN5clang9ASTReader19LoadMacroDefinitionEPNS_14IdentifierInfoE", "clang::ASTReader::LoadMacroDefinition(clang::IdentifierInfo*)"},
    {"_ZN5clang9ASTReader12ReadASTBlockERNS0_11PerFileDataE", "clang::ASTReader::ReadASTBlock(clang::ASTReader::PerFileData&)"},
    {"_ZN5clang9ASTReader11ReadASTCoreEN4llvm9StringRefENS0_11ASTFileTypeE", "clang::ASTReader::ReadASTCore(llvm::StringRef, clang::ASTReader::ASTFileType)"},
    {"_ZN5clang9ASTReader20ParseLanguageOptionsERKN4llvm15SmallVectorImplIyEE", "clang::ASTReader::ParseLanguageOptions(llvm::SmallVectorImpl<unsigned long long> const&)"},
    {"_ZN5clang9ASTReader7ReadASTERKSsNS0_11ASTFileTypeE", "clang::ASTReader::ReadAST(std::string const&, clang::ASTReader::ASTFileType)"},
    {"_ZN5clang9ASTReader17InitializeContextERNS_10ASTContextE", "clang::ASTReader::InitializeContext(clang::ASTContext&)"},
    {"_ZN5clang9ASTReader11PerFileDataC1ENS0_11ASTFileTypeE", "clang::ASTReader::PerFileData::PerFileData(clang::ASTReader::ASTFileType)"},
    {"_ZN5clang9ASTReader15setPreprocessorERNS_12PreprocessorE", "clang::ASTReader::setPreprocessor(clang::Preprocessor&)"},
    {"_ZN5clang9ASTReader22GetTranslationUnitDeclEv", "clang::ASTReader::GetTranslationUnitDecl()"},
    {"_ZN5clang9ASTReader7GetTypeEj", "clang::ASTReader::GetType(unsigned int)"},
    {"_ZN5clang9ASTReader28ReadPragmaDiagnosticMappingsERNS_10DiagnosticE", "clang::ASTReader::ReadPragmaDiagnosticMappings(clang::Diagnostic&)"},
    {"_ZN5clang9ASTReader7GetDeclEj", "clang::ASTReader::GetDecl(unsigned int)"},
    {"_ZN5clang9ASTReader21getOriginalSourceFileERKSsRNS_11FileManagerERNS_10DiagnosticE", "clang::ASTReader::getOriginalSourceFile(std::string const&, clang::FileManager&, clang::Diagnostic&)"},
    {"_ZThn8_N5clang9ASTReader24ReadPreprocessedEntitiesEv", "non-virtual thunk to clang::ASTReader::ReadPreprocessedEntities()"},
    {"_ZN5clang9ASTReader24ReadPreprocessedEntitiesEv", "clang::ASTReader::ReadPreprocessedEntities()"},
    {"_ZThn8_N5clang9ASTReader22ReadPreprocessedEntityEy", "non-virtual thunk to clang::ASTReader::ReadPreprocessedEntity(unsigned long long)"},
    {"_ZN5clang9ASTReader22ReadPreprocessedEntityEy", "clang::ASTReader::ReadPreprocessedEntity(unsigned long long)"},
    {"_ZN5clang9ASTReader18TypeCursorForIndexEj", "clang::ASTReader::TypeCursorForIndex(unsigned int)"},
    {"_ZN5clang9ASTReader14ReadTypeRecordEj", "clang::ASTReader::ReadTypeRecord(unsigned int)"},
    {"_ZN5clang9ASTReader9ReadAPIntERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadAPInt(llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader23ReadNestedNameSpecifierERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadNestedNameSpecifier(llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader20ReadTemplateArgumentERNS0_11PerFileDataERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadTemplateArgument(clang::ASTReader::PerFileData&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader15ReadSourceRangeERNS0_11PerFileDataERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadSourceRange(clang::ASTReader::PerFileData&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader16ReadTemplateNameERNS0_11PerFileDataERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadTemplateName(clang::ASTReader::PerFileData&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader24ReadTemplateArgumentListERN4llvm11SmallVectorINS_16TemplateArgumentELj8EEERNS0_11PerFileDataERKNS2_IyLj64EEERj", "clang::ASTReader::ReadTemplateArgumentList(llvm::SmallVector<clang::TemplateArgument, 8u>&, clang::ASTReader::PerFileData&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang13TypeLocReader21VisitQualifiedTypeLocENS_16QualifiedTypeLocE", "clang::TypeLocReader::VisitQualifiedTypeLoc(clang::QualifiedTypeLoc)"},
    {"_ZN5clang13TypeLocReader19VisitBuiltinTypeLocENS_14BuiltinTypeLocE", "clang::TypeLocReader::VisitBuiltinTypeLoc(clang::BuiltinTypeLoc)"},
    {"_ZN5clang13TypeLocReader19VisitComplexTypeLocENS_14ComplexTypeLocE", "clang::TypeLocReader::VisitComplexTypeLoc(clang::ComplexTypeLoc)"},
    {"_ZN5clang13TypeLocReader19VisitPointerTypeLocENS_14PointerTypeLocE", "clang::TypeLocReader::VisitPointerTypeLoc(clang::PointerTypeLoc)"},
    {"_ZN5clang13TypeLocReader24VisitBlockPointerTypeLocENS_19BlockPointerTypeLocE", "clang::TypeLocReader::VisitBlockPointerTypeLoc(clang::BlockPointerTypeLoc)"},
    {"_ZN5clang13TypeLocReader27VisitLValueReferenceTypeLocENS_22LValueReferenceTypeLocE", "clang::TypeLocReader::VisitLValueReferenceTypeLoc(clang::LValueReferenceTypeLoc)"},
    {"_ZN5clang13TypeLocReader27VisitRValueReferenceTypeLocENS_22RValueReferenceTypeLocE", "clang::TypeLocReader::VisitRValueReferenceTypeLoc(clang::RValueReferenceTypeLoc)"},
    {"_ZN5clang13TypeLocReader25VisitMemberPointerTypeLocENS_20MemberPointerTypeLocE", "clang::TypeLocReader::VisitMemberPointerTypeLoc(clang::MemberPointerTypeLoc)"},
    {"_ZN5clang13TypeLocReader17VisitArrayTypeLocENS_12ArrayTypeLocE", "clang::TypeLocReader::VisitArrayTypeLoc(clang::ArrayTypeLoc)"},
    {"_ZN5clang13TypeLocReader25VisitConstantArrayTypeLocENS_20ConstantArrayTypeLocE", "clang::TypeLocReader::VisitConstantArrayTypeLoc(clang::ConstantArrayTypeLoc)"},
    {"_ZN5clang13TypeLocReader27VisitIncompleteArrayTypeLocENS_22IncompleteArrayTypeLocE", "clang::TypeLocReader::VisitIncompleteArrayTypeLoc(clang::IncompleteArrayTypeLoc)"},
    {"_ZN5clang13TypeLocReader25VisitVariableArrayTypeLocENS_20VariableArrayTypeLocE", "clang::TypeLocReader::VisitVariableArrayTypeLoc(clang::VariableArrayTypeLoc)"},
    {"_ZN5clang13TypeLocReader31VisitDependentSizedArrayTypeLocENS_26DependentSizedArrayTypeLocE", "clang::TypeLocReader::VisitDependentSizedArrayTypeLoc(clang::DependentSizedArrayTypeLoc)"},
    {"_ZN5clang13TypeLocReader35VisitDependentSizedExtVectorTypeLocENS_30DependentSizedExtVectorTypeLocE", "clang::TypeLocReader::VisitDependentSizedExtVectorTypeLoc(clang::DependentSizedExtVectorTypeLoc)"},
    {"_ZN5clang13TypeLocReader18VisitVectorTypeLocENS_13VectorTypeLocE", "clang::TypeLocReader::VisitVectorTypeLoc(clang::VectorTypeLoc)"},
    {"_ZN5clang13TypeLocReader21VisitExtVectorTypeLocENS_16ExtVectorTypeLocE", "clang::TypeLocReader::VisitExtVectorTypeLoc(clang::ExtVectorTypeLoc)"},
    {"_ZN5clang13TypeLocReader20VisitFunctionTypeLocENS_15FunctionTypeLocE", "clang::TypeLocReader::VisitFunctionTypeLoc(clang::FunctionTypeLoc)"},
    {"_ZN5clang13TypeLocReader25VisitFunctionProtoTypeLocENS_20FunctionProtoTypeLocE", "clang::TypeLocReader::VisitFunctionProtoTypeLoc(clang::FunctionProtoTypeLoc)"},
    {"_ZN5clang13TypeLocReader27VisitFunctionNoProtoTypeLocENS_22FunctionNoProtoTypeLocE", "clang::TypeLocReader::VisitFunctionNoProtoTypeLoc(clang::FunctionNoProtoTypeLoc)"},
    {"_ZN5clang13TypeLocReader27VisitUnresolvedUsingTypeLocENS_22UnresolvedUsingTypeLocE", "clang::TypeLocReader::VisitUnresolvedUsingTypeLoc(clang::UnresolvedUsingTypeLoc)"},
    {"_ZN5clang13TypeLocReader19VisitTypedefTypeLocENS_14TypedefTypeLocE", "clang::TypeLocReader::VisitTypedefTypeLoc(clang::TypedefTypeLoc)"},
    {"_ZN5clang13TypeLocReader22VisitTypeOfExprTypeLocENS_17TypeOfExprTypeLocE", "clang::TypeLocReader::VisitTypeOfExprTypeLoc(clang::TypeOfExprTypeLoc)"},
    {"_ZN5clang13TypeLocReader18VisitTypeOfTypeLocENS_13TypeOfTypeLocE", "clang::TypeLocReader::VisitTypeOfTypeLoc(clang::TypeOfTypeLoc)"},
    {"_ZN5clang9ASTReader17GetTypeSourceInfoERNS0_11PerFileDataERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::GetTypeSourceInfo(clang::ASTReader::PerFileData&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang13TypeLocReader20VisitDecltypeTypeLocENS_15DecltypeTypeLocE", "clang::TypeLocReader::VisitDecltypeTypeLoc(clang::DecltypeTypeLoc)"},
    {"_ZN5clang13TypeLocReader18VisitRecordTypeLocENS_13RecordTypeLocE", "clang::TypeLocReader::VisitRecordTypeLoc(clang::RecordTypeLoc)"},
    {"_ZN5clang13TypeLocReader16VisitEnumTypeLocENS_11EnumTypeLocE", "clang::TypeLocReader::VisitEnumTypeLoc(clang::EnumTypeLoc)"},
    {"_ZN5clang13TypeLocReader22VisitAttributedTypeLocENS_17AttributedTypeLocE", "clang::TypeLocReader::VisitAttributedTypeLoc(clang::AttributedTypeLoc)"},
    {"_ZN5clang13TypeLocReader28VisitTemplateTypeParmTypeLocENS_23TemplateTypeParmTypeLocE", "clang::TypeLocReader::VisitTemplateTypeParmTypeLoc(clang::TemplateTypeParmTypeLoc)"},
    {"_ZN5clang13TypeLocReader33VisitSubstTemplateTypeParmTypeLocENS_28SubstTemplateTypeParmTypeLocE", "clang::TypeLocReader::VisitSubstTemplateTypeParmTypeLoc(clang::SubstTemplateTypeParmTypeLoc)"},
    {"_ZN5clang13TypeLocReader37VisitSubstTemplateTypeParmPackTypeLocENS_32SubstTemplateTypeParmPackTypeLocE", "clang::TypeLocReader::VisitSubstTemplateTypeParmPackTypeLoc(clang::SubstTemplateTypeParmPackTypeLoc)"},
    {"_ZN5clang13TypeLocReader34VisitTemplateSpecializationTypeLocENS_29TemplateSpecializationTypeLocE", "clang::TypeLocReader::VisitTemplateSpecializationTypeLoc(clang::TemplateSpecializationTypeLoc)"},
    {"_ZN5clang9ASTReader26GetTemplateArgumentLocInfoERNS0_11PerFileDataENS_16TemplateArgument7ArgKindERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::GetTemplateArgumentLocInfo(clang::ASTReader::PerFileData&, clang::TemplateArgument::ArgKind, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang13TypeLocReader17VisitParenTypeLocENS_12ParenTypeLocE", "clang::TypeLocReader::VisitParenTypeLoc(clang::ParenTypeLoc)"},
    {"_ZN5clang13TypeLocReader22VisitElaboratedTypeLocENS_17ElaboratedTypeLocE", "clang::TypeLocReader::VisitElaboratedTypeLoc(clang::ElaboratedTypeLoc)"},
    {"_ZN5clang13TypeLocReader29VisitInjectedClassNameTypeLocENS_24InjectedClassNameTypeLocE", "clang::TypeLocReader::VisitInjectedClassNameTypeLoc(clang::InjectedClassNameTypeLoc)"},
    {"_ZN5clang13TypeLocReader25VisitDependentNameTypeLocENS_20DependentNameTypeLocE", "clang::TypeLocReader::VisitDependentNameTypeLoc(clang::DependentNameTypeLoc)"},
    {"_ZN5clang13TypeLocReader43VisitDependentTemplateSpecializationTypeLocENS_38DependentTemplateSpecializationTypeLocE", "clang::TypeLocReader::VisitDependentTemplateSpecializationTypeLoc(clang::DependentTemplateSpecializationTypeLoc)"},
    {"_ZN5clang13TypeLocReader25VisitPackExpansionTypeLocENS_20PackExpansionTypeLocE", "clang::TypeLocReader::VisitPackExpansionTypeLoc(clang::PackExpansionTypeLoc)"},
    {"_ZN5clang13TypeLocReader25VisitObjCInterfaceTypeLocENS_20ObjCInterfaceTypeLocE", "clang::TypeLocReader::VisitObjCInterfaceTypeLoc(clang::ObjCInterfaceTypeLoc)"},
    {"_ZN5clang13TypeLocReader22VisitObjCObjectTypeLocENS_17ObjCObjectTypeLocE", "clang::TypeLocReader::VisitObjCObjectTypeLoc(clang::ObjCObjectTypeLoc)"},
    {"_ZN5clang13TypeLocReader29VisitObjCObjectPointerTypeLocENS_24ObjCObjectPointerTypeLocE", "clang::TypeLocReader::VisitObjCObjectPointerTypeLoc(clang::ObjCObjectPointerTypeLoc)"},
    {"_ZNK5clang9ASTReader9GetTypeIDENS_8QualTypeE", "clang::ASTReader::GetTypeID(clang::QualType) const"},
    {"_ZNK5clang9ASTReader10GetTypeIdxENS_8QualTypeE", "clang::ASTReader::GetTypeIdx(clang::QualType) const"},
    {"_ZNK5clang9ASTReader28getTotalNumCXXBaseSpecifiersEv", "clang::ASTReader::getTotalNumCXXBaseSpecifiers() const"},
    {"_ZN5clang9ASTReader23ReadTemplateArgumentLocERNS0_11PerFileDataERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadTemplateArgumentLoc(clang::ASTReader::PerFileData&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZThn16_N5clang9ASTReader15GetExternalDeclEj", "non-virtual thunk to clang::ASTReader::GetExternalDecl(unsigned int)"},
    {"_ZN5clang9ASTReader15GetExternalDeclEj", "clang::ASTReader::GetExternalDecl(unsigned int)"},
    {"_ZN5clang9ASTReader26GetCXXBaseSpecifiersOffsetEj", "clang::ASTReader::GetCXXBaseSpecifiersOffset(unsigned int)"},
    {"_ZThn16_N5clang9ASTReader28GetExternalCXXBaseSpecifiersEy", "non-virtual thunk to clang::ASTReader::GetExternalCXXBaseSpecifiers(unsigned long long)"},
    {"_ZN5clang9ASTReader28GetExternalCXXBaseSpecifiersEy", "clang::ASTReader::GetExternalCXXBaseSpecifiers(unsigned long long)"},
    {"_ZN5clang9ASTReader20ReadCXXBaseSpecifierERNS0_11PerFileDataERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadCXXBaseSpecifier(clang::ASTReader::PerFileData&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZThn16_N5clang9ASTReader19GetExternalDeclStmtEy", "non-virtual thunk to clang::ASTReader::GetExternalDeclStmt(unsigned long long)"},
    {"_ZN5clang9ASTReader19GetExternalDeclStmtEy", "clang::ASTReader::GetExternalDeclStmt(unsigned long long)"},
    {"_ZN5clang9ASTReader18ClearSwitchCaseIDsEv", "clang::ASTReader::ClearSwitchCaseIDs()"},
    {"_ZThn16_N5clang9ASTReader24FindExternalLexicalDeclsEPKNS_11DeclContextEPFbNS_4Decl4KindEERN4llvm15SmallVectorImplIPS4_EE", "non-virtual thunk to clang::ASTReader::FindExternalLexicalDecls(clang::DeclContext const*, bool (*)(clang::Decl::Kind), llvm::SmallVectorImpl<clang::Decl*>&)"},
    {"_ZN5clang9ASTReader24FindExternalLexicalDeclsEPKNS_11DeclContextEPFbNS_4Decl4KindEERN4llvm15SmallVectorImplIPS4_EE", "clang::ASTReader::FindExternalLexicalDecls(clang::DeclContext const*, bool (*)(clang::Decl::Kind), llvm::SmallVectorImpl<clang::Decl*>&)"},
    {"_ZThn16_N5clang9ASTReader30FindExternalVisibleDeclsByNameEPKNS_11DeclContextENS_15DeclarationNameE", "non-virtual thunk to clang::ASTReader::FindExternalVisibleDeclsByName(clang::DeclContext const*, clang::DeclarationName)"},
    {"_ZN5clang9ASTReader30FindExternalVisibleDeclsByNameEPKNS_11DeclContextENS_15DeclarationNameE", "clang::ASTReader::FindExternalVisibleDeclsByName(clang::DeclContext const*, clang::DeclarationName)"},
    {"_ZThn16_N5clang9ASTReader23MaterializeVisibleDeclsEPKNS_11DeclContextE", "non-virtual thunk to clang::ASTReader::MaterializeVisibleDecls(clang::DeclContext const*)"},
    {"_ZN5clang9ASTReader23MaterializeVisibleDeclsEPKNS_11DeclContextE", "clang::ASTReader::MaterializeVisibleDecls(clang::DeclContext const*)"},
    {"_ZN5clang9ASTReader30PassInterestingDeclsToConsumerEv", "clang::ASTReader::PassInterestingDeclsToConsumer()"},
    {"_ZThn16_N5clang9ASTReader20StartTranslationUnitEPNS_11ASTConsumerE", "non-virtual thunk to clang::ASTReader::StartTranslationUnit(clang::ASTConsumer*)"},
    {"_ZN5clang9ASTReader20StartTranslationUnitEPNS_11ASTConsumerE", "clang::ASTReader::StartTranslationUnit(clang::ASTConsumer*)"},
    {"_ZThn16_N5clang9ASTReader10PrintStatsEv", "non-virtual thunk to clang::ASTReader::PrintStats()"},
    {"_ZN5clang9ASTReader10PrintStatsEv", "clang::ASTReader::PrintStats()"},
    {"_ZThn16_N5clang9ASTReader14InitializeSemaERNS_4SemaE", "non-virtual thunk to clang::ASTReader::InitializeSema(clang::Sema&)"},
    {"_ZN5clang9ASTReader14InitializeSemaERNS_4SemaE", "clang::ASTReader::InitializeSema(clang::Sema&)"},
    {"_ZN5clang9ASTReader14DecodeSelectorEj", "clang::ASTReader::DecodeSelector(unsigned int)"},
    {"_ZN5clang9ASTReader3getEPKcS2_", "clang::ASTReader::get(char const*, char const*)"},
    {"_ZN5clang21ASTIdentifierIteratorC1ERKNS_9ASTReaderE", "clang::ASTIdentifierIterator::ASTIdentifierIterator(clang::ASTReader const&)"},
    {"_ZN5clang21ASTIdentifierIteratorC2ERKNS_9ASTReaderE", "clang::ASTIdentifierIterator::ASTIdentifierIterator(clang::ASTReader const&)"},
    {"_ZN5clang21ASTIdentifierIterator4NextEv", "clang::ASTIdentifierIterator::Next()"},
    {"_ZThn32_NK5clang9ASTReader14getIdentifiersEv", "non-virtual thunk to clang::ASTReader::getIdentifiers() const"},
    {"_ZNK5clang9ASTReader14getIdentifiersEv", "clang::ASTReader::getIdentifiers() const"},
    {"_ZThn16_N5clang9ASTReader14ReadMethodPoolENS_8SelectorE", "non-virtual thunk to clang::ASTReader::ReadMethodPool(clang::Selector)"},
    {"_ZN5clang9ASTReader14ReadMethodPoolENS_8SelectorE", "clang::ASTReader::ReadMethodPool(clang::Selector)"},
    {"_ZN5clang9ASTReader12LoadSelectorENS_8SelectorE", "clang::ASTReader::LoadSelector(clang::Selector)"},
    {"_ZN5clang9ASTReader17SetIdentifierInfoEjPNS_14IdentifierInfoE", "clang::ASTReader::SetIdentifierInfo(unsigned int, clang::IdentifierInfo*)"},
    {"_ZN5clang9ASTReader23SetGloballyVisibleDeclsEPNS_14IdentifierInfoERKN4llvm15SmallVectorImplIjEEb", "clang::ASTReader::SetGloballyVisibleDecls(clang::IdentifierInfo*, llvm::SmallVectorImpl<unsigned int> const&, bool)"},
    {"_ZThn48_N5clang9ASTReader13ReadSLocEntryEj", "non-virtual thunk to clang::ASTReader::ReadSLocEntry(unsigned int)"},
    {"_ZN5clang9ASTReader13ReadSLocEntryEj", "clang::ASTReader::ReadSLocEntry(unsigned int)"},
    {"_ZN12_GLOBAL__N_122ASTSelectorLookupTrait7ReadKeyEPKhj", "(anonymous namespace)::ASTSelectorLookupTrait::ReadKey(unsigned char const*, unsigned int)"},
    {"_ZThn16_N5clang9ASTReader19GetExternalSelectorEj", "non-virtual thunk to clang::ASTReader::GetExternalSelector(unsigned int)"},
    {"_ZN5clang9ASTReader19GetExternalSelectorEj", "clang::ASTReader::GetExternalSelector(unsigned int)"},
    {"_ZThn16_N5clang9ASTReader23GetNumExternalSelectorsEv", "non-virtual thunk to clang::ASTReader::GetNumExternalSelectors()"},
    {"_ZN5clang9ASTReader23GetNumExternalSelectorsEv", "clang::ASTReader::GetNumExternalSelectors()"},
    {"_ZN5clang9ASTReader19ReadDeclarationNameERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadDeclarationName(llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader22ReadDeclarationNameLocERNS0_11PerFileDataERNS_18DeclarationNameLocENS_15DeclarationNameERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadDeclarationNameLoc(clang::ASTReader::PerFileData&, clang::DeclarationNameLoc&, clang::DeclarationName, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader23ReadDeclarationNameInfoERNS0_11PerFileDataERNS_19DeclarationNameInfoERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadDeclarationNameInfo(clang::ASTReader::PerFileData&, clang::DeclarationNameInfo&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader17ReadQualifierInfoERNS0_11PerFileDataERNS_13QualifierInfoERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadQualifierInfo(clang::ASTReader::PerFileData&, clang::QualifierInfo&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader25ReadTemplateParameterListERNS0_11PerFileDataERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadTemplateParameterList(clang::ASTReader::PerFileData&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader10ReadAPSIntERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadAPSInt(llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader17ReadUnresolvedSetERNS_17UnresolvedSetImplERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadUnresolvedSet(clang::UnresolvedSetImpl&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader23ReadCXXCtorInitializersERNS0_11PerFileDataERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadCXXCtorInitializers(clang::ASTReader::PerFileData&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader11ReadAPFloatERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadAPFloat(llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader10ReadStringERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadString(llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader16ReadCXXTemporaryERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTReader::ReadCXXTemporary(llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang9ASTReader18getIdentifierTableEv", "clang::ASTReader::getIdentifierTable()"},
    {"_ZN5clang9ASTReader18RecordSwitchCaseIDEPNS_10SwitchCaseEj", "clang::ASTReader::RecordSwitchCaseID(clang::SwitchCase*, unsigned int)"},
    {"_ZN5clang9ASTReader19getSwitchCaseWithIDEj", "clang::ASTReader::getSwitchCaseWithID(unsigned int)"},
    {"_ZN5clang9ASTReader15RecordLabelStmtEPNS_9LabelStmtEj", "clang::ASTReader::RecordLabelStmt(clang::LabelStmt*, unsigned int)"},
    {"_ZN5clang9ASTReader10SetLabelOfEPNS_8GotoStmtEj", "clang::ASTReader::SetLabelOf(clang::GotoStmt*, unsigned int)"},
    {"_ZN5clang9ASTReader10SetLabelOfEPNS_13AddrLabelExprEj", "clang::ASTReader::SetLabelOf(clang::AddrLabelExpr*, unsigned int)"},
    {"_ZThn16_N5clang9ASTReader21FinishedDeserializingEv", "non-virtual thunk to clang::ASTReader::FinishedDeserializing()"},
    {"_ZN5clang9ASTReader21FinishedDeserializingEv", "clang::ASTReader::FinishedDeserializing()"},
    {"_ZN5clang9ASTReaderC1ERNS_12PreprocessorEPNS_10ASTContextEPKcbb", "clang::ASTReader::ASTReader(clang::Preprocessor&, clang::ASTContext*, char const*, bool, bool)"},
    {"_ZN5clang9ASTReaderC2ERNS_12PreprocessorEPNS_10ASTContextEPKcbb", "clang::ASTReader::ASTReader(clang::Preprocessor&, clang::ASTContext*, char const*, bool, bool)"},
    {"_ZN5clang9ASTReaderC1ERNS_13SourceManagerERNS_11FileManagerERNS_10DiagnosticEPKcbb", "clang::ASTReader::ASTReader(clang::SourceManager&, clang::FileManager&, clang::Diagnostic&, char const*, bool, bool)"},
    {"_ZN5clang9ASTReaderC2ERNS_13SourceManagerERNS_11FileManagerERNS_10DiagnosticEPKcbb", "clang::ASTReader::ASTReader(clang::SourceManager&, clang::FileManager&, clang::Diagnostic&, char const*, bool, bool)"},
    {"_ZThn8_N5clang9ASTReaderD0Ev", "non-virtual thunk to clang::ASTReader::~ASTReader()"},
    {"_ZN5clang9ASTReaderD0Ev", "clang::ASTReader::~ASTReader()"},
    {"_ZThn16_N5clang9ASTReaderD0Ev", "non-virtual thunk to clang::ASTReader::~ASTReader()"},
    {"_ZThn32_N5clang9ASTReaderD0Ev", "non-virtual thunk to clang::ASTReader::~ASTReader()"},
    {"_ZThn40_N5clang9ASTReaderD0Ev", "non-virtual thunk to clang::ASTReader::~ASTReader()"},
    {"_ZThn48_N5clang9ASTReaderD0Ev", "non-virtual thunk to clang::ASTReader::~ASTReader()"},
    {"_ZN5clang9ASTReaderD1Ev", "clang::ASTReader::~ASTReader()"},
    {"_ZThn8_N5clang9ASTReaderD1Ev", "non-virtual thunk to clang::ASTReader::~ASTReader()"},
    {"_ZThn16_N5clang9ASTReaderD1Ev", "non-virtual thunk to clang::ASTReader::~ASTReader()"},
    {"_ZThn32_N5clang9ASTReaderD1Ev", "non-virtual thunk to clang::ASTReader::~ASTReader()"},
    {"_ZThn40_N5clang9ASTReaderD1Ev", "non-virtual thunk to clang::ASTReader::~ASTReader()"},
    {"_ZThn48_N5clang9ASTReaderD1Ev", "non-virtual thunk to clang::ASTReader::~ASTReader()"},
    {"_ZN5clang9ASTReaderD2Ev", "clang::ASTReader::~ASTReader()"},
    {"_ZN5clang9ASTReader11PerFileDataD1Ev", "clang::ASTReader::PerFileData::~PerFileData()"},
    {"_ZN5clang9ASTReader11PerFileDataC2ENS0_11ASTFileTypeE", "clang::ASTReader::PerFileData::PerFileData(clang::ASTReader::ASTFileType)"},
    {"_ZN5clang9ASTReader11PerFileDataD2Ev", "clang::ASTReader::PerFileData::~PerFileData()"},
    {"_ZN12_GLOBAL__N_129ASTDeclContextNameLookupTrait7ReadKeyEPKhj", "(anonymous namespace)::ASTDeclContextNameLookupTrait::ReadKey(unsigned char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_112ASTStatCacheD1Ev", "(anonymous namespace)::ASTStatCache::~ASTStatCache()"},
    {"_ZN12_GLOBAL__N_112ASTStatCacheD0Ev", "(anonymous namespace)::ASTStatCache::~ASTStatCache()"},
    {"_ZN12_GLOBAL__N_112ASTStatCache7getStatEPKcR4statPi", "(anonymous namespace)::ASTStatCache::getStat(char const*, stat&, int*)"},
    {"_ZSt14set_differenceIPN4llvm9StringRefES2_St20back_insert_iteratorISt6vectorIS1_SaIS1_EEEET1_T_S9_T0_SA_S8_", "std::back_insert_iterator<std::vector<llvm::StringRef, std::allocator<llvm::StringRef>>> std::set_difference<llvm::StringRef*, llvm::StringRef*, std::back_insert_iterator<std::vector<llvm::StringRef, std::allocator<llvm::StringRef>>>>(llvm::StringRef*, llvm::StringRef*, llvm::StringRef*, llvm::StringRef*, std::back_insert_iterator<std::vector<llvm::StringRef, std::allocator<llvm::StringRef>>>)"},
    {"_ZN4llvm15BitstreamCursor10ReadRecordEjRNS_15SmallVectorImplIyEEPPKcPj", "llvm::BitstreamCursor::ReadRecord(unsigned int, llvm::SmallVectorImpl<unsigned long long>&, char const**, unsigned int*)"},
    {"_ZNSt6vectorIN5clang9LineEntryESaIS1_EE7reserveEm", "std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>::reserve(unsigned long)"},
    {"_ZN4llvm15BitstreamCursoraSERKS0_", "llvm::BitstreamCursor::operator=(llvm::BitstreamCursor const&)"},
    {"_ZN4llvm15BitstreamCursor9SkipBlockEv", "llvm::BitstreamCursor::SkipBlock()"},
    {"_ZN4llvm15BitstreamCursor13EnterSubBlockEjPj", "llvm::BitstreamCursor::EnterSubBlock(unsigned int, unsigned int*)"},
    {"_ZN4llvm15BitstreamCursor14ReadSubBlockIDEv", "llvm::BitstreamCursor::ReadSubBlockID()"},
    {"_ZN4llvm15BitstreamCursor16ReadAbbrevRecordEv", "llvm::BitstreamCursor::ReadAbbrevRecord()"},
    {"_ZN4llvm15SmallVectorImplIyE4swapERS1_", "llvm::SmallVectorImpl<unsigned long long>::swap(llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN4llvm15SmallVectorImplIyE6insertIPyEES3_S3_T_S4_", "unsigned long long* llvm::SmallVectorImpl<unsigned long long>::insert<unsigned long long*>(unsigned long long*, unsigned long long*, unsigned long long*)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang15MacroDefinitionEE6resizeEj", "llvm::SmallVectorImpl<clang::MacroDefinition*>::resize(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIN5clang8SelectorEE6resizeEj", "llvm::SmallVectorImpl<clang::Selector>::resize(unsigned int)"},
    {"_ZN5clang22OnDiskChainedHashTableINS_24ASTIdentifierLookupTraitEE4findERKSt4pairIPKcjEPS1_", "clang::OnDiskChainedHashTable<clang::ASTIdentifierLookupTrait>::find(std::pair<char const*, unsigned int> const&, clang::ASTIdentifierLookupTrait*)"},
    {"_ZN4llvm15BitstreamCursor4ReadEj", "llvm::BitstreamCursor::Read(unsigned int)"},
    {"_ZN4llvm15BitstreamCursor18ReadBlockInfoBlockEv", "llvm::BitstreamCursor::ReadBlockInfoBlock()"},
    {"_ZN4llvm15SmallVectorImplIN5clang9ASTReader15DeclContextInfoEE4swapERS4_", "llvm::SmallVectorImpl<clang::ASTReader::DeclContextInfo>::swap(llvm::SmallVectorImpl<clang::ASTReader::DeclContextInfo>&)"},
    {"_ZN5clang14TypeLocVisitorINS_13TypeLocReaderEvE5VisitENS_7TypeLocE", "clang::TypeLocVisitor<clang::TypeLocReader, void>::Visit(clang::TypeLoc)"},
    {"_ZN5clang13serialization10MakeTypeIDISt9binder1stISt16const_mem_fun1_tINS0_7TypeIdxENS_9ASTReaderENS_8QualTypeEEEEEjS6_T_", "unsigned int clang::serialization::MakeTypeID<std::binder1st<std::const_mem_fun1_t<clang::serialization::TypeIdx, clang::ASTReader, clang::QualType>>>(clang::QualType, std::binder1st<std::const_mem_fun1_t<clang::serialization::TypeIdx, clang::ASTReader, clang::QualType>>)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorENS1_14SourceLocationENS_12DenseMapInfoIS2_EENS4_IS3_EEE6insertERKSt4pairIS2_S3_E", "llvm::DenseMap<clang::Selector, clang::SourceLocation, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<clang::SourceLocation>>::insert(std::pair<clang::Selector, clang::SourceLocation> const&)"},
    {"_ZNSt5dequeISt4pairIPN5clang9ValueDeclENS1_14SourceLocationEESaIS5_EE9push_backERKS5_", "std::deque<std::pair<clang::ValueDecl*, clang::SourceLocation>, std::allocator<std::pair<clang::ValueDecl*, clang::SourceLocation>>>::push_back(std::pair<clang::ValueDecl*, clang::SourceLocation> const&)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoENS1_4Sema8WeakInfoENS_12DenseMapInfoIS3_EENS6_IS5_EEE6insertERKSt4pairIS3_S5_E", "llvm::DenseMap<clang::IdentifierInfo*, clang::Sema::WeakInfo, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::Sema::WeakInfo>>::insert(std::pair<clang::IdentifierInfo*, clang::Sema::WeakInfo> const&)"},
    {"_ZN5clang17ASTReaderListener19ReadLanguageOptionsERKNS_11LangOptionsE", "clang::ASTReaderListener::ReadLanguageOptions(clang::LangOptions const&)"},
    {"_ZN5clang17ASTReaderListener16ReadTargetTripleEN4llvm9StringRefE", "clang::ASTReaderListener::ReadTargetTriple(llvm::StringRef)"},
    {"_ZN5clang17ASTReaderListener20ReadPredefinesBufferERKN4llvm11SmallVectorINS_18PCHPredefinesBlockELj2EEENS1_9StringRefERSs", "clang::ASTReaderListener::ReadPredefinesBuffer(llvm::SmallVector<clang::PCHPredefinesBlock, 2u> const&, llvm::StringRef, std::string&)"},
    {"_ZN5clang17ASTReaderListener18ReadHeaderFileInfoERKNS_14HeaderFileInfoEj", "clang::ASTReaderListener::ReadHeaderFileInfo(clang::HeaderFileInfo const&, unsigned int)"},
    {"_ZN5clang17ASTReaderListener11ReadCounterEj", "clang::ASTReaderListener::ReadCounter(unsigned int)"},
    {"_ZN5clang12PCHValidatorD1Ev", "clang::PCHValidator::~PCHValidator()"},
    {"_ZN5clang12PCHValidatorD0Ev", "clang::PCHValidator::~PCHValidator()"},
    {"_ZN5clang9ASTReader20StartedDeserializingEv", "clang::ASTReader::StartedDeserializing()"},
    {"_ZN5clang9ASTReader10ForgetSemaEv", "clang::ASTReader::ForgetSema()"},
    {"_ZN5clang9ASTReader3getEN4llvm9StringRefE", "clang::ASTReader::get(llvm::StringRef)"},
    {"_ZN5clang9ASTReader13GetIdentifierEj", "clang::ASTReader::GetIdentifier(unsigned int)"},
    {"_ZThn16_N5clang9ASTReader20StartedDeserializingEv", "non-virtual thunk to clang::ASTReader::StartedDeserializing()"},
    {"_ZThn16_N5clang9ASTReader10ForgetSemaEv", "non-virtual thunk to clang::ASTReader::ForgetSema()"},
    {"_ZThn32_N5clang9ASTReader3getEN4llvm9StringRefE", "non-virtual thunk to clang::ASTReader::get(llvm::StringRef)"},
    {"_ZThn40_N5clang9ASTReader13GetIdentifierEj", "non-virtual thunk to clang::ASTReader::GetIdentifier(unsigned int)"},
    {"_ZN5clang21ASTIdentifierIteratorD1Ev", "clang::ASTIdentifierIterator::~ASTIdentifierIterator()"},
    {"_ZN5clang21ASTIdentifierIteratorD0Ev", "clang::ASTIdentifierIterator::~ASTIdentifierIterator()"},
    {"_ZNSt5dequeIN5clang9ASTReader21PendingIdentifierInfoESaIS2_EED2Ev", "std::deque<clang::ASTReader::PendingIdentifierInfo, std::allocator<clang::ASTReader::PendingIdentifierInfo>>::~deque()"},
    {"_ZNSt5dequeIN5clang9ASTReader21PendingIdentifierInfoESaIS2_EE19_M_destroy_data_auxESt15_Deque_iteratorIS2_RS2_PS2_ES8_", "std::deque<clang::ASTReader::PendingIdentifierInfo, std::allocator<clang::ASTReader::PendingIdentifierInfo>>::_M_destroy_data_aux(std::_Deque_iterator<clang::ASTReader::PendingIdentifierInfo, clang::ASTReader::PendingIdentifierInfo&, clang::ASTReader::PendingIdentifierInfo*>, std::_Deque_iterator<clang::ASTReader::PendingIdentifierInfo, clang::ASTReader::PendingIdentifierInfo&, clang::ASTReader::PendingIdentifierInfo*>)"},
    {"_ZNSt11_Deque_baseIPN5clang4DeclESaIS2_EE17_M_initialize_mapEm", "std::_Deque_base<clang::Decl*, std::allocator<clang::Decl*>>::_M_initialize_map(unsigned long)"},
    {"_ZNSt11_Deque_baseIN5clang9ASTReader21PendingIdentifierInfoESaIS2_EE17_M_initialize_mapEm", "std::_Deque_base<clang::ASTReader::PendingIdentifierInfo, std::allocator<clang::ASTReader::PendingIdentifierInfo>>::_M_initialize_map(unsigned long)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjPN5clang13AddrLabelExprEESt10_Select1stIS5_ESt4lessIjESaIS5_EE5eraseESt17_Rb_tree_iteratorIS5_ESD_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, clang::AddrLabelExpr*>, std::_Select1st<std::pair<unsigned int const, clang::AddrLabelExpr*>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, clang::AddrLabelExpr*>>>::erase(std::_Rb_tree_iterator<std::pair<unsigned int const, clang::AddrLabelExpr*>>, std::_Rb_tree_iterator<std::pair<unsigned int const, clang::AddrLabelExpr*>>)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjPN5clang13AddrLabelExprEESt10_Select1stIS5_ESt4lessIjESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, clang::AddrLabelExpr*>, std::_Select1st<std::pair<unsigned int const, clang::AddrLabelExpr*>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, clang::AddrLabelExpr*>>>::_M_erase(std::_Rb_tree_node<std::pair<unsigned int const, clang::AddrLabelExpr*>>*)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjPN5clang8GotoStmtEESt10_Select1stIS5_ESt4lessIjESaIS5_EE5eraseESt17_Rb_tree_iteratorIS5_ESD_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, clang::GotoStmt*>, std::_Select1st<std::pair<unsigned int const, clang::GotoStmt*>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, clang::GotoStmt*>>>::erase(std::_Rb_tree_iterator<std::pair<unsigned int const, clang::GotoStmt*>>, std::_Rb_tree_iterator<std::pair<unsigned int const, clang::GotoStmt*>>)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjPN5clang8GotoStmtEESt10_Select1stIS5_ESt4lessIjESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, clang::GotoStmt*>, std::_Select1st<std::pair<unsigned int const, clang::GotoStmt*>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, clang::GotoStmt*>>>::_M_erase(std::_Rb_tree_node<std::pair<unsigned int const, clang::GotoStmt*>>*)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjPN5clang9LabelStmtEESt10_Select1stIS5_ESt4lessIjESaIS5_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS5_ERKS5_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, clang::LabelStmt*>, std::_Select1st<std::pair<unsigned int const, clang::LabelStmt*>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, clang::LabelStmt*>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<unsigned int const, clang::LabelStmt*>>, std::pair<unsigned int const, clang::LabelStmt*> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjPN5clang9LabelStmtEESt10_Select1stIS5_ESt4lessIjESaIS5_EE16_M_insert_uniqueERKS5_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, clang::LabelStmt*>, std::_Select1st<std::pair<unsigned int const, clang::LabelStmt*>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, clang::LabelStmt*>>>::_M_insert_unique(std::pair<unsigned int const, clang::LabelStmt*> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjPN5clang10SwitchCaseEESt10_Select1stIS5_ESt4lessIjESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, clang::SwitchCase*>, std::_Select1st<std::pair<unsigned int const, clang::SwitchCase*>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, clang::SwitchCase*>>>::_M_erase(std::_Rb_tree_node<std::pair<unsigned int const, clang::SwitchCase*>>*)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjPN5clang10SwitchCaseEESt10_Select1stIS5_ESt4lessIjESaIS5_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS5_ERKS5_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, clang::SwitchCase*>, std::_Select1st<std::pair<unsigned int const, clang::SwitchCase*>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, clang::SwitchCase*>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<unsigned int const, clang::SwitchCase*>>, std::pair<unsigned int const, clang::SwitchCase*> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjPN5clang10SwitchCaseEESt10_Select1stIS5_ESt4lessIjESaIS5_EE16_M_insert_uniqueERKS5_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, clang::SwitchCase*>, std::_Select1st<std::pair<unsigned int const, clang::SwitchCase*>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, clang::SwitchCase*>>>::_M_insert_unique(std::pair<unsigned int const, clang::SwitchCase*> const&)"},
    {"_ZNSt5dequeIN5clang9ASTReader21PendingIdentifierInfoESaIS2_EE16_M_push_back_auxERKS2_", "std::deque<clang::ASTReader::PendingIdentifierInfo, std::allocator<clang::ASTReader::PendingIdentifierInfo>>::_M_push_back_aux(clang::ASTReader::PendingIdentifierInfo const&)"},
    {"_ZNSt5dequeIN5clang9ASTReader21PendingIdentifierInfoESaIS2_EE17_M_reallocate_mapEmb", "std::deque<clang::ASTReader::PendingIdentifierInfo, std::allocator<clang::ASTReader::PendingIdentifierInfo>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZN4llvm8DenseMapIPN5clang13CXXRecordDeclEbNS_12DenseMapInfoIS3_EENS4_IbEEE16InsertIntoBucketERKS3_RKbPSt4pairIS3_bE", "llvm::DenseMap<clang::CXXRecordDecl*, bool, llvm::DenseMapInfo<clang::CXXRecordDecl*>, llvm::DenseMapInfo<bool>>::InsertIntoBucket(clang::CXXRecordDecl* const&, bool const&, std::pair<clang::CXXRecordDecl*, bool>*)"},
    {"_ZN4llvm8DenseMapIPN5clang13CXXRecordDeclEbNS_12DenseMapInfoIS3_EENS4_IbEEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl*, bool, llvm::DenseMapInfo<clang::CXXRecordDecl*>, llvm::DenseMapInfo<bool>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoENS1_4Sema8WeakInfoENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::IdentifierInfo*, clang::Sema::WeakInfo, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::Sema::WeakInfo>>::InsertIntoBucket(clang::IdentifierInfo* const&, clang::Sema::WeakInfo const&, std::pair<clang::IdentifierInfo*, clang::Sema::WeakInfo>*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoENS1_4Sema8WeakInfoENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::IdentifierInfo*, clang::Sema::WeakInfo, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::Sema::WeakInfo>>::grow(unsigned int)"},
    {"_ZNSt5dequeISt4pairIPN5clang9ValueDeclENS1_14SourceLocationEESaIS5_EE17_M_reallocate_mapEmb", "std::deque<std::pair<clang::ValueDecl*, clang::SourceLocation>, std::allocator<std::pair<clang::ValueDecl*, clang::SourceLocation>>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorENS1_14SourceLocationENS_12DenseMapInfoIS2_EENS4_IS3_EEE16InsertIntoBucketERKS2_RKS3_PSt4pairIS2_S3_E", "llvm::DenseMap<clang::Selector, clang::SourceLocation, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<clang::SourceLocation>>::InsertIntoBucket(clang::Selector const&, clang::SourceLocation const&, std::pair<clang::Selector, clang::SourceLocation>*)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorENS1_14SourceLocationENS_12DenseMapInfoIS2_EENS4_IS3_EEE4growEj", "llvm::DenseMap<clang::Selector, clang::SourceLocation, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<clang::SourceLocation>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIN5clang15DeclarationNameEPNS1_9NamedDeclENS_12DenseMapInfoIS2_EENS5_IS4_EEE16InsertIntoBucketERKS2_RKS4_PSt4pairIS2_S4_E", "llvm::DenseMap<clang::DeclarationName, clang::NamedDecl*, llvm::DenseMapInfo<clang::DeclarationName>, llvm::DenseMapInfo<clang::NamedDecl*>>::InsertIntoBucket(clang::DeclarationName const&, clang::NamedDecl* const&, std::pair<clang::DeclarationName, clang::NamedDecl*>*)"},
    {"_ZN4llvm8DenseMapIN5clang15DeclarationNameEPNS1_9NamedDeclENS_12DenseMapInfoIS2_EENS5_IS4_EEE4growEj", "llvm::DenseMap<clang::DeclarationName, clang::NamedDecl*, llvm::DenseMapInfo<clang::DeclarationName>, llvm::DenseMapInfo<clang::NamedDecl*>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIN5clang9ASTReader15DeclContextInfoEEaSERKS4_", "llvm::SmallVectorImpl<clang::ASTReader::DeclContextInfo>::operator=(llvm::SmallVectorImpl<clang::ASTReader::DeclContextInfo> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang9ASTReader15DeclContextInfoELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::ASTReader::DeclContextInfo, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIN5clang8QualTypeENS1_13serialization7TypeIdxENS3_26UnsafeQualTypeDenseMapInfoENS_12DenseMapInfoIS4_EEE16InsertIntoBucketERKS2_RKS4_PSt4pairIS2_S4_E", "llvm::DenseMap<clang::QualType, clang::serialization::TypeIdx, clang::serialization::UnsafeQualTypeDenseMapInfo, llvm::DenseMapInfo<clang::serialization::TypeIdx>>::InsertIntoBucket(clang::QualType const&, clang::serialization::TypeIdx const&, std::pair<clang::QualType, clang::serialization::TypeIdx>*)"},
    {"_ZN4llvm8DenseMapIN5clang8QualTypeENS1_13serialization7TypeIdxENS3_26UnsafeQualTypeDenseMapInfoENS_12DenseMapInfoIS4_EEE4growEj", "llvm::DenseMap<clang::QualType, clang::serialization::TypeIdx, clang::serialization::UnsafeQualTypeDenseMapInfo, llvm::DenseMapInfo<clang::serialization::TypeIdx>>::grow(unsigned int)"},
    {"_ZN5clang24ASTIdentifierLookupTrait8ReadDataERKSt4pairIPKcjEPKhj", "clang::ASTIdentifierLookupTrait::ReadData(std::pair<char const*, unsigned int> const&, unsigned char const*, unsigned int)"},
    {"_ZNSt6vectorIPN5clang4DeclESaIS2_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS2_S4_EEmRKS2_", "std::vector<clang::Decl*, std::allocator<clang::Decl*>>::_M_fill_insert(__gnu_cxx::__normal_iterator<clang::Decl**, std::vector<clang::Decl*, std::allocator<clang::Decl*>>>, unsigned long, clang::Decl* const&)"},
    {"_ZNSt6vectorIN5clang8QualTypeESaIS1_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS1_S3_EEmRKS1_", "std::vector<clang::QualType, std::allocator<clang::QualType>>::_M_fill_insert(__gnu_cxx::__normal_iterator<clang::QualType*, std::vector<clang::QualType, std::allocator<clang::QualType>>>, unsigned long, clang::QualType const&)"},
    {"_ZNSt6vectorIPN5clang14IdentifierInfoESaIS2_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS2_S4_EEmRKS2_", "std::vector<clang::IdentifierInfo*, std::allocator<clang::IdentifierInfo*>>::_M_fill_insert(__gnu_cxx::__normal_iterator<clang::IdentifierInfo**, std::vector<clang::IdentifierInfo*, std::allocator<clang::IdentifierInfo*>>>, unsigned long, clang::IdentifierInfo* const&)"},
    {"_ZN4llvm8DenseMapIjSt4pairIPN5clang9ASTReader11PerFileDataEyENS_12DenseMapInfoIjEENS7_IS6_EEE16InsertIntoBucketERKjRKS6_PS1_IjS6_E", "llvm::DenseMap<unsigned int, std::pair<clang::ASTReader::PerFileData*, unsigned long long>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<std::pair<clang::ASTReader::PerFileData*, unsigned long long>>>::InsertIntoBucket(unsigned int const&, std::pair<clang::ASTReader::PerFileData*, unsigned long long> const&, std::pair<unsigned int, std::pair<clang::ASTReader::PerFileData*, unsigned long long>>*)"},
    {"_ZN4llvm8DenseMapIjSt4pairIPN5clang9ASTReader11PerFileDataEyENS_12DenseMapInfoIjEENS7_IS6_EEE4growEj", "llvm::DenseMap<unsigned int, std::pair<clang::ASTReader::PerFileData*, unsigned long long>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<std::pair<clang::ASTReader::PerFileData*, unsigned long long>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorISt4pairIPN5clang9ASTReader11PerFileDataEyELj2EEENS_12DenseMapInfoIjEENS9_IS8_EEE16FindAndConstructERKj", "llvm::DenseMap<unsigned int, llvm::SmallVector<std::pair<clang::ASTReader::PerFileData*, unsigned long long>, 2u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<std::pair<clang::ASTReader::PerFileData*, unsigned long long>, 2u>>>::FindAndConstruct(unsigned int const&)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorISt4pairIPN5clang9ASTReader11PerFileDataEyELj2EEENS_12DenseMapInfoIjEENS9_IS8_EEE16InsertIntoBucketERKjRKS8_PS2_IjS8_E", "llvm::DenseMap<unsigned int, llvm::SmallVector<std::pair<clang::ASTReader::PerFileData*, unsigned long long>, 2u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<std::pair<clang::ASTReader::PerFileData*, unsigned long long>, 2u>>>::InsertIntoBucket(unsigned int const&, llvm::SmallVector<std::pair<clang::ASTReader::PerFileData*, unsigned long long>, 2u> const&, std::pair<unsigned int, llvm::SmallVector<std::pair<clang::ASTReader::PerFileData*, unsigned long long>, 2u>>*)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorISt4pairIPN5clang9ASTReader11PerFileDataEyELj2EEENS_12DenseMapInfoIjEENS9_IS8_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::SmallVector<std::pair<clang::ASTReader::PerFileData*, unsigned long long>, 2u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<std::pair<clang::ASTReader::PerFileData*, unsigned long long>, 2u>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplISt4pairIPN5clang9ASTReader11PerFileDataEyEEaSERKS7_", "llvm::SmallVectorImpl<std::pair<clang::ASTReader::PerFileData*, unsigned long long>>::operator=(llvm::SmallVectorImpl<std::pair<clang::ASTReader::PerFileData*, unsigned long long>> const&)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIPvLj1EEENS_12DenseMapInfoIjEENS4_IS3_EEE16FindAndConstructERKj", "llvm::DenseMap<unsigned int, llvm::SmallVector<void*, 1u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<void*, 1u>>>::FindAndConstruct(unsigned int const&)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIPvLj1EEENS_12DenseMapInfoIjEENS4_IS3_EEE16InsertIntoBucketERKjRKS3_PSt4pairIjS3_E", "llvm::DenseMap<unsigned int, llvm::SmallVector<void*, 1u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<void*, 1u>>>::InsertIntoBucket(unsigned int const&, llvm::SmallVector<void*, 1u> const&, std::pair<unsigned int, llvm::SmallVector<void*, 1u>>*)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIPvLj1EEENS_12DenseMapInfoIjEENS4_IS3_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::SmallVector<void*, 1u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<void*, 1u>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIPvEaSERKS2_", "llvm::SmallVectorImpl<void*>::operator=(llvm::SmallVectorImpl<void*> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang11DeclContextENS_11SmallVectorINS1_9ASTReader15DeclContextInfoELj1EEENS_12DenseMapInfoIS4_EENS9_IS8_EEE16FindAndConstructERKS4_", "llvm::DenseMap<clang::DeclContext const*, llvm::SmallVector<clang::ASTReader::DeclContextInfo, 1u>, llvm::DenseMapInfo<clang::DeclContext const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::ASTReader::DeclContextInfo, 1u>>>::FindAndConstruct(clang::DeclContext const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang11DeclContextENS_11SmallVectorINS1_9ASTReader15DeclContextInfoELj1EEENS_12DenseMapInfoIS4_EENS9_IS8_EEE16InsertIntoBucketERKS4_RKS8_PSt4pairIS4_S8_E", "llvm::DenseMap<clang::DeclContext const*, llvm::SmallVector<clang::ASTReader::DeclContextInfo, 1u>, llvm::DenseMapInfo<clang::DeclContext const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::ASTReader::DeclContextInfo, 1u>>>::InsertIntoBucket(clang::DeclContext const* const&, llvm::SmallVector<clang::ASTReader::DeclContextInfo, 1u> const&, std::pair<clang::DeclContext const*, llvm::SmallVector<clang::ASTReader::DeclContextInfo, 1u>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang11DeclContextENS_11SmallVectorINS1_9ASTReader15DeclContextInfoELj1EEENS_12DenseMapInfoIS4_EENS9_IS8_EEE4growEj", "llvm::DenseMap<clang::DeclContext const*, llvm::SmallVector<clang::ASTReader::DeclContextInfo, 1u>, llvm::DenseMapInfo<clang::DeclContext const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::ASTReader::DeclContextInfo, 1u>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEyNS_12DenseMapInfoIS3_EENS4_IyEEE16InsertIntoBucketERKS3_RKyPSt4pairIS3_yE", "llvm::DenseMap<clang::IdentifierInfo*, unsigned long long, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<unsigned long long>>::InsertIntoBucket(clang::IdentifierInfo* const&, unsigned long long const&, std::pair<clang::IdentifierInfo*, unsigned long long>*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEyNS_12DenseMapInfoIS3_EENS4_IyEEE4growEj", "llvm::DenseMap<clang::IdentifierInfo*, unsigned long long, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<unsigned long long>>::grow(unsigned int)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang18PCHPredefinesBlockELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::PCHPredefinesBlock, false>::grow(unsigned long)"},
    {"_ZNSt8_Rb_treeIiSt4pairIKiiESt10_Select1stIS2_ESt4lessIiESaIS2_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS2_ERKS2_", "std::_Rb_tree<int, std::pair<int const, int>, std::_Select1st<std::pair<int const, int>>, std::less<int>, std::allocator<std::pair<int const, int>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<int const, int>>, std::pair<int const, int> const&)"},
    {"_ZNSt8_Rb_treeIiSt4pairIKiiESt10_Select1stIS2_ESt4lessIiESaIS2_EE16_M_insert_uniqueERKS2_", "std::_Rb_tree<int, std::pair<int const, int>, std::_Select1st<std::pair<int const, int>>, std::less<int>, std::allocator<std::pair<int const, int>>>::_M_insert_unique(std::pair<int const, int> const&)"},
    {"_ZSt16__introsort_loopIPN4llvm9StringRefElEvT_S3_T0_", "void std::__introsort_loop<llvm::StringRef*, long>(llvm::StringRef*, llvm::StringRef*, long)"},
    {"_ZSt22__final_insertion_sortIPN4llvm9StringRefEEvT_S3_", "void std::__final_insertion_sort<llvm::StringRef*>(llvm::StringRef*, llvm::StringRef*)"},
    {"_ZSt16__insertion_sortIPN4llvm9StringRefEEvT_S3_", "void std::__insertion_sort<llvm::StringRef*>(llvm::StringRef*, llvm::StringRef*)"},
    {"_ZSt21__unguarded_partitionIPN4llvm9StringRefES1_ET_S3_S3_T0_", "llvm::StringRef* std::__unguarded_partition<llvm::StringRef*, llvm::StringRef>(llvm::StringRef*, llvm::StringRef*, llvm::StringRef)"},
    {"_ZSt8__medianIN4llvm9StringRefEERKT_S4_S4_S4_", "llvm::StringRef const& std::__median<llvm::StringRef>(llvm::StringRef const&, llvm::StringRef const&, llvm::StringRef const&)"},
    {"_ZSt13__heap_selectIPN4llvm9StringRefEEvT_S3_S3_", "void std::__heap_select<llvm::StringRef*>(llvm::StringRef*, llvm::StringRef*, llvm::StringRef*)"},
    {"_ZSt13__adjust_heapIPN4llvm9StringRefElS1_EvT_T0_S4_T1_", "void std::__adjust_heap<llvm::StringRef*, long, llvm::StringRef>(llvm::StringRef*, long, long, llvm::StringRef)"},
    {"_ZN4llvm15SmallVectorImplIN5clang18PCHPredefinesBlockEEaSERKS3_", "llvm::SmallVectorImpl<clang::PCHPredefinesBlock>::operator=(llvm::SmallVectorImpl<clang::PCHPredefinesBlock> const&)"},
    {"_ZN4llvm15SmallVectorImplINS_9StringRefEEaSERKS2_", "llvm::SmallVectorImpl<llvm::StringRef>::operator=(llvm::SmallVectorImpl<llvm::StringRef> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjPN5clang9LabelStmtEESt10_Select1stIS5_ESt4lessIjESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, clang::LabelStmt*>, std::_Select1st<std::pair<unsigned int const, clang::LabelStmt*>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, clang::LabelStmt*>>>::_M_erase(std::_Rb_tree_node<std::pair<unsigned int const, clang::LabelStmt*>>*)"},
    {"_ZN5clang18ExternalSemaSource14InitializeSemaERNS_4SemaE", "clang::ExternalSemaSource::InitializeSema(clang::Sema&)"},
    {"_ZN5clang18ExternalSemaSource10ForgetSemaEv", "clang::ExternalSemaSource::ForgetSema()"},
    {"_ZN4llvm15BitstreamReaderD2Ev", "llvm::BitstreamReader::~BitstreamReader()"},
    {"_ZN4llvm15BitstreamReader9BlockInfoD2Ev", "llvm::BitstreamReader::BlockInfo::~BlockInfo()"},
    {"_ZN4llvm15BitstreamReader20getOrCreateBlockInfoEj", "llvm::BitstreamReader::getOrCreateBlockInfo(unsigned int)"},
    {"_ZNSt6vectorISt4pairIjSsESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<std::pair<unsigned int, std::string>, std::allocator<std::pair<unsigned int, std::string>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<unsigned int, std::string>*, std::vector<std::pair<unsigned int, std::string>, std::allocator<std::pair<unsigned int, std::string>>>>, std::pair<unsigned int, std::string> const&)"},
    {"_ZN9__gnu_cxx13new_allocatorIN4llvm15BitstreamReader9BlockInfoEE9constructEPS3_RKS3_", "__gnu_cxx::new_allocator<llvm::BitstreamReader::BlockInfo>::construct(llvm::BitstreamReader::BlockInfo*, llvm::BitstreamReader::BlockInfo const&)"},
    {"_ZNSt6vectorIN4llvm15BitstreamReader9BlockInfoESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::BitstreamReader::BlockInfo, std::allocator<llvm::BitstreamReader::BlockInfo>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::BitstreamReader::BlockInfo*, std::vector<llvm::BitstreamReader::BlockInfo, std::allocator<llvm::BitstreamReader::BlockInfo>>>, llvm::BitstreamReader::BlockInfo const&)"},
    {"_ZSt24__uninitialized_copy_auxIPN4llvm15BitstreamReader9BlockInfoES3_ET0_T_S5_S4_St12__false_type", "llvm::BitstreamReader::BlockInfo* std::__uninitialized_copy_aux<llvm::BitstreamReader::BlockInfo*, llvm::BitstreamReader::BlockInfo*>(llvm::BitstreamReader::BlockInfo*, llvm::BitstreamReader::BlockInfo*, llvm::BitstreamReader::BlockInfo*, std::__false_type)"},
    {"_ZNSt6vectorIPN4llvm13BitCodeAbbrevESaIS2_EEaSERKS4_", "std::vector<llvm::BitCodeAbbrev*, std::allocator<llvm::BitCodeAbbrev*>>::operator=(std::vector<llvm::BitCodeAbbrev*, std::allocator<llvm::BitCodeAbbrev*>> const&)"},
    {"_ZNSt6vectorISt4pairIjSsESaIS1_EEaSERKS3_", "std::vector<std::pair<unsigned int, std::string>, std::allocator<std::pair<unsigned int, std::string>>>::operator=(std::vector<std::pair<unsigned int, std::string>, std::allocator<std::pair<unsigned int, std::string>>> const&)"},
    {"_ZNSt6vectorISt4pairIjSsESaIS1_EEC2ERKS3_", "std::vector<std::pair<unsigned int, std::string>, std::allocator<std::pair<unsigned int, std::string>>>::vector(std::vector<std::pair<unsigned int, std::string>, std::allocator<std::pair<unsigned int, std::string>>> const&)"},
    {"_ZNSt6vectorIPN4llvm13BitCodeAbbrevESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::BitCodeAbbrev*, std::allocator<llvm::BitCodeAbbrev*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::BitCodeAbbrev**, std::vector<llvm::BitCodeAbbrev*, std::allocator<llvm::BitCodeAbbrev*>>>, llvm::BitCodeAbbrev* const&)"},
    {"_ZN4llvm15BitstreamCursor9freeStateEv", "llvm::BitstreamCursor::freeState()"},
    {"_ZN5clang19FileSystemStatCacheD1Ev", "clang::FileSystemStatCache::~FileSystemStatCache()"},
    {"_ZN5clang19FileSystemStatCacheD0Ev", "clang::FileSystemStatCache::~FileSystemStatCache()"},
    {"_ZN4llvm15BitstreamCursorD2Ev", "llvm::BitstreamCursor::~BitstreamCursor()"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_15BitCodeAbbrevOpELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::BitCodeAbbrevOp, false>::grow(unsigned long)"},
    {"_ZN4llvm15BitstreamCursor13PopBlockScopeEv", "llvm::BitstreamCursor::PopBlockScope()"},
    {"_ZN4llvm15SmallVectorImplINS_15BitstreamCursor5BlockEE9push_backERKS2_", "llvm::SmallVectorImpl<llvm::BitstreamCursor::Block>::push_back(llvm::BitstreamCursor::Block const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_15BitstreamCursor5BlockELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::BitstreamCursor::Block, false>::grow(unsigned long)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_15BitstreamCursor5BlockELb0EE18uninitialized_copyIPS2_S5_EEvT_S6_T0_", "void llvm::SmallVectorTemplateBase<llvm::BitstreamCursor::Block, false>::uninitialized_copy<llvm::BitstreamCursor::Block*, llvm::BitstreamCursor::Block*>(llvm::BitstreamCursor::Block*, llvm::BitstreamCursor::Block*, llvm::BitstreamCursor::Block*)"},
    {"_ZNSt8_Rb_treeIiSt4pairIKiiESt10_Select1stIS2_ESt4lessIiESaIS2_EE8_M_eraseEPSt13_Rb_tree_nodeIS2_E", "std::_Rb_tree<int, std::pair<int const, int>, std::_Select1st<std::pair<int const, int>>, std::less<int>, std::allocator<std::pair<int const, int>>>::_M_erase(std::_Rb_tree_node<std::pair<int const, int>>*)"},
    {"_ZN4llvm15BitstreamCursor20ReadAbbreviatedFieldERKNS_15BitCodeAbbrevOpERNS_15SmallVectorImplIyEE", "llvm::BitstreamCursor::ReadAbbreviatedField(llvm::BitCodeAbbrevOp const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang13ASTDeclReader22GetCurrentCursorOffsetEv", "clang::ASTDeclReader::GetCurrentCursorOffset()"},
    {"_ZN5clang13ASTDeclReader5VisitEPNS_4DeclE", "clang::ASTDeclReader::Visit(clang::Decl*)"},
    {"_ZN5clang13ASTDeclReader9VisitDeclEPNS_4DeclE", "clang::ASTDeclReader::VisitDecl(clang::Decl*)"},
    {"_ZN5clang9ASTReader14ReadAttributesERNS0_11PerFileDataERN4llvm11SmallVectorIPNS_4AttrELj2EEERKNS4_IyLj64EEERj", "clang::ASTReader::ReadAttributes(clang::ASTReader::PerFileData&, llvm::SmallVector<clang::Attr*, 2u>&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang13ASTDeclReader24VisitTranslationUnitDeclEPNS_19TranslationUnitDeclE", "clang::ASTDeclReader::VisitTranslationUnitDecl(clang::TranslationUnitDecl*)"},
    {"_ZN5clang13ASTDeclReader14VisitNamedDeclEPNS_9NamedDeclE", "clang::ASTDeclReader::VisitNamedDecl(clang::NamedDecl*)"},
    {"_ZN5clang13ASTDeclReader13VisitTypeDeclEPNS_8TypeDeclE", "clang::ASTDeclReader::VisitTypeDecl(clang::TypeDecl*)"},
    {"_ZN5clang13ASTDeclReader16VisitTypedefDeclEPNS_11TypedefDeclE", "clang::ASTDeclReader::VisitTypedefDecl(clang::TypedefDecl*)"},
    {"_ZN5clang13ASTDeclReader12VisitTagDeclEPNS_7TagDeclE", "clang::ASTDeclReader::VisitTagDecl(clang::TagDecl*)"},
    {"_ZN5clang13ASTDeclReader13VisitEnumDeclEPNS_8EnumDeclE", "clang::ASTDeclReader::VisitEnumDecl(clang::EnumDecl*)"},
    {"_ZN5clang13ASTDeclReader15VisitRecordDeclEPNS_10RecordDeclE", "clang::ASTDeclReader::VisitRecordDecl(clang::RecordDecl*)"},
    {"_ZN5clang13ASTDeclReader14VisitValueDeclEPNS_9ValueDeclE", "clang::ASTDeclReader::VisitValueDecl(clang::ValueDecl*)"},
    {"_ZN5clang13ASTDeclReader21VisitEnumConstantDeclEPNS_16EnumConstantDeclE", "clang::ASTDeclReader::VisitEnumConstantDecl(clang::EnumConstantDecl*)"},
    {"_ZN5clang13ASTDeclReader19VisitDeclaratorDeclEPNS_14DeclaratorDeclE", "clang::ASTDeclReader::VisitDeclaratorDecl(clang::DeclaratorDecl*)"},
    {"_ZN5clang13ASTDeclReader17VisitFunctionDeclEPNS_12FunctionDeclE", "clang::ASTDeclReader::VisitFunctionDecl(clang::FunctionDecl*)"},
    {"_ZN5clang13ASTDeclReader19VisitObjCMethodDeclEPNS_14ObjCMethodDeclE", "clang::ASTDeclReader::VisitObjCMethodDecl(clang::ObjCMethodDecl*)"},
    {"_ZN5clang13ASTDeclReader22VisitObjCContainerDeclEPNS_17ObjCContainerDeclE", "clang::ASTDeclReader::VisitObjCContainerDecl(clang::ObjCContainerDecl*)"},
    {"_ZN5clang13ASTDeclReader22VisitObjCInterfaceDeclEPNS_17ObjCInterfaceDeclE", "clang::ASTDeclReader::VisitObjCInterfaceDecl(clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang13ASTDeclReader17VisitObjCIvarDeclEPNS_12ObjCIvarDeclE", "clang::ASTDeclReader::VisitObjCIvarDecl(clang::ObjCIvarDecl*)"},
    {"_ZN5clang13ASTDeclReader14VisitFieldDeclEPNS_9FieldDeclE", "clang::ASTDeclReader::VisitFieldDecl(clang::FieldDecl*)"},
    {"_ZN5clang13ASTDeclReader21VisitObjCProtocolDeclEPNS_16ObjCProtocolDeclE", "clang::ASTDeclReader::VisitObjCProtocolDecl(clang::ObjCProtocolDecl*)"},
    {"_ZN5clang13ASTDeclReader24VisitObjCAtDefsFieldDeclEPNS_19ObjCAtDefsFieldDeclE", "clang::ASTDeclReader::VisitObjCAtDefsFieldDecl(clang::ObjCAtDefsFieldDecl*)"},
    {"_ZN5clang13ASTDeclReader18VisitObjCClassDeclEPNS_13ObjCClassDeclE", "clang::ASTDeclReader::VisitObjCClassDecl(clang::ObjCClassDecl*)"},
    {"_ZN5clang13ASTDeclReader28VisitObjCForwardProtocolDeclEPNS_23ObjCForwardProtocolDeclE", "clang::ASTDeclReader::VisitObjCForwardProtocolDecl(clang::ObjCForwardProtocolDecl*)"},
    {"_ZN5clang13ASTDeclReader21VisitObjCCategoryDeclEPNS_16ObjCCategoryDeclE", "clang::ASTDeclReader::VisitObjCCategoryDecl(clang::ObjCCategoryDecl*)"},
    {"_ZN5clang13ASTDeclReader28VisitObjCCompatibleAliasDeclEPNS_23ObjCCompatibleAliasDeclE", "clang::ASTDeclReader::VisitObjCCompatibleAliasDecl(clang::ObjCCompatibleAliasDecl*)"},
    {"_ZN5clang13ASTDeclReader21VisitObjCPropertyDeclEPNS_16ObjCPropertyDeclE", "clang::ASTDeclReader::VisitObjCPropertyDecl(clang::ObjCPropertyDecl*)"},
    {"_ZN5clang13ASTDeclReader17VisitObjCImplDeclEPNS_12ObjCImplDeclE", "clang::ASTDeclReader::VisitObjCImplDecl(clang::ObjCImplDecl*)"},
    {"_ZN5clang13ASTDeclReader25VisitObjCCategoryImplDeclEPNS_20ObjCCategoryImplDeclE", "clang::ASTDeclReader::VisitObjCCategoryImplDecl(clang::ObjCCategoryImplDecl*)"},
    {"_ZN5clang13ASTDeclReader27VisitObjCImplementationDeclEPNS_22ObjCImplementationDeclE", "clang::ASTDeclReader::VisitObjCImplementationDecl(clang::ObjCImplementationDecl*)"},
    {"_ZN5clang13ASTDeclReader25VisitObjCPropertyImplDeclEPNS_20ObjCPropertyImplDeclE", "clang::ASTDeclReader::VisitObjCPropertyImplDecl(clang::ObjCPropertyImplDecl*)"},
    {"_ZN5clang13ASTDeclReader22VisitIndirectFieldDeclEPNS_17IndirectFieldDeclE", "clang::ASTDeclReader::VisitIndirectFieldDecl(clang::IndirectFieldDecl*)"},
    {"_ZN5clang13ASTDeclReader12VisitVarDeclEPNS_7VarDeclE", "clang::ASTDeclReader::VisitVarDecl(clang::VarDecl*)"},
    {"_ZN5clang13ASTDeclReader22VisitImplicitParamDeclEPNS_17ImplicitParamDeclE", "clang::ASTDeclReader::VisitImplicitParamDecl(clang::ImplicitParamDecl*)"},
    {"_ZN5clang13ASTDeclReader16VisitParmVarDeclEPNS_11ParmVarDeclE", "clang::ASTDeclReader::VisitParmVarDecl(clang::ParmVarDecl*)"},
    {"_ZN5clang13ASTDeclReader21VisitFileScopeAsmDeclEPNS_16FileScopeAsmDeclE", "clang::ASTDeclReader::VisitFileScopeAsmDecl(clang::FileScopeAsmDecl*)"},
    {"_ZN5clang13ASTDeclReader14VisitBlockDeclEPNS_9BlockDeclE", "clang::ASTDeclReader::VisitBlockDecl(clang::BlockDecl*)"},
    {"_ZN5clang13ASTDeclReader20VisitLinkageSpecDeclEPNS_15LinkageSpecDeclE", "clang::ASTDeclReader::VisitLinkageSpecDecl(clang::LinkageSpecDecl*)"},
    {"_ZN5clang13ASTDeclReader18VisitNamespaceDeclEPNS_13NamespaceDeclE", "clang::ASTDeclReader::VisitNamespaceDecl(clang::NamespaceDecl*)"},
    {"_ZN5clang13ASTDeclReader23VisitNamespaceAliasDeclEPNS_18NamespaceAliasDeclE", "clang::ASTDeclReader::VisitNamespaceAliasDecl(clang::NamespaceAliasDecl*)"},
    {"_ZN5clang13ASTDeclReader14VisitUsingDeclEPNS_9UsingDeclE", "clang::ASTDeclReader::VisitUsingDecl(clang::UsingDecl*)"},
    {"_ZN5clang13ASTDeclReader20VisitUsingShadowDeclEPNS_15UsingShadowDeclE", "clang::ASTDeclReader::VisitUsingShadowDecl(clang::UsingShadowDecl*)"},
    {"_ZN5clang13ASTDeclReader23VisitUsingDirectiveDeclEPNS_18UsingDirectiveDeclE", "clang::ASTDeclReader::VisitUsingDirectiveDecl(clang::UsingDirectiveDecl*)"},
    {"_ZN5clang13ASTDeclReader29VisitUnresolvedUsingValueDeclEPNS_24UnresolvedUsingValueDeclE", "clang::ASTDeclReader::VisitUnresolvedUsingValueDecl(clang::UnresolvedUsingValueDecl*)"},
    {"_ZN5clang13ASTDeclReader32VisitUnresolvedUsingTypenameDeclEPNS_27UnresolvedUsingTypenameDeclE", "clang::ASTDeclReader::VisitUnresolvedUsingTypenameDecl(clang::UnresolvedUsingTypenameDecl*)"},
    {"_ZN5clang13ASTDeclReader21ReadCXXDefinitionDataERNS_13CXXRecordDecl14DefinitionDataERKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTDeclReader::ReadCXXDefinitionData(clang::CXXRecordDecl::DefinitionData&, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang13ASTDeclReader27InitializeCXXDefinitionDataEPNS_13CXXRecordDeclES2_RKN4llvm11SmallVectorIyLj64EEERj", "clang::ASTDeclReader::InitializeCXXDefinitionData(clang::CXXRecordDecl*, clang::CXXRecordDecl*, llvm::SmallVector<unsigned long long, 64u> const&, unsigned int&)"},
    {"_ZN5clang13ASTDeclReader18VisitCXXRecordDeclEPNS_13CXXRecordDeclE", "clang::ASTDeclReader::VisitCXXRecordDecl(clang::CXXRecordDecl*)"},
    {"_ZN5clang13ASTDeclReader18VisitCXXMethodDeclEPNS_13CXXMethodDeclE", "clang::ASTDeclReader::VisitCXXMethodDecl(clang::CXXMethodDecl*)"},
    {"_ZN5clang13ASTDeclReader23VisitCXXConstructorDeclEPNS_18CXXConstructorDeclE", "clang::ASTDeclReader::VisitCXXConstructorDecl(clang::CXXConstructorDecl*)"},
    {"_ZN5clang13ASTDeclReader22VisitCXXDestructorDeclEPNS_17CXXDestructorDeclE", "clang::ASTDeclReader::VisitCXXDestructorDecl(clang::CXXDestructorDecl*)"},
    {"_ZN5clang13ASTDeclReader22VisitCXXConversionDeclEPNS_17CXXConversionDeclE", "clang::ASTDeclReader::VisitCXXConversionDecl(clang::CXXConversionDecl*)"},
    {"_ZN5clang13ASTDeclReader19VisitAccessSpecDeclEPNS_14AccessSpecDeclE", "clang::ASTDeclReader::VisitAccessSpecDecl(clang::AccessSpecDecl*)"},
    {"_ZN5clang13ASTDeclReader15VisitFriendDeclEPNS_10FriendDeclE", "clang::ASTDeclReader::VisitFriendDecl(clang::FriendDecl*)"},
    {"_ZN5clang13ASTDeclReader23VisitFriendTemplateDeclEPNS_18FriendTemplateDeclE", "clang::ASTDeclReader::VisitFriendTemplateDecl(clang::FriendTemplateDecl*)"},
    {"_ZN5clang13ASTDeclReader17VisitTemplateDeclEPNS_12TemplateDeclE", "clang::ASTDeclReader::VisitTemplateDecl(clang::TemplateDecl*)"},
    {"_ZN5clang13ASTDeclReader29VisitRedeclarableTemplateDeclEPNS_24RedeclarableTemplateDeclE", "clang::ASTDeclReader::VisitRedeclarableTemplateDecl(clang::RedeclarableTemplateDecl*)"},
    {"_ZN5clang13ASTDeclReader22VisitClassTemplateDeclEPNS_17ClassTemplateDeclE", "clang::ASTDeclReader::VisitClassTemplateDecl(clang::ClassTemplateDecl*)"},
    {"_ZN5clang13ASTDeclReader36VisitClassTemplateSpecializationDeclEPNS_31ClassTemplateSpecializationDeclE", "clang::ASTDeclReader::VisitClassTemplateSpecializationDecl(clang::ClassTemplateSpecializationDecl*)"},
    {"_ZN5clang13ASTDeclReader43VisitClassTemplatePartialSpecializationDeclEPNS_38ClassTemplatePartialSpecializationDeclE", "clang::ASTDeclReader::VisitClassTemplatePartialSpecializationDecl(clang::ClassTemplatePartialSpecializationDecl*)"},
    {"_ZN5clang13ASTDeclReader25VisitFunctionTemplateDeclEPNS_20FunctionTemplateDeclE", "clang::ASTDeclReader::VisitFunctionTemplateDecl(clang::FunctionTemplateDecl*)"},
    {"_ZN5clang13ASTDeclReader25VisitTemplateTypeParmDeclEPNS_20TemplateTypeParmDeclE", "clang::ASTDeclReader::VisitTemplateTypeParmDecl(clang::TemplateTypeParmDecl*)"},
    {"_ZN5clang13ASTDeclReader28VisitNonTypeTemplateParmDeclEPNS_23NonTypeTemplateParmDeclE", "clang::ASTDeclReader::VisitNonTypeTemplateParmDecl(clang::NonTypeTemplateParmDecl*)"},
    {"_ZN5clang13ASTDeclReader29VisitTemplateTemplateParmDeclEPNS_24TemplateTemplateParmDeclE", "clang::ASTDeclReader::VisitTemplateTemplateParmDecl(clang::TemplateTemplateParmDecl*)"},
    {"_ZN5clang13ASTDeclReader21VisitStaticAssertDeclEPNS_16StaticAssertDeclE", "clang::ASTDeclReader::VisitStaticAssertDecl(clang::StaticAssertDecl*)"},
    {"_ZN5clang13ASTDeclReader16VisitDeclContextEPNS_11DeclContextE", "clang::ASTDeclReader::VisitDeclContext(clang::DeclContext*)"},
    {"_ZN5clang9ASTReader18DeclCursorForIndexEjj", "clang::ASTReader::DeclCursorForIndex(unsigned int, unsigned int)"},
    {"_ZN5clang9ASTReader14ReadDeclRecordEjj", "clang::ASTReader::ReadDeclRecord(unsigned int, unsigned int)"},
    {"_ZN5clang13ASTDeclReader10UpdateDeclEPNS_4DeclERKN4llvm11SmallVectorIyLj64EEE", "clang::ASTDeclReader::UpdateDecl(clang::Decl*, llvm::SmallVector<unsigned long long, 64u> const&)"},
    {"_ZN5clang11DeclVisitorINS_13ASTDeclReaderEvE5VisitEPNS_4DeclE", "clang::DeclVisitor<clang::ASTDeclReader, void>::Visit(clang::Decl*)"},
    {"_ZN5clang13ASTDeclReader17VisitRedeclarableINS_7TagDeclEEEvPNS_12RedeclarableIT_EE", "void clang::ASTDeclReader::VisitRedeclarable<clang::TagDecl>(clang::Redeclarable<clang::TagDecl>*)"},
    {"_ZN5clang13ASTDeclReader17VisitRedeclarableINS_12FunctionDeclEEEvPNS_12RedeclarableIT_EE", "void clang::ASTDeclReader::VisitRedeclarable<clang::FunctionDecl>(clang::Redeclarable<clang::FunctionDecl>*)"},
    {"_ZN5clang13ASTDeclReader17VisitRedeclarableINS_7VarDeclEEEvPNS_12RedeclarableIT_EE", "void clang::ASTDeclReader::VisitRedeclarable<clang::VarDecl>(clang::Redeclarable<clang::VarDecl>*)"},
    {"_ZN5clang14AccessSpecDecl6CreateERNS_10ASTContextENS_4Decl10EmptyShellE", "clang::AccessSpecDecl::Create(clang::ASTContext&, clang::Decl::EmptyShell)"},
    {"_ZN4llvm15SmallVectorImplIN5clang9ASTReader15DeclContextInfoEE6insertEPS3_RKS3_", "llvm::SmallVectorImpl<clang::ASTReader::DeclContextInfo>::insert(clang::ASTReader::DeclContextInfo*, clang::ASTReader::DeclContextInfo const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS_11SmallVectorIPS2_Lj4EEENS_12DenseMapInfoIS4_EENS8_IS7_EEE16FindAndConstructERKS4_", "llvm::DenseMap<clang::CXXRecordDecl const*, llvm::SmallVector<clang::CXXRecordDecl*, 4u>, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::CXXRecordDecl*, 4u>>>::FindAndConstruct(clang::CXXRecordDecl const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS_11SmallVectorIPS2_Lj4EEENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::CXXRecordDecl const*, llvm::SmallVector<clang::CXXRecordDecl*, 4u>, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::CXXRecordDecl*, 4u>>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, llvm::SmallVector<clang::CXXRecordDecl*, 4u> const&, std::pair<clang::CXXRecordDecl const*, llvm::SmallVector<clang::CXXRecordDecl*, 4u>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS_11SmallVectorIPS2_Lj4EEENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, llvm::SmallVector<clang::CXXRecordDecl*, 4u>, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::CXXRecordDecl*, 4u>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang13CXXRecordDeclEEaSERKS4_", "llvm::SmallVectorImpl<clang::CXXRecordDecl*>::operator=(llvm::SmallVectorImpl<clang::CXXRecordDecl*> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang9BlockDecl7CaptureELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::BlockDecl::Capture, false>::grow(unsigned long)"},
    {"_ZN5clang13ASTStmtReader32ReadExplicitTemplateArgumentListERNS_28ExplicitTemplateArgumentListEj", "clang::ASTStmtReader::ReadExplicitTemplateArgumentList(clang::ExplicitTemplateArgumentList&, unsigned int)"},
    {"_ZN5clang13ASTStmtReader9VisitStmtEPNS_4StmtE", "clang::ASTStmtReader::VisitStmt(clang::Stmt*)"},
    {"_ZN5clang13ASTStmtReader13VisitNullStmtEPNS_8NullStmtE", "clang::ASTStmtReader::VisitNullStmt(clang::NullStmt*)"},
    {"_ZN5clang13ASTStmtReader17VisitCompoundStmtEPNS_12CompoundStmtE", "clang::ASTStmtReader::VisitCompoundStmt(clang::CompoundStmt*)"},
    {"_ZN5clang13ASTStmtReader15VisitSwitchCaseEPNS_10SwitchCaseE", "clang::ASTStmtReader::VisitSwitchCase(clang::SwitchCase*)"},
    {"_ZN5clang13ASTStmtReader13VisitCaseStmtEPNS_8CaseStmtE", "clang::ASTStmtReader::VisitCaseStmt(clang::CaseStmt*)"},
    {"_ZN5clang9ASTReader11ReadSubExprEv", "clang::ASTReader::ReadSubExpr()"},
    {"_ZN5clang13ASTStmtReader16VisitDefaultStmtEPNS_11DefaultStmtE", "clang::ASTStmtReader::VisitDefaultStmt(clang::DefaultStmt*)"},
    {"_ZN5clang13ASTStmtReader14VisitLabelStmtEPNS_9LabelStmtE", "clang::ASTStmtReader::VisitLabelStmt(clang::LabelStmt*)"},
    {"_ZN5clang13ASTStmtReader11VisitIfStmtEPNS_6IfStmtE", "clang::ASTStmtReader::VisitIfStmt(clang::IfStmt*)"},
    {"_ZN5clang13ASTStmtReader15VisitSwitchStmtEPNS_10SwitchStmtE", "clang::ASTStmtReader::VisitSwitchStmt(clang::SwitchStmt*)"},
    {"_ZN5clang13ASTStmtReader14VisitWhileStmtEPNS_9WhileStmtE", "clang::ASTStmtReader::VisitWhileStmt(clang::WhileStmt*)"},
    {"_ZN5clang13ASTStmtReader11VisitDoStmtEPNS_6DoStmtE", "clang::ASTStmtReader::VisitDoStmt(clang::DoStmt*)"},
    {"_ZN5clang13ASTStmtReader12VisitForStmtEPNS_7ForStmtE", "clang::ASTStmtReader::VisitForStmt(clang::ForStmt*)"},
    {"_ZN5clang13ASTStmtReader13VisitGotoStmtEPNS_8GotoStmtE", "clang::ASTStmtReader::VisitGotoStmt(clang::GotoStmt*)"},
    {"_ZN5clang13ASTStmtReader21VisitIndirectGotoStmtEPNS_16IndirectGotoStmtE", "clang::ASTStmtReader::VisitIndirectGotoStmt(clang::IndirectGotoStmt*)"},
    {"_ZN5clang13ASTStmtReader17VisitContinueStmtEPNS_12ContinueStmtE", "clang::ASTStmtReader::VisitContinueStmt(clang::ContinueStmt*)"},
    {"_ZN5clang13ASTStmtReader14VisitBreakStmtEPNS_9BreakStmtE", "clang::ASTStmtReader::VisitBreakStmt(clang::BreakStmt*)"},
    {"_ZN5clang13ASTStmtReader15VisitReturnStmtEPNS_10ReturnStmtE", "clang::ASTStmtReader::VisitReturnStmt(clang::ReturnStmt*)"},
    {"_ZN5clang13ASTStmtReader13VisitDeclStmtEPNS_8DeclStmtE", "clang::ASTStmtReader::VisitDeclStmt(clang::DeclStmt*)"},
    {"_ZN5clang13ASTStmtReader12VisitAsmStmtEPNS_7AsmStmtE", "clang::ASTStmtReader::VisitAsmStmt(clang::AsmStmt*)"},
    {"_ZN5clang13ASTStmtReader9VisitExprEPNS_4ExprE", "clang::ASTStmtReader::VisitExpr(clang::Expr*)"},
    {"_ZN5clang13ASTStmtReader19VisitPredefinedExprEPNS_14PredefinedExprE", "clang::ASTStmtReader::VisitPredefinedExpr(clang::PredefinedExpr*)"},
    {"_ZN5clang13ASTStmtReader16VisitDeclRefExprEPNS_11DeclRefExprE", "clang::ASTStmtReader::VisitDeclRefExpr(clang::DeclRefExpr*)"},
    {"_ZN5clang13ASTStmtReader19VisitIntegerLiteralEPNS_14IntegerLiteralE", "clang::ASTStmtReader::VisitIntegerLiteral(clang::IntegerLiteral*)"},
    {"_ZN5clang13ASTStmtReader20VisitFloatingLiteralEPNS_15FloatingLiteralE", "clang::ASTStmtReader::VisitFloatingLiteral(clang::FloatingLiteral*)"},
    {"_ZN5clang13ASTStmtReader21VisitImaginaryLiteralEPNS_16ImaginaryLiteralE", "clang::ASTStmtReader::VisitImaginaryLiteral(clang::ImaginaryLiteral*)"},
    {"_ZN5clang13ASTStmtReader18VisitStringLiteralEPNS_13StringLiteralE", "clang::ASTStmtReader::VisitStringLiteral(clang::StringLiteral*)"},
    {"_ZN5clang13ASTStmtReader21VisitCharacterLiteralEPNS_16CharacterLiteralE", "clang::ASTStmtReader::VisitCharacterLiteral(clang::CharacterLiteral*)"},
    {"_ZN5clang13ASTStmtReader14VisitParenExprEPNS_9ParenExprE", "clang::ASTStmtReader::VisitParenExpr(clang::ParenExpr*)"},
    {"_ZN5clang13ASTStmtReader18VisitParenListExprEPNS_13ParenListExprE", "clang::ASTStmtReader::VisitParenListExpr(clang::ParenListExpr*)"},
    {"_ZN5clang13ASTStmtReader18VisitUnaryOperatorEPNS_13UnaryOperatorE", "clang::ASTStmtReader::VisitUnaryOperator(clang::UnaryOperator*)"},
    {"_ZN5clang13ASTStmtReader17VisitOffsetOfExprEPNS_12OffsetOfExprE", "clang::ASTStmtReader::VisitOffsetOfExpr(clang::OffsetOfExpr*)"},
    {"_ZN5clang13ASTStmtReader22VisitSizeOfAlignOfExprEPNS_17SizeOfAlignOfExprE", "clang::ASTStmtReader::VisitSizeOfAlignOfExpr(clang::SizeOfAlignOfExpr*)"},
    {"_ZN5clang13ASTStmtReader23VisitArraySubscriptExprEPNS_18ArraySubscriptExprE", "clang::ASTStmtReader::VisitArraySubscriptExpr(clang::ArraySubscriptExpr*)"},
    {"_ZN5clang13ASTStmtReader13VisitCallExprEPNS_8CallExprE", "clang::ASTStmtReader::VisitCallExpr(clang::CallExpr*)"},
    {"_ZN5clang13ASTStmtReader15VisitMemberExprEPNS_10MemberExprE", "clang::ASTStmtReader::VisitMemberExpr(clang::MemberExpr*)"},
    {"_ZN5clang13ASTStmtReader16VisitObjCIsaExprEPNS_11ObjCIsaExprE", "clang::ASTStmtReader::VisitObjCIsaExpr(clang::ObjCIsaExpr*)"},
    {"_ZN5clang13ASTStmtReader13VisitCastExprEPNS_8CastExprE", "clang::ASTStmtReader::VisitCastExpr(clang::CastExpr*)"},
    {"_ZN5clang13ASTStmtReader19VisitBinaryOperatorEPNS_14BinaryOperatorE", "clang::ASTStmtReader::VisitBinaryOperator(clang::BinaryOperator*)"},
    {"_ZN5clang13ASTStmtReader27VisitCompoundAssignOperatorEPNS_22CompoundAssignOperatorE", "clang::ASTStmtReader::VisitCompoundAssignOperator(clang::CompoundAssignOperator*)"},
    {"_ZN5clang13ASTStmtReader24VisitConditionalOperatorEPNS_19ConditionalOperatorE", "clang::ASTStmtReader::VisitConditionalOperator(clang::ConditionalOperator*)"},
    {"_ZN5clang13ASTStmtReader21VisitImplicitCastExprEPNS_16ImplicitCastExprE", "clang::ASTStmtReader::VisitImplicitCastExpr(clang::ImplicitCastExpr*)"},
    {"_ZN5clang13ASTStmtReader21VisitExplicitCastExprEPNS_16ExplicitCastExprE", "clang::ASTStmtReader::VisitExplicitCastExpr(clang::ExplicitCastExpr*)"},
    {"_ZN5clang13ASTStmtReader19VisitCStyleCastExprEPNS_14CStyleCastExprE", "clang::ASTStmtReader::VisitCStyleCastExpr(clang::CStyleCastExpr*)"},
    {"_ZN5clang13ASTStmtReader24VisitCompoundLiteralExprEPNS_19CompoundLiteralExprE", "clang::ASTStmtReader::VisitCompoundLiteralExpr(clang::CompoundLiteralExpr*)"},
    {"_ZN5clang13ASTStmtReader25VisitExtVectorElementExprEPNS_20ExtVectorElementExprE", "clang::ASTStmtReader::VisitExtVectorElementExpr(clang::ExtVectorElementExpr*)"},
    {"_ZN5clang13ASTStmtReader17VisitInitListExprEPNS_12InitListExprE", "clang::ASTStmtReader::VisitInitListExpr(clang::InitListExpr*)"},
    {"_ZN5clang13ASTStmtReader23VisitDesignatedInitExprEPNS_18DesignatedInitExprE", "clang::ASTStmtReader::VisitDesignatedInitExpr(clang::DesignatedInitExpr*)"},
    {"_ZN5clang13ASTStmtReader26VisitImplicitValueInitExprEPNS_21ImplicitValueInitExprE", "clang::ASTStmtReader::VisitImplicitValueInitExpr(clang::ImplicitValueInitExpr*)"},
    {"_ZN5clang13ASTStmtReader14VisitVAArgExprEPNS_9VAArgExprE", "clang::ASTStmtReader::VisitVAArgExpr(clang::VAArgExpr*)"},
    {"_ZN5clang13ASTStmtReader18VisitAddrLabelExprEPNS_13AddrLabelExprE", "clang::ASTStmtReader::VisitAddrLabelExpr(clang::AddrLabelExpr*)"},
    {"_ZN5clang13ASTStmtReader13VisitStmtExprEPNS_8StmtExprE", "clang::ASTStmtReader::VisitStmtExpr(clang::StmtExpr*)"},
    {"_ZN5clang13ASTStmtReader15VisitChooseExprEPNS_10ChooseExprE", "clang::ASTStmtReader::VisitChooseExpr(clang::ChooseExpr*)"},
    {"_ZN5clang13ASTStmtReader16VisitGNUNullExprEPNS_11GNUNullExprE", "clang::ASTStmtReader::VisitGNUNullExpr(clang::GNUNullExpr*)"},
    {"_ZN5clang13ASTStmtReader22VisitShuffleVectorExprEPNS_17ShuffleVectorExprE", "clang::ASTStmtReader::VisitShuffleVectorExpr(clang::ShuffleVectorExpr*)"},
    {"_ZN5clang13ASTStmtReader14VisitBlockExprEPNS_9BlockExprE", "clang::ASTStmtReader::VisitBlockExpr(clang::BlockExpr*)"},
    {"_ZN5clang13ASTStmtReader21VisitBlockDeclRefExprEPNS_16BlockDeclRefExprE", "clang::ASTStmtReader::VisitBlockDeclRefExpr(clang::BlockDeclRefExpr*)"},
    {"_ZN5clang13ASTStmtReader22VisitObjCStringLiteralEPNS_17ObjCStringLiteralE", "clang::ASTStmtReader::VisitObjCStringLiteral(clang::ObjCStringLiteral*)"},
    {"_ZN5clang13ASTStmtReader19VisitObjCEncodeExprEPNS_14ObjCEncodeExprE", "clang::ASTStmtReader::VisitObjCEncodeExpr(clang::ObjCEncodeExpr*)"},
    {"_ZN5clang13ASTStmtReader21VisitObjCSelectorExprEPNS_16ObjCSelectorExprE", "clang::ASTStmtReader::VisitObjCSelectorExpr(clang::ObjCSelectorExpr*)"},
    {"_ZN5clang13ASTStmtReader21VisitObjCProtocolExprEPNS_16ObjCProtocolExprE", "clang::ASTStmtReader::VisitObjCProtocolExpr(clang::ObjCProtocolExpr*)"},
    {"_ZN5clang13ASTStmtReader20VisitObjCIvarRefExprEPNS_15ObjCIvarRefExprE", "clang::ASTStmtReader::VisitObjCIvarRefExpr(clang::ObjCIvarRefExpr*)"},
    {"_ZN5clang13ASTStmtReader24VisitObjCPropertyRefExprEPNS_19ObjCPropertyRefExprE", "clang::ASTStmtReader::VisitObjCPropertyRefExpr(clang::ObjCPropertyRefExpr*)"},
    {"_ZN5clang13ASTStmtReader20VisitObjCMessageExprEPNS_15ObjCMessageExprE", "clang::ASTStmtReader::VisitObjCMessageExpr(clang::ObjCMessageExpr*)"},
    {"_ZN5clang13ASTStmtReader26VisitObjCForCollectionStmtEPNS_21ObjCForCollectionStmtE", "clang::ASTStmtReader::VisitObjCForCollectionStmt(clang::ObjCForCollectionStmt*)"},
    {"_ZN5clang13ASTStmtReader20VisitObjCAtCatchStmtEPNS_15ObjCAtCatchStmtE", "clang::ASTStmtReader::VisitObjCAtCatchStmt(clang::ObjCAtCatchStmt*)"},
    {"_ZN5clang13ASTStmtReader22VisitObjCAtFinallyStmtEPNS_17ObjCAtFinallyStmtE", "clang::ASTStmtReader::VisitObjCAtFinallyStmt(clang::ObjCAtFinallyStmt*)"},
    {"_ZN5clang13ASTStmtReader18VisitObjCAtTryStmtEPNS_13ObjCAtTryStmtE", "clang::ASTStmtReader::VisitObjCAtTryStmt(clang::ObjCAtTryStmt*)"},
    {"_ZN5clang13ASTStmtReader27VisitObjCAtSynchronizedStmtEPNS_22ObjCAtSynchronizedStmtE", "clang::ASTStmtReader::VisitObjCAtSynchronizedStmt(clang::ObjCAtSynchronizedStmt*)"},
    {"_ZN5clang13ASTStmtReader20VisitObjCAtThrowStmtEPNS_15ObjCAtThrowStmtE", "clang::ASTStmtReader::VisitObjCAtThrowStmt(clang::ObjCAtThrowStmt*)"},
    {"_ZN5clang13ASTStmtReader17VisitCXXCatchStmtEPNS_12CXXCatchStmtE", "clang::ASTStmtReader::VisitCXXCatchStmt(clang::CXXCatchStmt*)"},
    {"_ZN5clang13ASTStmtReader15VisitCXXTryStmtEPNS_10CXXTryStmtE", "clang::ASTStmtReader::VisitCXXTryStmt(clang::CXXTryStmt*)"},
    {"_ZN5clang13ASTStmtReader24VisitCXXOperatorCallExprEPNS_19CXXOperatorCallExprE", "clang::ASTStmtReader::VisitCXXOperatorCallExpr(clang::CXXOperatorCallExpr*)"},
    {"_ZN5clang13ASTStmtReader21VisitCXXConstructExprEPNS_16CXXConstructExprE", "clang::ASTStmtReader::VisitCXXConstructExpr(clang::CXXConstructExpr*)"},
    {"_ZN5clang13ASTStmtReader27VisitCXXTemporaryObjectExprEPNS_22CXXTemporaryObjectExprE", "clang::ASTStmtReader::VisitCXXTemporaryObjectExpr(clang::CXXTemporaryObjectExpr*)"},
    {"_ZN5clang13ASTStmtReader21VisitCXXNamedCastExprEPNS_16CXXNamedCastExprE", "clang::ASTStmtReader::VisitCXXNamedCastExpr(clang::CXXNamedCastExpr*)"},
    {"_ZN5clang13ASTStmtReader22VisitCXXStaticCastExprEPNS_17CXXStaticCastExprE", "clang::ASTStmtReader::VisitCXXStaticCastExpr(clang::CXXStaticCastExpr*)"},
    {"_ZN5clang13ASTStmtReader23VisitCXXDynamicCastExprEPNS_18CXXDynamicCastExprE", "clang::ASTStmtReader::VisitCXXDynamicCastExpr(clang::CXXDynamicCastExpr*)"},
    {"_ZN5clang13ASTStmtReader27VisitCXXReinterpretCastExprEPNS_22CXXReinterpretCastExprE", "clang::ASTStmtReader::VisitCXXReinterpretCastExpr(clang::CXXReinterpretCastExpr*)"},
    {"_ZN5clang13ASTStmtReader21VisitCXXConstCastExprEPNS_16CXXConstCastExprE", "clang::ASTStmtReader::VisitCXXConstCastExpr(clang::CXXConstCastExpr*)"},
    {"_ZN5clang13ASTStmtReader26VisitCXXFunctionalCastExprEPNS_21CXXFunctionalCastExprE", "clang::ASTStmtReader::VisitCXXFunctionalCastExpr(clang::CXXFunctionalCastExpr*)"},
    {"_ZN5clang13ASTStmtReader23VisitCXXBoolLiteralExprEPNS_18CXXBoolLiteralExprE", "clang::ASTStmtReader::VisitCXXBoolLiteralExpr(clang::CXXBoolLiteralExpr*)"},
    {"_ZN5clang13ASTStmtReader26VisitCXXNullPtrLiteralExprEPNS_21CXXNullPtrLiteralExprE", "clang::ASTStmtReader::VisitCXXNullPtrLiteralExpr(clang::CXXNullPtrLiteralExpr*)"},
    {"_ZN5clang13ASTStmtReader18VisitCXXTypeidExprEPNS_13CXXTypeidExprE", "clang::ASTStmtReader::VisitCXXTypeidExpr(clang::CXXTypeidExpr*)"},
    {"_ZN5clang13ASTStmtReader18VisitCXXUuidofExprEPNS_13CXXUuidofExprE", "clang::ASTStmtReader::VisitCXXUuidofExpr(clang::CXXUuidofExpr*)"},
    {"_ZN5clang13ASTStmtReader16VisitCXXThisExprEPNS_11CXXThisExprE", "clang::ASTStmtReader::VisitCXXThisExpr(clang::CXXThisExpr*)"},
    {"_ZN5clang13ASTStmtReader17VisitCXXThrowExprEPNS_12CXXThrowExprE", "clang::ASTStmtReader::VisitCXXThrowExpr(clang::CXXThrowExpr*)"},
    {"_ZN5clang13ASTStmtReader22VisitCXXDefaultArgExprEPNS_17CXXDefaultArgExprE", "clang::ASTStmtReader::VisitCXXDefaultArgExpr(clang::CXXDefaultArgExpr*)"},
    {"_ZN5clang13ASTStmtReader25VisitCXXBindTemporaryExprEPNS_20CXXBindTemporaryExprE", "clang::ASTStmtReader::VisitCXXBindTemporaryExpr(clang::CXXBindTemporaryExpr*)"},
    {"_ZN5clang13ASTStmtReader27VisitCXXScalarValueInitExprEPNS_22CXXScalarValueInitExprE", "clang::ASTStmtReader::VisitCXXScalarValueInitExpr(clang::CXXScalarValueInitExpr*)"},
    {"_ZN5clang13ASTStmtReader15VisitCXXNewExprEPNS_10CXXNewExprE", "clang::ASTStmtReader::VisitCXXNewExpr(clang::CXXNewExpr*)"},
    {"_ZN5clang13ASTStmtReader18VisitCXXDeleteExprEPNS_13CXXDeleteExprE", "clang::ASTStmtReader::VisitCXXDeleteExpr(clang::CXXDeleteExpr*)"},
    {"_ZN5clang13ASTStmtReader28VisitCXXPseudoDestructorExprEPNS_23CXXPseudoDestructorExprE", "clang::ASTStmtReader::VisitCXXPseudoDestructorExpr(clang::CXXPseudoDestructorExpr*)"},
    {"_ZN5clang13ASTStmtReader21VisitExprWithCleanupsEPNS_16ExprWithCleanupsE", "clang::ASTStmtReader::VisitExprWithCleanups(clang::ExprWithCleanups*)"},
    {"_ZN5clang13ASTStmtReader32VisitCXXDependentScopeMemberExprEPNS_27CXXDependentScopeMemberExprE", "clang::ASTStmtReader::VisitCXXDependentScopeMemberExpr(clang::CXXDependentScopeMemberExpr*)"},
    {"_ZN5clang13ASTStmtReader30VisitDependentScopeDeclRefExprEPNS_25DependentScopeDeclRefExprE", "clang::ASTStmtReader::VisitDependentScopeDeclRefExpr(clang::DependentScopeDeclRefExpr*)"},
    {"_ZN5clang13ASTStmtReader31VisitCXXUnresolvedConstructExprEPNS_26CXXUnresolvedConstructExprE", "clang::ASTStmtReader::VisitCXXUnresolvedConstructExpr(clang::CXXUnresolvedConstructExpr*)"},
    {"_ZN5clang13ASTStmtReader17VisitOverloadExprEPNS_12OverloadExprE", "clang::ASTStmtReader::VisitOverloadExpr(clang::OverloadExpr*)"},
    {"_ZN5clang13ASTStmtReader25VisitUnresolvedMemberExprEPNS_20UnresolvedMemberExprE", "clang::ASTStmtReader::VisitUnresolvedMemberExpr(clang::UnresolvedMemberExpr*)"},
    {"_ZN5clang13ASTStmtReader25VisitUnresolvedLookupExprEPNS_20UnresolvedLookupExprE", "clang::ASTStmtReader::VisitUnresolvedLookupExpr(clang::UnresolvedLookupExpr*)"},
    {"_ZN5clang13ASTStmtReader23VisitUnaryTypeTraitExprEPNS_18UnaryTypeTraitExprE", "clang::ASTStmtReader::VisitUnaryTypeTraitExpr(clang::UnaryTypeTraitExpr*)"},
    {"_ZN5clang13ASTStmtReader24VisitBinaryTypeTraitExprEPNS_19BinaryTypeTraitExprE", "clang::ASTStmtReader::VisitBinaryTypeTraitExpr(clang::BinaryTypeTraitExpr*)"},
    {"_ZN5clang13ASTStmtReader20VisitCXXNoexceptExprEPNS_15CXXNoexceptExprE", "clang::ASTStmtReader::VisitCXXNoexceptExpr(clang::CXXNoexceptExpr*)"},
    {"_ZN5clang13ASTStmtReader22VisitPackExpansionExprEPNS_17PackExpansionExprE", "clang::ASTStmtReader::VisitPackExpansionExpr(clang::PackExpansionExpr*)"},
    {"_ZN5clang13ASTStmtReader19VisitSizeOfPackExprEPNS_14SizeOfPackExprE", "clang::ASTStmtReader::VisitSizeOfPackExpr(clang::SizeOfPackExpr*)"},
    {"_ZN5clang13ASTStmtReader37VisitSubstNonTypeTemplateParmPackExprEPNS_32SubstNonTypeTemplateParmPackExprE", "clang::ASTStmtReader::VisitSubstNonTypeTemplateParmPackExpr(clang::SubstNonTypeTemplateParmPackExpr*)"},
    {"_ZN5clang13ASTStmtReader20VisitOpaqueValueExprEPNS_15OpaqueValueExprE", "clang::ASTStmtReader::VisitOpaqueValueExpr(clang::OpaqueValueExpr*)"},
    {"_ZN5clang13ASTStmtReader23VisitCUDAKernelCallExprEPNS_18CUDAKernelCallExprE", "clang::ASTStmtReader::VisitCUDAKernelCallExpr(clang::CUDAKernelCallExpr*)"},
    {"_ZN5clang9ASTReader8ReadStmtERNS0_11PerFileDataE", "clang::ASTReader::ReadStmt(clang::ASTReader::PerFileData&)"},
    {"_ZN5clang9ASTReader18ReadStmtFromStreamERNS0_11PerFileDataE", "clang::ASTReader::ReadStmtFromStream(clang::ASTReader::PerFileData&)"},
    {"_ZN5clang9ASTReader8ReadExprERNS0_11PerFileDataE", "clang::ASTReader::ReadExpr(clang::ASTReader::PerFileData&)"},
    {"_ZN5clang11StmtVisitorINS_13ASTStmtReaderEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<clang::ASTStmtReader, void>::Visit(clang::Stmt*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang18DesignatedInitExpr10DesignatorELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::DesignatedInitExpr::Designator, false>::grow(unsigned long)"},
    {"_ZN5clang9ASTWriter19WriteBlockInfoBlockEv", "clang::ASTWriter::WriteBlockInfoBlock()"},
    {"_Z11EmitBlockIDjPKcRN4llvm15BitstreamWriterERNS1_15SmallVectorImplIyEE", "EmitBlockID(unsigned int, char const*, llvm::BitstreamWriter&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_Z12EmitRecordIDjPKcRN4llvm15BitstreamWriterERNS1_15SmallVectorImplIyEE", "EmitRecordID(unsigned int, char const*, llvm::BitstreamWriter&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter13WriteMetadataERNS_10ASTContextEPKc", "clang::ASTWriter::WriteMetadata(clang::ASTContext&, char const*)"},
    {"_ZN5clang9ASTWriter20WriteLanguageOptionsERKNS_11LangOptionsE", "clang::ASTWriter::WriteLanguageOptions(clang::LangOptions const&)"},
    {"_ZN5clang9ASTWriter14WriteStatCacheERNS_17MemorizeStatCallsE", "clang::ASTWriter::WriteStatCache(clang::MemorizeStatCalls&)"},
    {"_ZN5clang9ASTWriter23WriteSourceManagerBlockERNS_13SourceManagerERKNS_12PreprocessorEPKc", "clang::ASTWriter::WriteSourceManagerBlock(clang::SourceManager&, clang::Preprocessor const&, char const*)"},
    {"_ZN5clang9ASTWriter16AddIdentifierRefEPKNS_14IdentifierInfoERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddIdentifierRef(clang::IdentifierInfo const*, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter17WritePreprocessorERKNS_12PreprocessorE", "clang::ASTWriter::WritePreprocessor(clang::Preprocessor const&)"},
    {"_ZN5clang9ASTWriter20getMacroDefinitionIDEPNS_15MacroDefinitionE", "clang::ASTWriter::getMacroDefinitionID(clang::MacroDefinition*)"},
    {"_ZN5clang9ASTWriter23WritePreprocessorDetailERNS_19PreprocessingRecordE", "clang::ASTWriter::WritePreprocessorDetail(clang::PreprocessingRecord&)"},
    {"_ZN5clang9ASTWriter17AddSourceLocationENS_14SourceLocationERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddSourceLocation(clang::SourceLocation, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter29WritePragmaDiagnosticMappingsERKNS_10DiagnosticE", "clang::ASTWriter::WritePragmaDiagnosticMappings(clang::Diagnostic const&)"},
    {"_ZN5clang9ASTWriter9WriteTypeENS_8QualTypeE", "clang::ASTWriter::WriteType(clang::QualType)"},
    {"_ZN5clang9ASTWriter10AddTypeRefENS_8QualTypeERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddTypeRef(clang::QualType, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN12_GLOBAL__N_113ASTTypeWriter15VisitVectorTypeEPKN5clang10VectorTypeE", "(anonymous namespace)::ASTTypeWriter::VisitVectorType(clang::VectorType const*)"},
    {"_ZN5clang9ASTWriter28WriteDeclContextLexicalBlockERNS_10ASTContextEPNS_11DeclContextE", "clang::ASTWriter::WriteDeclContextLexicalBlock(clang::ASTContext&, clang::DeclContext*)"},
    {"_ZN5clang9ASTWriter10GetDeclRefEPKNS_4DeclE", "clang::ASTWriter::GetDeclRef(clang::Decl const*)"},
    {"_ZN5clang9ASTWriter20WriteTypeDeclOffsetsEv", "clang::ASTWriter::WriteTypeDeclOffsets()"},
    {"_ZN5clang9ASTWriter14WriteSelectorsERNS_4SemaE", "clang::ASTWriter::WriteSelectors(clang::Sema&)"},
    {"_ZN5clang9ASTWriter28WriteReferencedSelectorsPoolERNS_4SemaE", "clang::ASTWriter::WriteReferencedSelectorsPool(clang::Sema&)"},
    {"_ZN5clang9ASTWriter14AddSelectorRefENS_8SelectorERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddSelectorRef(clang::Selector, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter20WriteIdentifierTableERNS_12PreprocessorE", "clang::ASTWriter::WriteIdentifierTable(clang::Preprocessor&)"},
    {"_ZN5clang9ASTWriter16getIdentifierRefEPKNS_14IdentifierInfoE", "clang::ASTWriter::getIdentifierRef(clang::IdentifierInfo const*)"},
    {"_ZN5clang9ASTWriter28WriteDeclContextVisibleBlockERNS_10ASTContextEPNS_11DeclContextE", "clang::ASTWriter::WriteDeclContextVisibleBlock(clang::ASTContext&, clang::DeclContext*)"},
    {"_ZN5clang31OnDiskChainedHashTableGeneratorIN12_GLOBAL__N_129ASTDeclContextNameLookupTraitEE6insertENS_15DeclarationNameERKNS_23DeclContextLookupResultERS2_", "clang::OnDiskChainedHashTableGenerator<(anonymous namespace)::ASTDeclContextNameLookupTrait>::insert(clang::DeclarationName, clang::DeclContextLookupResult const&, (anonymous namespace)::ASTDeclContextNameLookupTrait&)"},
    {"_ZN5clang31OnDiskChainedHashTableGeneratorIN12_GLOBAL__N_129ASTDeclContextNameLookupTraitEE4EmitERN4llvm11raw_ostreamERS2_", "clang::OnDiskChainedHashTableGenerator<(anonymous namespace)::ASTDeclContextNameLookupTrait>::Emit(llvm::raw_ostream&, (anonymous namespace)::ASTDeclContextNameLookupTrait&)"},
    {"_ZN5clang9ASTWriter29WriteDeclContextVisibleUpdateEPKNS_11DeclContextE", "clang::ASTWriter::WriteDeclContextVisibleUpdate(clang::DeclContext const*)"},
    {"_ZN5clang9ASTWriter9getDeclIDEPKNS_4DeclE", "clang::ASTWriter::getDeclID(clang::Decl const*)"},
    {"_ZN5clang9ASTWriter15WriteAttributesERKN4llvm11SmallVectorIPNS_4AttrELj2EEERNS1_15SmallVectorImplIyEE", "clang::ASTWriter::WriteAttributes(llvm::SmallVector<clang::Attr*, 2u> const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter9AddStringEN4llvm9StringRefERNS1_15SmallVectorImplIyEE", "clang::ASTWriter::AddString(llvm::StringRef, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter17AddTypeSourceInfoEPNS_14TypeSourceInfoERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddTypeSourceInfo(clang::TypeSourceInfo*, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter10AddDeclRefEPKNS_4DeclERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddDeclRef(clang::Decl const*, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter19SetIdentifierOffsetEPKNS_14IdentifierInfoEj", "clang::ASTWriter::SetIdentifierOffset(clang::IdentifierInfo const*, unsigned int)"},
    {"_ZN5clang9ASTWriter17SetSelectorOffsetENS_8SelectorEj", "clang::ASTWriter::SetSelectorOffset(clang::Selector, unsigned int)"},
    {"_ZN5clang9ASTWriterC1ERN4llvm15BitstreamWriterE", "clang::ASTWriter::ASTWriter(llvm::BitstreamWriter&)"},
    {"_ZN5clang9ASTWriterC2ERN4llvm15BitstreamWriterE", "clang::ASTWriter::ASTWriter(llvm::BitstreamWriter&)"},
    {"_ZN5clang9ASTWriter8WriteASTERNS_4SemaEPNS_17MemorizeStatCallsEPKc", "clang::ASTWriter::WriteAST(clang::Sema&, clang::MemorizeStatCalls*, char const*)"},
    {"_ZN5clang9ASTWriter13WriteASTChainERNS_4SemaEPNS_17MemorizeStatCallsEPKc", "clang::ASTWriter::WriteASTChain(clang::Sema&, clang::MemorizeStatCalls*, char const*)"},
    {"_ZN5clang9ASTWriter12WriteASTCoreERNS_4SemaEPNS_17MemorizeStatCallsEPKc", "clang::ASTWriter::WriteASTCore(clang::Sema&, clang::MemorizeStatCalls*, char const*)"},
    {"_ZN5clang9ASTWriter22WriteDeclUpdatesBlocksEv", "clang::ASTWriter::WriteDeclUpdatesBlocks()"},
    {"_ZN5clang9ASTWriter26WriteDeclReplacementsBlockEv", "clang::ASTWriter::WriteDeclReplacementsBlock()"},
    {"_ZN5clang9ASTWriter14AddSourceRangeENS_11SourceRangeERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddSourceRange(clang::SourceRange, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter8AddAPIntERKN4llvm5APIntERNS1_15SmallVectorImplIyEE", "clang::ASTWriter::AddAPInt(llvm::APInt const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter9AddAPSIntERKN4llvm6APSIntERNS1_15SmallVectorImplIyEE", "clang::ASTWriter::AddAPSInt(llvm::APSInt const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter10AddAPFloatERKN4llvm7APFloatERNS1_15SmallVectorImplIyEE", "clang::ASTWriter::AddAPFloat(llvm::APFloat const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter14getSelectorRefENS_8SelectorE", "clang::ASTWriter::getSelectorRef(clang::Selector)"},
    {"_ZN5clang9ASTWriter15AddCXXTemporaryEPKNS_12CXXTemporaryERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddCXXTemporary(clang::CXXTemporary const*, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter23AddCXXBaseSpecifiersRefEPKNS_16CXXBaseSpecifierES3_RN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddCXXBaseSpecifiersRef(clang::CXXBaseSpecifier const*, clang::CXXBaseSpecifier const*, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter26AddTemplateArgumentLocInfoENS_16TemplateArgument7ArgKindERKNS_23TemplateArgumentLocInfoERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddTemplateArgumentLocInfo(clang::TemplateArgument::ArgKind, clang::TemplateArgumentLocInfo const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter22AddTemplateArgumentLocERKNS_19TemplateArgumentLocERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddTemplateArgumentLoc(clang::TemplateArgumentLoc const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter19AddTemplateArgumentERKNS_16TemplateArgumentERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddTemplateArgument(clang::TemplateArgument const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter17GetOrCreateTypeIDENS_8QualTypeE", "clang::ASTWriter::GetOrCreateTypeID(clang::QualType)"},
    {"_ZN5clang9ASTWriter18GetOrCreateTypeIdxENS_8QualTypeE", "clang::ASTWriter::GetOrCreateTypeIdx(clang::QualType)"},
    {"_ZNK5clang9ASTWriter9getTypeIDENS_8QualTypeE", "clang::ASTWriter::getTypeID(clang::QualType) const"},
    {"_ZNK5clang9ASTWriter10getTypeIdxENS_8QualTypeE", "clang::ASTWriter::getTypeIdx(clang::QualType) const"},
    {"_ZN5clang9ASTWriter18AddDeclarationNameENS_15DeclarationNameERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddDeclarationName(clang::DeclarationName, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter21AddDeclarationNameLocERKNS_18DeclarationNameLocENS_15DeclarationNameERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddDeclarationNameLoc(clang::DeclarationNameLoc const&, clang::DeclarationName, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter22AddDeclarationNameInfoERKNS_19DeclarationNameInfoERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddDeclarationNameInfo(clang::DeclarationNameInfo const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter16AddQualifierInfoERKNS_13QualifierInfoERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddQualifierInfo(clang::QualifierInfo const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter22AddNestedNameSpecifierEPNS_19NestedNameSpecifierERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddNestedNameSpecifier(clang::NestedNameSpecifier*, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter24AddTemplateParameterListEPKNS_21TemplateParameterListERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddTemplateParameterList(clang::TemplateParameterList const*, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter15AddTemplateNameENS_12TemplateNameERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddTemplateName(clang::TemplateName, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter23AddTemplateArgumentListEPKNS_20TemplateArgumentListERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddTemplateArgumentList(clang::TemplateArgumentList const*, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter16AddUnresolvedSetERKNS_17UnresolvedSetImplERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddUnresolvedSet(clang::UnresolvedSetImpl const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter19AddCXXBaseSpecifierERKNS_16CXXBaseSpecifierERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddCXXBaseSpecifier(clang::CXXBaseSpecifier const&, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter22FlushCXXBaseSpecifiersEv", "clang::ASTWriter::FlushCXXBaseSpecifiers()"},
    {"_ZN5clang9ASTWriter22AddCXXCtorInitializersEPKPKNS_18CXXCtorInitializerEjRN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddCXXCtorInitializers(clang::CXXCtorInitializer const* const*, unsigned int, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter20AddCXXDefinitionDataEPKNS_13CXXRecordDeclERN4llvm15SmallVectorImplIyEE", "clang::ASTWriter::AddCXXDefinitionData(clang::CXXRecordDecl const*, llvm::SmallVectorImpl<unsigned long long>&)"},
    {"_ZN5clang9ASTWriter17ReaderInitializedEPNS_9ASTReaderE", "clang::ASTWriter::ReaderInitialized(clang::ASTReader*)"},
    {"_ZN5clang9ASTWriter14IdentifierReadEjPNS_14IdentifierInfoE", "clang::ASTWriter::IdentifierRead(unsigned int, clang::IdentifierInfo*)"},
    {"_ZN5clang9ASTWriter8TypeReadENS_13serialization7TypeIdxENS_8QualTypeE", "clang::ASTWriter::TypeRead(clang::serialization::TypeIdx, clang::QualType)"},
    {"_ZN5clang9ASTWriter8DeclReadEjPKNS_4DeclE", "clang::ASTWriter::DeclRead(unsigned int, clang::Decl const*)"},
    {"_ZN5clang9ASTWriter12SelectorReadEjNS_8SelectorE", "clang::ASTWriter::SelectorRead(unsigned int, clang::Selector)"},
    {"_ZN5clang9ASTWriter19MacroDefinitionReadEjPNS_15MacroDefinitionE", "clang::ASTWriter::MacroDefinitionRead(unsigned int, clang::MacroDefinition*)"},
    {"_ZThn8_N5clang9ASTWriter22CompletedTagDefinitionEPKNS_7TagDeclE", "non-virtual thunk to clang::ASTWriter::CompletedTagDefinition(clang::TagDecl const*)"},
    {"_ZN5clang9ASTWriter22CompletedTagDefinitionEPKNS_7TagDeclE", "clang::ASTWriter::CompletedTagDefinition(clang::TagDecl const*)"},
    {"_ZThn8_N5clang9ASTWriter16AddedVisibleDeclEPKNS_11DeclContextEPKNS_4DeclE", "non-virtual thunk to clang::ASTWriter::AddedVisibleDecl(clang::DeclContext const*, clang::Decl const*)"},
    {"_ZN5clang9ASTWriter16AddedVisibleDeclEPKNS_11DeclContextEPKNS_4DeclE", "clang::ASTWriter::AddedVisibleDecl(clang::DeclContext const*, clang::Decl const*)"},
    {"_ZThn8_N5clang9ASTWriter22AddedCXXImplicitMemberEPKNS_13CXXRecordDeclEPKNS_4DeclE", "non-virtual thunk to clang::ASTWriter::AddedCXXImplicitMember(clang::CXXRecordDecl const*, clang::Decl const*)"},
    {"_ZN5clang9ASTWriter22AddedCXXImplicitMemberEPKNS_13CXXRecordDeclEPKNS_4DeclE", "clang::ASTWriter::AddedCXXImplicitMember(clang::CXXRecordDecl const*, clang::Decl const*)"},
    {"_ZThn8_N5clang9ASTWriter30AddedCXXTemplateSpecializationEPKNS_17ClassTemplateDeclEPKNS_31ClassTemplateSpecializationDeclE", "non-virtual thunk to clang::ASTWriter::AddedCXXTemplateSpecialization(clang::ClassTemplateDecl const*, clang::ClassTemplateSpecializationDecl const*)"},
    {"_ZN5clang9ASTWriter30AddedCXXTemplateSpecializationEPKNS_17ClassTemplateDeclEPKNS_31ClassTemplateSpecializationDeclE", "clang::ASTWriter::AddedCXXTemplateSpecialization(clang::ClassTemplateDecl const*, clang::ClassTemplateSpecializationDecl const*)"},
    {"_ZN5clang24ASTSerializationListenerD0Ev", "clang::ASTSerializationListener::~ASTSerializationListener()"},
    {"_ZN5clang24ASTSerializationListenerD1Ev", "clang::ASTSerializationListener::~ASTSerializationListener()"},
    {"_ZN5clang24ASTSerializationListenerD2Ev", "clang::ASTSerializationListener::~ASTSerializationListener()"},
    {"_ZN12_GLOBAL__N_113TypeLocWriter20VisitFunctionTypeLocEN5clang15FunctionTypeLocE", "(anonymous namespace)::TypeLocWriter::VisitFunctionTypeLoc(clang::FunctionTypeLoc)"},
    {"_ZN12_GLOBAL__N_113TypeLocWriter17VisitArrayTypeLocEN5clang12ArrayTypeLocE", "(anonymous namespace)::TypeLocWriter::VisitArrayTypeLoc(clang::ArrayTypeLoc)"},
    {"_ZN12_GLOBAL__N_113ASTTypeWriter12VisitTagTypeEPKN5clang7TagTypeE", "(anonymous namespace)::ASTTypeWriter::VisitTagType(clang::TagType const*)"},
    {"_ZN12_GLOBAL__N_113ASTTypeWriter17VisitFunctionTypeEPKN5clang12FunctionTypeE", "(anonymous namespace)::ASTTypeWriter::VisitFunctionType(clang::FunctionType const*)"},
    {"_ZN12_GLOBAL__N_113ASTTypeWriter14VisitArrayTypeEPKN5clang9ArrayTypeE", "(anonymous namespace)::ASTTypeWriter::VisitArrayType(clang::ArrayType const*)"},
    {"_ZN4llvm15BitstreamWriter13EnterSubblockEjj", "llvm::BitstreamWriter::EnterSubblock(unsigned int, unsigned int)"},
    {"_ZN4llvm15BitstreamWriter9ExitBlockEv", "llvm::BitstreamWriter::ExitBlock()"},
    {"_ZN4llvm15BitstreamWriter10EmitRecordIyEEvjRNS_15SmallVectorImplIT_EEj", "void llvm::BitstreamWriter::EmitRecord<unsigned long long>(unsigned int, llvm::SmallVectorImpl<unsigned long long>&, unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIyE6insertIPKcEEPyS5_T_S6_", "unsigned long long* llvm::SmallVectorImpl<unsigned long long>::insert<char const*>(unsigned long long*, char const*, char const*)"},
    {"_ZN4llvm15BitstreamWriter4EmitEjj", "llvm::BitstreamWriter::Emit(unsigned int, unsigned int)"},
    {"_ZN5clang13serialization10MakeTypeIDISt9binder1stISt10mem_fun1_tINS0_7TypeIdxENS_9ASTWriterENS_8QualTypeEEEEEjS6_T_", "unsigned int clang::serialization::MakeTypeID<std::binder1st<std::mem_fun1_t<clang::serialization::TypeIdx, clang::ASTWriter, clang::QualType>>>(clang::QualType, std::binder1st<std::mem_fun1_t<clang::serialization::TypeIdx, clang::ASTWriter, clang::QualType>>)"},
    {"_ZN5clang13serialization10MakeTypeIDISt9binder1stISt16const_mem_fun1_tINS0_7TypeIdxENS_9ASTWriterENS_8QualTypeEEEEEjS6_T_", "unsigned int clang::serialization::MakeTypeID<std::binder1st<std::const_mem_fun1_t<clang::serialization::TypeIdx, clang::ASTWriter, clang::QualType>>>(clang::QualType, std::binder1st<std::const_mem_fun1_t<clang::serialization::TypeIdx, clang::ASTWriter, clang::QualType>>)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclENS_11SmallVectorIyLj2EEENS_12DenseMapInfoIS4_EENS7_IS6_EEE16FindAndConstructERKS4_", "llvm::DenseMap<clang::Decl const*, llvm::SmallVector<unsigned long long, 2u>, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::SmallVector<unsigned long long, 2u>>>::FindAndConstruct(clang::Decl const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclENS_11SmallVectorIyLj2EEENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::Decl const*, llvm::SmallVector<unsigned long long, 2u>, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::SmallVector<unsigned long long, 2u>>>::InsertIntoBucket(clang::Decl const* const&, llvm::SmallVector<unsigned long long, 2u> const&, std::pair<clang::Decl const*, llvm::SmallVector<unsigned long long, 2u>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclENS_11SmallVectorIyLj2EEENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::Decl const*, llvm::SmallVector<unsigned long long, 2u>, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::SmallVector<unsigned long long, 2u>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIyEaSERKS1_", "llvm::SmallVectorImpl<unsigned long long>::operator=(llvm::SmallVectorImpl<unsigned long long> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang9ASTWriter23QueuedCXXBaseSpecifiersELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::ASTWriter::QueuedCXXBaseSpecifiers, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIPKN5clang15MacroDefinitionEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::MacroDefinition const*, unsigned int, llvm::DenseMapInfo<clang::MacroDefinition const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::MacroDefinition const* const&, unsigned int const&, std::pair<clang::MacroDefinition const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang15MacroDefinitionEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::MacroDefinition const*, unsigned int, llvm::DenseMapInfo<clang::MacroDefinition const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZNSt5dequeIN5clang9ASTWriter10DeclOrTypeESaIS2_EE9push_backERKS2_", "std::deque<clang::ASTWriter::DeclOrType, std::allocator<clang::ASTWriter::DeclOrType>>::push_back(clang::ASTWriter::DeclOrType const&)"},
    {"_ZNSt5dequeIN5clang9ASTWriter10DeclOrTypeESaIS2_EE17_M_reallocate_mapEmb", "std::deque<clang::ASTWriter::DeclOrType, std::allocator<clang::ASTWriter::DeclOrType>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZNSt11_Deque_baseIN5clang9ASTWriter10DeclOrTypeESaIS2_EE17_M_initialize_mapEm", "std::_Deque_base<clang::ASTWriter::DeclOrType, std::allocator<clang::ASTWriter::DeclOrType>>::_M_initialize_map(unsigned long)"},
    {"_ZNSt5dequeIN5clang9ASTWriter10DeclOrTypeESaIS2_EEC2ERKS4_", "std::deque<clang::ASTWriter::DeclOrType, std::allocator<clang::ASTWriter::DeclOrType>>::deque(std::deque<clang::ASTWriter::DeclOrType, std::allocator<clang::ASTWriter::DeclOrType>> const&)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEjNS_12DenseMapInfoIS2_EENS3_IjEEE16InsertIntoBucketERKS2_RKjPSt4pairIS2_jE", "llvm::DenseMap<clang::Selector, unsigned int, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::Selector const&, unsigned int const&, std::pair<clang::Selector, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEjNS_12DenseMapInfoIS2_EENS3_IjEEE4growEj", "llvm::DenseMap<clang::Selector, unsigned int, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang4DeclEE6appendINS1_18IdentifierResolver8iteratorEEEvT_S8_", "void llvm::SmallVectorImpl<clang::Decl*>::append<clang::IdentifierResolver::iterator>(clang::IdentifierResolver::iterator, clang::IdentifierResolver::iterator)"},
    {"_ZN4llvm15BitstreamWriter24EmitRecordWithAbbrevImplIyEEvjRNS_15SmallVectorImplIT_EENS_9StringRefE", "void llvm::BitstreamWriter::EmitRecordWithAbbrevImpl<unsigned long long>(unsigned int, llvm::SmallVectorImpl<unsigned long long>&, llvm::StringRef)"},
    {"_ZN4llvm15BitstreamWriter20EmitAbbreviatedFieldIhEEvRKNS_15BitCodeAbbrevOpET_", "void llvm::BitstreamWriter::EmitAbbreviatedField<unsigned char>(llvm::BitCodeAbbrevOp const&, unsigned char)"},
    {"_ZN4llvm15BitstreamWriter20EmitAbbreviatedFieldIyEEvRKNS_15BitCodeAbbrevOpET_", "void llvm::BitstreamWriter::EmitAbbreviatedField<unsigned long long>(llvm::BitCodeAbbrevOp const&, unsigned long long)"},
    {"_ZN4llvm15BitstreamWriter11FlushToWordEv", "llvm::BitstreamWriter::FlushToWord()"},
    {"_ZNSt6vectorIhSaIhEE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPhS1_EERKh", "std::vector<unsigned char, std::allocator<unsigned char>>::_M_insert_aux(__gnu_cxx::__normal_iterator<unsigned char*, std::vector<unsigned char, std::allocator<unsigned char>>>, unsigned char const&)"},
    {"_ZN4llvm15BitstreamWriter9EmitVBR64Eyj", "llvm::BitstreamWriter::EmitVBR64(unsigned long long, unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIyE6insertEPyRKy", "llvm::SmallVectorImpl<unsigned long long>::insert(unsigned long long*, unsigned long long const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang14IdentifierInfoEyNS_12DenseMapInfoIS4_EENS5_IyEEE16InsertIntoBucketERKS4_RKyPSt4pairIS4_yE", "llvm::DenseMap<clang::IdentifierInfo const*, unsigned long long, llvm::DenseMapInfo<clang::IdentifierInfo const*>, llvm::DenseMapInfo<unsigned long long>>::InsertIntoBucket(clang::IdentifierInfo const* const&, unsigned long long const&, std::pair<clang::IdentifierInfo const*, unsigned long long>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang14IdentifierInfoEyNS_12DenseMapInfoIS4_EENS5_IyEEE4growEj", "llvm::DenseMap<clang::IdentifierInfo const*, unsigned long long, llvm::DenseMapInfo<clang::IdentifierInfo const*>, llvm::DenseMapInfo<unsigned long long>>::grow(unsigned int)"},
    {"_ZN4llvm15BitstreamWriter12EncodeAbbrevEPNS_13BitCodeAbbrevE", "llvm::BitstreamWriter::EncodeAbbrev(llvm::BitCodeAbbrev*)"},
    {"_ZNSt6vectorIN4llvm15BitstreamWriter5BlockESaIS2_EE9push_backERKS2_", "std::vector<llvm::BitstreamWriter::Block, std::allocator<llvm::BitstreamWriter::Block>>::push_back(llvm::BitstreamWriter::Block const&)"},
    {"_ZNSt6vectorIN4llvm15BitstreamWriter5BlockESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::BitstreamWriter::Block, std::allocator<llvm::BitstreamWriter::Block>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::BitstreamWriter::Block*, std::vector<llvm::BitstreamWriter::Block, std::allocator<llvm::BitstreamWriter::Block>>>, llvm::BitstreamWriter::Block const&)"},
    {"_ZN5clang13ASTDeclWriter5VisitEPNS_4DeclE", "clang::ASTDeclWriter::Visit(clang::Decl*)"},
    {"_ZN5clang13ASTDeclWriter9VisitDeclEPNS_4DeclE", "clang::ASTDeclWriter::VisitDecl(clang::Decl*)"},
    {"_ZN5clang13ASTDeclWriter24VisitTranslationUnitDeclEPNS_19TranslationUnitDeclE", "clang::ASTDeclWriter::VisitTranslationUnitDecl(clang::TranslationUnitDecl*)"},
    {"_ZN5clang13ASTDeclWriter14VisitNamedDeclEPNS_9NamedDeclE", "clang::ASTDeclWriter::VisitNamedDecl(clang::NamedDecl*)"},
    {"_ZN5clang13ASTDeclWriter13VisitTypeDeclEPNS_8TypeDeclE", "clang::ASTDeclWriter::VisitTypeDecl(clang::TypeDecl*)"},
    {"_ZN5clang13ASTDeclWriter16VisitTypedefDeclEPNS_11TypedefDeclE", "clang::ASTDeclWriter::VisitTypedefDecl(clang::TypedefDecl*)"},
    {"_ZN5clang13ASTDeclWriter12VisitTagDeclEPNS_7TagDeclE", "clang::ASTDeclWriter::VisitTagDecl(clang::TagDecl*)"},
    {"_ZN5clang13ASTDeclWriter13VisitEnumDeclEPNS_8EnumDeclE", "clang::ASTDeclWriter::VisitEnumDecl(clang::EnumDecl*)"},
    {"_ZN5clang13ASTDeclWriter15VisitRecordDeclEPNS_10RecordDeclE", "clang::ASTDeclWriter::VisitRecordDecl(clang::RecordDecl*)"},
    {"_ZN5clang13ASTDeclWriter14VisitValueDeclEPNS_9ValueDeclE", "clang::ASTDeclWriter::VisitValueDecl(clang::ValueDecl*)"},
    {"_ZN5clang13ASTDeclWriter21VisitEnumConstantDeclEPNS_16EnumConstantDeclE", "clang::ASTDeclWriter::VisitEnumConstantDecl(clang::EnumConstantDecl*)"},
    {"_ZN5clang13ASTDeclWriter19VisitDeclaratorDeclEPNS_14DeclaratorDeclE", "clang::ASTDeclWriter::VisitDeclaratorDecl(clang::DeclaratorDecl*)"},
    {"_ZN5clang13ASTDeclWriter17VisitFunctionDeclEPNS_12FunctionDeclE", "clang::ASTDeclWriter::VisitFunctionDecl(clang::FunctionDecl*)"},
    {"_ZN5clang13ASTDeclWriter19VisitObjCMethodDeclEPNS_14ObjCMethodDeclE", "clang::ASTDeclWriter::VisitObjCMethodDecl(clang::ObjCMethodDecl*)"},
    {"_ZN5clang13ASTDeclWriter22VisitObjCContainerDeclEPNS_17ObjCContainerDeclE", "clang::ASTDeclWriter::VisitObjCContainerDecl(clang::ObjCContainerDecl*)"},
    {"_ZN5clang13ASTDeclWriter22VisitObjCInterfaceDeclEPNS_17ObjCInterfaceDeclE", "clang::ASTDeclWriter::VisitObjCInterfaceDecl(clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang13ASTDeclWriter17VisitObjCIvarDeclEPNS_12ObjCIvarDeclE", "clang::ASTDeclWriter::VisitObjCIvarDecl(clang::ObjCIvarDecl*)"},
    {"_ZN5clang13ASTDeclWriter14VisitFieldDeclEPNS_9FieldDeclE", "clang::ASTDeclWriter::VisitFieldDecl(clang::FieldDecl*)"},
    {"_ZN5clang13ASTDeclWriter21VisitObjCProtocolDeclEPNS_16ObjCProtocolDeclE", "clang::ASTDeclWriter::VisitObjCProtocolDecl(clang::ObjCProtocolDecl*)"},
    {"_ZN5clang13ASTDeclWriter24VisitObjCAtDefsFieldDeclEPNS_19ObjCAtDefsFieldDeclE", "clang::ASTDeclWriter::VisitObjCAtDefsFieldDecl(clang::ObjCAtDefsFieldDecl*)"},
    {"_ZN5clang13ASTDeclWriter18VisitObjCClassDeclEPNS_13ObjCClassDeclE", "clang::ASTDeclWriter::VisitObjCClassDecl(clang::ObjCClassDecl*)"},
    {"_ZN5clang13ASTDeclWriter28VisitObjCForwardProtocolDeclEPNS_23ObjCForwardProtocolDeclE", "clang::ASTDeclWriter::VisitObjCForwardProtocolDecl(clang::ObjCForwardProtocolDecl*)"},
    {"_ZN5clang13ASTDeclWriter21VisitObjCCategoryDeclEPNS_16ObjCCategoryDeclE", "clang::ASTDeclWriter::VisitObjCCategoryDecl(clang::ObjCCategoryDecl*)"},
    {"_ZN5clang13ASTDeclWriter28VisitObjCCompatibleAliasDeclEPNS_23ObjCCompatibleAliasDeclE", "clang::ASTDeclWriter::VisitObjCCompatibleAliasDecl(clang::ObjCCompatibleAliasDecl*)"},
    {"_ZN5clang13ASTDeclWriter21VisitObjCPropertyDeclEPNS_16ObjCPropertyDeclE", "clang::ASTDeclWriter::VisitObjCPropertyDecl(clang::ObjCPropertyDecl*)"},
    {"_ZN5clang13ASTDeclWriter17VisitObjCImplDeclEPNS_12ObjCImplDeclE", "clang::ASTDeclWriter::VisitObjCImplDecl(clang::ObjCImplDecl*)"},
    {"_ZN5clang13ASTDeclWriter25VisitObjCCategoryImplDeclEPNS_20ObjCCategoryImplDeclE", "clang::ASTDeclWriter::VisitObjCCategoryImplDecl(clang::ObjCCategoryImplDecl*)"},
    {"_ZN5clang13ASTDeclWriter27VisitObjCImplementationDeclEPNS_22ObjCImplementationDeclE", "clang::ASTDeclWriter::VisitObjCImplementationDecl(clang::ObjCImplementationDecl*)"},
    {"_ZN5clang13ASTDeclWriter25VisitObjCPropertyImplDeclEPNS_20ObjCPropertyImplDeclE", "clang::ASTDeclWriter::VisitObjCPropertyImplDecl(clang::ObjCPropertyImplDecl*)"},
    {"_ZN5clang13ASTDeclWriter22VisitIndirectFieldDeclEPNS_17IndirectFieldDeclE", "clang::ASTDeclWriter::VisitIndirectFieldDecl(clang::IndirectFieldDecl*)"},
    {"_ZN5clang13ASTDeclWriter12VisitVarDeclEPNS_7VarDeclE", "clang::ASTDeclWriter::VisitVarDecl(clang::VarDecl*)"},
    {"_ZN5clang13ASTDeclWriter22VisitImplicitParamDeclEPNS_17ImplicitParamDeclE", "clang::ASTDeclWriter::VisitImplicitParamDecl(clang::ImplicitParamDecl*)"},
    {"_ZN5clang13ASTDeclWriter16VisitParmVarDeclEPNS_11ParmVarDeclE", "clang::ASTDeclWriter::VisitParmVarDecl(clang::ParmVarDecl*)"},
    {"_ZN5clang13ASTDeclWriter21VisitFileScopeAsmDeclEPNS_16FileScopeAsmDeclE", "clang::ASTDeclWriter::VisitFileScopeAsmDecl(clang::FileScopeAsmDecl*)"},
    {"_ZN5clang13ASTDeclWriter14VisitBlockDeclEPNS_9BlockDeclE", "clang::ASTDeclWriter::VisitBlockDecl(clang::BlockDecl*)"},
    {"_ZN5clang13ASTDeclWriter20VisitLinkageSpecDeclEPNS_15LinkageSpecDeclE", "clang::ASTDeclWriter::VisitLinkageSpecDecl(clang::LinkageSpecDecl*)"},
    {"_ZN5clang13ASTDeclWriter18VisitNamespaceDeclEPNS_13NamespaceDeclE", "clang::ASTDeclWriter::VisitNamespaceDecl(clang::NamespaceDecl*)"},
    {"_ZN5clang13ASTDeclWriter23VisitNamespaceAliasDeclEPNS_18NamespaceAliasDeclE", "clang::ASTDeclWriter::VisitNamespaceAliasDecl(clang::NamespaceAliasDecl*)"},
    {"_ZN5clang13ASTDeclWriter14VisitUsingDeclEPNS_9UsingDeclE", "clang::ASTDeclWriter::VisitUsingDecl(clang::UsingDecl*)"},
    {"_ZN5clang13ASTDeclWriter20VisitUsingShadowDeclEPNS_15UsingShadowDeclE", "clang::ASTDeclWriter::VisitUsingShadowDecl(clang::UsingShadowDecl*)"},
    {"_ZN5clang13ASTDeclWriter23VisitUsingDirectiveDeclEPNS_18UsingDirectiveDeclE", "clang::ASTDeclWriter::VisitUsingDirectiveDecl(clang::UsingDirectiveDecl*)"},
    {"_ZN5clang13ASTDeclWriter29VisitUnresolvedUsingValueDeclEPNS_24UnresolvedUsingValueDeclE", "clang::ASTDeclWriter::VisitUnresolvedUsingValueDecl(clang::UnresolvedUsingValueDecl*)"},
    {"_ZN5clang13ASTDeclWriter32VisitUnresolvedUsingTypenameDeclEPNS_27UnresolvedUsingTypenameDeclE", "clang::ASTDeclWriter::VisitUnresolvedUsingTypenameDecl(clang::UnresolvedUsingTypenameDecl*)"},
    {"_ZN5clang13ASTDeclWriter18VisitCXXRecordDeclEPNS_13CXXRecordDeclE", "clang::ASTDeclWriter::VisitCXXRecordDecl(clang::CXXRecordDecl*)"},
    {"_ZN5clang13ASTDeclWriter18VisitCXXMethodDeclEPNS_13CXXMethodDeclE", "clang::ASTDeclWriter::VisitCXXMethodDecl(clang::CXXMethodDecl*)"},
    {"_ZN5clang13ASTDeclWriter23VisitCXXConstructorDeclEPNS_18CXXConstructorDeclE", "clang::ASTDeclWriter::VisitCXXConstructorDecl(clang::CXXConstructorDecl*)"},
    {"_ZN5clang13ASTDeclWriter22VisitCXXDestructorDeclEPNS_17CXXDestructorDeclE", "clang::ASTDeclWriter::VisitCXXDestructorDecl(clang::CXXDestructorDecl*)"},
    {"_ZN5clang13ASTDeclWriter22VisitCXXConversionDeclEPNS_17CXXConversionDeclE", "clang::ASTDeclWriter::VisitCXXConversionDecl(clang::CXXConversionDecl*)"},
    {"_ZN5clang13ASTDeclWriter19VisitAccessSpecDeclEPNS_14AccessSpecDeclE", "clang::ASTDeclWriter::VisitAccessSpecDecl(clang::AccessSpecDecl*)"},
    {"_ZN5clang13ASTDeclWriter15VisitFriendDeclEPNS_10FriendDeclE", "clang::ASTDeclWriter::VisitFriendDecl(clang::FriendDecl*)"},
    {"_ZN5clang13ASTDeclWriter23VisitFriendTemplateDeclEPNS_18FriendTemplateDeclE", "clang::ASTDeclWriter::VisitFriendTemplateDecl(clang::FriendTemplateDecl*)"},
    {"_ZN5clang13ASTDeclWriter17VisitTemplateDeclEPNS_12TemplateDeclE", "clang::ASTDeclWriter::VisitTemplateDecl(clang::TemplateDecl*)"},
    {"_ZN5clang13ASTDeclWriter29VisitRedeclarableTemplateDeclEPNS_24RedeclarableTemplateDeclE", "clang::ASTDeclWriter::VisitRedeclarableTemplateDecl(clang::RedeclarableTemplateDecl*)"},
    {"_ZN5clang13ASTDeclWriter22VisitClassTemplateDeclEPNS_17ClassTemplateDeclE", "clang::ASTDeclWriter::VisitClassTemplateDecl(clang::ClassTemplateDecl*)"},
    {"_ZN5clang13ASTDeclWriter36VisitClassTemplateSpecializationDeclEPNS_31ClassTemplateSpecializationDeclE", "clang::ASTDeclWriter::VisitClassTemplateSpecializationDecl(clang::ClassTemplateSpecializationDecl*)"},
    {"_ZN5clang13ASTDeclWriter43VisitClassTemplatePartialSpecializationDeclEPNS_38ClassTemplatePartialSpecializationDeclE", "clang::ASTDeclWriter::VisitClassTemplatePartialSpecializationDecl(clang::ClassTemplatePartialSpecializationDecl*)"},
    {"_ZN5clang13ASTDeclWriter25VisitFunctionTemplateDeclEPNS_20FunctionTemplateDeclE", "clang::ASTDeclWriter::VisitFunctionTemplateDecl(clang::FunctionTemplateDecl*)"},
    {"_ZN5clang13ASTDeclWriter25VisitTemplateTypeParmDeclEPNS_20TemplateTypeParmDeclE", "clang::ASTDeclWriter::VisitTemplateTypeParmDecl(clang::TemplateTypeParmDecl*)"},
    {"_ZN5clang13ASTDeclWriter28VisitNonTypeTemplateParmDeclEPNS_23NonTypeTemplateParmDeclE", "clang::ASTDeclWriter::VisitNonTypeTemplateParmDecl(clang::NonTypeTemplateParmDecl*)"},
    {"_ZN5clang13ASTDeclWriter29VisitTemplateTemplateParmDeclEPNS_24TemplateTemplateParmDeclE", "clang::ASTDeclWriter::VisitTemplateTemplateParmDecl(clang::TemplateTemplateParmDecl*)"},
    {"_ZN5clang13ASTDeclWriter21VisitStaticAssertDeclEPNS_16StaticAssertDeclE", "clang::ASTDeclWriter::VisitStaticAssertDecl(clang::StaticAssertDecl*)"},
    {"_ZN5clang13ASTDeclWriter16VisitDeclContextEPNS_11DeclContextEyy", "clang::ASTDeclWriter::VisitDeclContext(clang::DeclContext*, unsigned long long, unsigned long long)"},
    {"_ZN5clang9ASTWriter22WriteDeclsBlockAbbrevsEv", "clang::ASTWriter::WriteDeclsBlockAbbrevs()"},
    {"_ZN5clang9ASTWriter9WriteDeclERNS_10ASTContextEPNS_4DeclE", "clang::ASTWriter::WriteDecl(clang::ASTContext&, clang::Decl*)"},
    {"_ZN5clang11DeclVisitorINS_13ASTDeclWriterEvE5VisitEPNS_4DeclE", "clang::DeclVisitor<clang::ASTDeclWriter, void>::Visit(clang::Decl*)"},
    {"_ZN5clang13ASTDeclWriter17VisitRedeclarableINS_7TagDeclEEEvPNS_12RedeclarableIT_EE", "void clang::ASTDeclWriter::VisitRedeclarable<clang::TagDecl>(clang::Redeclarable<clang::TagDecl>*)"},
    {"_ZN5clang13ASTDeclWriter17VisitRedeclarableINS_12FunctionDeclEEEvPNS_12RedeclarableIT_EE", "void clang::ASTDeclWriter::VisitRedeclarable<clang::FunctionDecl>(clang::Redeclarable<clang::FunctionDecl>*)"},
    {"_ZN5clang13ASTDeclWriter17VisitRedeclarableINS_7VarDeclEEEvPNS_12RedeclarableIT_EE", "void clang::ASTDeclWriter::VisitRedeclarable<clang::VarDecl>(clang::Redeclarable<clang::VarDecl>*)"},
    {"_ZN5clang13ASTStmtWriter31AddExplicitTemplateArgumentListERKNS_28ExplicitTemplateArgumentListE", "clang::ASTStmtWriter::AddExplicitTemplateArgumentList(clang::ExplicitTemplateArgumentList const&)"},
    {"_ZN5clang13ASTStmtWriter9VisitStmtEPNS_4StmtE", "clang::ASTStmtWriter::VisitStmt(clang::Stmt*)"},
    {"_ZN5clang13ASTStmtWriter13VisitNullStmtEPNS_8NullStmtE", "clang::ASTStmtWriter::VisitNullStmt(clang::NullStmt*)"},
    {"_ZN5clang13ASTStmtWriter17VisitCompoundStmtEPNS_12CompoundStmtE", "clang::ASTStmtWriter::VisitCompoundStmt(clang::CompoundStmt*)"},
    {"_ZN5clang13ASTStmtWriter15VisitSwitchCaseEPNS_10SwitchCaseE", "clang::ASTStmtWriter::VisitSwitchCase(clang::SwitchCase*)"},
    {"_ZN5clang9ASTWriter15getSwitchCaseIDEPNS_10SwitchCaseE", "clang::ASTWriter::getSwitchCaseID(clang::SwitchCase*)"},
    {"_ZN5clang13ASTStmtWriter13VisitCaseStmtEPNS_8CaseStmtE", "clang::ASTStmtWriter::VisitCaseStmt(clang::CaseStmt*)"},
    {"_ZN5clang13ASTStmtWriter16VisitDefaultStmtEPNS_11DefaultStmtE", "clang::ASTStmtWriter::VisitDefaultStmt(clang::DefaultStmt*)"},
    {"_ZN5clang13ASTStmtWriter14VisitLabelStmtEPNS_9LabelStmtE", "clang::ASTStmtWriter::VisitLabelStmt(clang::LabelStmt*)"},
    {"_ZN5clang9ASTWriter10GetLabelIDEPNS_9LabelStmtE", "clang::ASTWriter::GetLabelID(clang::LabelStmt*)"},
    {"_ZN5clang13ASTStmtWriter11VisitIfStmtEPNS_6IfStmtE", "clang::ASTStmtWriter::VisitIfStmt(clang::IfStmt*)"},
    {"_ZN5clang13ASTStmtWriter15VisitSwitchStmtEPNS_10SwitchStmtE", "clang::ASTStmtWriter::VisitSwitchStmt(clang::SwitchStmt*)"},
    {"_ZN5clang9ASTWriter18RecordSwitchCaseIDEPNS_10SwitchCaseE", "clang::ASTWriter::RecordSwitchCaseID(clang::SwitchCase*)"},
    {"_ZN5clang13ASTStmtWriter14VisitWhileStmtEPNS_9WhileStmtE", "clang::ASTStmtWriter::VisitWhileStmt(clang::WhileStmt*)"},
    {"_ZN5clang13ASTStmtWriter11VisitDoStmtEPNS_6DoStmtE", "clang::ASTStmtWriter::VisitDoStmt(clang::DoStmt*)"},
    {"_ZN5clang13ASTStmtWriter12VisitForStmtEPNS_7ForStmtE", "clang::ASTStmtWriter::VisitForStmt(clang::ForStmt*)"},
    {"_ZN5clang13ASTStmtWriter13VisitGotoStmtEPNS_8GotoStmtE", "clang::ASTStmtWriter::VisitGotoStmt(clang::GotoStmt*)"},
    {"_ZN5clang13ASTStmtWriter21VisitIndirectGotoStmtEPNS_16IndirectGotoStmtE", "clang::ASTStmtWriter::VisitIndirectGotoStmt(clang::IndirectGotoStmt*)"},
    {"_ZN5clang13ASTStmtWriter17VisitContinueStmtEPNS_12ContinueStmtE", "clang::ASTStmtWriter::VisitContinueStmt(clang::ContinueStmt*)"},
    {"_ZN5clang13ASTStmtWriter14VisitBreakStmtEPNS_9BreakStmtE", "clang::ASTStmtWriter::VisitBreakStmt(clang::BreakStmt*)"},
    {"_ZN5clang13ASTStmtWriter15VisitReturnStmtEPNS_10ReturnStmtE", "clang::ASTStmtWriter::VisitReturnStmt(clang::ReturnStmt*)"},
    {"_ZN5clang13ASTStmtWriter13VisitDeclStmtEPNS_8DeclStmtE", "clang::ASTStmtWriter::VisitDeclStmt(clang::DeclStmt*)"},
    {"_ZN5clang13ASTStmtWriter12VisitAsmStmtEPNS_7AsmStmtE", "clang::ASTStmtWriter::VisitAsmStmt(clang::AsmStmt*)"},
    {"_ZN5clang13ASTStmtWriter9VisitExprEPNS_4ExprE", "clang::ASTStmtWriter::VisitExpr(clang::Expr*)"},
    {"_ZN5clang13ASTStmtWriter19VisitPredefinedExprEPNS_14PredefinedExprE", "clang::ASTStmtWriter::VisitPredefinedExpr(clang::PredefinedExpr*)"},
    {"_ZN5clang13ASTStmtWriter16VisitDeclRefExprEPNS_11DeclRefExprE", "clang::ASTStmtWriter::VisitDeclRefExpr(clang::DeclRefExpr*)"},
    {"_ZN5clang13ASTStmtWriter19VisitIntegerLiteralEPNS_14IntegerLiteralE", "clang::ASTStmtWriter::VisitIntegerLiteral(clang::IntegerLiteral*)"},
    {"_ZN5clang13ASTStmtWriter20VisitFloatingLiteralEPNS_15FloatingLiteralE", "clang::ASTStmtWriter::VisitFloatingLiteral(clang::FloatingLiteral*)"},
    {"_ZN5clang13ASTStmtWriter21VisitImaginaryLiteralEPNS_16ImaginaryLiteralE", "clang::ASTStmtWriter::VisitImaginaryLiteral(clang::ImaginaryLiteral*)"},
    {"_ZN5clang13ASTStmtWriter18VisitStringLiteralEPNS_13StringLiteralE", "clang::ASTStmtWriter::VisitStringLiteral(clang::StringLiteral*)"},
    {"_ZN5clang13ASTStmtWriter21VisitCharacterLiteralEPNS_16CharacterLiteralE", "clang::ASTStmtWriter::VisitCharacterLiteral(clang::CharacterLiteral*)"},
    {"_ZN5clang13ASTStmtWriter14VisitParenExprEPNS_9ParenExprE", "clang::ASTStmtWriter::VisitParenExpr(clang::ParenExpr*)"},
    {"_ZN5clang13ASTStmtWriter18VisitParenListExprEPNS_13ParenListExprE", "clang::ASTStmtWriter::VisitParenListExpr(clang::ParenListExpr*)"},
    {"_ZN5clang13ASTStmtWriter18VisitUnaryOperatorEPNS_13UnaryOperatorE", "clang::ASTStmtWriter::VisitUnaryOperator(clang::UnaryOperator*)"},
    {"_ZN5clang13ASTStmtWriter17VisitOffsetOfExprEPNS_12OffsetOfExprE", "clang::ASTStmtWriter::VisitOffsetOfExpr(clang::OffsetOfExpr*)"},
    {"_ZN5clang13ASTStmtWriter22VisitSizeOfAlignOfExprEPNS_17SizeOfAlignOfExprE", "clang::ASTStmtWriter::VisitSizeOfAlignOfExpr(clang::SizeOfAlignOfExpr*)"},
    {"_ZN5clang13ASTStmtWriter23VisitArraySubscriptExprEPNS_18ArraySubscriptExprE", "clang::ASTStmtWriter::VisitArraySubscriptExpr(clang::ArraySubscriptExpr*)"},
    {"_ZN5clang13ASTStmtWriter13VisitCallExprEPNS_8CallExprE", "clang::ASTStmtWriter::VisitCallExpr(clang::CallExpr*)"},
    {"_ZN5clang13ASTStmtWriter15VisitMemberExprEPNS_10MemberExprE", "clang::ASTStmtWriter::VisitMemberExpr(clang::MemberExpr*)"},
    {"_ZN5clang13ASTStmtWriter16VisitObjCIsaExprEPNS_11ObjCIsaExprE", "clang::ASTStmtWriter::VisitObjCIsaExpr(clang::ObjCIsaExpr*)"},
    {"_ZN5clang13ASTStmtWriter13VisitCastExprEPNS_8CastExprE", "clang::ASTStmtWriter::VisitCastExpr(clang::CastExpr*)"},
    {"_ZN5clang13ASTStmtWriter19VisitBinaryOperatorEPNS_14BinaryOperatorE", "clang::ASTStmtWriter::VisitBinaryOperator(clang::BinaryOperator*)"},
    {"_ZN5clang13ASTStmtWriter27VisitCompoundAssignOperatorEPNS_22CompoundAssignOperatorE", "clang::ASTStmtWriter::VisitCompoundAssignOperator(clang::CompoundAssignOperator*)"},
    {"_ZN5clang13ASTStmtWriter24VisitConditionalOperatorEPNS_19ConditionalOperatorE", "clang::ASTStmtWriter::VisitConditionalOperator(clang::ConditionalOperator*)"},
    {"_ZN5clang13ASTStmtWriter21VisitImplicitCastExprEPNS_16ImplicitCastExprE", "clang::ASTStmtWriter::VisitImplicitCastExpr(clang::ImplicitCastExpr*)"},
    {"_ZN5clang13ASTStmtWriter21VisitExplicitCastExprEPNS_16ExplicitCastExprE", "clang::ASTStmtWriter::VisitExplicitCastExpr(clang::ExplicitCastExpr*)"},
    {"_ZN5clang13ASTStmtWriter19VisitCStyleCastExprEPNS_14CStyleCastExprE", "clang::ASTStmtWriter::VisitCStyleCastExpr(clang::CStyleCastExpr*)"},
    {"_ZN5clang13ASTStmtWriter24VisitCompoundLiteralExprEPNS_19CompoundLiteralExprE", "clang::ASTStmtWriter::VisitCompoundLiteralExpr(clang::CompoundLiteralExpr*)"},
    {"_ZN5clang13ASTStmtWriter25VisitExtVectorElementExprEPNS_20ExtVectorElementExprE", "clang::ASTStmtWriter::VisitExtVectorElementExpr(clang::ExtVectorElementExpr*)"},
    {"_ZN5clang13ASTStmtWriter17VisitInitListExprEPNS_12InitListExprE", "clang::ASTStmtWriter::VisitInitListExpr(clang::InitListExpr*)"},
    {"_ZN5clang13ASTStmtWriter23VisitDesignatedInitExprEPNS_18DesignatedInitExprE", "clang::ASTStmtWriter::VisitDesignatedInitExpr(clang::DesignatedInitExpr*)"},
    {"_ZN5clang13ASTStmtWriter26VisitImplicitValueInitExprEPNS_21ImplicitValueInitExprE", "clang::ASTStmtWriter::VisitImplicitValueInitExpr(clang::ImplicitValueInitExpr*)"},
    {"_ZN5clang13ASTStmtWriter14VisitVAArgExprEPNS_9VAArgExprE", "clang::ASTStmtWriter::VisitVAArgExpr(clang::VAArgExpr*)"},
    {"_ZN5clang13ASTStmtWriter18VisitAddrLabelExprEPNS_13AddrLabelExprE", "clang::ASTStmtWriter::VisitAddrLabelExpr(clang::AddrLabelExpr*)"},
    {"_ZN5clang13ASTStmtWriter13VisitStmtExprEPNS_8StmtExprE", "clang::ASTStmtWriter::VisitStmtExpr(clang::StmtExpr*)"},
    {"_ZN5clang13ASTStmtWriter15VisitChooseExprEPNS_10ChooseExprE", "clang::ASTStmtWriter::VisitChooseExpr(clang::ChooseExpr*)"},
    {"_ZN5clang13ASTStmtWriter16VisitGNUNullExprEPNS_11GNUNullExprE", "clang::ASTStmtWriter::VisitGNUNullExpr(clang::GNUNullExpr*)"},
    {"_ZN5clang13ASTStmtWriter22VisitShuffleVectorExprEPNS_17ShuffleVectorExprE", "clang::ASTStmtWriter::VisitShuffleVectorExpr(clang::ShuffleVectorExpr*)"},
    {"_ZN5clang13ASTStmtWriter14VisitBlockExprEPNS_9BlockExprE", "clang::ASTStmtWriter::VisitBlockExpr(clang::BlockExpr*)"},
    {"_ZN5clang13ASTStmtWriter21VisitBlockDeclRefExprEPNS_16BlockDeclRefExprE", "clang::ASTStmtWriter::VisitBlockDeclRefExpr(clang::BlockDeclRefExpr*)"},
    {"_ZN5clang13ASTStmtWriter22VisitObjCStringLiteralEPNS_17ObjCStringLiteralE", "clang::ASTStmtWriter::VisitObjCStringLiteral(clang::ObjCStringLiteral*)"},
    {"_ZN5clang13ASTStmtWriter19VisitObjCEncodeExprEPNS_14ObjCEncodeExprE", "clang::ASTStmtWriter::VisitObjCEncodeExpr(clang::ObjCEncodeExpr*)"},
    {"_ZN5clang13ASTStmtWriter21VisitObjCSelectorExprEPNS_16ObjCSelectorExprE", "clang::ASTStmtWriter::VisitObjCSelectorExpr(clang::ObjCSelectorExpr*)"},
    {"_ZN5clang13ASTStmtWriter21VisitObjCProtocolExprEPNS_16ObjCProtocolExprE", "clang::ASTStmtWriter::VisitObjCProtocolExpr(clang::ObjCProtocolExpr*)"},
    {"_ZN5clang13ASTStmtWriter20VisitObjCIvarRefExprEPNS_15ObjCIvarRefExprE", "clang::ASTStmtWriter::VisitObjCIvarRefExpr(clang::ObjCIvarRefExpr*)"},
    {"_ZN5clang13ASTStmtWriter24VisitObjCPropertyRefExprEPNS_19ObjCPropertyRefExprE", "clang::ASTStmtWriter::VisitObjCPropertyRefExpr(clang::ObjCPropertyRefExpr*)"},
    {"_ZN5clang13ASTStmtWriter20VisitObjCMessageExprEPNS_15ObjCMessageExprE", "clang::ASTStmtWriter::VisitObjCMessageExpr(clang::ObjCMessageExpr*)"},
    {"_ZN5clang13ASTStmtWriter26VisitObjCForCollectionStmtEPNS_21ObjCForCollectionStmtE", "clang::ASTStmtWriter::VisitObjCForCollectionStmt(clang::ObjCForCollectionStmt*)"},
    {"_ZN5clang13ASTStmtWriter20VisitObjCAtCatchStmtEPNS_15ObjCAtCatchStmtE", "clang::ASTStmtWriter::VisitObjCAtCatchStmt(clang::ObjCAtCatchStmt*)"},
    {"_ZN5clang13ASTStmtWriter22VisitObjCAtFinallyStmtEPNS_17ObjCAtFinallyStmtE", "clang::ASTStmtWriter::VisitObjCAtFinallyStmt(clang::ObjCAtFinallyStmt*)"},
    {"_ZN5clang13ASTStmtWriter18VisitObjCAtTryStmtEPNS_13ObjCAtTryStmtE", "clang::ASTStmtWriter::VisitObjCAtTryStmt(clang::ObjCAtTryStmt*)"},
    {"_ZN5clang13ASTStmtWriter27VisitObjCAtSynchronizedStmtEPNS_22ObjCAtSynchronizedStmtE", "clang::ASTStmtWriter::VisitObjCAtSynchronizedStmt(clang::ObjCAtSynchronizedStmt*)"},
    {"_ZN5clang13ASTStmtWriter20VisitObjCAtThrowStmtEPNS_15ObjCAtThrowStmtE", "clang::ASTStmtWriter::VisitObjCAtThrowStmt(clang::ObjCAtThrowStmt*)"},
    {"_ZN5clang13ASTStmtWriter17VisitCXXCatchStmtEPNS_12CXXCatchStmtE", "clang::ASTStmtWriter::VisitCXXCatchStmt(clang::CXXCatchStmt*)"},
    {"_ZN5clang13ASTStmtWriter15VisitCXXTryStmtEPNS_10CXXTryStmtE", "clang::ASTStmtWriter::VisitCXXTryStmt(clang::CXXTryStmt*)"},
    {"_ZN5clang13ASTStmtWriter24VisitCXXOperatorCallExprEPNS_19CXXOperatorCallExprE", "clang::ASTStmtWriter::VisitCXXOperatorCallExpr(clang::CXXOperatorCallExpr*)"},
    {"_ZN5clang13ASTStmtWriter22VisitCXXMemberCallExprEPNS_17CXXMemberCallExprE", "clang::ASTStmtWriter::VisitCXXMemberCallExpr(clang::CXXMemberCallExpr*)"},
    {"_ZN5clang13ASTStmtWriter21VisitCXXConstructExprEPNS_16CXXConstructExprE", "clang::ASTStmtWriter::VisitCXXConstructExpr(clang::CXXConstructExpr*)"},
    {"_ZN5clang13ASTStmtWriter27VisitCXXTemporaryObjectExprEPNS_22CXXTemporaryObjectExprE", "clang::ASTStmtWriter::VisitCXXTemporaryObjectExpr(clang::CXXTemporaryObjectExpr*)"},
    {"_ZN5clang13ASTStmtWriter21VisitCXXNamedCastExprEPNS_16CXXNamedCastExprE", "clang::ASTStmtWriter::VisitCXXNamedCastExpr(clang::CXXNamedCastExpr*)"},
    {"_ZN5clang13ASTStmtWriter22VisitCXXStaticCastExprEPNS_17CXXStaticCastExprE", "clang::ASTStmtWriter::VisitCXXStaticCastExpr(clang::CXXStaticCastExpr*)"},
    {"_ZN5clang13ASTStmtWriter23VisitCXXDynamicCastExprEPNS_18CXXDynamicCastExprE", "clang::ASTStmtWriter::VisitCXXDynamicCastExpr(clang::CXXDynamicCastExpr*)"},
    {"_ZN5clang13ASTStmtWriter27VisitCXXReinterpretCastExprEPNS_22CXXReinterpretCastExprE", "clang::ASTStmtWriter::VisitCXXReinterpretCastExpr(clang::CXXReinterpretCastExpr*)"},
    {"_ZN5clang13ASTStmtWriter21VisitCXXConstCastExprEPNS_16CXXConstCastExprE", "clang::ASTStmtWriter::VisitCXXConstCastExpr(clang::CXXConstCastExpr*)"},
    {"_ZN5clang13ASTStmtWriter26VisitCXXFunctionalCastExprEPNS_21CXXFunctionalCastExprE", "clang::ASTStmtWriter::VisitCXXFunctionalCastExpr(clang::CXXFunctionalCastExpr*)"},
    {"_ZN5clang13ASTStmtWriter23VisitCXXBoolLiteralExprEPNS_18CXXBoolLiteralExprE", "clang::ASTStmtWriter::VisitCXXBoolLiteralExpr(clang::CXXBoolLiteralExpr*)"},
    {"_ZN5clang13ASTStmtWriter26VisitCXXNullPtrLiteralExprEPNS_21CXXNullPtrLiteralExprE", "clang::ASTStmtWriter::VisitCXXNullPtrLiteralExpr(clang::CXXNullPtrLiteralExpr*)"},
    {"_ZN5clang13ASTStmtWriter18VisitCXXTypeidExprEPNS_13CXXTypeidExprE", "clang::ASTStmtWriter::VisitCXXTypeidExpr(clang::CXXTypeidExpr*)"},
    {"_ZN5clang13ASTStmtWriter18VisitCXXUuidofExprEPNS_13CXXUuidofExprE", "clang::ASTStmtWriter::VisitCXXUuidofExpr(clang::CXXUuidofExpr*)"},
    {"_ZN5clang13ASTStmtWriter16VisitCXXThisExprEPNS_11CXXThisExprE", "clang::ASTStmtWriter::VisitCXXThisExpr(clang::CXXThisExpr*)"},
    {"_ZN5clang13ASTStmtWriter17VisitCXXThrowExprEPNS_12CXXThrowExprE", "clang::ASTStmtWriter::VisitCXXThrowExpr(clang::CXXThrowExpr*)"},
    {"_ZN5clang13ASTStmtWriter22VisitCXXDefaultArgExprEPNS_17CXXDefaultArgExprE", "clang::ASTStmtWriter::VisitCXXDefaultArgExpr(clang::CXXDefaultArgExpr*)"},
    {"_ZN5clang13ASTStmtWriter25VisitCXXBindTemporaryExprEPNS_20CXXBindTemporaryExprE", "clang::ASTStmtWriter::VisitCXXBindTemporaryExpr(clang::CXXBindTemporaryExpr*)"},
    {"_ZN5clang13ASTStmtWriter27VisitCXXScalarValueInitExprEPNS_22CXXScalarValueInitExprE", "clang::ASTStmtWriter::VisitCXXScalarValueInitExpr(clang::CXXScalarValueInitExpr*)"},
    {"_ZN5clang13ASTStmtWriter15VisitCXXNewExprEPNS_10CXXNewExprE", "clang::ASTStmtWriter::VisitCXXNewExpr(clang::CXXNewExpr*)"},
    {"_ZN5clang13ASTStmtWriter18VisitCXXDeleteExprEPNS_13CXXDeleteExprE", "clang::ASTStmtWriter::VisitCXXDeleteExpr(clang::CXXDeleteExpr*)"},
    {"_ZN5clang13ASTStmtWriter28VisitCXXPseudoDestructorExprEPNS_23CXXPseudoDestructorExprE", "clang::ASTStmtWriter::VisitCXXPseudoDestructorExpr(clang::CXXPseudoDestructorExpr*)"},
    {"_ZN5clang13ASTStmtWriter21VisitExprWithCleanupsEPNS_16ExprWithCleanupsE", "clang::ASTStmtWriter::VisitExprWithCleanups(clang::ExprWithCleanups*)"},
    {"_ZN5clang13ASTStmtWriter32VisitCXXDependentScopeMemberExprEPNS_27CXXDependentScopeMemberExprE", "clang::ASTStmtWriter::VisitCXXDependentScopeMemberExpr(clang::CXXDependentScopeMemberExpr*)"},
    {"_ZN5clang13ASTStmtWriter30VisitDependentScopeDeclRefExprEPNS_25DependentScopeDeclRefExprE", "clang::ASTStmtWriter::VisitDependentScopeDeclRefExpr(clang::DependentScopeDeclRefExpr*)"},
    {"_ZN5clang13ASTStmtWriter31VisitCXXUnresolvedConstructExprEPNS_26CXXUnresolvedConstructExprE", "clang::ASTStmtWriter::VisitCXXUnresolvedConstructExpr(clang::CXXUnresolvedConstructExpr*)"},
    {"_ZN5clang13ASTStmtWriter17VisitOverloadExprEPNS_12OverloadExprE", "clang::ASTStmtWriter::VisitOverloadExpr(clang::OverloadExpr*)"},
    {"_ZN5clang13ASTStmtWriter25VisitUnresolvedMemberExprEPNS_20UnresolvedMemberExprE", "clang::ASTStmtWriter::VisitUnresolvedMemberExpr(clang::UnresolvedMemberExpr*)"},
    {"_ZN5clang13ASTStmtWriter25VisitUnresolvedLookupExprEPNS_20UnresolvedLookupExprE", "clang::ASTStmtWriter::VisitUnresolvedLookupExpr(clang::UnresolvedLookupExpr*)"},
    {"_ZN5clang13ASTStmtWriter23VisitUnaryTypeTraitExprEPNS_18UnaryTypeTraitExprE", "clang::ASTStmtWriter::VisitUnaryTypeTraitExpr(clang::UnaryTypeTraitExpr*)"},
    {"_ZN5clang13ASTStmtWriter24VisitBinaryTypeTraitExprEPNS_19BinaryTypeTraitExprE", "clang::ASTStmtWriter::VisitBinaryTypeTraitExpr(clang::BinaryTypeTraitExpr*)"},
    {"_ZN5clang13ASTStmtWriter20VisitCXXNoexceptExprEPNS_15CXXNoexceptExprE", "clang::ASTStmtWriter::VisitCXXNoexceptExpr(clang::CXXNoexceptExpr*)"},
    {"_ZN5clang13ASTStmtWriter22VisitPackExpansionExprEPNS_17PackExpansionExprE", "clang::ASTStmtWriter::VisitPackExpansionExpr(clang::PackExpansionExpr*)"},
    {"_ZN5clang13ASTStmtWriter19VisitSizeOfPackExprEPNS_14SizeOfPackExprE", "clang::ASTStmtWriter::VisitSizeOfPackExpr(clang::SizeOfPackExpr*)"},
    {"_ZN5clang13ASTStmtWriter37VisitSubstNonTypeTemplateParmPackExprEPNS_32SubstNonTypeTemplateParmPackExprE", "clang::ASTStmtWriter::VisitSubstNonTypeTemplateParmPackExpr(clang::SubstNonTypeTemplateParmPackExpr*)"},
    {"_ZN5clang13ASTStmtWriter20VisitOpaqueValueExprEPNS_15OpaqueValueExprE", "clang::ASTStmtWriter::VisitOpaqueValueExpr(clang::OpaqueValueExpr*)"},
    {"_ZN5clang13ASTStmtWriter23VisitCUDAKernelCallExprEPNS_18CUDAKernelCallExprE", "clang::ASTStmtWriter::VisitCUDAKernelCallExpr(clang::CUDAKernelCallExpr*)"},
    {"_ZN5clang9ASTWriter18ClearSwitchCaseIDsEv", "clang::ASTWriter::ClearSwitchCaseIDs()"},
    {"_ZN5clang9ASTWriter12WriteSubStmtEPNS_4StmtE", "clang::ASTWriter::WriteSubStmt(clang::Stmt*)"},
    {"_ZN5clang9ASTWriter10FlushStmtsEv", "clang::ASTWriter::FlushStmts()"},
    {"_ZN5clang11StmtVisitorINS_13ASTStmtWriterEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<clang::ASTStmtWriter, void>::Visit(clang::Stmt*)"},
    {"_ZNSt8_Rb_treeIPN5clang9LabelStmtESt4pairIKS2_jESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS5_ERKS5_", "std::_Rb_tree<clang::LabelStmt*, std::pair<clang::LabelStmt* const, unsigned int>, std::_Select1st<std::pair<clang::LabelStmt* const, unsigned int>>, std::less<clang::LabelStmt*>, std::allocator<std::pair<clang::LabelStmt* const, unsigned int>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::LabelStmt* const, unsigned int>>, std::pair<clang::LabelStmt* const, unsigned int> const&)"},
    {"_ZNSt8_Rb_treeIPN5clang9LabelStmtESt4pairIKS2_jESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE16_M_insert_uniqueERKS5_", "std::_Rb_tree<clang::LabelStmt*, std::pair<clang::LabelStmt* const, unsigned int>, std::_Select1st<std::pair<clang::LabelStmt* const, unsigned int>>, std::less<clang::LabelStmt*>, std::allocator<std::pair<clang::LabelStmt* const, unsigned int>>>::_M_insert_unique(std::pair<clang::LabelStmt* const, unsigned int> const&)"},
    {"_ZNSt8_Rb_treeIPN5clang10SwitchCaseESt4pairIKS2_jESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS5_ERKS5_", "std::_Rb_tree<clang::SwitchCase*, std::pair<clang::SwitchCase* const, unsigned int>, std::_Select1st<std::pair<clang::SwitchCase* const, unsigned int>>, std::less<clang::SwitchCase*>, std::allocator<std::pair<clang::SwitchCase* const, unsigned int>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::SwitchCase* const, unsigned int>>, std::pair<clang::SwitchCase* const, unsigned int> const&)"},
    {"_ZNSt8_Rb_treeIPN5clang10SwitchCaseESt4pairIKS2_jESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE16_M_insert_uniqueERKS5_", "std::_Rb_tree<clang::SwitchCase*, std::pair<clang::SwitchCase* const, unsigned int>, std::_Select1st<std::pair<clang::SwitchCase* const, unsigned int>>, std::less<clang::SwitchCase*>, std::allocator<std::pair<clang::SwitchCase* const, unsigned int>>>::_M_insert_unique(std::pair<clang::SwitchCase* const, unsigned int> const&)"},
    {"_ZN5clang12PCHGeneratorC1ERKNS_12PreprocessorEbPKcPN4llvm11raw_ostreamE", "clang::PCHGenerator::PCHGenerator(clang::Preprocessor const&, bool, char const*, llvm::raw_ostream*)"},
    {"_ZN5clang12PCHGeneratorC2ERKNS_12PreprocessorEbPKcPN4llvm11raw_ostreamE", "clang::PCHGenerator::PCHGenerator(clang::Preprocessor const&, bool, char const*, llvm::raw_ostream*)"},
    {"_ZN5clang12PCHGenerator21HandleTranslationUnitERNS_10ASTContextE", "clang::PCHGenerator::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN5clang12PCHGenerator22GetASTMutationListenerEv", "clang::PCHGenerator::GetASTMutationListener()"},
    {"_ZN5clang12PCHGenerator27GetASTSerializationListenerEv", "clang::PCHGenerator::GetASTSerializationListener()"},
    {"_ZN5clang12PCHGenerator29GetASTDeserializationListenerEv", "clang::PCHGenerator::GetASTDeserializationListener()"},
    {"_ZN5clang17EmitBackendOutputERNS_10DiagnosticERKNS_14CodeGenOptionsERKNS_13TargetOptionsEPN4llvm6ModuleENS_13BackendActionEPNS8_11raw_ostreamE", "clang::EmitBackendOutput(clang::Diagnostic&, clang::CodeGenOptions const&, clang::TargetOptions const&, llvm::Module*, clang::BackendAction, llvm::raw_ostream*)"},
    {"_ZN5clang7CodeGen11CGBlockInfoC1EPKNS_9BlockExprEPKc", "clang::CodeGen::CGBlockInfo::CGBlockInfo(clang::BlockExpr const*, char const*)"},
    {"_ZN5clang7CodeGen11CGBlockInfoC2EPKNS_9BlockExprEPKc", "clang::CodeGen::CGBlockInfo::CGBlockInfo(clang::BlockExpr const*, char const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitBlockLiteralEPKNS_9BlockExprE", "clang::CodeGen::CodeGenFunction::EmitBlockLiteral(clang::BlockExpr const*)"},
    {"_Z16computeBlockInfoRN5clang7CodeGen13CodeGenModuleERNS0_11CGBlockInfoE", "computeBlockInfo(clang::CodeGen::CodeGenModule&, clang::CodeGen::CGBlockInfo&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21GenerateBlockFunctionENS0_10GlobalDeclERKNS0_11CGBlockInfoEPKNS_4DeclERKN4llvm8DenseMapIS8_PNS9_5ValueENS9_12DenseMapInfoIS8_EENSD_ISC_EEEE", "clang::CodeGen::CodeGenFunction::GenerateBlockFunction(clang::CodeGen::GlobalDecl, clang::CodeGen::CGBlockInfo const&, clang::Decl const*, llvm::DenseMap<clang::Decl const*, llvm::Value*, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::Value*>> const&)"},
    {"_Z16buildGlobalBlockRN5clang7CodeGen13CodeGenModuleERKNS0_11CGBlockInfoEPN4llvm8ConstantE", "buildGlobalBlock(clang::CodeGen::CodeGenModule&, clang::CodeGen::CGBlockInfo const&, llvm::Constant*)"},
    {"_Z20buildBlockDescriptorRN5clang7CodeGen13CodeGenModuleERKNS0_11CGBlockInfoE", "buildBlockDescriptor(clang::CodeGen::CodeGenModule&, clang::CodeGen::CGBlockInfo const&)"},
    {"_ZN5clang7CodeGen13CodeGenModule22getBlockDescriptorTypeEv", "clang::CodeGen::CodeGenModule::getBlockDescriptorType()"},
    {"_ZN5clang7CodeGen13CodeGenModule26getGenericBlockLiteralTypeEv", "clang::CodeGen::CodeGenModule::getGenericBlockLiteralType()"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitBlockCallExprEPKNS_8CallExprENS0_15ReturnValueSlotE", "clang::CodeGen::CodeGenFunction::EmitBlockCallExpr(clang::CallExpr const*, clang::CodeGen::ReturnValueSlot)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18GetAddrOfBlockDeclEPKNS_7VarDeclEb", "clang::CodeGen::CodeGenFunction::GetAddrOfBlockDecl(clang::VarDecl const*, bool)"},
    {"_ZN5clang7CodeGen13CodeGenModule20GetAddrOfGlobalBlockEPKNS_9BlockExprEPKc", "clang::CodeGen::CodeGenModule::GetAddrOfGlobalBlock(clang::BlockExpr const*, char const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26GenerateCopyHelperFunctionERKNS0_11CGBlockInfoE", "clang::CodeGen::CodeGenFunction::GenerateCopyHelperFunction(clang::CodeGen::CGBlockInfo const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction29GenerateDestroyHelperFunctionERKNS0_11CGBlockInfoE", "clang::CodeGen::CodeGenFunction::GenerateDestroyHelperFunction(clang::CodeGen::CGBlockInfo const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17BuildBlockReleaseEPN4llvm5ValueENS0_15BlockFieldFlagsE", "clang::CodeGen::CodeGenFunction::BuildBlockRelease(llvm::Value*, clang::CodeGen::BlockFieldFlags)"},
    {"_ZN5clang7CodeGen15CodeGenFunction31GeneratebyrefCopyHelperFunctionEPKN4llvm4TypeENS0_15BlockFieldFlagsEPKNS_7VarDeclE", "clang::CodeGen::CodeGenFunction::GeneratebyrefCopyHelperFunction(llvm::Type const*, clang::CodeGen::BlockFieldFlags, clang::VarDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction34GeneratebyrefDestroyHelperFunctionEPKN4llvm4TypeENS0_15BlockFieldFlagsEPKNS_7VarDeclE", "clang::CodeGen::CodeGenFunction::GeneratebyrefDestroyHelperFunction(llvm::Type const*, clang::CodeGen::BlockFieldFlags, clang::VarDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule20BuildbyrefCopyHelperEPKN4llvm4TypeENS0_15BlockFieldFlagsEjPKNS_7VarDeclE", "clang::CodeGen::CodeGenModule::BuildbyrefCopyHelper(llvm::Type const*, clang::CodeGen::BlockFieldFlags, unsigned int, clang::VarDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule23BuildbyrefDestroyHelperEPKN4llvm4TypeENS0_15BlockFieldFlagsEjPKNS_7VarDeclE", "clang::CodeGen::CodeGenModule::BuildbyrefDestroyHelper(llvm::Type const*, clang::CodeGen::BlockFieldFlags, unsigned int, clang::VarDecl const*)"},
    {"_ZSt21__inplace_stable_sortIPN12_GLOBAL__N_116BlockLayoutChunkEEvT_S3_", "void std::__inplace_stable_sort<(anonymous namespace)::BlockLayoutChunk*>((anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*)"},
    {"_ZSt22__stable_sort_adaptiveIPN12_GLOBAL__N_116BlockLayoutChunkES2_lEvT_S3_T0_T1_", "void std::__stable_sort_adaptive<(anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*, long>((anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*, long)"},
    {"_ZSt24__merge_sort_with_bufferIPN12_GLOBAL__N_116BlockLayoutChunkES2_EvT_S3_T0_", "void std::__merge_sort_with_buffer<(anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*>((anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*)"},
    {"_ZSt16__merge_adaptiveIPN12_GLOBAL__N_116BlockLayoutChunkElS2_EvT_S3_S3_T0_S4_T1_S4_", "void std::__merge_adaptive<(anonymous namespace)::BlockLayoutChunk*, long, (anonymous namespace)::BlockLayoutChunk*>((anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*, long, long, (anonymous namespace)::BlockLayoutChunk*, long)"},
    {"_ZSt13copy_backwardIPN12_GLOBAL__N_116BlockLayoutChunkES2_ET0_T_S4_S3_", "(anonymous namespace)::BlockLayoutChunk* std::copy_backward<(anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*>((anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*)"},
    {"_ZSt6rotateIPN12_GLOBAL__N_116BlockLayoutChunkEEvT_S3_S3_", "void std::rotate<(anonymous namespace)::BlockLayoutChunk*>((anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*)"},
    {"_ZSt16__insertion_sortIPN12_GLOBAL__N_116BlockLayoutChunkEEvT_S3_", "void std::__insertion_sort<(anonymous namespace)::BlockLayoutChunk*>((anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*)"},
    {"_ZSt22__merge_without_bufferIPN12_GLOBAL__N_116BlockLayoutChunkElEvT_S3_S3_T0_S4_", "void std::__merge_without_buffer<(anonymous namespace)::BlockLayoutChunk*, long>((anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*, (anonymous namespace)::BlockLayoutChunk*, long, long)"},
    {"_Z15hasMutableFieldPKN5clang13CXXRecordDeclE", "hasMutableField(clang::CXXRecordDecl const*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN12_GLOBAL__N_116BlockLayoutChunkELb0EE4growEm", "llvm::SmallVectorTemplateBase<(anonymous namespace)::BlockLayoutChunk, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIyPNS_8ConstantENS_12DenseMapInfoIyEENS3_IS2_EEE16InsertIntoBucketERKyRKS2_PSt4pairIyS2_E", "llvm::DenseMap<unsigned long long, llvm::Constant*, llvm::DenseMapInfo<unsigned long long>, llvm::DenseMapInfo<llvm::Constant*>>::InsertIntoBucket(unsigned long long const&, llvm::Constant* const&, std::pair<unsigned long long, llvm::Constant*>*)"},
    {"_ZN4llvm8DenseMapIyPNS_8ConstantENS_12DenseMapInfoIyEENS3_IS2_EEE4growEj", "llvm::DenseMap<unsigned long long, llvm::Constant*, llvm::DenseMapInfo<unsigned long long>, llvm::DenseMapInfo<llvm::Constant*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclENS1_7CodeGen11CGBlockInfo7CaptureENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::VarDecl const*, clang::CodeGen::CGBlockInfo::Capture, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<clang::CodeGen::CGBlockInfo::Capture>>::InsertIntoBucket(clang::VarDecl const* const&, clang::CodeGen::CGBlockInfo::Capture const&, std::pair<clang::VarDecl const*, clang::CodeGen::CGBlockInfo::Capture>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclENS1_7CodeGen11CGBlockInfo7CaptureENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::VarDecl const*, clang::CodeGen::CGBlockInfo::Capture, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<clang::CodeGen::CGBlockInfo::Capture>>::grow(unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15EmitBuiltinExprEPKNS_12FunctionDeclEjPKNS_8CallExprE", "clang::CodeGen::CodeGenFunction::EmitBuiltinExpr(clang::FunctionDecl const*, unsigned int, clang::CallExpr const*)"},
    {"_Z8EmitFAbsRN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueENS_8QualTypeE", "EmitFAbs(clang::CodeGen::CodeGenFunction&, llvm::Value*, clang::QualType)"},
    {"_Z16EmitBinaryAtomicRN5clang7CodeGen15CodeGenFunctionEN4llvm9Intrinsic2IDEPKNS_8CallExprE", "EmitBinaryAtomic(clang::CodeGen::CodeGenFunction&, llvm::Intrinsic::ID, clang::CallExpr const*)"},
    {"_Z20EmitBinaryAtomicPostRN5clang7CodeGen15CodeGenFunctionEN4llvm9Intrinsic2IDEPKNS_8CallExprENS3_11Instruction9BinaryOpsE", "EmitBinaryAtomicPost(clang::CodeGen::CodeGenFunction&, llvm::Intrinsic::ID, clang::CallExpr const*, llvm::Instruction::BinaryOps)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21EmitTargetBuiltinExprEjPKNS_8CallExprE", "clang::CodeGen::CodeGenFunction::EmitTargetBuiltinExpr(unsigned int, clang::CallExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitARMBuiltinExprEjPKNS_8CallExprE", "clang::CodeGen::CodeGenFunction::EmitARMBuiltinExpr(unsigned int, clang::CallExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitX86BuiltinExprEjPKNS_8CallExprE", "clang::CodeGen::CodeGenFunction::EmitX86BuiltinExpr(unsigned int, clang::CallExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitPPCBuiltinExprEjPKNS_8CallExprE", "clang::CodeGen::CodeGenFunction::EmitPPCBuiltinExpr(unsigned int, clang::CallExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction13EmitNeonSplatEPN4llvm5ValueEPNS2_8ConstantE", "clang::CodeGen::CodeGenFunction::EmitNeonSplat(llvm::Value*, llvm::Constant*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12EmitNeonCallEPN4llvm8FunctionERNS2_15SmallVectorImplIPNS2_5ValueEEEPKcjb", "clang::CodeGen::CodeGenFunction::EmitNeonCall(llvm::Function*, llvm::SmallVectorImpl<llvm::Value*>&, char const*, unsigned int, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19EmitNeonShiftVectorEPN4llvm5ValueEPKNS2_4TypeEb", "clang::CodeGen::CodeGenFunction::EmitNeonShiftVector(llvm::Value*, llvm::Type const*, bool)"},
    {"_Z19GetPointeeAlignmentRN5clang7CodeGen15CodeGenFunctionEPKNS_4ExprE", "GetPointeeAlignment(clang::CodeGen::CodeGenFunction&, clang::Expr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction11BuildVectorERKN4llvm15SmallVectorImplIPNS2_5ValueEEE", "clang::CodeGen::CodeGenFunction::BuildVector(llvm::SmallVectorImpl<llvm::Value*> const&)"},
    {"_ZN5clang7CodeGen13CodeGenModule28TryEmitBaseDestructorAsAliasEPKNS_17CXXDestructorDeclE", "clang::CodeGen::CodeGenModule::TryEmitBaseDestructorAsAlias(clang::CXXDestructorDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule24TryEmitDefinitionAsAliasENS0_10GlobalDeclES2_", "clang::CodeGen::CodeGenModule::TryEmitDefinitionAsAlias(clang::CodeGen::GlobalDecl, clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen13CodeGenModule19EmitCXXConstructorsEPKNS_18CXXConstructorDeclE", "clang::CodeGen::CodeGenModule::EmitCXXConstructors(clang::CXXConstructorDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule18EmitCXXConstructorEPKNS_18CXXConstructorDeclENS_11CXXCtorTypeE", "clang::CodeGen::CodeGenModule::EmitCXXConstructor(clang::CXXConstructorDecl const*, clang::CXXCtorType)"},
    {"_ZN5clang7CodeGen13CodeGenModule23GetAddrOfCXXConstructorEPKNS_18CXXConstructorDeclENS_11CXXCtorTypeE", "clang::CodeGen::CodeGenModule::GetAddrOfCXXConstructor(clang::CXXConstructorDecl const*, clang::CXXCtorType)"},
    {"_ZN5clang7CodeGen13CodeGenModule18EmitCXXDestructorsEPKNS_17CXXDestructorDeclE", "clang::CodeGen::CodeGenModule::EmitCXXDestructors(clang::CXXDestructorDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule17EmitCXXDestructorEPKNS_17CXXDestructorDeclENS_11CXXDtorTypeE", "clang::CodeGen::CodeGenModule::EmitCXXDestructor(clang::CXXDestructorDecl const*, clang::CXXDtorType)"},
    {"_ZN5clang7CodeGen13CodeGenModule22GetAddrOfCXXDestructorEPKNS_17CXXDestructorDeclENS_11CXXDtorTypeE", "clang::CodeGen::CodeGenModule::GetAddrOfCXXDestructor(clang::CXXDestructorDecl const*, clang::CXXDtorType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16BuildVirtualCallEPKNS_13CXXMethodDeclEPN4llvm5ValueEPKNS5_4TypeE", "clang::CodeGen::CodeGenFunction::BuildVirtualCall(clang::CXXMethodDecl const*, llvm::Value*, llvm::Type const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction25BuildAppleKextVirtualCallEPKNS_13CXXMethodDeclEPNS_19NestedNameSpecifierEPKN4llvm4TypeE", "clang::CodeGen::CodeGenFunction::BuildAppleKextVirtualCall(clang::CXXMethodDecl const*, clang::NestedNameSpecifier*, llvm::Type const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction35BuildAppleKextVirtualDestructorCallEPKNS_17CXXDestructorDeclENS_11CXXDtorTypeEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenFunction::BuildAppleKextVirtualDestructorCall(clang::CXXDestructorDecl const*, clang::CXXDtorType, clang::CXXRecordDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16BuildVirtualCallEPKNS_17CXXDestructorDeclENS_11CXXDtorTypeEPN4llvm5ValueEPKNS6_4TypeE", "clang::CodeGen::CodeGenFunction::BuildVirtualCall(clang::CXXDestructorDecl const*, clang::CXXDtorType, llvm::Value*, llvm::Type const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule15GetAddrOfGlobalENS0_10GlobalDeclE", "clang::CodeGen::CodeGenModule::GetAddrOfGlobal(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen8CGCXXABID0Ev", "clang::CodeGen::CGCXXABI::~CGCXXABI()"},
    {"_ZN5clang7CodeGen8CGCXXABID1Ev", "clang::CodeGen::CGCXXABI::~CGCXXABI()"},
    {"_ZN5clang7CodeGen8CGCXXABID2Ev", "clang::CodeGen::CGCXXABI::~CGCXXABI()"},
    {"_ZN5clang7CodeGen8CGCXXABI24ConvertMemberPointerTypeEPKNS_17MemberPointerTypeE", "clang::CodeGen::CGCXXABI::ConvertMemberPointerType(clang::MemberPointerType const*)"},
    {"_ZN5clang7CodeGen8CGCXXABI31EmitLoadOfMemberFunctionPointerERNS0_15CodeGenFunctionERPN4llvm5ValueES6_PKNS_17MemberPointerTypeE", "clang::CodeGen::CGCXXABI::EmitLoadOfMemberFunctionPointer(clang::CodeGen::CodeGenFunction&, llvm::Value*&, llvm::Value*, clang::MemberPointerType const*)"},
    {"_ZN5clang7CodeGen8CGCXXABI28EmitMemberDataPointerAddressERNS0_15CodeGenFunctionEPN4llvm5ValueES6_PKNS_17MemberPointerTypeE", "clang::CodeGen::CGCXXABI::EmitMemberDataPointerAddress(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, clang::MemberPointerType const*)"},
    {"_ZN5clang7CodeGen8CGCXXABI27EmitMemberPointerConversionERNS0_15CodeGenFunctionEPKNS_8CastExprEPN4llvm5ValueE", "clang::CodeGen::CGCXXABI::EmitMemberPointerConversion(clang::CodeGen::CodeGenFunction&, clang::CastExpr const*, llvm::Value*)"},
    {"_ZN5clang7CodeGen8CGCXXABI27EmitMemberPointerComparisonERNS0_15CodeGenFunctionEPN4llvm5ValueES6_PKNS_17MemberPointerTypeEb", "clang::CodeGen::CGCXXABI::EmitMemberPointerComparison(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, clang::MemberPointerType const*, bool)"},
    {"_ZN5clang7CodeGen8CGCXXABI26EmitMemberPointerIsNotNullERNS0_15CodeGenFunctionEPN4llvm5ValueEPKNS_17MemberPointerTypeE", "clang::CodeGen::CGCXXABI::EmitMemberPointerIsNotNull(clang::CodeGen::CodeGenFunction&, llvm::Value*, clang::MemberPointerType const*)"},
    {"_ZN5clang7CodeGen8CGCXXABI27EmitMemberPointerConversionEPN4llvm8ConstantEPKNS_8CastExprE", "clang::CodeGen::CGCXXABI::EmitMemberPointerConversion(llvm::Constant*, clang::CastExpr const*)"},
    {"_ZN5clang7CodeGen8CGCXXABI21EmitNullMemberPointerEPKNS_17MemberPointerTypeE", "clang::CodeGen::CGCXXABI::EmitNullMemberPointer(clang::MemberPointerType const*)"},
    {"_ZN5clang7CodeGen8CGCXXABI17EmitMemberPointerEPKNS_13CXXMethodDeclE", "clang::CodeGen::CGCXXABI::EmitMemberPointer(clang::CXXMethodDecl const*)"},
    {"_ZN5clang7CodeGen8CGCXXABI21EmitMemberDataPointerEPKNS_17MemberPointerTypeENS_9CharUnitsE", "clang::CodeGen::CGCXXABI::EmitMemberDataPointer(clang::MemberPointerType const*, clang::CharUnits)"},
    {"_ZN5clang7CodeGen8CGCXXABI19isZeroInitializableEPKNS_17MemberPointerTypeE", "clang::CodeGen::CGCXXABI::isZeroInitializable(clang::MemberPointerType const*)"},
    {"_ZN5clang7CodeGen8CGCXXABI14BuildThisParamERNS0_15CodeGenFunctionERN4llvm11SmallVectorISt4pairIPKNS_7VarDeclENS_8QualTypeEELj16EEE", "clang::CodeGen::CGCXXABI::BuildThisParam(clang::CodeGen::CodeGenFunction&, llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u>&)"},
    {"_ZN5clang7CodeGen8CGCXXABI13EmitThisParamERNS0_15CodeGenFunctionE", "clang::CodeGen::CGCXXABI::EmitThisParam(clang::CodeGen::CodeGenFunction&)"},
    {"_ZN5clang7CodeGen8CGCXXABI19EmitReturnFromThunkERNS0_15CodeGenFunctionENS0_6RValueENS_8QualTypeE", "clang::CodeGen::CGCXXABI::EmitReturnFromThunk(clang::CodeGen::CodeGenFunction&, clang::CodeGen::RValue, clang::QualType)"},
    {"_ZN5clang7CodeGen8CGCXXABI18GetArrayCookieSizeEPKNS_10CXXNewExprE", "clang::CodeGen::CGCXXABI::GetArrayCookieSize(clang::CXXNewExpr const*)"},
    {"_ZN5clang7CodeGen8CGCXXABI21InitializeArrayCookieERNS0_15CodeGenFunctionEPN4llvm5ValueES6_PKNS_10CXXNewExprENS_8QualTypeE", "clang::CodeGen::CGCXXABI::InitializeArrayCookie(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, clang::CXXNewExpr const*, clang::QualType)"},
    {"_ZN5clang7CodeGen8CGCXXABI15ReadArrayCookieERNS0_15CodeGenFunctionEPN4llvm5ValueEPKNS_13CXXDeleteExprENS_8QualTypeERS6_SB_RNS_9CharUnitsE", "clang::CodeGen::CGCXXABI::ReadArrayCookie(clang::CodeGen::CodeGenFunction&, llvm::Value*, clang::CXXDeleteExpr const*, clang::QualType, llvm::Value*&, llvm::Value*&, clang::CharUnits&)"},
    {"_ZN5clang7CodeGen8CGCXXABI15EmitGuardedInitERNS0_15CodeGenFunctionERKNS_7VarDeclEPN4llvm14GlobalVariableE", "clang::CodeGen::CGCXXABI::EmitGuardedInit(clang::CodeGen::CodeGenFunction&, clang::VarDecl const&, llvm::GlobalVariable*)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoENS_7CanQualINS_19FunctionNoProtoTypeEEEb", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::CanQual<clang::FunctionNoProtoType>, bool)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoENS_7CanQualINS_4TypeEEERKN4llvm15SmallVectorImplIS4_EERKNS_12FunctionType7ExtInfoEb", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::CanQual<clang::Type>, llvm::SmallVectorImpl<clang::CanQual<clang::Type>> const&, clang::FunctionType::ExtInfo const&, bool)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoENS_7CanQualINS_17FunctionProtoTypeEEEb", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::CanQual<clang::FunctionProtoType>, bool)"},
    {"_Z15getFunctionInfoRN5clang7CodeGen12CodeGenTypesERN4llvm15SmallVectorImplINS_7CanQualINS_4TypeEEEEENS5_INS_17FunctionProtoTypeEEEb", "getFunctionInfo(clang::CodeGen::CodeGenTypes&, llvm::SmallVectorImpl<clang::CanQual<clang::Type>>&, clang::CanQual<clang::FunctionProtoType>, bool)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoEPKNS_13CXXRecordDeclEPKNS_17FunctionProtoTypeE", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::CXXRecordDecl const*, clang::FunctionProtoType const*)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoEPKNS_13CXXMethodDeclE", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::CXXMethodDecl const*)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoEPKNS_18CXXConstructorDeclENS_11CXXCtorTypeE", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::CXXConstructorDecl const*, clang::CXXCtorType)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoEPKNS_17CXXDestructorDeclENS_11CXXDtorTypeE", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::CXXDestructorDecl const*, clang::CXXDtorType)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoEPKNS_12FunctionDeclE", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::FunctionDecl const*)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoEPKNS_14ObjCMethodDeclE", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::ObjCMethodDecl const*)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoENS0_10GlobalDeclE", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoENS_8QualTypeERKN4llvm11SmallVectorISt4pairINS0_6RValueES2_ELj16EEERKNS_12FunctionType7ExtInfoE", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::QualType, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&, clang::FunctionType::ExtInfo const&)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15getFunctionInfoENS_8QualTypeERKN4llvm11SmallVectorISt4pairIPKNS_7VarDeclES2_ELj16EEERKNS_12FunctionType7ExtInfoE", "clang::CodeGen::CodeGenTypes::getFunctionInfo(clang::QualType, llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u> const&, clang::FunctionType::ExtInfo const&)"},
    {"_ZN5clang7CodeGen14CGFunctionInfoC1EjbjNS_7CanQualINS_4TypeEEEPKS4_j", "clang::CodeGen::CGFunctionInfo::CGFunctionInfo(unsigned int, bool, unsigned int, clang::CanQual<clang::Type>, clang::CanQual<clang::Type> const*, unsigned int)"},
    {"_ZN5clang7CodeGen14CGFunctionInfoC2EjbjNS_7CanQualINS_4TypeEEEPKS4_j", "clang::CodeGen::CGFunctionInfo::CGFunctionInfo(unsigned int, bool, unsigned int, clang::CanQual<clang::Type>, clang::CanQual<clang::Type> const*, unsigned int)"},
    {"_ZN5clang7CodeGen12CodeGenTypes16GetExpandedTypesENS_8QualTypeERSt6vectorIPKN4llvm4TypeESaIS7_EEb", "clang::CodeGen::CodeGenTypes::GetExpandedTypes(clang::QualType, std::vector<llvm::Type const*, std::allocator<llvm::Type const*>>&, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18ExpandTypeFromArgsENS_8QualTypeENS0_6LValueEN4llvm14ilist_iteratorINS4_8ArgumentEEE", "clang::CodeGen::CodeGenFunction::ExpandTypeFromArgs(clang::QualType, clang::CodeGen::LValue, llvm::ilist_iterator<llvm::Argument>)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16ExpandTypeToArgsENS_8QualTypeENS0_6RValueERN4llvm11SmallVectorIPNS4_5ValueELj16EEE", "clang::CodeGen::CodeGenFunction::ExpandTypeToArgs(clang::QualType, clang::CodeGen::RValue, llvm::SmallVector<llvm::Value*, 16u>&)"},
    {"_ZN5clang7CodeGen13CodeGenModule18ReturnTypeUsesSRetERKNS0_14CGFunctionInfoE", "clang::CodeGen::CodeGenModule::ReturnTypeUsesSRet(clang::CodeGen::CGFunctionInfo const&)"},
    {"_ZN5clang7CodeGen13CodeGenModule19ReturnTypeUsesFPRetENS_8QualTypeE", "clang::CodeGen::CodeGenModule::ReturnTypeUsesFPRet(clang::QualType)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15GetFunctionTypeENS0_10GlobalDeclE", "clang::CodeGen::CodeGenTypes::GetFunctionType(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen12CodeGenTypes15GetFunctionTypeERKNS0_14CGFunctionInfoEbb", "clang::CodeGen::CodeGenTypes::GetFunctionType(clang::CodeGen::CGFunctionInfo const&, bool, bool)"},
    {"_ZN5clang7CodeGen12CodeGenTypes24GetFunctionTypeForVTableENS0_10GlobalDeclE", "clang::CodeGen::CodeGenTypes::GetFunctionTypeForVTable(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen13CodeGenModule22ConstructAttributeListERKNS0_14CGFunctionInfoEPKNS_4DeclERN4llvm11SmallVectorINS8_18AttributeWithIndexELj8EEERj", "clang::CodeGen::CodeGenModule::ConstructAttributeList(clang::CodeGen::CGFunctionInfo const&, clang::Decl const*, llvm::SmallVector<llvm::AttributeWithIndex, 8u>&, unsigned int&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitFunctionPrologERKNS0_14CGFunctionInfoEPN4llvm8FunctionERKNS5_11SmallVectorISt4pairIPKNS_7VarDeclENS_8QualTypeEELj16EEE", "clang::CodeGen::CodeGenFunction::EmitFunctionProlog(clang::CodeGen::CGFunctionInfo const&, llvm::Function*, llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u> const&)"},
    {"_Z18CreateCoercedStorePN4llvm5ValueES1_bRN5clang7CodeGen15CodeGenFunctionE", "CreateCoercedStore(llvm::Value*, llvm::Value*, bool, clang::CodeGen::CodeGenFunction&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitFunctionEpilogERKNS0_14CGFunctionInfoE", "clang::CodeGen::CodeGenFunction::EmitFunctionEpilog(clang::CodeGen::CGFunctionInfo const&)"},
    {"_Z17CreateCoercedLoadPN4llvm5ValueEPKNS_4TypeERN5clang7CodeGen15CodeGenFunctionE", "CreateCoercedLoad(llvm::Value*, llvm::Type const*, clang::CodeGen::CodeGenFunction&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19EmitDelegateCallArgEPKNS_7VarDeclE", "clang::CodeGen::CodeGenFunction::EmitDelegateCallArg(clang::VarDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction11EmitCallArgEPKNS_4ExprENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitCallArg(clang::Expr const*, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitCallOrInvokeEPN4llvm5ValueEPKS4_S6_RKNS2_5TwineE", "clang::CodeGen::CodeGenFunction::EmitCallOrInvoke(llvm::Value*, llvm::Value* const*, llvm::Value* const*, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction8EmitCallERKNS0_14CGFunctionInfoEPN4llvm5ValueENS0_15ReturnValueSlotERKNS5_11SmallVectorISt4pairINS0_6RValueENS_8QualTypeEELj16EEEPKNS_4DeclEPPNS5_11InstructionE", "clang::CodeGen::CodeGenFunction::EmitCall(clang::CodeGen::CGFunctionInfo const&, llvm::Value*, clang::CodeGen::ReturnValueSlot, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&, clang::Decl const*, llvm::Instruction**)"},
    {"_ZN5clang7CodeGen15CodeGenFunction9EmitVAArgEPN4llvm5ValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitVAArg(llvm::Value*, clang::QualType)"},
    {"_Z34EnterStructPointerForCoercedAccessPN4llvm5ValueEPKNS_10StructTypeEyRN5clang7CodeGen15CodeGenFunctionE", "EnterStructPointerForCoercedAccess(llvm::Value*, llvm::StructType const*, unsigned long long, clang::CodeGen::CodeGenFunction&)"},
    {"_Z24CoerceIntOrPtrToIntOrPtrPN4llvm5ValueEPKNS_4TypeERN5clang7CodeGen15CodeGenFunctionE", "CoerceIntOrPtrToIntOrPtr(llvm::Value*, llvm::Type const*, clang::CodeGen::CodeGenFunction&)"},
    {"_ZN5clang7CodeGen14CGFunctionInfo7ProfileIPKNS_7CanQualINS_4TypeEEEEEvRN4llvm16FoldingSetNodeIDERKNS_12FunctionType7ExtInfoES5_T_SF_", "void clang::CodeGen::CGFunctionInfo::Profile<clang::CanQual<clang::Type> const*>(llvm::FoldingSetNodeID&, clang::FunctionType::ExtInfo const&, clang::CanQual<clang::Type>, clang::CanQual<clang::Type> const*, clang::CanQual<clang::Type> const*)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE18CreateConstGEP2_32EPNS_5ValueEjjRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateConstGEP2_32(llvm::Value*, unsigned int, unsigned int, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE13CreateRetVoidEv", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateRetVoid()"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateRetEPNS_5ValueE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateRet(llvm::Value*)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateCallIPKPNS_5ValueEEEPNS_8CallInstES7_T_SC_RKNS_5TwineE", "llvm::CallInst* llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateCall<llvm::Value* const*>(llvm::Value*, llvm::Value* const*, llvm::Value* const*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE12CreateInvokeIPKPNS_5ValueEEEPNS_10InvokeInstES7_PNS_10BasicBlockESD_T_SE_RKNS_5TwineE", "llvm::InvokeInst* llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateInvoke<llvm::Value* const*>(llvm::Value*, llvm::BasicBlock*, llvm::BasicBlock*, llvm::Value* const*, llvm::Value* const*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE18CreateExtractValueEPNS_5ValueEjRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateExtractValue(llvm::Value*, unsigned int, llvm::Twine const&)"},
    {"_ZN4llvm10InvokeInstC2IPKPNS_5ValueEEES3_PNS_10BasicBlockES7_T_S8_jRKNS_5TwineEPNS_11InstructionE", "llvm::InvokeInst::InvokeInst<llvm::Value* const*>(llvm::Value*, llvm::BasicBlock*, llvm::BasicBlock*, llvm::Value* const*, llvm::Value* const*, unsigned int, llvm::Twine const&, llvm::Instruction*)"},
    {"_ZN4llvm8CallInstC2IPKPNS_5ValueEEES3_T_S6_RKNS_5TwineEPNS_11InstructionE", "llvm::CallInst::CallInst<llvm::Value* const*>(llvm::Value*, llvm::Value* const*, llvm::Value* const*, llvm::Twine const&, llvm::Instruction*)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE13CreateIntCastEPNS_5ValueEPKNS_4TypeEbRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateIntCast(llvm::Value*, llvm::Type const*, bool, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen13CodeGenModule28GetNonVirtualBaseClassOffsetEPKNS_13CXXRecordDeclEPKPKNS_16CXXBaseSpecifierES9_", "clang::CodeGen::CodeGenModule::GetNonVirtualBaseClassOffset(clang::CXXRecordDecl const*, clang::CXXBaseSpecifier const* const*, clang::CXXBaseSpecifier const* const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction37GetAddressOfDirectBaseInCompleteClassEPN4llvm5ValueEPKNS_13CXXRecordDeclES7_b", "clang::CodeGen::CodeGenFunction::GetAddressOfDirectBaseInCompleteClass(llvm::Value*, clang::CXXRecordDecl const*, clang::CXXRecordDecl const*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21GetAddressOfBaseClassEPN4llvm5ValueEPKNS_13CXXRecordDeclEPKPKNS_16CXXBaseSpecifierESC_b", "clang::CodeGen::CodeGenFunction::GetAddressOfBaseClass(llvm::Value*, clang::CXXRecordDecl const*, clang::CXXBaseSpecifier const* const*, clang::CXXBaseSpecifier const* const*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction25GetVirtualBaseClassOffsetEPN4llvm5ValueEPKNS_13CXXRecordDeclES7_", "clang::CodeGen::CodeGenFunction::GetVirtualBaseClassOffset(llvm::Value*, clang::CXXRecordDecl const*, clang::CXXRecordDecl const*)"},
    {"_Z31ApplyNonVirtualAndVirtualOffsetRN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueEyS5_", "ApplyNonVirtualAndVirtualOffset(clang::CodeGen::CodeGenFunction&, llvm::Value*, unsigned long long, llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24GetAddressOfDerivedClassEPN4llvm5ValueEPKNS_13CXXRecordDeclEPKPKNS_16CXXBaseSpecifierESC_b", "clang::CodeGen::CodeGenFunction::GetAddressOfDerivedClass(llvm::Value*, clang::CXXRecordDecl const*, clang::CXXBaseSpecifier const* const*, clang::CXXBaseSpecifier const* const*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19EmitConstructorBodyERN4llvm11SmallVectorISt4pairIPKNS_7VarDeclENS_8QualTypeEELj16EEE", "clang::CodeGen::CodeGenFunction::EmitConstructorBody(llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u>&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction30EmitDelegateCXXConstructorCallEPKNS_18CXXConstructorDeclENS_11CXXCtorTypeERKN4llvm11SmallVectorISt4pairIPKNS_7VarDeclENS_8QualTypeEELj16EEE", "clang::CodeGen::CodeGenFunction::EmitDelegateCXXConstructorCall(clang::CXXConstructorDecl const*, clang::CXXCtorType, llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u> const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitCtorPrologueEPKNS_18CXXConstructorDeclENS_11CXXCtorTypeERN4llvm11SmallVectorISt4pairIPKNS_7VarDeclENS_8QualTypeEELj16EEE", "clang::CodeGen::CodeGenFunction::EmitCtorPrologue(clang::CXXConstructorDecl const*, clang::CXXCtorType, llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u>&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24InitializeVTablePointersEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenFunction::InitializeVTablePointers(clang::CXXRecordDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitDestructorBodyERN4llvm11SmallVectorISt4pairIPKNS_7VarDeclENS_8QualTypeEELj16EEE", "clang::CodeGen::CodeGenFunction::EmitDestructorBody(llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u>&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EnterDtorCleanupsEPKNS_17CXXDestructorDeclENS_11CXXDtorTypeE", "clang::CodeGen::CodeGenFunction::EnterDtorCleanups(clang::CXXDestructorDecl const*, clang::CXXDtorType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21EmitCXXDestructorCallEPKNS_17CXXDestructorDeclENS_11CXXDtorTypeEbPN4llvm5ValueE", "clang::CodeGen::CodeGenFunction::EmitCXXDestructorCall(clang::CXXDestructorDecl const*, clang::CXXDtorType, bool, llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26EmitCXXAggrConstructorCallEPKNS_18CXXConstructorDeclEPKNS_17ConstantArrayTypeEPN4llvm5ValueENS_17ConstExprIteratorESB_b", "clang::CodeGen::CodeGenFunction::EmitCXXAggrConstructorCall(clang::CXXConstructorDecl const*, clang::ConstantArrayType const*, llvm::Value*, clang::ConstExprIterator, clang::ConstExprIterator, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26EmitCXXAggrConstructorCallEPKNS_18CXXConstructorDeclEPN4llvm5ValueES7_NS_17ConstExprIteratorES8_b", "clang::CodeGen::CodeGenFunction::EmitCXXAggrConstructorCall(clang::CXXConstructorDecl const*, llvm::Value*, llvm::Value*, clang::ConstExprIterator, clang::ConstExprIterator, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction22EmitCXXConstructorCallEPKNS_18CXXConstructorDeclENS_11CXXCtorTypeEbPN4llvm5ValueENS_17ConstExprIteratorES9_", "clang::CodeGen::CodeGenFunction::EmitCXXConstructorCall(clang::CXXConstructorDecl const*, clang::CXXCtorType, bool, llvm::Value*, clang::ConstExprIterator, clang::ConstExprIterator)"},
    {"_ZN5clang7CodeGen15CodeGenFunction25EmitCXXAggrDestructorCallEPKNS_17CXXDestructorDeclEPKNS_9ArrayTypeEPN4llvm5ValueE", "clang::CodeGen::CodeGenFunction::EmitCXXAggrDestructorCall(clang::CXXDestructorDecl const*, clang::ArrayType const*, llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction25EmitCXXAggrDestructorCallEPKNS_17CXXDestructorDeclEPN4llvm5ValueES7_", "clang::CodeGen::CodeGenFunction::EmitCXXAggrDestructorCall(clang::CXXDestructorDecl const*, llvm::Value*, llvm::Value*)"},
    {"_Z15GetVTTParameterRN5clang7CodeGen15CodeGenFunctionENS0_10GlobalDeclEb", "GetVTTParameter(clang::CodeGen::CodeGenFunction&, clang::CodeGen::GlobalDecl, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction30EmitSynthesizedCXXCopyCtorCallEPKNS_18CXXConstructorDeclEPN4llvm5ValueES7_NS_17ConstExprIteratorES8_", "clang::CodeGen::CodeGenFunction::EmitSynthesizedCXXCopyCtorCall(clang::CXXConstructorDecl const*, llvm::Value*, llvm::Value*, clang::ConstExprIterator, clang::ConstExprIterator)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21PushDestructorCleanupEPKNS_17CXXDestructorDeclEPN4llvm5ValueE", "clang::CodeGen::CodeGenFunction::PushDestructorCleanup(clang::CXXDestructorDecl const*, llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21PushDestructorCleanupENS_8QualTypeEPN4llvm5ValueE", "clang::CodeGen::CodeGenFunction::PushDestructorCleanup(clang::QualType, llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12GetVTablePtrEPN4llvm5ValueEPKNS2_4TypeE", "clang::CodeGen::CodeGenFunction::GetVTablePtr(llvm::Value*, llvm::Type const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction23InitializeVTablePointerENS0_13BaseSubobjectEPKNS_13CXXRecordDeclEyPN4llvm8ConstantES5_", "clang::CodeGen::CodeGenFunction::InitializeVTablePointer(clang::CodeGen::BaseSubobject, clang::CXXRecordDecl const*, unsigned long long, llvm::Constant*, clang::CXXRecordDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24InitializeVTablePointersENS0_13BaseSubobjectEPKNS_13CXXRecordDeclEybPN4llvm8ConstantES5_RNS6_11SmallPtrSetIS5_Lj4EEE", "clang::CodeGen::CodeGenFunction::InitializeVTablePointers(clang::CodeGen::BaseSubobject, clang::CXXRecordDecl const*, unsigned long long, bool, llvm::Constant*, clang::CXXRecordDecl const*, llvm::SmallPtrSet<clang::CXXRecordDecl const*, 4u>&)"},
    {"_ZN12_GLOBAL__N_113CallLocalDtorD1Ev", "(anonymous namespace)::CallLocalDtor::~CallLocalDtor()"},
    {"_ZN12_GLOBAL__N_113CallLocalDtorD0Ev", "(anonymous namespace)::CallLocalDtor::~CallLocalDtor()"},
    {"_ZN12_GLOBAL__N_113CallLocalDtor4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallLocalDtor::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_113CallFieldDtorD1Ev", "(anonymous namespace)::CallFieldDtor::~CallFieldDtor()"},
    {"_ZN12_GLOBAL__N_113CallFieldDtorD0Ev", "(anonymous namespace)::CallFieldDtor::~CallFieldDtor()"},
    {"_ZN12_GLOBAL__N_113CallFieldDtor4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallFieldDtor::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_118CallArrayFieldDtorD1Ev", "(anonymous namespace)::CallArrayFieldDtor::~CallArrayFieldDtor()"},
    {"_ZN12_GLOBAL__N_118CallArrayFieldDtorD0Ev", "(anonymous namespace)::CallArrayFieldDtor::~CallArrayFieldDtor()"},
    {"_ZN12_GLOBAL__N_118CallArrayFieldDtor4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallArrayFieldDtor::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_114CallDtorDeleteD1Ev", "(anonymous namespace)::CallDtorDelete::~CallDtorDelete()"},
    {"_ZN12_GLOBAL__N_114CallDtorDeleteD0Ev", "(anonymous namespace)::CallDtorDelete::~CallDtorDelete()"},
    {"_ZN12_GLOBAL__N_114CallDtorDelete4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallDtorDelete::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_112CallBaseDtorD1Ev", "(anonymous namespace)::CallBaseDtor::~CallBaseDtor()"},
    {"_ZN12_GLOBAL__N_112CallBaseDtorD0Ev", "(anonymous namespace)::CallBaseDtor::~CallBaseDtor()"},
    {"_ZN12_GLOBAL__N_112CallBaseDtor4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallBaseDtor::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_Z24EmitAggMemberInitializerRN5clang7CodeGen15CodeGenFunctionENS0_6LValueEPN4llvm5ValueEPNS_18CXXCtorInitializerENS_8QualTypeEj", "EmitAggMemberInitializer(clang::CodeGen::CodeGenFunction&, clang::CodeGen::LValue, llvm::Value*, clang::CXXCtorInitializer*, clang::QualType, unsigned int)"},
    {"_ZN12_GLOBAL__N_114CallMemberDtorD1Ev", "(anonymous namespace)::CallMemberDtor::~CallMemberDtor()"},
    {"_ZN12_GLOBAL__N_114CallMemberDtorD0Ev", "(anonymous namespace)::CallMemberDtor::~CallMemberDtor()"},
    {"_ZN12_GLOBAL__N_114CallMemberDtor4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallMemberDtor::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_121DynamicThisUseCheckerEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::DynamicThisUseChecker, void>::Visit(clang::Stmt*)"},
    {"_ZN5clang20EvaluatedExprVisitorIN12_GLOBAL__N_121DynamicThisUseCheckerEE9VisitStmtEPNS_4StmtE", "clang::EvaluatedExprVisitor<(anonymous namespace)::DynamicThisUseChecker>::VisitStmt(clang::Stmt*)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE18CreateConstGEP1_64EPNS_5ValueEyRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateConstGEP1_64(llvm::Value*, unsigned long long, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE26CreateConstInBoundsGEP2_64EPNS_5ValueEyyRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateConstInBoundsGEP2_64(llvm::Value*, unsigned long long, unsigned long long, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen15DominatingValueINS0_6RValueEE10saved_type11needsSavingES2_", "clang::CodeGen::DominatingValue<clang::CodeGen::RValue>::saved_type::needsSaving(clang::CodeGen::RValue)"},
    {"_ZN5clang7CodeGen15DominatingValueINS0_6RValueEE10saved_type4saveERNS0_15CodeGenFunctionES2_", "clang::CodeGen::DominatingValue<clang::CodeGen::RValue>::saved_type::save(clang::CodeGen::CodeGenFunction&, clang::CodeGen::RValue)"},
    {"_ZN5clang7CodeGen15DominatingValueINS0_6RValueEE10saved_type7restoreERNS0_15CodeGenFunctionE", "clang::CodeGen::DominatingValue<clang::CodeGen::RValue>::saved_type::restore(clang::CodeGen::CodeGenFunction&)"},
    {"_ZN5clang7CodeGen12EHScopeStack8allocateEm", "clang::CodeGen::EHScopeStack::allocate(unsigned long)"},
    {"_ZNK5clang7CodeGen12EHScopeStack21getEnclosingEHCleanupENS1_8iteratorE", "clang::CodeGen::EHScopeStack::getEnclosingEHCleanup(clang::CodeGen::EHScopeStack::iterator) const"},
    {"_ZN5clang7CodeGen12EHScopeStack11pushCleanupENS0_11CleanupKindEm", "clang::CodeGen::EHScopeStack::pushCleanup(clang::CodeGen::CleanupKind, unsigned long)"},
    {"_ZN5clang7CodeGen12EHScopeStack10popCleanupEv", "clang::CodeGen::EHScopeStack::popCleanup()"},
    {"_ZN5clang7CodeGen12EHScopeStack13popNullFixupsEv", "clang::CodeGen::EHScopeStack::popNullFixups()"},
    {"_ZN5clang7CodeGen12EHScopeStack10pushFilterEj", "clang::CodeGen::EHScopeStack::pushFilter(unsigned int)"},
    {"_ZN5clang7CodeGen12EHScopeStack9popFilterEv", "clang::CodeGen::EHScopeStack::popFilter()"},
    {"_ZN5clang7CodeGen12EHScopeStack9pushCatchEj", "clang::CodeGen::EHScopeStack::pushCatch(unsigned int)"},
    {"_ZN5clang7CodeGen12EHScopeStack13pushTerminateEv", "clang::CodeGen::EHScopeStack::pushTerminate()"},
    {"_ZN5clang7CodeGen15CodeGenFunction19initFullExprCleanupEv", "clang::CodeGen::CodeGenFunction::initFullExprCleanup()"},
    {"_ZN5clang7CodeGen12EHScopeStack7CleanupD0Ev", "clang::CodeGen::EHScopeStack::Cleanup::~Cleanup()"},
    {"_ZN5clang7CodeGen12EHScopeStack7CleanupD1Ev", "clang::CodeGen::EHScopeStack::Cleanup::~Cleanup()"},
    {"_ZN5clang7CodeGen12EHScopeStack7CleanupD2Ev", "clang::CodeGen::EHScopeStack::Cleanup::~Cleanup()"},
    {"_ZN5clang7CodeGen15CodeGenFunction19ResolveBranchFixupsEPN4llvm10BasicBlockE", "clang::CodeGen::CodeGenFunction::ResolveBranchFixups(llvm::BasicBlock*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16PopCleanupBlocksENS0_12EHScopeStack15stable_iteratorE", "clang::CodeGen::CodeGenFunction::PopCleanupBlocks(clang::CodeGen::EHScopeStack::stable_iterator)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15PopCleanupBlockEb", "clang::CodeGen::CodeGenFunction::PopCleanupBlock(bool)"},
    {"_Z29ForwardPrebranchedFallthroughPN4llvm10BasicBlockES1_S1_", "ForwardPrebranchedFallthrough(llvm::BasicBlock*, llvm::BasicBlock*, llvm::BasicBlock*)"},
    {"_Z20SimplifyCleanupEntryRN5clang7CodeGen15CodeGenFunctionEPN4llvm10BasicBlockE", "SimplifyCleanupEntry(clang::CodeGen::CodeGenFunction&, llvm::BasicBlock*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20getEHCleanupDestSlotEv", "clang::CodeGen::CodeGenFunction::getEHCleanupDestSlot()"},
    {"_Z11EmitCleanupRN5clang7CodeGen15CodeGenFunctionEPNS0_12EHScopeStack7CleanupEbPN4llvm5ValueE", "EmitCleanup(clang::CodeGen::CodeGenFunction&, clang::CodeGen::EHScopeStack::Cleanup*, bool, llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24getNormalCleanupDestSlotEv", "clang::CodeGen::CodeGenFunction::getNormalCleanupDestSlot()"},
    {"_ZN5clang7CodeGen15CodeGenFunction24EmitBranchThroughCleanupENS1_8JumpDestE", "clang::CodeGen::CodeGenFunction::EmitBranchThroughCleanup(clang::CodeGen::CodeGenFunction::JumpDest)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26EmitBranchThroughEHCleanupENS1_10UnwindDestE", "clang::CodeGen::CodeGenFunction::EmitBranchThroughEHCleanup(clang::CodeGen::CodeGenFunction::UnwindDest)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20ActivateCleanupBlockENS0_12EHScopeStack15stable_iteratorE", "clang::CodeGen::CodeGenFunction::ActivateCleanupBlock(clang::CodeGen::EHScopeStack::stable_iterator)"},
    {"_Z27SetupCleanupBlockActivationRN5clang7CodeGen15CodeGenFunctionENS0_12EHScopeStack15stable_iteratorE15ForActivation_t", "SetupCleanupBlockActivation(clang::CodeGen::CodeGenFunction&, clang::CodeGen::EHScopeStack::stable_iterator, ForActivation_t)"},
    {"_ZN5clang7CodeGen15CodeGenFunction22DeactivateCleanupBlockENS0_12EHScopeStack15stable_iteratorE", "clang::CodeGen::CodeGenFunction::DeactivateCleanupBlock(clang::CodeGen::EHScopeStack::stable_iterator)"},
    {"_ZN5clang7CodeGen14EHCleanupScope14addBranchAfterEPN4llvm11ConstantIntEPNS2_10BasicBlockE", "clang::CodeGen::EHCleanupScope::addBranchAfter(llvm::ConstantInt*, llvm::BasicBlock*)"},
    {"_ZN5clang7CodeGen14EHCleanupScope16addEHBranchAfterEPN4llvm11ConstantIntEPNS2_10BasicBlockE", "clang::CodeGen::EHCleanupScope::addEHBranchAfter(llvm::ConstantInt*, llvm::BasicBlock*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang7CodeGen11BranchFixupELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::CodeGen::BranchFixup, false>::grow(unsigned long)"},
    {"_ZN5clang7CodeGen14EHCleanupScopeD2Ev", "clang::CodeGen::EHCleanupScope::~EHCleanupScope()"},
    {"_ZN5clang7CodeGen11CGDebugInfoC1ERNS0_13CodeGenModuleE", "clang::CodeGen::CGDebugInfo::CGDebugInfo(clang::CodeGen::CodeGenModule&)"},
    {"_ZN5clang7CodeGen11CGDebugInfoC2ERNS0_13CodeGenModuleE", "clang::CodeGen::CGDebugInfo::CGDebugInfo(clang::CodeGen::CodeGenModule&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo17CreateCompileUnitEv", "clang::CodeGen::CGDebugInfo::CreateCompileUnit()"},
    {"_ZN5clang7CodeGen11CGDebugInfoD1Ev", "clang::CodeGen::CGDebugInfo::~CGDebugInfo()"},
    {"_ZN5clang7CodeGen11CGDebugInfoD2Ev", "clang::CodeGen::CGDebugInfo::~CGDebugInfo()"},
    {"_ZN5clang7CodeGen11CGDebugInfo11setLocationENS_14SourceLocationE", "clang::CodeGen::CGDebugInfo::setLocation(clang::SourceLocation)"},
    {"_ZN5clang7CodeGen11CGDebugInfo20getContextDescriptorEPKNS_4DeclE", "clang::CodeGen::CGDebugInfo::getContextDescriptor(clang::Decl const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo20getOrCreateNameSpaceEPKNS_13NamespaceDeclE", "clang::CodeGen::CGDebugInfo::getOrCreateNameSpace(clang::NamespaceDecl const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo15getOrCreateTypeENS_8QualTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::getOrCreateType(clang::QualType, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo19getOrCreateMainFileEv", "clang::CodeGen::CGDebugInfo::getOrCreateMainFile()"},
    {"_ZN5clang7CodeGen11CGDebugInfo15getFunctionNameEPKNS_12FunctionDeclE", "clang::CodeGen::CGDebugInfo::getFunctionName(clang::FunctionDecl const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo17getObjCMethodNameEPKNS_14ObjCMethodDeclE", "clang::CodeGen::CGDebugInfo::getObjCMethodName(clang::ObjCMethodDecl const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo12getClassNameEPNS_10RecordDeclE", "clang::CodeGen::CGDebugInfo::getClassName(clang::RecordDecl*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo15getOrCreateFileENS_14SourceLocationE", "clang::CodeGen::CGDebugInfo::getOrCreateFile(clang::SourceLocation)"},
    {"_ZN5clang7CodeGen11CGDebugInfo17getCurrentDirnameEv", "clang::CodeGen::CGDebugInfo::getCurrentDirname()"},
    {"_ZN5clang7CodeGen11CGDebugInfo13getLineNumberENS_14SourceLocationE", "clang::CodeGen::CGDebugInfo::getLineNumber(clang::SourceLocation)"},
    {"_ZN5clang7CodeGen11CGDebugInfo15getColumnNumberENS_14SourceLocationE", "clang::CodeGen::CGDebugInfo::getColumnNumber(clang::SourceLocation)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_11BuiltinTypeE", "clang::CodeGen::CGDebugInfo::CreateType(clang::BuiltinType const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_11ComplexTypeE", "clang::CodeGen::CGDebugInfo::CreateType(clang::ComplexType const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo19CreateQualifiedTypeENS_8QualTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateQualifiedType(clang::QualType, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_21ObjCObjectPointerTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::ObjCObjectPointerType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo21CreatePointerLikeTypeEjPKNS_4TypeENS_8QualTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreatePointerLikeType(unsigned int, clang::Type const*, clang::QualType, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_11PointerTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::PointerType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo17CreatePointeeTypeENS_8QualTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreatePointeeType(clang::QualType, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_16BlockPointerTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::BlockPointerType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo16CreateMemberTypeEN4llvm6DIFileENS_8QualTypeENS2_9StringRefEPy", "clang::CodeGen::CGDebugInfo::CreateMemberType(llvm::DIFile, clang::QualType, llvm::StringRef, unsigned long long*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_11TypedefTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::TypedefType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_12FunctionTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::FunctionType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo19CollectRecordFieldsEPKNS_10RecordDeclEN4llvm6DIFileERNS5_15SmallVectorImplIPNS5_5ValueEEE", "clang::CodeGen::CGDebugInfo::CollectRecordFields(clang::RecordDecl const*, llvm::DIFile, llvm::SmallVectorImpl<llvm::Value*>&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo21getOrCreateMethodTypeEPKNS_13CXXMethodDeclEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::getOrCreateMethodType(clang::CXXMethodDecl const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo23CreateCXXMemberFunctionEPKNS_13CXXMethodDeclEN4llvm6DIFileENS5_6DITypeE", "clang::CodeGen::CGDebugInfo::CreateCXXMemberFunction(clang::CXXMethodDecl const*, llvm::DIFile, llvm::DIType)"},
    {"_ZN5clang7CodeGen11CGDebugInfo25CollectCXXMemberFunctionsEPKNS_13CXXRecordDeclEN4llvm6DIFileERNS5_15SmallVectorImplIPNS5_5ValueEEENS5_6DITypeE", "clang::CodeGen::CGDebugInfo::CollectCXXMemberFunctions(clang::CXXRecordDecl const*, llvm::DIFile, llvm::SmallVectorImpl<llvm::Value*>&, llvm::DIType)"},
    {"_ZN5clang7CodeGen11CGDebugInfo17CollectCXXFriendsEPKNS_13CXXRecordDeclEN4llvm6DIFileERNS5_15SmallVectorImplIPNS5_5ValueEEENS5_6DITypeE", "clang::CodeGen::CGDebugInfo::CollectCXXFriends(clang::CXXRecordDecl const*, llvm::DIFile, llvm::SmallVectorImpl<llvm::Value*>&, llvm::DIType)"},
    {"_ZN5clang7CodeGen11CGDebugInfo15CollectCXXBasesEPKNS_13CXXRecordDeclEN4llvm6DIFileERNS5_15SmallVectorImplIPNS5_5ValueEEENS5_6DITypeE", "clang::CodeGen::CGDebugInfo::CollectCXXBases(clang::CXXRecordDecl const*, llvm::DIFile, llvm::SmallVectorImpl<llvm::Value*>&, llvm::DIType)"},
    {"_ZN5clang7CodeGen11CGDebugInfo24getOrCreateVTablePtrTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::getOrCreateVTablePtrType(llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo13getVTableNameEPKNS_13CXXRecordDeclE", "clang::CodeGen::CGDebugInfo::getVTableName(clang::CXXRecordDecl const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo17CollectVTableInfoEPKNS_13CXXRecordDeclEN4llvm6DIFileERNS5_15SmallVectorImplIPNS5_5ValueEEE", "clang::CodeGen::CGDebugInfo::CollectVTableInfo(clang::CXXRecordDecl const*, llvm::DIFile, llvm::SmallVectorImpl<llvm::Value*>&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo21getOrCreateRecordTypeENS_8QualTypeENS_14SourceLocationE", "clang::CodeGen::CGDebugInfo::getOrCreateRecordType(clang::QualType, clang::SourceLocation)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_10RecordTypeE", "clang::CodeGen::CGDebugInfo::CreateType(clang::RecordType const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_14ObjCObjectTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::ObjCObjectType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_17ObjCInterfaceTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::ObjCInterfaceType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_7TagTypeE", "clang::CodeGen::CGDebugInfo::CreateType(clang::TagType const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo14CreateEnumTypeEPKNS_8EnumDeclE", "clang::CodeGen::CGDebugInfo::CreateEnumType(clang::EnumDecl const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_10VectorTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::VectorType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_9ArrayTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::ArrayType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_19LValueReferenceTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::LValueReferenceType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_19RValueReferenceTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::RValueReferenceType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo10CreateTypeEPKNS_17MemberPointerTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateType(clang::MemberPointerType const*, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo14CreateTypeNodeENS_8QualTypeEN4llvm6DIFileE", "clang::CodeGen::CGDebugInfo::CreateTypeNode(clang::QualType, llvm::DIFile)"},
    {"_ZN5clang7CodeGen11CGDebugInfo17EmitFunctionStartENS0_10GlobalDeclENS_8QualTypeEPN4llvm8FunctionERNS4_9IRBuilderILb0ENS4_14ConstantFolderENS4_24IRBuilderDefaultInserterILb0EEEEE", "clang::CodeGen::CGDebugInfo::EmitFunctionStart(clang::CodeGen::GlobalDecl, clang::QualType, llvm::Function*, llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo13EmitStopPointERN4llvm9IRBuilderILb0ENS2_14ConstantFolderENS2_24IRBuilderDefaultInserterILb0EEEEE", "clang::CodeGen::CGDebugInfo::EmitStopPoint(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo25UpdateLineDirectiveRegionERN4llvm9IRBuilderILb0ENS2_14ConstantFolderENS2_24IRBuilderDefaultInserterILb0EEEEE", "clang::CodeGen::CGDebugInfo::UpdateLineDirectiveRegion(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo15EmitRegionStartERN4llvm9IRBuilderILb0ENS2_14ConstantFolderENS2_24IRBuilderDefaultInserterILb0EEEEE", "clang::CodeGen::CGDebugInfo::EmitRegionStart(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo13EmitRegionEndERN4llvm9IRBuilderILb0ENS2_14ConstantFolderENS2_24IRBuilderDefaultInserterILb0EEEEE", "clang::CodeGen::CGDebugInfo::EmitRegionEnd(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo15EmitFunctionEndERN4llvm9IRBuilderILb0ENS2_14ConstantFolderENS2_24IRBuilderDefaultInserterILb0EEEEE", "clang::CodeGen::CGDebugInfo::EmitFunctionEnd(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo28EmitTypeForVarWithBlocksAttrEPKNS_9ValueDeclEPy", "clang::CodeGen::CGDebugInfo::EmitTypeForVarWithBlocksAttr(clang::ValueDecl const*, unsigned long long*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo11EmitDeclareEPKNS_7VarDeclEjPN4llvm5ValueERNS5_9IRBuilderILb0ENS5_14ConstantFolderENS5_24IRBuilderDefaultInserterILb0EEEEEb", "clang::CodeGen::CGDebugInfo::EmitDeclare(clang::VarDecl const*, unsigned int, llvm::Value*, llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, bool)"},
    {"_ZN5clang7CodeGen11CGDebugInfo11EmitDeclareEPKNS_7VarDeclEjPN4llvm5ValueERNS5_9IRBuilderILb0ENS5_14ConstantFolderENS5_24IRBuilderDefaultInserterILb0EEEEERKNS0_11CGBlockInfoE", "clang::CodeGen::CGDebugInfo::EmitDeclare(clang::VarDecl const*, unsigned int, llvm::Value*, llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::CodeGen::CGBlockInfo const&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo25EmitDeclareOfAutoVariableEPKNS_7VarDeclEPN4llvm5ValueERNS5_9IRBuilderILb0ENS5_14ConstantFolderENS5_24IRBuilderDefaultInserterILb0EEEEE", "clang::CodeGen::CGDebugInfo::EmitDeclareOfAutoVariable(clang::VarDecl const*, llvm::Value*, llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo33EmitDeclareOfBlockDeclRefVariableEPKNS_7VarDeclEPN4llvm5ValueERNS5_9IRBuilderILb0ENS5_14ConstantFolderENS5_24IRBuilderDefaultInserterILb0EEEEERKNS0_11CGBlockInfoE", "clang::CodeGen::CGDebugInfo::EmitDeclareOfBlockDeclRefVariable(clang::VarDecl const*, llvm::Value*, llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::CodeGen::CGBlockInfo const&)"},
    {"_ZN5clang7CodeGen11CGDebugInfo24EmitDeclareOfArgVariableEPKNS_7VarDeclEPN4llvm5ValueERNS5_9IRBuilderILb0ENS5_14ConstantFolderENS5_24IRBuilderDefaultInserterILb0EEEEEb", "clang::CodeGen::CGDebugInfo::EmitDeclareOfArgVariable(clang::VarDecl const*, llvm::Value*, llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, bool)"},
    {"_ZN5clang7CodeGen11CGDebugInfo18EmitGlobalVariableEPN4llvm14GlobalVariableEPKNS_7VarDeclE", "clang::CodeGen::CGDebugInfo::EmitGlobalVariable(llvm::GlobalVariable*, clang::VarDecl const*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo18EmitGlobalVariableEPN4llvm14GlobalVariableEPNS_17ObjCInterfaceDeclE", "clang::CodeGen::CGDebugInfo::EmitGlobalVariable(llvm::GlobalVariable*, clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang7CodeGen11CGDebugInfo18EmitGlobalVariableEPKNS_9ValueDeclEPN4llvm8ConstantE", "clang::CodeGen::CGDebugInfo::EmitGlobalVariable(clang::ValueDecl const*, llvm::Constant*)"},
    {"_ZNK5clang15ASTRecordLayout24getBaseClassOffsetInBitsEPKNS_13CXXRecordDeclE", "clang::ASTRecordLayout::getBaseClassOffsetInBits(clang::CXXRecordDecl const*) const"},
    {"_ZN4llvm8DenseMapIPKN5clang13NamespaceDeclENS_6WeakVHENS_12DenseMapInfoIS4_EENS6_IS5_EEE16FindAndConstructERKS4_", "llvm::DenseMap<clang::NamespaceDecl const*, llvm::WeakVH, llvm::DenseMapInfo<clang::NamespaceDecl const*>, llvm::DenseMapInfo<llvm::WeakVH>>::FindAndConstruct(clang::NamespaceDecl const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13NamespaceDeclENS_6WeakVHENS_12DenseMapInfoIS4_EENS6_IS5_EEE16InsertIntoBucketERKS4_RKS5_PSt4pairIS4_S5_E", "llvm::DenseMap<clang::NamespaceDecl const*, llvm::WeakVH, llvm::DenseMapInfo<clang::NamespaceDecl const*>, llvm::DenseMapInfo<llvm::WeakVH>>::InsertIntoBucket(clang::NamespaceDecl const* const&, llvm::WeakVH const&, std::pair<clang::NamespaceDecl const*, llvm::WeakVH>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13NamespaceDeclENS_6WeakVHENS_12DenseMapInfoIS4_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::NamespaceDecl const*, llvm::WeakVH, llvm::DenseMapInfo<clang::NamespaceDecl const*>, llvm::DenseMapInfo<llvm::WeakVH>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclENS_6WeakVHENS_12DenseMapInfoIS4_EENS6_IS5_EEE16FindAndConstructERKS4_", "llvm::DenseMap<clang::Decl const*, llvm::WeakVH, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::WeakVH>>::FindAndConstruct(clang::Decl const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclENS_6WeakVHENS_12DenseMapInfoIS4_EENS6_IS5_EEE16InsertIntoBucketERKS4_RKS5_PSt4pairIS4_S5_E", "llvm::DenseMap<clang::Decl const*, llvm::WeakVH, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::WeakVH>>::InsertIntoBucket(clang::Decl const* const&, llvm::WeakVH const&, std::pair<clang::Decl const*, llvm::WeakVH>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclENS_6WeakVHENS_12DenseMapInfoIS4_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::Decl const*, llvm::WeakVH, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::WeakVH>>::grow(unsigned int)"},
    {"_ZNSt6vectorIN4llvm10TrackingVHINS0_6MDNodeEEESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<llvm::TrackingVH<llvm::MDNode>, std::allocator<llvm::TrackingVH<llvm::MDNode>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::TrackingVH<llvm::MDNode>*, std::vector<llvm::TrackingVH<llvm::MDNode>, std::allocator<llvm::TrackingVH<llvm::MDNode>>>>, llvm::TrackingVH<llvm::MDNode> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang12FunctionDeclENS_6WeakVHENS_12DenseMapInfoIS4_EENS6_IS5_EEE16FindAndConstructERKS4_", "llvm::DenseMap<clang::FunctionDecl const*, llvm::WeakVH, llvm::DenseMapInfo<clang::FunctionDecl const*>, llvm::DenseMapInfo<llvm::WeakVH>>::FindAndConstruct(clang::FunctionDecl const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang12FunctionDeclENS_6WeakVHENS_12DenseMapInfoIS4_EENS6_IS5_EEE16InsertIntoBucketERKS4_RKS5_PSt4pairIS4_S5_E", "llvm::DenseMap<clang::FunctionDecl const*, llvm::WeakVH, llvm::DenseMapInfo<clang::FunctionDecl const*>, llvm::DenseMapInfo<llvm::WeakVH>>::InsertIntoBucket(clang::FunctionDecl const* const&, llvm::WeakVH const&, std::pair<clang::FunctionDecl const*, llvm::WeakVH>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang12FunctionDeclENS_6WeakVHENS_12DenseMapInfoIS4_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::FunctionDecl const*, llvm::WeakVH, llvm::DenseMapInfo<clang::FunctionDecl const*>, llvm::DenseMapInfo<llvm::WeakVH>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPvNS_6WeakVHENS_12DenseMapInfoIS1_EENS3_IS2_EEE16FindAndConstructERKS1_", "llvm::DenseMap<void*, llvm::WeakVH, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<llvm::WeakVH>>::FindAndConstruct(void* const&)"},
    {"_ZN4llvm8DenseMapIPvNS_6WeakVHENS_12DenseMapInfoIS1_EENS3_IS2_EEE16InsertIntoBucketERKS1_RKS2_PSt4pairIS1_S2_E", "llvm::DenseMap<void*, llvm::WeakVH, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<llvm::WeakVH>>::InsertIntoBucket(void* const&, llvm::WeakVH const&, std::pair<void*, llvm::WeakVH>*)"},
    {"_ZN4llvm8DenseMapIPvNS_6WeakVHENS_12DenseMapInfoIS1_EENS3_IS2_EEE4growEj", "llvm::DenseMap<void*, llvm::WeakVH, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<llvm::WeakVH>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKcNS_6WeakVHENS_12DenseMapInfoIS2_EENS4_IS3_EEE16FindAndConstructERKS2_", "llvm::DenseMap<char const*, llvm::WeakVH, llvm::DenseMapInfo<char const*>, llvm::DenseMapInfo<llvm::WeakVH>>::FindAndConstruct(char const* const&)"},
    {"_ZN4llvm8DenseMapIPKcNS_6WeakVHENS_12DenseMapInfoIS2_EENS4_IS3_EEE16InsertIntoBucketERKS2_RKS3_PSt4pairIS2_S3_E", "llvm::DenseMap<char const*, llvm::WeakVH, llvm::DenseMapInfo<char const*>, llvm::DenseMapInfo<llvm::WeakVH>>::InsertIntoBucket(char const* const&, llvm::WeakVH const&, std::pair<char const*, llvm::WeakVH>*)"},
    {"_ZN4llvm8DenseMapIPKcNS_6WeakVHENS_12DenseMapInfoIS2_EENS4_IS3_EEE4growEj", "llvm::DenseMap<char const*, llvm::WeakVH, llvm::DenseMapInfo<char const*>, llvm::DenseMapInfo<llvm::WeakVH>>::grow(unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunction8EmitDeclERKNS_4DeclE", "clang::CodeGen::CodeGenFunction::EmitDecl(clang::Decl const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction11EmitVarDeclERKNS_7VarDeclE", "clang::CodeGen::CodeGenFunction::EmitVarDecl(clang::VarDecl const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15EmitAutoVarDeclERKNS_7VarDeclEPFvRS1_S4_PN4llvm5ValueEE", "clang::CodeGen::CodeGenFunction::EmitAutoVarDecl(clang::VarDecl const&, void (*)(clang::CodeGen::CodeGenFunction&, clang::VarDecl const&, llvm::Value*))"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitStaticVarDeclERKNS_7VarDeclEN4llvm11GlobalValue12LinkageTypesE", "clang::CodeGen::CodeGenFunction::EmitStaticVarDecl(clang::VarDecl const&, llvm::GlobalValue::LinkageTypes)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19CreateStaticVarDeclERKNS_7VarDeclEPKcN4llvm11GlobalValue12LinkageTypesE", "clang::CodeGen::CodeGenFunction::CreateStaticVarDecl(clang::VarDecl const&, char const*, llvm::GlobalValue::LinkageTypes)"},
    {"_Z17GetStaticDeclNameRN5clang7CodeGen15CodeGenFunctionERKNS_7VarDeclEPKc", "GetStaticDeclName(clang::CodeGen::CodeGenFunction&, clang::VarDecl const&, char const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction29AddInitializerToStaticVarDeclERKNS_7VarDeclEPN4llvm14GlobalVariableE", "clang::CodeGen::CodeGenFunction::AddInitializerToStaticVarDecl(clang::VarDecl const&, llvm::GlobalVariable*)"},
    {"_ZNK5clang7CodeGen15CodeGenFunction22getByRefValueLLVMFieldEPKNS_9ValueDeclE", "clang::CodeGen::CodeGenFunction::getByRefValueLLVMField(clang::ValueDecl const*) const"},
    {"_ZN5clang7CodeGen15CodeGenFunction22BuildBlockByrefAddressEPN4llvm5ValueEPKNS_7VarDeclE", "clang::CodeGen::CodeGenFunction::BuildBlockByrefAddress(llvm::Value*, clang::VarDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14BuildByRefTypeEPKNS_7VarDeclE", "clang::CodeGen::CodeGenFunction::BuildByRefType(clang::VarDecl const*)"},
    {"_Z28emitStoresForInitAfterMemsetPN4llvm8ConstantEPNS_5ValueERNS_9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEEE", "emitStoresForInitAfterMemset(llvm::Constant*, llvm::Value*, llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12EmitParmDeclERKNS_7VarDeclEPN4llvm5ValueEb", "clang::CodeGen::CodeGenFunction::EmitParmDecl(clang::VarDecl const&, llvm::Value*, bool)"},
    {"_ZN12_GLOBAL__N_116CallBlockReleaseD1Ev", "(anonymous namespace)::CallBlockRelease::~CallBlockRelease()"},
    {"_ZN12_GLOBAL__N_116CallBlockReleaseD0Ev", "(anonymous namespace)::CallBlockRelease::~CallBlockRelease()"},
    {"_ZN12_GLOBAL__N_116CallBlockRelease4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallBlockRelease::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_119CallCleanupFunctionD1Ev", "(anonymous namespace)::CallCleanupFunction::~CallCleanupFunction()"},
    {"_ZN12_GLOBAL__N_119CallCleanupFunctionD0Ev", "(anonymous namespace)::CallCleanupFunction::~CallCleanupFunction()"},
    {"_ZN12_GLOBAL__N_119CallCleanupFunction4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallCleanupFunction::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_111CallVarDtorD1Ev", "(anonymous namespace)::CallVarDtor::~CallVarDtor()"},
    {"_ZN12_GLOBAL__N_111CallVarDtorD0Ev", "(anonymous namespace)::CallVarDtor::~CallVarDtor()"},
    {"_ZN12_GLOBAL__N_111CallVarDtor4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallVarDtor::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_113CallArrayDtorD1Ev", "(anonymous namespace)::CallArrayDtor::~CallArrayDtor()"},
    {"_ZN12_GLOBAL__N_113CallArrayDtorD0Ev", "(anonymous namespace)::CallArrayDtor::~CallArrayDtor()"},
    {"_ZN12_GLOBAL__N_113CallArrayDtor4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallArrayDtor::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_116CallStackRestoreD1Ev", "(anonymous namespace)::CallStackRestore::~CallStackRestore()"},
    {"_ZN12_GLOBAL__N_116CallStackRestoreD0Ev", "(anonymous namespace)::CallStackRestore::~CallStackRestore()"},
    {"_ZN12_GLOBAL__N_116CallStackRestore4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallStackRestore::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_Z35canEmitInitWithFewStoresAfterMemsetPN4llvm8ConstantERj", "canEmitInitWithFewStoresAfterMemset(llvm::Constant*, unsigned int&)"},
    {"_ZNK5clang4Decl7getAttrINS_11CleanupAttrEEEPT_v", "clang::CleanupAttr* clang::Decl::getAttr<clang::CleanupAttr>() const"},
    {"_ZN4llvm8DenseMapIPKN5clang9ValueDeclESt4pairIPKNS_4TypeEjENS_12DenseMapInfoIS4_EENSA_IS9_EEE16InsertIntoBucketERKS4_RKS9_PS5_IS4_S9_E", "llvm::DenseMap<clang::ValueDecl const*, std::pair<llvm::Type const*, unsigned int>, llvm::DenseMapInfo<clang::ValueDecl const*>, llvm::DenseMapInfo<std::pair<llvm::Type const*, unsigned int>>>::InsertIntoBucket(clang::ValueDecl const* const&, std::pair<llvm::Type const*, unsigned int> const&, std::pair<clang::ValueDecl const*, std::pair<llvm::Type const*, unsigned int>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang9ValueDeclESt4pairIPKNS_4TypeEjENS_12DenseMapInfoIS4_EENSA_IS9_EEE4growEj", "llvm::DenseMap<clang::ValueDecl const*, std::pair<llvm::Type const*, unsigned int>, llvm::DenseMapInfo<clang::ValueDecl const*>, llvm::DenseMapInfo<std::pair<llvm::Type const*, unsigned int>>>::grow(unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24EmitCXXGlobalVarDeclInitERKNS_7VarDeclEPN4llvm8ConstantE", "clang::CodeGen::CodeGenFunction::EmitCXXGlobalVarDeclInit(clang::VarDecl const&, llvm::Constant*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction29EmitCXXGlobalDtorRegistrationEPN4llvm8ConstantES4_", "clang::CodeGen::CodeGenFunction::EmitCXXGlobalDtorRegistration(llvm::Constant*, llvm::Constant*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitCXXGuardedInitERKNS_7VarDeclEPN4llvm14GlobalVariableE", "clang::CodeGen::CodeGenFunction::EmitCXXGuardedInit(clang::VarDecl const&, llvm::GlobalVariable*)"},
    {"_ZN5clang7CodeGen13CodeGenModule28EmitCXXGlobalVarDeclInitFuncEPKNS_7VarDeclEPN4llvm14GlobalVariableE", "clang::CodeGen::CodeGenModule::EmitCXXGlobalVarDeclInitFunc(clang::VarDecl const*, llvm::GlobalVariable*)"},
    {"_Z34CreateGlobalInitOrDestructFunctionRN5clang7CodeGen13CodeGenModuleEPKN4llvm12FunctionTypeENS3_9StringRefE", "CreateGlobalInitOrDestructFunction(clang::CodeGen::CodeGenModule&, llvm::FunctionType const*, llvm::StringRef)"},
    {"_ZN5clang7CodeGen15CodeGenFunction32GenerateCXXGlobalVarDeclInitFuncEPN4llvm8FunctionEPKNS_7VarDeclEPNS2_14GlobalVariableE", "clang::CodeGen::CodeGenFunction::GenerateCXXGlobalVarDeclInitFunc(llvm::Function*, clang::VarDecl const*, llvm::GlobalVariable*)"},
    {"_ZN5clang7CodeGen13CodeGenModule21EmitCXXGlobalInitFuncEv", "clang::CodeGen::CodeGenModule::EmitCXXGlobalInitFunc()"},
    {"_ZN5clang7CodeGen15CodeGenFunction25GenerateCXXGlobalInitFuncEPN4llvm8FunctionEPPNS2_8ConstantEj", "clang::CodeGen::CodeGenFunction::GenerateCXXGlobalInitFunc(llvm::Function*, llvm::Constant**, unsigned int)"},
    {"_ZN5clang7CodeGen13CodeGenModule21EmitCXXGlobalDtorFuncEv", "clang::CodeGen::CodeGenModule::EmitCXXGlobalDtorFunc()"},
    {"_ZN5clang7CodeGen15CodeGenFunction25GenerateCXXGlobalDtorFuncEPN4llvm8FunctionERKSt6vectorISt4pairINS2_6WeakVHEPNS2_8ConstantEESaISA_EE", "clang::CodeGen::CodeGenFunction::GenerateCXXGlobalDtorFunc(llvm::Function*, std::vector<std::pair<llvm::WeakVH, llvm::Constant*>, std::allocator<std::pair<llvm::WeakVH, llvm::Constant*>>> const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction31GenerateCXXAggrDestructorHelperEPKNS_17CXXDestructorDeclEPKNS_9ArrayTypeEPN4llvm5ValueE", "clang::CodeGen::CodeGenFunction::GenerateCXXAggrDestructorHelper(clang::CXXDestructorDecl const*, clang::ArrayType const*, llvm::Value*)"},
    {"_ZN4llvm25array_pod_sort_comparatorISt4pairIN5clang7CodeGen16OrderGlobalInitsEPNS_8FunctionEEEEiPKvS9_", "int llvm::array_pod_sort_comparator<std::pair<clang::CodeGen::OrderGlobalInits, llvm::Function*>>(void const*, void const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule15AddCXXDtorEntryEPN4llvm8ConstantES4_", "clang::CodeGen::CodeGenModule::AddCXXDtorEntry(llvm::Constant*, llvm::Constant*)"},
    {"_ZNK5clang4Decl7getAttrINS_16InitPriorityAttrEEEPT_v", "clang::InitPriorityAttr* clang::Decl::getAttr<clang::InitPriorityAttr>() const"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateCallEPNS_5ValueERKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateCall(llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairIN5clang7CodeGen16OrderGlobalInitsEPNS_8FunctionEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<clang::CodeGen::OrderGlobalInits, llvm::Function*>, false>::grow(unsigned long)"},
    {"_ZNSt6vectorISt4pairIN4llvm6WeakVHEPNS1_8ConstantEESaIS5_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS5_S7_EERKS5_", "std::vector<std::pair<llvm::WeakVH, llvm::Constant*>, std::allocator<std::pair<llvm::WeakVH, llvm::Constant*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::WeakVH, llvm::Constant*>*, std::vector<std::pair<llvm::WeakVH, llvm::Constant*>, std::allocator<std::pair<llvm::WeakVH, llvm::Constant*>>>>, std::pair<llvm::WeakVH, llvm::Constant*> const&)"},
    {"_ZNSt15__copy_backwardILb0ESt26random_access_iterator_tagE8__copy_bIPSt4pairIN4llvm6WeakVHEPNS4_8ConstantEES9_EET0_T_SB_SA_", "std::pair<llvm::WeakVH, llvm::Constant*>* std::__copy_backward<false, std::random_access_iterator_tag>::__copy_b<std::pair<llvm::WeakVH, llvm::Constant*>*, std::pair<llvm::WeakVH, llvm::Constant*>*>(std::pair<llvm::WeakVH, llvm::Constant*>*, std::pair<llvm::WeakVH, llvm::Constant*>*, std::pair<llvm::WeakVH, llvm::Constant*>*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26getUnwindResumeOrRethrowFnEv", "clang::CodeGen::CodeGenFunction::getUnwindResumeOrRethrowFn()"},
    {"_ZN5clang7CodeGen13EHPersonality3getERKNS_11LangOptionsE", "clang::CodeGen::EHPersonality::get(clang::LangOptions const&)"},
    {"_ZN5clang7CodeGen13CodeGenModule19SimplifyPersonalityEv", "clang::CodeGen::CodeGenModule::SimplifyPersonality()"},
    {"_Z25PersonalityHasOnlyCXXUsesPN4llvm8ConstantE", "PersonalityHasOnlyCXXUses(llvm::Constant*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16getExceptionSlotEv", "clang::CodeGen::CodeGenFunction::getExceptionSlot()"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitCXXThrowExprEPKNS_12CXXThrowExprE", "clang::CodeGen::CodeGenFunction::EmitCXXThrowExpr(clang::CXXThrowExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15EmitStartEHSpecEPKNS_4DeclE", "clang::CodeGen::CodeGenFunction::EmitStartEHSpec(clang::Decl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction13EmitEndEHSpecEPKNS_4DeclE", "clang::CodeGen::CodeGenFunction::EmitEndEHSpec(clang::Decl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitCXXTryStmtERKNS_10CXXTryStmtE", "clang::CodeGen::CodeGenFunction::EmitCXXTryStmt(clang::CXXTryStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15EnterCXXTryStmtERKNS_10CXXTryStmtEb", "clang::CodeGen::CodeGenFunction::EnterCXXTryStmt(clang::CXXTryStmt const&, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14ExitCXXTryStmtERKNS_10CXXTryStmtEb", "clang::CodeGen::CodeGenFunction::ExitCXXTryStmt(clang::CXXTryStmt const&, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17getInvokeDestImplEv", "clang::CodeGen::CodeGenFunction::getInvokeDestImpl()"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitLandingPadEv", "clang::CodeGen::CodeGenFunction::EmitLandingPad()"},
    {"_ZN5clang7CodeGen15CodeGenFunction22getTerminateLandingPadEv", "clang::CodeGen::CodeGenFunction::getTerminateLandingPad()"},
    {"_Z22getOpaquePersonalityFnRN5clang7CodeGen13CodeGenModuleERKNS0_13EHPersonalityE", "getOpaquePersonalityFn(clang::CodeGen::CodeGenModule&, clang::CodeGen::EHPersonality const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19getTerminateHandlerEv", "clang::CodeGen::CodeGenFunction::getTerminateHandler()"},
    {"_ZN5clang7CodeGen15CodeGenFunction14getRethrowDestEv", "clang::CodeGen::CodeGenFunction::getRethrowDest()"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EnterFinallyBlockEPKNS_4StmtEPN4llvm8ConstantES7_S7_", "clang::CodeGen::CodeGenFunction::EnterFinallyBlock(clang::Stmt const*, llvm::Constant*, llvm::Constant*, llvm::Constant*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16ExitFinallyBlockERNS1_11FinallyInfoE", "clang::CodeGen::CodeGenFunction::ExitFinallyBlock(clang::CodeGen::CodeGenFunction::FinallyInfo&)"},
    {"_Z14getTerminateFnRN5clang7CodeGen15CodeGenFunctionE", "getTerminateFn(clang::CodeGen::CodeGenFunction&)"},
    {"_ZN12_GLOBAL__N_114PerformFinallyD1Ev", "(anonymous namespace)::PerformFinally::~PerformFinally()"},
    {"_ZN12_GLOBAL__N_114PerformFinallyD0Ev", "(anonymous namespace)::PerformFinally::~PerformFinally()"},
    {"_ZN12_GLOBAL__N_114PerformFinally4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::PerformFinally::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_122CallEndCatchForFinallyD1Ev", "(anonymous namespace)::CallEndCatchForFinally::~CallEndCatchForFinally()"},
    {"_ZN12_GLOBAL__N_122CallEndCatchForFinallyD0Ev", "(anonymous namespace)::CallEndCatchForFinally::~CallEndCatchForFinally()"},
    {"_ZN12_GLOBAL__N_122CallEndCatchForFinally4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallEndCatchForFinally::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_111CallRethrowD1Ev", "(anonymous namespace)::CallRethrow::~CallRethrow()"},
    {"_ZN12_GLOBAL__N_111CallRethrowD0Ev", "(anonymous namespace)::CallRethrow::~CallRethrow()"},
    {"_ZN12_GLOBAL__N_111CallRethrow4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallRethrow::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_Z14CallBeginCatchRN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueEb", "CallBeginCatch(clang::CodeGen::CodeGenFunction&, llvm::Value*, bool)"},
    {"_Z14InitCatchParamRN5clang7CodeGen15CodeGenFunctionERKNS_7VarDeclEPN4llvm5ValueE", "InitCatchParam(clang::CodeGen::CodeGenFunction&, clang::VarDecl const&, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_112CallEndCatchD1Ev", "(anonymous namespace)::CallEndCatch::~CallEndCatch()"},
    {"_ZN12_GLOBAL__N_112CallEndCatchD0Ev", "(anonymous namespace)::CallEndCatch::~CallEndCatch()"},
    {"_ZN12_GLOBAL__N_112CallEndCatch4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallEndCatch::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN5clang7CodeGen12EHScopeStack19ConditionalCleanup1IN12_GLOBAL__N_113FreeExceptionEPN4llvm5ValueEED1Ev", "clang::CodeGen::EHScopeStack::ConditionalCleanup1<(anonymous namespace)::FreeException, llvm::Value*>::~ConditionalCleanup1()"},
    {"_ZN5clang7CodeGen12EHScopeStack19ConditionalCleanup1IN12_GLOBAL__N_113FreeExceptionEPN4llvm5ValueEED0Ev", "clang::CodeGen::EHScopeStack::ConditionalCleanup1<(anonymous namespace)::FreeException, llvm::Value*>::~ConditionalCleanup1()"},
    {"_ZN5clang7CodeGen12EHScopeStack19ConditionalCleanup1IN12_GLOBAL__N_113FreeExceptionEPN4llvm5ValueEE4EmitERNS0_15CodeGenFunctionEb", "clang::CodeGen::EHScopeStack::ConditionalCleanup1<(anonymous namespace)::FreeException, llvm::Value*>::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_113FreeException4EmitERN5clang7CodeGen15CodeGenFunctionEbPN4llvm5ValueE", "(anonymous namespace)::FreeException::Emit(clang::CodeGen::CodeGenFunction&, bool, llvm::Value*)"},
    {"_ZN5clang7CodeGen12EHScopeStack21UnconditionalCleanup1IN12_GLOBAL__N_113FreeExceptionEPN4llvm5ValueEED1Ev", "clang::CodeGen::EHScopeStack::UnconditionalCleanup1<(anonymous namespace)::FreeException, llvm::Value*>::~UnconditionalCleanup1()"},
    {"_ZN5clang7CodeGen12EHScopeStack21UnconditionalCleanup1IN12_GLOBAL__N_113FreeExceptionEPN4llvm5ValueEED0Ev", "clang::CodeGen::EHScopeStack::UnconditionalCleanup1<(anonymous namespace)::FreeException, llvm::Value*>::~UnconditionalCleanup1()"},
    {"_ZN5clang7CodeGen12EHScopeStack21UnconditionalCleanup1IN12_GLOBAL__N_113FreeExceptionEPN4llvm5ValueEE4EmitERNS0_15CodeGenFunctionEb", "clang::CodeGen::EHScopeStack::UnconditionalCleanup1<(anonymous namespace)::FreeException, llvm::Value*>::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE12CreateInvokeEPNS_5ValueEPNS_10BasicBlockES8_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateInvoke(llvm::Value*, llvm::BasicBlock*, llvm::BasicBlock*, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19getUnreachableBlockEv", "clang::CodeGen::CodeGenFunction::getUnreachableBlock()"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE13CreateInvoke3EPNS_5ValueEPNS_10BasicBlockES8_S6_S6_S6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateInvoke3(llvm::Value*, llvm::BasicBlock*, llvm::BasicBlock*, llvm::Value*, llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang7CodeGen12EHCatchScope7HandlerELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::CodeGen::EHCatchScope::Handler, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIPNS_5ValueEN5clang7CodeGen15CodeGenFunction10UnwindDestENS_12DenseMapInfoIS2_EENS7_IS6_EEE16InsertIntoBucketERKS2_RKS6_PSt4pairIS2_S6_E", "llvm::DenseMap<llvm::Value*, clang::CodeGen::CodeGenFunction::UnwindDest, llvm::DenseMapInfo<llvm::Value*>, llvm::DenseMapInfo<clang::CodeGen::CodeGenFunction::UnwindDest>>::InsertIntoBucket(llvm::Value* const&, clang::CodeGen::CodeGenFunction::UnwindDest const&, std::pair<llvm::Value*, clang::CodeGen::CodeGenFunction::UnwindDest>*)"},
    {"_ZN4llvm8DenseMapIPNS_5ValueEN5clang7CodeGen15CodeGenFunction10UnwindDestENS_12DenseMapInfoIS2_EENS7_IS6_EEE4growEj", "llvm::DenseMap<llvm::Value*, clang::CodeGen::CodeGenFunction::UnwindDest, llvm::DenseMapInfo<llvm::Value*>, llvm::DenseMapInfo<clang::CodeGen::CodeGenFunction::UnwindDest>>::grow(unsigned int)"},
    {"_ZN5clang7CodeGen19DominatingLLVMValue4saveERNS0_15CodeGenFunctionEPN4llvm5ValueE", "clang::CodeGen::DominatingLLVMValue::save(clang::CodeGen::CodeGenFunction&, llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitCastToVoidPtrEPN4llvm5ValueE", "clang::CodeGen::CodeGenFunction::EmitCastToVoidPtr(llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16CreateTempAllocaEPKN4llvm4TypeERKNS2_5TwineE", "clang::CodeGen::CodeGenFunction::CreateTempAlloca(llvm::Type const*, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14InitTempAllocaEPN4llvm10AllocaInstEPNS2_5ValueE", "clang::CodeGen::CodeGenFunction::InitTempAlloca(llvm::AllocaInst*, llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12CreateIRTempENS_8QualTypeERKN4llvm5TwineE", "clang::CodeGen::CodeGenFunction::CreateIRTemp(clang::QualType, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction13CreateMemTempENS_8QualTypeERKN4llvm5TwineE", "clang::CodeGen::CodeGenFunction::CreateMemTemp(clang::QualType, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EvaluateExprAsBoolEPKNS_4ExprE", "clang::CodeGen::CodeGenFunction::EvaluateExprAsBool(clang::Expr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15EmitIgnoredExprEPKNS_4ExprE", "clang::CodeGen::CodeGenFunction::EmitIgnoredExpr(clang::Expr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction11EmitAnyExprEPKNS_4ExprENS0_12AggValueSlotEb", "clang::CodeGen::CodeGenFunction::EmitAnyExpr(clang::Expr const*, clang::CodeGen::AggValueSlot, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction10EmitLValueEPKNS_4ExprE", "clang::CodeGen::CodeGenFunction::EmitLValue(clang::Expr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitAnyExprToTempEPKNS_4ExprE", "clang::CodeGen::CodeGenFunction::EmitAnyExprToTemp(clang::Expr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitAnyExprToMemEPKNS_4ExprEPN4llvm5ValueEbb", "clang::CodeGen::CodeGenFunction::EmitAnyExprToMem(clang::Expr const*, llvm::Value*, bool, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction22EmitStoreThroughLValueENS0_6RValueENS0_6LValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitStoreThroughLValue(clang::CodeGen::RValue, clang::CodeGen::LValue, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26EmitReferenceBindingToExprEPKNS_4ExprEPKNS_9NamedDeclE", "clang::CodeGen::CodeGenFunction::EmitReferenceBindingToExpr(clang::Expr const*, clang::NamedDecl const*)"},
    {"_Z27EmitExprForReferenceBindingRN5clang7CodeGen15CodeGenFunctionEPKNS_4ExprERPN4llvm5ValueERPKNS_17CXXDestructorDeclEPKNS_9NamedDeclE", "EmitExprForReferenceBinding(clang::CodeGen::CodeGenFunction&, clang::Expr const*, llvm::Value*&, clang::CXXDestructorDecl const*&, clang::NamedDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18getAccessedFieldNoEjPKN4llvm8ConstantE", "clang::CodeGen::CodeGenFunction::getAccessedFieldNo(unsigned int, llvm::Constant const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction9EmitCheckEPN4llvm5ValueEj", "clang::CodeGen::CodeGenFunction::EmitCheck(llvm::Value*, unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunction9getTrapBBEv", "clang::CodeGen::CodeGenFunction::getTrapBB()"},
    {"_ZN5clang7CodeGen15CodeGenFunction24EmitComplexPrePostIncDecEPKNS_13UnaryOperatorENS0_6LValueEbb", "clang::CodeGen::CodeGenFunction::EmitComplexPrePostIncDec(clang::UnaryOperator const*, clang::CodeGen::LValue, bool, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14GetUndefRValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::GetUndefRValue(clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21EmitUnsupportedRValueEPKNS_4ExprEPKc", "clang::CodeGen::CodeGenFunction::EmitUnsupportedRValue(clang::Expr const*, char const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21EmitUnsupportedLValueEPKNS_4ExprEPKc", "clang::CodeGen::CodeGenFunction::EmitUnsupportedLValue(clang::Expr const*, char const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitCheckedLValueEPKNS_4ExprE", "clang::CodeGen::CodeGenFunction::EmitCheckedLValue(clang::Expr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction22EmitObjCSelectorLValueEPKNS_16ObjCSelectorExprE", "clang::CodeGen::CodeGenFunction::EmitObjCSelectorLValue(clang::ObjCSelectorExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24EmitBinaryOperatorLValueEPKNS_14BinaryOperatorE", "clang::CodeGen::CodeGenFunction::EmitBinaryOperatorLValue(clang::BinaryOperator const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitCallExprLValueEPKNS_8CallExprE", "clang::CodeGen::CodeGenFunction::EmitCallExprLValue(clang::CallExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19EmitVAArgExprLValueEPKNS_9VAArgExprE", "clang::CodeGen::CodeGenFunction::EmitVAArgExprLValue(clang::VAArgExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitDeclRefLValueEPKNS_11DeclRefExprE", "clang::CodeGen::CodeGenFunction::EmitDeclRefLValue(clang::DeclRefExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20EmitPredefinedLValueEPKNS_14PredefinedExprE", "clang::CodeGen::CodeGenFunction::EmitPredefinedLValue(clang::PredefinedExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction23EmitStringLiteralLValueEPKNS_13StringLiteralE", "clang::CodeGen::CodeGenFunction::EmitStringLiteralLValue(clang::StringLiteral const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24EmitObjCEncodeExprLValueEPKNS_14ObjCEncodeExprE", "clang::CodeGen::CodeGenFunction::EmitObjCEncodeExprLValue(clang::ObjCEncodeExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction22EmitBlockDeclRefLValueEPKNS_16BlockDeclRefExprE", "clang::CodeGen::CodeGenFunction::EmitBlockDeclRefLValue(clang::BlockDeclRefExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction22EmitCXXConstructLValueEPKNS_16CXXConstructExprE", "clang::CodeGen::CodeGenFunction::EmitCXXConstructLValue(clang::CXXConstructExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26EmitCXXBindTemporaryLValueEPKNS_20CXXBindTemporaryExprE", "clang::CodeGen::CodeGenFunction::EmitCXXBindTemporaryLValue(clang::CXXBindTemporaryExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction28EmitNullInitializationLValueEPKNS_22CXXScalarValueInitExprE", "clang::CodeGen::CodeGenFunction::EmitNullInitializationLValue(clang::CXXScalarValueInitExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19EmitCXXTypeidLValueEPKNS_13CXXTypeidExprE", "clang::CodeGen::CodeGenFunction::EmitCXXTypeidLValue(clang::CXXTypeidExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction25EmitObjCMessageExprLValueEPKNS_15ObjCMessageExprE", "clang::CodeGen::CodeGenFunction::EmitObjCMessageExprLValue(clang::ObjCMessageExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21EmitObjCIvarRefLValueEPKNS_15ObjCIvarRefExprE", "clang::CodeGen::CodeGenFunction::EmitObjCIvarRefLValue(clang::ObjCIvarRefExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitStmtExprLValueEPKNS_8StmtExprE", "clang::CodeGen::CodeGenFunction::EmitStmtExprLValue(clang::StmtExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitUnaryOpLValueEPKNS_13UnaryOperatorE", "clang::CodeGen::CodeGenFunction::EmitUnaryOpLValue(clang::UnaryOperator const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction22EmitArraySubscriptExprEPKNS_18ArraySubscriptExprE", "clang::CodeGen::CodeGenFunction::EmitArraySubscriptExpr(clang::ArraySubscriptExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24EmitExtVectorElementExprEPKNS_20ExtVectorElementExprE", "clang::CodeGen::CodeGenFunction::EmitExtVectorElementExpr(clang::ExtVectorElementExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitMemberExprEPKNS_10MemberExprE", "clang::CodeGen::CodeGenFunction::EmitMemberExpr(clang::MemberExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction25EmitCompoundLiteralLValueEPKNS_19CompoundLiteralExprE", "clang::CodeGen::CodeGenFunction::EmitCompoundLiteralLValue(clang::CompoundLiteralExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction29EmitConditionalOperatorLValueEPKNS_19ConditionalOperatorE", "clang::CodeGen::CodeGenFunction::EmitConditionalOperatorLValue(clang::ConditionalOperator const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitCastLValueEPKNS_8CastExprE", "clang::CodeGen::CodeGenFunction::EmitCastLValue(clang::CastExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitLoadOfScalarEPN4llvm5ValueEbjNS_8QualTypeEPNS2_6MDNodeE", "clang::CodeGen::CodeGenFunction::EmitLoadOfScalar(llvm::Value*, bool, unsigned int, clang::QualType, llvm::MDNode*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitFromMemoryEPN4llvm5ValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitFromMemory(llvm::Value*, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12EmitToMemoryEPN4llvm5ValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitToMemory(llvm::Value*, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitStoreOfScalarEPN4llvm5ValueES4_bjNS_8QualTypeEPNS2_6MDNodeE", "clang::CodeGen::CodeGenFunction::EmitStoreOfScalar(llvm::Value*, llvm::Value*, bool, unsigned int, clang::QualType, llvm::MDNode*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitLoadOfLValueENS0_6LValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitLoadOfLValue(clang::CodeGen::LValue, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction32EmitLoadOfExtVectorElementLValueENS0_6LValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitLoadOfExtVectorElementLValue(clang::CodeGen::LValue, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24EmitLoadOfBitfieldLValueENS0_6LValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitLoadOfBitfieldLValue(clang::CodeGen::LValue, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction40EmitStoreThroughExtVectorComponentLValueENS0_6RValueENS0_6LValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitStoreThroughExtVectorComponentLValue(clang::CodeGen::RValue, clang::CodeGen::LValue, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction30EmitStoreThroughBitfieldLValueENS0_6RValueENS0_6LValueENS_8QualTypeEPPN4llvm5ValueE", "clang::CodeGen::CodeGenFunction::EmitStoreThroughBitfieldLValue(clang::CodeGen::RValue, clang::CodeGen::LValue, clang::QualType, llvm::Value**)"},
    {"_Z23EmitGlobalVarDeclLValueRN5clang7CodeGen15CodeGenFunctionEPKNS_4ExprEPKNS_7VarDeclE", "EmitGlobalVarDeclLValue(clang::CodeGen::CodeGenFunction&, clang::Expr const*, clang::VarDecl const*)"},
    {"_Z20setObjCGCLValueClassRKN5clang10ASTContextEPKNS_4ExprERNS_7CodeGen6LValueE", "setObjCGCLValueClass(clang::ASTContext const&, clang::Expr const*, clang::CodeGen::LValue&)"},
    {"_Z22EmitFunctionDeclLValueRN5clang7CodeGen15CodeGenFunctionEPKNS_4ExprEPKNS_12FunctionDeclE", "EmitFunctionDeclLValue(clang::CodeGen::CodeGenFunction&, clang::Expr const*, clang::FunctionDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitLValueForFieldEPN4llvm5ValueEPKNS_9FieldDeclEj", "clang::CodeGen::CodeGenFunction::EmitLValueForField(llvm::Value*, clang::FieldDecl const*, unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21EmitLValueForBitfieldEPN4llvm5ValueEPKNS_9FieldDeclEj", "clang::CodeGen::CodeGenFunction::EmitLValueForBitfield(llvm::Value*, clang::FieldDecl const*, unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunction28EmitLValueForAnonRecordFieldEPN4llvm5ValueEPKNS_17IndirectFieldDeclEj", "clang::CodeGen::CodeGenFunction::EmitLValueForAnonRecordField(llvm::Value*, clang::IndirectFieldDecl const*, unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunction32EmitLValueForFieldInitializationEPN4llvm5ValueEPKNS_9FieldDeclEj", "clang::CodeGen::CodeGenFunction::EmitLValueForFieldInitialization(llvm::Value*, clang::FieldDecl const*, unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12EmitCallExprEPKNS_8CallExprENS0_15ReturnValueSlotE", "clang::CodeGen::CodeGenFunction::EmitCallExpr(clang::CallExpr const*, clang::CodeGen::ReturnValueSlot)"},
    {"_ZN5clang7CodeGen15CodeGenFunction8EmitCallENS_8QualTypeEPN4llvm5ValueENS0_15ReturnValueSlotENS_17ConstExprIteratorES7_PKNS_4DeclE", "clang::CodeGen::CodeGenFunction::EmitCall(clang::QualType, llvm::Value*, clang::CodeGen::ReturnValueSlot, clang::ConstExprIterator, clang::ConstExprIterator, clang::Decl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction33EmitPointerToDataMemberBinaryExprEPKNS_14BinaryOperatorE", "clang::CodeGen::CodeGenFunction::EmitPointerToDataMemberBinaryExpr(clang::BinaryOperator const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitIvarOffsetEPKNS_17ObjCInterfaceDeclEPKNS_12ObjCIvarDeclE", "clang::CodeGen::CodeGenFunction::EmitIvarOffset(clang::ObjCInterfaceDecl const*, clang::ObjCIvarDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitLValueForIvarENS_8QualTypeEPN4llvm5ValueEPKNS_12ObjCIvarDeclEj", "clang::CodeGen::CodeGenFunction::EmitLValueForIvar(clang::QualType, llvm::Value*, clang::ObjCIvarDecl const*, unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIN12_GLOBAL__N_119SubobjectAdjustmentEE9push_backERKS2_", "llvm::SmallVectorImpl<(anonymous namespace)::SubobjectAdjustment>::push_back((anonymous namespace)::SubobjectAdjustment const&)"},
    {"_Z24CreateReferenceTemporaryRN5clang7CodeGen15CodeGenFunctionENS_8QualTypeEPKNS_9NamedDeclE", "CreateReferenceTemporary(clang::CodeGen::CodeGenFunction&, clang::QualType, clang::NamedDecl const*)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE17CreateInBoundsGEPIPPNS_5ValueEEES7_S7_T_S9_RKNS_5TwineE", "llvm::Value* llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateInBoundsGEP<llvm::Value**>(llvm::Value*, llvm::Value**, llvm::Value**, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12EmitCallArgsINS_17FunctionProtoTypeEEEvRN4llvm11SmallVectorISt4pairINS0_6RValueENS_8QualTypeEELj16EEEPKT_NS_17ConstExprIteratorESF_", "void clang::CodeGen::CodeGenFunction::EmitCallArgs<clang::FunctionProtoType>(llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u>&, clang::FunctionProtoType const*, clang::ConstExprIterator, clang::ConstExprIterator)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ExprENS1_7CodeGen6LValueENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::Expr const*, clang::CodeGen::LValue, llvm::DenseMapInfo<clang::Expr const*>, llvm::DenseMapInfo<clang::CodeGen::LValue>>::InsertIntoBucket(clang::Expr const* const&, clang::CodeGen::LValue const&, std::pair<clang::Expr const*, clang::CodeGen::LValue>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ExprENS1_7CodeGen6LValueENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::Expr const*, clang::CodeGen::LValue, llvm::DenseMapInfo<clang::Expr const*>, llvm::DenseMapInfo<clang::CodeGen::LValue>>::grow(unsigned int)"},
    {"_ZN4llvm11SmallVectorIPNS_8ConstantELj4EEC2EjRKS2_", "llvm::SmallVector<llvm::Constant*, 4u>::SmallVector(unsigned int, llvm::Constant* const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction11EmitAggExprEPKNS_4ExprENS0_12AggValueSlotEb", "clang::CodeGen::CodeGenFunction::EmitAggExpr(clang::Expr const*, clang::CodeGen::AggValueSlot, bool)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_114AggExprEmitterEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::AggExprEmitter, void>::Visit(clang::Stmt*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19EmitAggExprToLValueEPKNS_4ExprE", "clang::CodeGen::CodeGenFunction::EmitAggExprToLValue(clang::Expr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitAggregateCopyEPN4llvm5ValueES4_NS_8QualTypeEb", "clang::CodeGen::CodeGenFunction::EmitAggregateCopy(llvm::Value*, llvm::Value*, clang::QualType, bool)"},
    {"_ZN12_GLOBAL__N_114AggExprEmitter13VisitCallExprEPKN5clang8CallExprE", "(anonymous namespace)::AggExprEmitter::VisitCallExpr(clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_114AggExprEmitter17EmitFinalDestCopyEPKN5clang4ExprENS1_7CodeGen6LValueEb", "(anonymous namespace)::AggExprEmitter::EmitFinalDestCopy(clang::Expr const*, clang::CodeGen::LValue, bool)"},
    {"_ZN12_GLOBAL__N_114AggExprEmitter10EmitGCMoveEPKN5clang4ExprENS1_7CodeGen6RValueE", "(anonymous namespace)::AggExprEmitter::EmitGCMove(clang::Expr const*, clang::CodeGen::RValue)"},
    {"_ZN12_GLOBAL__N_114AggExprEmitter26EmitInitializationToLValueEPN5clang4ExprENS1_7CodeGen6LValueENS1_8QualTypeE", "(anonymous namespace)::AggExprEmitter::EmitInitializationToLValue(clang::Expr*, clang::CodeGen::LValue, clang::QualType)"},
    {"_ZN12_GLOBAL__N_114AggExprEmitter30EmitNullInitializationToLValueEN5clang7CodeGen6LValueENS1_8QualTypeE", "(anonymous namespace)::AggExprEmitter::EmitNullInitializationToLValue(clang::CodeGen::LValue, clang::QualType)"},
    {"_Z12isSimpleZeroPKN5clang4ExprERNS_7CodeGen15CodeGenFunctionE", "isSimpleZero(clang::Expr const*, clang::CodeGen::CodeGenFunction&)"},
    {"_ZN12_GLOBAL__N_114AggExprEmitter13VisitCastExprEPN5clang8CastExprE", "(anonymous namespace)::AggExprEmitter::VisitCastExpr(clang::CastExpr*)"},
    {"_Z24GetNumNonZeroBytesInInitPKN5clang4ExprERNS_7CodeGen15CodeGenFunctionE", "GetNumNonZeroBytesInInit(clang::Expr const*, clang::CodeGen::CodeGenFunction&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitCXXMemberCallEPKNS_13CXXMethodDeclEPN4llvm5ValueENS0_15ReturnValueSlotES7_S7_NS_17ConstExprIteratorES9_", "clang::CodeGen::CodeGenFunction::EmitCXXMemberCall(clang::CXXMethodDecl const*, llvm::Value*, clang::CodeGen::ReturnValueSlot, llvm::Value*, llvm::Value*, clang::ConstExprIterator, clang::ConstExprIterator)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21EmitCXXMemberCallExprEPKNS_17CXXMemberCallExprENS0_15ReturnValueSlotE", "clang::CodeGen::CodeGenFunction::EmitCXXMemberCallExpr(clang::CXXMemberCallExpr const*, clang::CodeGen::ReturnValueSlot)"},
    {"_ZN5clang7CodeGen15CodeGenFunction28EmitCXXMemberPointerCallExprEPKNS_17CXXMemberCallExprENS0_15ReturnValueSlotE", "clang::CodeGen::CodeGenFunction::EmitCXXMemberPointerCallExpr(clang::CXXMemberCallExpr const*, clang::CodeGen::ReturnValueSlot)"},
    {"_Z34canDevirtualizeMemberFunctionCallsRN5clang10ASTContextEPKNS_4ExprEPKNS_13CXXMethodDeclE", "canDevirtualizeMemberFunctionCalls(clang::ASTContext&, clang::Expr const*, clang::CXXMethodDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction29EmitCXXOperatorMemberCallExprEPKNS_19CXXOperatorCallExprEPKNS_13CXXMethodDeclENS0_15ReturnValueSlotE", "clang::CodeGen::CodeGenFunction::EmitCXXOperatorMemberCallExpr(clang::CXXOperatorCallExpr const*, clang::CXXMethodDecl const*, clang::CodeGen::ReturnValueSlot)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20EmitCXXConstructExprEPKNS_16CXXConstructExprENS0_12AggValueSlotE", "clang::CodeGen::CodeGenFunction::EmitCXXConstructExpr(clang::CXXConstructExpr const*, clang::CodeGen::AggValueSlot)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26EmitSynthesizedCXXCopyCtorEPN4llvm5ValueES4_PKNS_4ExprE", "clang::CodeGen::CodeGenFunction::EmitSynthesizedCXXCopyCtor(llvm::Value*, llvm::Value*, clang::Expr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction23EmitNewArrayInitializerEPKNS_10CXXNewExprEPN4llvm5ValueES7_", "clang::CodeGen::CodeGenFunction::EmitNewArrayInitializer(clang::CXXNewExpr const*, llvm::Value*, llvm::Value*)"},
    {"_Z23StoreAnyExprIntoOneUnitRN5clang7CodeGen15CodeGenFunctionEPKNS_10CXXNewExprEPN4llvm5ValueE", "StoreAnyExprIntoOneUnit(clang::CodeGen::CodeGenFunction&, clang::CXXNewExpr const*, llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitCXXNewExprEPKNS_10CXXNewExprE", "clang::CodeGen::CodeGenFunction::EmitCXXNewExpr(clang::CXXNewExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitDeleteCallEPKNS_12FunctionDeclEPN4llvm5ValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitDeleteCall(clang::FunctionDecl const*, llvm::Value*, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitCXXDeleteExprEPKNS_13CXXDeleteExprE", "clang::CodeGen::CodeGenFunction::EmitCXXDeleteExpr(clang::CXXDeleteExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitCXXTypeidExprEPKNS_13CXXTypeidExprE", "clang::CodeGen::CodeGenFunction::EmitCXXTypeidExpr(clang::CXXTypeidExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15EmitDynamicCastEPN4llvm5ValueEPKNS_18CXXDynamicCastExprE", "clang::CodeGen::CodeGenFunction::EmitDynamicCast(llvm::Value*, clang::CXXDynamicCastExpr const*)"},
    {"_ZN12_GLOBAL__N_116CallObjectDeleteD1Ev", "(anonymous namespace)::CallObjectDelete::~CallObjectDelete()"},
    {"_ZN12_GLOBAL__N_116CallObjectDeleteD0Ev", "(anonymous namespace)::CallObjectDelete::~CallObjectDelete()"},
    {"_ZN12_GLOBAL__N_116CallObjectDelete4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallObjectDelete::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_115CallArrayDeleteD1Ev", "(anonymous namespace)::CallArrayDelete::~CallArrayDelete()"},
    {"_ZN12_GLOBAL__N_115CallArrayDeleteD0Ev", "(anonymous namespace)::CallArrayDelete::~CallArrayDelete()"},
    {"_ZN12_GLOBAL__N_115CallArrayDelete4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallArrayDelete::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_130CallDeleteDuringConditionalNewD1Ev", "(anonymous namespace)::CallDeleteDuringConditionalNew::~CallDeleteDuringConditionalNew()"},
    {"_ZN12_GLOBAL__N_130CallDeleteDuringConditionalNewD0Ev", "(anonymous namespace)::CallDeleteDuringConditionalNew::~CallDeleteDuringConditionalNew()"},
    {"_ZN12_GLOBAL__N_130CallDeleteDuringConditionalNew4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallDeleteDuringConditionalNew::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_119CallDeleteDuringNewD1Ev", "(anonymous namespace)::CallDeleteDuringNew::~CallDeleteDuringNew()"},
    {"_ZN12_GLOBAL__N_119CallDeleteDuringNewD0Ev", "(anonymous namespace)::CallDeleteDuringNew::~CallDeleteDuringNew()"},
    {"_ZN12_GLOBAL__N_119CallDeleteDuringNew4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallDeleteDuringNew::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15EmitComplexExprEPKNS_4ExprEbb", "clang::CodeGen::CodeGenFunction::EmitComplexExpr(clang::Expr const*, bool, bool)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter5VisitEPN5clang4ExprE", "(anonymous namespace)::ComplexExprEmitter::Visit(clang::Expr*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction23EmitComplexExprIntoAddrEPKNS_4ExprEPN4llvm5ValueEb", "clang::CodeGen::CodeGenFunction::EmitComplexExprIntoAddr(clang::Expr const*, llvm::Value*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18StoreComplexToAddrESt4pairIPN4llvm5ValueES5_ES5_b", "clang::CodeGen::CodeGenFunction::StoreComplexToAddr(std::pair<llvm::Value*, llvm::Value*>, llvm::Value*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19LoadComplexFromAddrEPN4llvm5ValueEb", "clang::CodeGen::CodeGenFunction::LoadComplexFromAddr(llvm::Value*, bool)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter17EmitLoadOfComplexEPN4llvm5ValueEb", "(anonymous namespace)::ComplexExprEmitter::EmitLoadOfComplex(llvm::Value*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction27EmitComplexAssignmentLValueEPKNS_14BinaryOperatorE", "clang::CodeGen::CodeGenFunction::EmitComplexAssignmentLValue(clang::BinaryOperator const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction35EmitComplexCompoundAssignmentLValueEPKNS_22CompoundAssignOperatorE", "clang::CodeGen::CodeGenFunction::EmitComplexCompoundAssignmentLValue(clang::CompoundAssignOperator const*)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter10EmitBinMulERKNS0_9BinOpInfoE", "(anonymous namespace)::ComplexExprEmitter::EmitBinMul((anonymous namespace)::ComplexExprEmitter::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter10EmitBinDivERKNS0_9BinOpInfoE", "(anonymous namespace)::ComplexExprEmitter::EmitBinDiv((anonymous namespace)::ComplexExprEmitter::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter10EmitBinSubERKNS0_9BinOpInfoE", "(anonymous namespace)::ComplexExprEmitter::EmitBinSub((anonymous namespace)::ComplexExprEmitter::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter10EmitBinAddERKNS0_9BinOpInfoE", "(anonymous namespace)::ComplexExprEmitter::EmitBinAdd((anonymous namespace)::ComplexExprEmitter::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter24EmitCompoundAssignLValueEPKN5clang22CompoundAssignOperatorEMS0_FSt4pairIPN4llvm5ValueES8_ERKNS0_9BinOpInfoEERS9_", "(anonymous namespace)::ComplexExprEmitter::EmitCompoundAssignLValue(clang::CompoundAssignOperator const*, std::pair<llvm::Value*, llvm::Value*> ((anonymous namespace)::ComplexExprEmitter::*)((anonymous namespace)::ComplexExprEmitter::BinOpInfo const&), std::pair<llvm::Value*, llvm::Value*>&)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter24EmitComplexToComplexCastESt4pairIPN4llvm5ValueES4_EN5clang8QualTypeES7_", "(anonymous namespace)::ComplexExprEmitter::EmitComplexToComplexCast(std::pair<llvm::Value*, llvm::Value*>, clang::QualType, clang::QualType)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter22EmitStoreThroughLValueESt4pairIPN4llvm5ValueES4_EN5clang7CodeGen6LValueE", "(anonymous namespace)::ComplexExprEmitter::EmitStoreThroughLValue(std::pair<llvm::Value*, llvm::Value*>, clang::CodeGen::LValue)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_118ComplexExprEmitterESt4pairIPN4llvm5ValueES6_EE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::ComplexExprEmitter, std::pair<llvm::Value*, llvm::Value*>>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter9VisitExprEPN5clang4ExprE", "(anonymous namespace)::ComplexExprEmitter::VisitExpr(clang::Expr*)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter16EmitLoadOfLValueEPKN5clang4ExprE", "(anonymous namespace)::ComplexExprEmitter::EmitLoadOfLValue(clang::Expr const*)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter8EmitCastEN5clang8CastKindEPNS1_4ExprENS1_8QualTypeE", "(anonymous namespace)::ComplexExprEmitter::EmitCast(clang::CastKind, clang::Expr*, clang::QualType)"},
    {"_ZN12_GLOBAL__N_118ComplexExprEmitter18EmitCompoundAssignEPKN5clang22CompoundAssignOperatorEMS0_FSt4pairIPN4llvm5ValueES8_ERKNS0_9BinOpInfoEE", "(anonymous namespace)::ComplexExprEmitter::EmitCompoundAssign(clang::CompoundAssignOperator const*, std::pair<llvm::Value*, llvm::Value*> ((anonymous namespace)::ComplexExprEmitter::*)((anonymous namespace)::ComplexExprEmitter::BinOpInfo const&))"},
    {"_ZN4llvm8DenseMapIPKN5clang4ExprESt4pairIPNS_5ValueES7_ENS_12DenseMapInfoIS4_EENS9_IS8_EEE16InsertIntoBucketERKS4_RKS8_PS5_IS4_S8_E", "llvm::DenseMap<clang::Expr const*, std::pair<llvm::Value*, llvm::Value*>, llvm::DenseMapInfo<clang::Expr const*>, llvm::DenseMapInfo<std::pair<llvm::Value*, llvm::Value*>>>::InsertIntoBucket(clang::Expr const* const&, std::pair<llvm::Value*, llvm::Value*> const&, std::pair<clang::Expr const*, std::pair<llvm::Value*, llvm::Value*>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ExprESt4pairIPNS_5ValueES7_ENS_12DenseMapInfoIS4_EENS9_IS8_EEE4growEj", "llvm::DenseMap<clang::Expr const*, std::pair<llvm::Value*, llvm::Value*>, llvm::DenseMapInfo<clang::Expr const*>, llvm::DenseMapInfo<std::pair<llvm::Value*, llvm::Value*>>>::grow(unsigned int)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateFNegEPNS_5ValueERKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateFNeg(llvm::Value*, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen13CodeGenModule16EmitConstantExprEPKNS_4ExprENS_8QualTypeEPNS0_15CodeGenFunctionE", "clang::CodeGen::CodeGenModule::EmitConstantExpr(clang::Expr const*, clang::QualType, clang::CodeGen::CodeGenFunction*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_116ConstExprEmitterEPN4llvm8ConstantEE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::ConstExprEmitter, llvm::Constant*>::Visit(clang::Stmt*)"},
    {"_ZN5clang7CodeGen13CodeGenModule24getMemberPointerConstantEPKNS_13UnaryOperatorE", "clang::CodeGen::CodeGenModule::getMemberPointerConstant(clang::UnaryOperator const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule16EmitNullConstantENS_8QualTypeE", "clang::CodeGen::CodeGenModule::EmitNullConstant(clang::QualType)"},
    {"_Z16EmitNullConstantRN5clang7CodeGen13CodeGenModuleEPKNS_13CXXRecordDeclE", "EmitNullConstant(clang::CodeGen::CodeGenModule&, clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_116ConstExprEmitter21VisitCXXConstructExprEPN5clang16CXXConstructExprE", "(anonymous namespace)::ConstExprEmitter::VisitCXXConstructExpr(clang::CXXConstructExpr*)"},
    {"_ZN12_GLOBAL__N_116ConstExprEmitter23EmitArrayInitializationEPN5clang12InitListExprE", "(anonymous namespace)::ConstExprEmitter::EmitArrayInitialization(clang::InitListExpr*)"},
    {"_ZN12_GLOBAL__N_118ConstStructBuilder5BuildEPN5clang12InitListExprE", "(anonymous namespace)::ConstStructBuilder::Build(clang::InitListExpr*)"},
    {"_ZN12_GLOBAL__N_118ConstStructBuilder21ConvertStructToPackedEv", "(anonymous namespace)::ConstStructBuilder::ConvertStructToPacked()"},
    {"_ZN12_GLOBAL__N_118ConstStructBuilder13AppendPaddingEy", "(anonymous namespace)::ConstStructBuilder::AppendPadding(unsigned long long)"},
    {"_ZNK12_GLOBAL__N_118ConstStructBuilder14getSizeInBytesEPKN4llvm8ConstantE", "(anonymous namespace)::ConstStructBuilder::getSizeInBytes(llvm::Constant const*) const"},
    {"_ZN12_GLOBAL__N_116ConstExprEmitter13VisitCastExprEPN5clang8CastExprE", "(anonymous namespace)::ConstExprEmitter::VisitCastExpr(clang::CastExpr*)"},
    {"_Z28FillInNullDataMemberPointersRN5clang7CodeGen13CodeGenModuleENS_8QualTypeERSt6vectorIPN4llvm8ConstantESaIS7_EEy", "FillInNullDataMemberPointers(clang::CodeGen::CodeGenModule&, clang::QualType, std::vector<llvm::Constant*, std::allocator<llvm::Constant*>>&, unsigned long long)"},
    {"_ZNSt6vectorIPN4llvm8ConstantESaIS2_EEaSERKS4_", "std::vector<llvm::Constant*, std::allocator<llvm::Constant*>>::operator=(std::vector<llvm::Constant*, std::allocator<llvm::Constant*>> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclEPNS_5ValueENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::Decl const*, llvm::Value*, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::Value*>>::InsertIntoBucket(clang::Decl const* const&, llvm::Value* const&, std::pair<clang::Decl const*, llvm::Value*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclEPNS_5ValueENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::Decl const*, llvm::Value*, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::Value*>>::grow(unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitScalarExprEPKNS_4ExprEb", "clang::CodeGen::CodeGenFunction::EmitScalarExpr(clang::Expr const*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20EmitScalarConversionEPN4llvm5ValueENS_8QualTypeES5_", "clang::CodeGen::CodeGenFunction::EmitScalarConversion(llvm::Value*, clang::QualType, clang::QualType)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter20EmitScalarConversionEPN4llvm5ValueEN5clang8QualTypeES5_", "(anonymous namespace)::ScalarExprEmitter::EmitScalarConversion(llvm::Value*, clang::QualType, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction29EmitComplexToScalarConversionESt4pairIPN4llvm5ValueES5_ENS_8QualTypeES7_", "clang::CodeGen::CodeGenFunction::EmitComplexToScalarConversion(std::pair<llvm::Value*, llvm::Value*>, clang::QualType, clang::QualType)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter29EmitComplexToScalarConversionESt4pairIPN4llvm5ValueES4_EN5clang8QualTypeES7_", "(anonymous namespace)::ScalarExprEmitter::EmitComplexToScalarConversion(std::pair<llvm::Value*, llvm::Value*>, clang::QualType, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction23EmitScalarPrePostIncDecEPKNS_13UnaryOperatorENS0_6LValueEbb", "clang::CodeGen::CodeGenFunction::EmitScalarPrePostIncDec(clang::UnaryOperator const*, clang::CodeGen::LValue, bool, bool)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter23EmitScalarPrePostIncDecEPKN5clang13UnaryOperatorENS1_7CodeGen6LValueEbb", "(anonymous namespace)::ScalarExprEmitter::EmitScalarPrePostIncDec(clang::UnaryOperator const*, clang::CodeGen::LValue, bool, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15EmitObjCIsaExprEPKNS_11ObjCIsaExprE", "clang::CodeGen::CodeGenFunction::EmitObjCIsaExpr(clang::ObjCIsaExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction28EmitCompoundAssignmentLValueEPKNS_22CompoundAssignOperatorE", "clang::CodeGen::CodeGenFunction::EmitCompoundAssignmentLValue(clang::CompoundAssignOperator const*)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter24EmitCompoundAssignLValueEPKN5clang22CompoundAssignOperatorEMS0_FPN4llvm5ValueERKNS_9BinOpInfoEERS7_", "(anonymous namespace)::ScalarExprEmitter::EmitCompoundAssignLValue(clang::CompoundAssignOperator const*, llvm::Value* ((anonymous namespace)::ScalarExprEmitter::*)((anonymous namespace)::BinOpInfo const&), llvm::Value*&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter7EmitMulERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitMul((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter7EmitDivERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitDiv((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter7EmitRemERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitRem((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter7EmitAddERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitAdd((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter7EmitSubERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitSub((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter7EmitShlERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitShl((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter7EmitShrERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitShr((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter7EmitAndERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitAnd((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter7EmitXorERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitXor((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter6EmitOrERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitOr((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter24EmitOverflowCheckedBinOpERKNS_9BinOpInfoE", "(anonymous namespace)::ScalarExprEmitter::EmitOverflowCheckedBinOp((anonymous namespace)::BinOpInfo const&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter42EmitUndefinedBehaviorIntegerDivAndRemCheckERKNS_9BinOpInfoEPN4llvm5ValueEb", "(anonymous namespace)::ScalarExprEmitter::EmitUndefinedBehaviorIntegerDivAndRemCheck((anonymous namespace)::BinOpInfo const&, llvm::Value*, bool)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter31EmitAddConsiderOverflowBehaviorEPKN5clang13UnaryOperatorEPN4llvm5ValueES7_b", "(anonymous namespace)::ScalarExprEmitter::EmitAddConsiderOverflowBehavior(clang::UnaryOperator const*, llvm::Value*, llvm::Value*, bool)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter25EmitFloatToBoolConversionEPN4llvm5ValueE", "(anonymous namespace)::ScalarExprEmitter::EmitFloatToBoolConversion(llvm::Value*)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter23EmitIntToBoolConversionEPN4llvm5ValueE", "(anonymous namespace)::ScalarExprEmitter::EmitIntToBoolConversion(llvm::Value*)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter27EmitPointerToBoolConversionEPN4llvm5ValueE", "(anonymous namespace)::ScalarExprEmitter::EmitPointerToBoolConversion(llvm::Value*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_117ScalarExprEmitterEPN4llvm5ValueEE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::ScalarExprEmitter, llvm::Value*>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter13VisitCallExprEPKN5clang8CallExprE", "(anonymous namespace)::ScalarExprEmitter::VisitCallExpr(clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter13EmitNullValueEN5clang8QualTypeE", "(anonymous namespace)::ScalarExprEmitter::EmitNullValue(clang::QualType)"},
    {"_Z38isCheapEnoughToEvaluateUnconditionallyPKN5clang4ExprERNS_7CodeGen15CodeGenFunctionE", "isCheapEnoughToEvaluateUnconditionally(clang::Expr const*, clang::CodeGen::CodeGenFunction&)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter12EmitCastExprEPN5clang8CastExprE", "(anonymous namespace)::ScalarExprEmitter::EmitCastExpr(clang::CastExpr*)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter18EmitCompoundAssignEPKN5clang22CompoundAssignOperatorEMS0_FPN4llvm5ValueERKNS_9BinOpInfoEE", "(anonymous namespace)::ScalarExprEmitter::EmitCompoundAssign(clang::CompoundAssignOperator const*, llvm::Value* ((anonymous namespace)::ScalarExprEmitter::*)((anonymous namespace)::BinOpInfo const&))"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter10EmitBinOpsEPKN5clang14BinaryOperatorE", "(anonymous namespace)::ScalarExprEmitter::EmitBinOps(clang::BinaryOperator const*)"},
    {"_ZN12_GLOBAL__N_117ScalarExprEmitter11EmitCompareEPKN5clang14BinaryOperatorEjjj", "(anonymous namespace)::ScalarExprEmitter::EmitCompare(clang::BinaryOperator const*, unsigned int, unsigned int, unsigned int)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateXorEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateXor(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateLShrEPNS_5ValueES6_RKNS_5TwineEb", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateLShr(llvm::Value*, llvm::Value*, llvm::Twine const&, bool)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateShlEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateShl(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateFSubEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateFSub(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateNegEPNS_5ValueERKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateNeg(llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateSDivEPNS_5ValueES6_RKNS_5TwineEb", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateSDiv(llvm::Value*, llvm::Value*, llvm::Twine const&, bool)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE11CreateCall4EPNS_5ValueES6_S6_S6_S6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateCall4(llvm::Value*, llvm::Value*, llvm::Value*, llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateFAddEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateFAdd(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateURemEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateURem(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateSRemEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateSRem(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateFDivEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateFDiv(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateUDivEPNS_5ValueES6_RKNS_5TwineEb", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateUDiv(llvm::Value*, llvm::Value*, llvm::Twine const&, bool)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateFCmpENS_7CmpInst9PredicateEPNS_5ValueES8_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateFCmp(llvm::CmpInst::Predicate, llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE12CreateNSWMulEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateNSWMul(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateFMulEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateFMul(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE19CreateInsertElementEPNS_5ValueES6_S6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateInsertElement(llvm::Value*, llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE19CreateShuffleVectorEPNS_5ValueES6_S6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateShuffleVector(llvm::Value*, llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE11CreateVAArgEPNS_5ValueEPKNS_4TypeERKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateVAArg(llvm::Value*, llvm::Type const*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE20CreateExtractElementEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateExtractElement(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateNotEPNS_5ValueERKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateNot(llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE19CreateZExtOrBitCastEPNS_5ValueEPKNS_4TypeERKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateZExtOrBitCast(llvm::Value*, llvm::Type const*, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21EmitObjCStringLiteralEPKNS_17ObjCStringLiteralE", "clang::CodeGen::CodeGenFunction::EmitObjCStringLiteral(clang::ObjCStringLiteral const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20EmitObjCSelectorExprEPKNS_16ObjCSelectorExprE", "clang::CodeGen::CodeGenFunction::EmitObjCSelectorExpr(clang::ObjCSelectorExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20EmitObjCProtocolExprEPKNS_16ObjCProtocolExprE", "clang::CodeGen::CodeGenFunction::EmitObjCProtocolExpr(clang::ObjCProtocolExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19EmitObjCMessageExprEPKNS_15ObjCMessageExprENS0_15ReturnValueSlotE", "clang::CodeGen::CodeGenFunction::EmitObjCMessageExpr(clang::ObjCMessageExpr const*, clang::CodeGen::ReturnValueSlot)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12LoadObjCSelfEv", "clang::CodeGen::CodeGenFunction::LoadObjCSelf()"},
    {"_ZN5clang7CodeGen15CodeGenFunction15StartObjCMethodEPKNS_14ObjCMethodDeclEPKNS_17ObjCContainerDeclE", "clang::CodeGen::CodeGenFunction::StartObjCMethod(clang::ObjCMethodDecl const*, clang::ObjCContainerDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18GenerateObjCMethodEPKNS_14ObjCMethodDeclE", "clang::CodeGen::CodeGenFunction::GenerateObjCMethod(clang::ObjCMethodDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18GenerateObjCGetterEPNS_22ObjCImplementationDeclEPKNS_20ObjCPropertyImplDeclE", "clang::CodeGen::CodeGenFunction::GenerateObjCGetter(clang::ObjCImplementationDecl*, clang::ObjCPropertyImplDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16TypeOfSelfObjectEv", "clang::CodeGen::CodeGenFunction::TypeOfSelfObject()"},
    {"_ZN5clang7CodeGen15CodeGenFunction25IvarTypeWithAggrGCObjectsENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::IvarTypeWithAggrGCObjects(clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18GenerateObjCSetterEPNS_22ObjCImplementationDeclEPKNS_20ObjCPropertyImplDeclE", "clang::CodeGen::CodeGenFunction::GenerateObjCSetter(clang::ObjCImplementationDecl*, clang::ObjCPropertyImplDecl const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction21IndirectObjCSetterArgERKNS0_14CGFunctionInfoE", "clang::CodeGen::CodeGenFunction::IndirectObjCSetterArg(clang::CodeGen::CGFunctionInfo const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26GenerateObjCCtorDtorMethodEPNS_22ObjCImplementationDeclEPNS_14ObjCMethodDeclEb", "clang::CodeGen::CodeGenFunction::GenerateObjCCtorDtorMethod(clang::ObjCImplementationDecl*, clang::ObjCMethodDecl*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction25EmitObjCPropertyRefLValueEPKNS_19ObjCPropertyRefExprE", "clang::CodeGen::CodeGenFunction::EmitObjCPropertyRefLValue(clang::ObjCPropertyRefExpr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction27EmitLoadOfPropertyRefLValueENS0_6LValueENS0_15ReturnValueSlotE", "clang::CodeGen::CodeGenFunction::EmitLoadOfPropertyRefLValue(clang::CodeGen::LValue, clang::CodeGen::ReturnValueSlot)"},
    {"_Z24GenerateMessageSendSuperRN5clang7CodeGen15CodeGenFunctionENS0_15ReturnValueSlotENS_8QualTypeENS_8SelectorEPN4llvm5ValueERKNS6_11SmallVectorISt4pairINS0_6RValueES4_ELj16EEE", "GenerateMessageSendSuper(clang::CodeGen::CodeGenFunction&, clang::CodeGen::ReturnValueSlot, clang::QualType, clang::Selector, llvm::Value*, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction33EmitStoreThroughPropertyRefLValueENS0_6RValueENS0_6LValueE", "clang::CodeGen::CodeGenFunction::EmitStoreThroughPropertyRefLValue(clang::CodeGen::RValue, clang::CodeGen::LValue)"},
    {"_ZN5clang7CodeGen15CodeGenFunction25EmitObjCForCollectionStmtERKNS_21ObjCForCollectionStmtE", "clang::CodeGen::CodeGenFunction::EmitObjCForCollectionStmt(clang::ObjCForCollectionStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitObjCAtTryStmtERKNS_13ObjCAtTryStmtE", "clang::CodeGen::CodeGenFunction::EmitObjCAtTryStmt(clang::ObjCAtTryStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19EmitObjCAtThrowStmtERKNS_15ObjCAtThrowStmtE", "clang::CodeGen::CodeGenFunction::EmitObjCAtThrowStmt(clang::ObjCAtThrowStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26EmitObjCAtSynchronizedStmtERKNS_22ObjCAtSynchronizedStmtE", "clang::CodeGen::CodeGenFunction::EmitObjCAtSynchronizedStmt(clang::ObjCAtSynchronizedStmt const&)"},
    {"_ZN5clang7CodeGen13CGObjCRuntimeD0Ev", "clang::CodeGen::CGObjCRuntime::~CGObjCRuntime()"},
    {"_ZN5clang7CodeGen13CGObjCRuntimeD1Ev", "clang::CodeGen::CGObjCRuntime::~CGObjCRuntime()"},
    {"_ZN5clang7CodeGen13CGObjCRuntimeD2Ev", "clang::CodeGen::CGObjCRuntime::~CGObjCRuntime()"},
    {"_ZN5clang7CodeGen15CodeGenFunction12EmitCallArgsINS_14ObjCMethodDeclEEEvRN4llvm11SmallVectorISt4pairINS0_6RValueENS_8QualTypeEELj16EEEPKT_NS_17ConstExprIteratorESF_", "void clang::CodeGen::CodeGenFunction::EmitCallArgs<clang::ObjCMethodDecl>(llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u>&, clang::ObjCMethodDecl const*, clang::ConstExprIterator, clang::ConstExprIterator)"},
    {"_ZNK5clang9ValueDecl7getTypeEv", "clang::ValueDecl::getType() const"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang7CodeGen15CodeGenFunction13BreakContinueELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::CodeGen::CodeGenFunction::BreakContinue, false>::grow(unsigned long)"},
    {"_ZN5clang7CodeGen20CreateGNUObjCRuntimeERNS0_13CodeGenModuleE", "clang::CodeGen::CreateGNUObjCRuntime(clang::CodeGen::CodeGenModule&)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNUD1Ev", "(anonymous namespace)::CGObjCGNU::~CGObjCGNU()"},
    {"_ZN12_GLOBAL__N_19CGObjCGNUD0Ev", "(anonymous namespace)::CGObjCGNU::~CGObjCGNU()"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU18ModuleInitFunctionEv", "(anonymous namespace)::CGObjCGNU::ModuleInitFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU11GetSelectorERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEN5clang8SelectorEb", "(anonymous namespace)::CGObjCGNU::GetSelector(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::Selector, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU11GetSelectorERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::CGObjCGNU::GetSelector(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU9GetEHTypeEN5clang8QualTypeE", "(anonymous namespace)::CGObjCGNU::GetEHType(clang::QualType)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU22GenerateConstantStringEPKN5clang13StringLiteralE", "(anonymous namespace)::CGObjCGNU::GenerateConstantString(clang::StringLiteral const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU16GenerateCategoryEPKN5clang20ObjCCategoryImplDeclE", "(anonymous namespace)::CGObjCGNU::GenerateCategory(clang::ObjCCategoryImplDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU13GenerateClassEPKN5clang22ObjCImplementationDeclE", "(anonymous namespace)::CGObjCGNU::GenerateClass(clang::ObjCImplementationDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU19GenerateMessageSendERN5clang7CodeGen15CodeGenFunctionENS2_15ReturnValueSlotENS1_8QualTypeENS1_8SelectorEPN4llvm5ValueERKNS8_11SmallVectorISt4pairINS2_6RValueES6_ELj16EEEPKNS1_17ObjCInterfaceDeclEPKNS1_14ObjCMethodDeclE", "(anonymous namespace)::CGObjCGNU::GenerateMessageSend(clang::CodeGen::CodeGenFunction&, clang::CodeGen::ReturnValueSlot, clang::QualType, clang::Selector, llvm::Value*, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&, clang::ObjCInterfaceDecl const*, clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU24GenerateMessageSendSuperERN5clang7CodeGen15CodeGenFunctionENS2_15ReturnValueSlotENS1_8QualTypeENS1_8SelectorEPKNS1_17ObjCInterfaceDeclEbPN4llvm5ValueEbRKNSB_11SmallVectorISt4pairINS2_6RValueES6_ELj16EEEPKNS1_14ObjCMethodDeclE", "(anonymous namespace)::CGObjCGNU::GenerateMessageSendSuper(clang::CodeGen::CodeGenFunction&, clang::CodeGen::ReturnValueSlot, clang::QualType, clang::Selector, clang::ObjCInterfaceDecl const*, bool, llvm::Value*, bool, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&, clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU19GenerateProtocolRefERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang16ObjCProtocolDeclE", "(anonymous namespace)::CGObjCGNU::GenerateProtocolRef(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCProtocolDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU16GenerateProtocolEPKN5clang16ObjCProtocolDeclE", "(anonymous namespace)::CGObjCGNU::GenerateProtocol(clang::ObjCProtocolDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU14GenerateMethodEPKN5clang14ObjCMethodDeclEPKNS1_17ObjCContainerDeclE", "(anonymous namespace)::CGObjCGNU::GenerateMethod(clang::ObjCMethodDecl const*, clang::ObjCContainerDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU22GetPropertyGetFunctionEv", "(anonymous namespace)::CGObjCGNU::GetPropertyGetFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU22GetPropertySetFunctionEv", "(anonymous namespace)::CGObjCGNU::GetPropertySetFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU20GetGetStructFunctionEv", "(anonymous namespace)::CGObjCGNU::GetGetStructFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU20GetSetStructFunctionEv", "(anonymous namespace)::CGObjCGNU::GetSetStructFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU8GetClassERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang17ObjCInterfaceDeclE", "(anonymous namespace)::CGObjCGNU::GetClass(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCInterfaceDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU27EnumerationMutationFunctionEv", "(anonymous namespace)::CGObjCGNU::EnumerationMutationFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU20EmitSynchronizedStmtERN5clang7CodeGen15CodeGenFunctionERKNS1_22ObjCAtSynchronizedStmtE", "(anonymous namespace)::CGObjCGNU::EmitSynchronizedStmt(clang::CodeGen::CodeGenFunction&, clang::ObjCAtSynchronizedStmt const&)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU11EmitTryStmtERN5clang7CodeGen15CodeGenFunctionERKNS1_13ObjCAtTryStmtE", "(anonymous namespace)::CGObjCGNU::EmitTryStmt(clang::CodeGen::CodeGenFunction&, clang::ObjCAtTryStmt const&)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU13EmitThrowStmtERN5clang7CodeGen15CodeGenFunctionERKNS1_15ObjCAtThrowStmtE", "(anonymous namespace)::CGObjCGNU::EmitThrowStmt(clang::CodeGen::CodeGenFunction&, clang::ObjCAtThrowStmt const&)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU16EmitObjCWeakReadERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "(anonymous namespace)::CGObjCGNU::EmitObjCWeakRead(clang::CodeGen::CodeGenFunction&, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU18EmitObjCWeakAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_", "(anonymous namespace)::CGObjCGNU::EmitObjCWeakAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU20EmitObjCGlobalAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_b", "(anonymous namespace)::CGObjCGNU::EmitObjCGlobalAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU18EmitObjCIvarAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_S7_", "(anonymous namespace)::CGObjCGNU::EmitObjCIvarAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU24EmitObjCStrongCastAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_", "(anonymous namespace)::CGObjCGNU::EmitObjCStrongCastAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU20EmitObjCValueForIvarERN5clang7CodeGen15CodeGenFunctionENS1_8QualTypeEPN4llvm5ValueEPKNS1_12ObjCIvarDeclEj", "(anonymous namespace)::CGObjCGNU::EmitObjCValueForIvar(clang::CodeGen::CodeGenFunction&, clang::QualType, llvm::Value*, clang::ObjCIvarDecl const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU14EmitIvarOffsetERN5clang7CodeGen15CodeGenFunctionEPKNS1_17ObjCInterfaceDeclEPKNS1_12ObjCIvarDeclE", "(anonymous namespace)::CGObjCGNU::EmitIvarOffset(clang::CodeGen::CodeGenFunction&, clang::ObjCInterfaceDecl const*, clang::ObjCIvarDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU24EmitGCMemmoveCollectableERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_S7_", "(anonymous namespace)::CGObjCGNU::EmitGCMemmoveCollectable(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU18BuildGCBlockLayoutERN5clang7CodeGen13CodeGenModuleERKNS2_11CGBlockInfoE", "(anonymous namespace)::CGObjCGNU::BuildGCBlockLayout(clang::CodeGen::CodeGenModule&, clang::CodeGen::CGBlockInfo const&)"},
    {"_Z17FindIvarInterfaceRN5clang10ASTContextEPKNS_17ObjCInterfaceDeclEPKNS_12ObjCIvarDeclE", "FindIvarInterface(clang::ASTContext&, clang::ObjCInterfaceDecl const*, clang::ObjCIvarDecl const*)"},
    {"_ZN12_GLOBAL__N_112CallSyncExitD1Ev", "(anonymous namespace)::CallSyncExit::~CallSyncExit()"},
    {"_ZN12_GLOBAL__N_112CallSyncExitD0Ev", "(anonymous namespace)::CallSyncExit::~CallSyncExit()"},
    {"_ZN12_GLOBAL__N_112CallSyncExit4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallSyncExit::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU12EmitClassRefERKSs", "(anonymous namespace)::CGObjCGNU::EmitClassRef(std::string const&)"},
    {"_Z19SymbolNameForMethodRKSsS0_S0_b", "SymbolNameForMethod(std::string const&, std::string const&, std::string const&, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU20GenerateProtocolListERKN4llvm15SmallVectorImplISsEE", "(anonymous namespace)::CGObjCGNU::GenerateProtocolList(llvm::SmallVectorImpl<std::string> const&)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU26GenerateProtocolMethodListERKN4llvm15SmallVectorImplIPNS1_8ConstantEEES7_", "(anonymous namespace)::CGObjCGNU::GenerateProtocolMethodList(llvm::SmallVectorImpl<llvm::Constant*> const&, llvm::SmallVectorImpl<llvm::Constant*> const&)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU18GenerateMethodListERKSsS2_RKN4llvm15SmallVectorImplIN5clang8SelectorEEERKNS4_IPNS3_8ConstantEEEb", "(anonymous namespace)::CGObjCGNU::GenerateMethodList(std::string const&, std::string const&, llvm::SmallVectorImpl<clang::Selector> const&, llvm::SmallVectorImpl<llvm::Constant*> const&, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU16GenerateIvarListERKN4llvm15SmallVectorImplIPNS1_8ConstantEEES7_S7_", "(anonymous namespace)::CGObjCGNU::GenerateIvarList(llvm::SmallVectorImpl<llvm::Constant*> const&, llvm::SmallVectorImpl<llvm::Constant*> const&, llvm::SmallVectorImpl<llvm::Constant*> const&)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU22GenerateClassStructureEPN4llvm8ConstantES3_jPKcS3_S3_S3_S3_S3_S3_S3_b", "(anonymous namespace)::CGObjCGNU::GenerateClassStructure(llvm::Constant*, llvm::Constant*, unsigned int, char const*, llvm::Constant*, llvm::Constant*, llvm::Constant*, llvm::Constant*, llvm::Constant*, llvm::Constant*, llvm::Constant*, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCGNU18ExportUniqueStringERKSsSs", "(anonymous namespace)::CGObjCGNU::ExportUniqueString(std::string const&, std::string)"},
    {"_Z19MangleSelectorTypesRKSs", "MangleSelectorTypes(std::string const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE11CreateCall3EPNS_5ValueES6_S6_S6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateCall3(llvm::Value*, llvm::Value*, llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateLoadEPNS_5ValueEbRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateLoad(llvm::Value*, bool, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE11CreateCall2EPNS_5ValueES6_S6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateCall2(llvm::Value*, llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateCallEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateCall(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE17CreateUnreachableEv", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateUnreachable()"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE12CreateInvokeIPPNS_5ValueEEEPNS_10InvokeInstES7_PNS_10BasicBlockESC_T_SD_RKNS_5TwineE", "llvm::InvokeInst* llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateInvoke<llvm::Value**>(llvm::Value*, llvm::BasicBlock*, llvm::BasicBlock*, llvm::Value**, llvm::Value**, llvm::Twine const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang7CanQualINS1_4TypeEEELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::CanQual<clang::Type>, false>::grow(unsigned long)"},
    {"_ZN4llvm15SmallVectorImplISt4pairIN5clang7CodeGen6RValueENS2_8QualTypeEEE6insertIPKS6_EEPS6_SB_T_SC_", "std::pair<clang::CodeGen::RValue, clang::QualType>* llvm::SmallVectorImpl<std::pair<clang::CodeGen::RValue, clang::QualType>>::insert<std::pair<clang::CodeGen::RValue, clang::QualType> const*>(std::pair<clang::CodeGen::RValue, clang::QualType>*, std::pair<clang::CodeGen::RValue, clang::QualType> const*, std::pair<clang::CodeGen::RValue, clang::QualType> const*)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE12CreateAllocaEPKNS_4TypeEPNS_5ValueERKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateAlloca(llvm::Type const*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateCallIPPNS_5ValueEEEPNS_8CallInstES7_T_SB_RKNS_5TwineE", "llvm::CallInst* llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateCall<llvm::Value**>(llvm::Value*, llvm::Value**, llvm::Value**, llvm::Twine const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairIN5clang7CodeGen6RValueENS2_8QualTypeEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<clang::CodeGen::RValue, clang::QualType>, false>::grow(unsigned long)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE8CreateBrEPNS_10BasicBlockE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateBr(llvm::BasicBlock*)"},
    {"_ZNSt3mapISt4pairISsSsEPN4llvm11GlobalAliasESt4lessIS1_ESaIS0_IKS1_S4_EEEixERS7_", "std::map<std::pair<std::string, std::string>, llvm::GlobalAlias*, std::less<std::pair<std::string, std::string>>, std::allocator<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>>::operator[](std::pair<std::string, std::string> const&)"},
    {"_ZNKSt4lessISt4pairISsSsEEclERKS1_S4_", "std::less<std::pair<std::string, std::string>>::operator()(std::pair<std::string, std::string> const&, std::pair<std::string, std::string> const&) const"},
    {"_ZNSt8_Rb_treeISt4pairISsSsES0_IKS1_PN4llvm11GlobalAliasEESt10_Select1stIS6_ESt4lessIS1_ESaIS6_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS6_ERKS6_", "std::_Rb_tree<std::pair<std::string, std::string>, std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>, std::_Select1st<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>, std::less<std::pair<std::string, std::string>>, std::allocator<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>, std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*> const&)"},
    {"_ZNSt8_Rb_treeISt4pairISsSsES0_IKS1_PN4llvm11GlobalAliasEESt10_Select1stIS6_ESt4lessIS1_ESaIS6_EE9_M_insertEPSt18_Rb_tree_node_baseSE_RKS6_", "std::_Rb_tree<std::pair<std::string, std::string>, std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>, std::_Select1st<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>, std::less<std::pair<std::string, std::string>>, std::allocator<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*> const&)"},
    {"_ZNSt8_Rb_treeISt4pairISsSsES0_IKS1_PN4llvm11GlobalAliasEESt10_Select1stIS6_ESt4lessIS1_ESaIS6_EE16_M_insert_uniqueERKS6_", "std::_Rb_tree<std::pair<std::string, std::string>, std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>, std::_Select1st<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>, std::less<std::pair<std::string, std::string>>, std::allocator<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>>::_M_insert_unique(std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*> const&)"},
    {"_ZN4llvm9StringMapIPNS_11GlobalAliasENS_15MallocAllocatorEE16GetOrCreateValueIS2_EERNS_14StringMapEntryIS2_EENS_9StringRefET_", "llvm::StringMapEntry<llvm::GlobalAlias*>& llvm::StringMap<llvm::GlobalAlias*, llvm::MallocAllocator>::GetOrCreateValue<llvm::GlobalAlias*>(llvm::StringRef, llvm::GlobalAlias*)"},
    {"_ZNSt6vectorIPN4llvm8ConstantESaIS2_EE15_M_range_insertIN9__gnu_cxx17__normal_iteratorIPS2_S4_EEEEvS9_T_SA_St20forward_iterator_tag", "void std::vector<llvm::Constant*, std::allocator<llvm::Constant*>>::_M_range_insert<__gnu_cxx::__normal_iterator<llvm::Constant**, std::vector<llvm::Constant*, std::allocator<llvm::Constant*>>>>(__gnu_cxx::__normal_iterator<llvm::Constant**, std::vector<llvm::Constant*, std::allocator<llvm::Constant*>>>, __gnu_cxx::__normal_iterator<llvm::Constant**, std::vector<llvm::Constant*, std::allocator<llvm::Constant*>>>, __gnu_cxx::__normal_iterator<llvm::Constant**, std::vector<llvm::Constant*, std::allocator<llvm::Constant*>>>, std::forward_iterator_tag)"},
    {"_ZNSt8_Rb_treeISt4pairISsSsES0_IKS1_PN4llvm11GlobalAliasEESt10_Select1stIS6_ESt4lessIS1_ESaIS6_EE8_M_eraseEPSt13_Rb_tree_nodeIS6_E", "std::_Rb_tree<std::pair<std::string, std::string>, std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>, std::_Select1st<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>, std::less<std::pair<std::string, std::string>>, std::allocator<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>>::_M_erase(std::_Rb_tree_node<std::pair<std::pair<std::string, std::string> const, llvm::GlobalAlias*>>*)"},
    {"_ZN5clang7CodeGen13CGObjCRuntime21ComputeIvarBaseOffsetERNS0_13CodeGenModuleEPKNS_17ObjCInterfaceDeclEPKNS_12ObjCIvarDeclE", "clang::CodeGen::CGObjCRuntime::ComputeIvarBaseOffset(clang::CodeGen::CodeGenModule&, clang::ObjCInterfaceDecl const*, clang::ObjCIvarDecl const*)"},
    {"_Z20LookupFieldBitOffsetRN5clang7CodeGen13CodeGenModuleEPKNS_17ObjCInterfaceDeclEPKNS_22ObjCImplementationDeclEPKNS_12ObjCIvarDeclE", "LookupFieldBitOffset(clang::CodeGen::CodeGenModule&, clang::ObjCInterfaceDecl const*, clang::ObjCImplementationDecl const*, clang::ObjCIvarDecl const*)"},
    {"_ZN5clang7CodeGen13CGObjCRuntime21ComputeIvarBaseOffsetERNS0_13CodeGenModuleEPKNS_22ObjCImplementationDeclEPKNS_12ObjCIvarDeclE", "clang::CodeGen::CGObjCRuntime::ComputeIvarBaseOffset(clang::CodeGen::CodeGenModule&, clang::ObjCImplementationDecl const*, clang::ObjCIvarDecl const*)"},
    {"_ZN5clang7CodeGen13CGObjCRuntime24EmitValueForIvarAtOffsetERNS0_15CodeGenFunctionEPKNS_17ObjCInterfaceDeclEPN4llvm5ValueEPKNS_12ObjCIvarDeclEjS9_", "clang::CodeGen::CGObjCRuntime::EmitValueForIvarAtOffset(clang::CodeGen::CodeGenFunction&, clang::ObjCInterfaceDecl const*, llvm::Value*, clang::ObjCIvarDecl const*, unsigned int, llvm::Value*)"},
    {"_ZN5clang7CodeGen20CreateMacObjCRuntimeERNS0_13CodeGenModuleE", "clang::CodeGen::CreateMacObjCRuntime(clang::CodeGen::CodeGenModule&)"},
    {"_ZN5clang7CodeGen33CreateMacNonFragileABIObjCRuntimeERNS0_13CodeGenModuleE", "clang::CodeGen::CreateMacNonFragileABIObjCRuntime(clang::CodeGen::CodeGenModule&)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMacC2ERN5clang7CodeGen13CodeGenModuleE", "(anonymous namespace)::CGObjCCommonMac::CGObjCCommonMac(clang::CodeGen::CodeGenModule&)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMacD1Ev", "(anonymous namespace)::CGObjCNonFragileABIMac::~CGObjCNonFragileABIMac()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMacD0Ev", "(anonymous namespace)::CGObjCNonFragileABIMac::~CGObjCNonFragileABIMac()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac18ModuleInitFunctionEv", "(anonymous namespace)::CGObjCNonFragileABIMac::ModuleInitFunction()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac11GetSelectorERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEN5clang8SelectorEb", "(anonymous namespace)::CGObjCNonFragileABIMac::GetSelector(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::Selector, bool)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac11GetSelectorERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GetSelector(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac9GetEHTypeEN5clang8QualTypeE", "(anonymous namespace)::CGObjCNonFragileABIMac::GetEHType(clang::QualType)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac22GenerateConstantStringEPKN5clang13StringLiteralE", "(anonymous namespace)::CGObjCCommonMac::GenerateConstantString(clang::StringLiteral const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac16GenerateCategoryEPKN5clang20ObjCCategoryImplDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GenerateCategory(clang::ObjCCategoryImplDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac13GenerateClassEPKN5clang22ObjCImplementationDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GenerateClass(clang::ObjCImplementationDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac19GenerateMessageSendERN5clang7CodeGen15CodeGenFunctionENS2_15ReturnValueSlotENS1_8QualTypeENS1_8SelectorEPN4llvm5ValueERKNS8_11SmallVectorISt4pairINS2_6RValueES6_ELj16EEEPKNS1_17ObjCInterfaceDeclEPKNS1_14ObjCMethodDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GenerateMessageSend(clang::CodeGen::CodeGenFunction&, clang::CodeGen::ReturnValueSlot, clang::QualType, clang::Selector, llvm::Value*, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&, clang::ObjCInterfaceDecl const*, clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac24GenerateMessageSendSuperERN5clang7CodeGen15CodeGenFunctionENS2_15ReturnValueSlotENS1_8QualTypeENS1_8SelectorEPKNS1_17ObjCInterfaceDeclEbPN4llvm5ValueEbRKNSB_11SmallVectorISt4pairINS2_6RValueES6_ELj16EEEPKNS1_14ObjCMethodDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GenerateMessageSendSuper(clang::CodeGen::CodeGenFunction&, clang::CodeGen::ReturnValueSlot, clang::QualType, clang::Selector, clang::ObjCInterfaceDecl const*, bool, llvm::Value*, bool, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&, clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac19GenerateProtocolRefERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang16ObjCProtocolDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GenerateProtocolRef(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCProtocolDecl const*)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac16GenerateProtocolEPKN5clang16ObjCProtocolDeclE", "(anonymous namespace)::CGObjCCommonMac::GenerateProtocol(clang::ObjCProtocolDecl const*)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac14GenerateMethodEPKN5clang14ObjCMethodDeclEPKNS1_17ObjCContainerDeclE", "(anonymous namespace)::CGObjCCommonMac::GenerateMethod(clang::ObjCMethodDecl const*, clang::ObjCContainerDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac22GetPropertyGetFunctionEv", "(anonymous namespace)::CGObjCNonFragileABIMac::GetPropertyGetFunction()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac22GetPropertySetFunctionEv", "(anonymous namespace)::CGObjCNonFragileABIMac::GetPropertySetFunction()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac20GetGetStructFunctionEv", "(anonymous namespace)::CGObjCNonFragileABIMac::GetGetStructFunction()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac20GetSetStructFunctionEv", "(anonymous namespace)::CGObjCNonFragileABIMac::GetSetStructFunction()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac8GetClassERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang17ObjCInterfaceDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GetClass(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCInterfaceDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac27EnumerationMutationFunctionEv", "(anonymous namespace)::CGObjCNonFragileABIMac::EnumerationMutationFunction()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac20EmitSynchronizedStmtERN5clang7CodeGen15CodeGenFunctionERKNS1_22ObjCAtSynchronizedStmtE", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitSynchronizedStmt(clang::CodeGen::CodeGenFunction&, clang::ObjCAtSynchronizedStmt const&)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac11EmitTryStmtERN5clang7CodeGen15CodeGenFunctionERKNS1_13ObjCAtTryStmtE", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitTryStmt(clang::CodeGen::CodeGenFunction&, clang::ObjCAtTryStmt const&)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac13EmitThrowStmtERN5clang7CodeGen15CodeGenFunctionERKNS1_15ObjCAtThrowStmtE", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitThrowStmt(clang::CodeGen::CodeGenFunction&, clang::ObjCAtThrowStmt const&)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac16EmitObjCWeakReadERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitObjCWeakRead(clang::CodeGen::CodeGenFunction&, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac18EmitObjCWeakAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitObjCWeakAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac20EmitObjCGlobalAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_b", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitObjCGlobalAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, bool)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac18EmitObjCIvarAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_S7_", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitObjCIvarAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac24EmitObjCStrongCastAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitObjCStrongCastAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac20EmitObjCValueForIvarERN5clang7CodeGen15CodeGenFunctionENS1_8QualTypeEPN4llvm5ValueEPKNS1_12ObjCIvarDeclEj", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitObjCValueForIvar(clang::CodeGen::CodeGenFunction&, clang::QualType, llvm::Value*, clang::ObjCIvarDecl const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac14EmitIvarOffsetERN5clang7CodeGen15CodeGenFunctionEPKNS1_17ObjCInterfaceDeclEPKNS1_12ObjCIvarDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitIvarOffset(clang::CodeGen::CodeGenFunction&, clang::ObjCInterfaceDecl const*, clang::ObjCIvarDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac24EmitGCMemmoveCollectableERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_S7_", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitGCMemmoveCollectable(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac18BuildGCBlockLayoutERN5clang7CodeGen13CodeGenModuleERKNS2_11CGBlockInfoE", "(anonymous namespace)::CGObjCCommonMac::BuildGCBlockLayout(clang::CodeGen::CodeGenModule&, clang::CodeGen::CGBlockInfo const&)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac17GetOrEmitProtocolEPKN5clang16ObjCProtocolDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GetOrEmitProtocol(clang::ObjCProtocolDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac20GetOrEmitProtocolRefEPKN5clang16ObjCProtocolDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GetOrEmitProtocolRef(clang::ObjCProtocolDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac28GetMethodDescriptionConstantEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GetMethodDescriptionConstant(clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac12GetClassNameEPN5clang14IdentifierInfoE", "(anonymous namespace)::CGObjCCommonMac::GetClassName(clang::IdentifierInfo*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac16EmitProtocolListEN4llvm5TwineEPKPN5clang16ObjCProtocolDeclES7_", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitProtocolList(llvm::Twine, clang::ObjCProtocolDecl* const*, clang::ObjCProtocolDecl* const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac14EmitMethodListEN4llvm5TwineEPKcRKSt6vectorIPNS1_8ConstantESaIS7_EE", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitMethodList(llvm::Twine, char const*, std::vector<llvm::Constant*, std::allocator<llvm::Constant*>> const&)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac16EmitPropertyListEN4llvm5TwineEPKN5clang4DeclEPKNS3_17ObjCContainerDeclERKNS_21ObjCCommonTypesHelperE", "(anonymous namespace)::CGObjCCommonMac::EmitPropertyList(llvm::Twine, clang::Decl const*, clang::ObjCContainerDecl const*, (anonymous namespace)::ObjCCommonTypesHelper const&)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac15GetPropertyNameEPN5clang14IdentifierInfoE", "(anonymous namespace)::CGObjCCommonMac::GetPropertyName(clang::IdentifierInfo*)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac21GetPropertyTypeStringEPKN5clang16ObjCPropertyDeclEPKNS1_4DeclE", "(anonymous namespace)::CGObjCCommonMac::GetPropertyTypeString(clang::ObjCPropertyDecl const*, clang::Decl const*)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac22PushProtocolPropertiesERN4llvm11SmallPtrSetIPKN5clang14IdentifierInfoELj16EEERSt6vectorIPNS1_8ConstantESaISB_EEPKNS3_4DeclEPKNS3_16ObjCProtocolDeclERKNS_21ObjCCommonTypesHelperE", "(anonymous namespace)::CGObjCCommonMac::PushProtocolProperties(llvm::SmallPtrSet<clang::IdentifierInfo const*, 16u>&, std::vector<llvm::Constant*, std::allocator<llvm::Constant*>>&, clang::Decl const*, clang::ObjCProtocolDecl const*, (anonymous namespace)::ObjCCommonTypesHelper const&)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac17CreateMetadataVarEN4llvm5TwineEPNS1_8ConstantEPKcjb", "(anonymous namespace)::CGObjCCommonMac::CreateMetadataVar(llvm::Twine, llvm::Constant*, char const*, unsigned int, bool)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac16GetMethodVarNameEN5clang8SelectorE", "(anonymous namespace)::CGObjCCommonMac::GetMethodVarName(clang::Selector)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac16GetMethodVarTypeEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::CGObjCCommonMac::GetMethodVarType(clang::ObjCMethodDecl const*)"},
    {"_ZN4llvm15SmallVectorImplIN12_GLOBAL__N_115CGObjCCommonMac7GC_IVAREE9push_backERKS3_", "llvm::SmallVectorImpl<(anonymous namespace)::CGObjCCommonMac::GC_IVAR>::push_back((anonymous namespace)::CGObjCCommonMac::GC_IVAR const&)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac25BuildAggrIvarRecordLayoutEPKN5clang10RecordTypeEjbRb", "(anonymous namespace)::CGObjCCommonMac::BuildAggrIvarRecordLayout(clang::RecordType const*, unsigned int, bool, bool&)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac21BuildIvarLayoutBitmapERSs", "(anonymous namespace)::CGObjCCommonMac::BuildIvarLayoutBitmap(std::string&)"},
    {"_ZN4llvm15SmallVectorImplIN12_GLOBAL__N_115CGObjCCommonMac9SKIP_SCANEE9push_backERKS3_", "llvm::SmallVectorImpl<(anonymous namespace)::CGObjCCommonMac::SKIP_SCAN>::push_back((anonymous namespace)::CGObjCCommonMac::SKIP_SCAN const&)"},
    {"_ZN4llvm25array_pod_sort_comparatorIN12_GLOBAL__N_115CGObjCCommonMac7GC_IVAREEEiPKvS5_", "int llvm::array_pod_sort_comparator<(anonymous namespace)::CGObjCCommonMac::GC_IVAR>(void const*, void const*)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac19BuildAggrIvarLayoutEPKN5clang22ObjCImplementationDeclEPKN4llvm12StructLayoutEPKNS1_10RecordDeclERKNS5_15SmallVectorImplIPNS1_9FieldDeclEEEjbRb", "(anonymous namespace)::CGObjCCommonMac::BuildAggrIvarLayout(clang::ObjCImplementationDecl const*, llvm::StructLayout const*, clang::RecordDecl const*, llvm::SmallVectorImpl<clang::FieldDecl*> const&, unsigned int, bool, bool&)"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper22GcMemmoveCollectableFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::GcMemmoveCollectableFn()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac22ObjCIvarOffsetVariableEPKN5clang17ObjCInterfaceDeclEPKNS1_12ObjCIvarDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::ObjCIvarOffsetVariable(clang::ObjCInterfaceDecl const*, clang::ObjCIvarDecl const*)"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper23getGcAssignStrongCastFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getGcAssignStrongCastFn()"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper17getGcAssignIvarFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getGcAssignIvarFn()"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper19getGcAssignGlobalFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getGcAssignGlobalFn()"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper24getGcAssignThreadLocalFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getGcAssignThreadLocalFn()"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper17getGcAssignWeakFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getGcAssignWeakFn()"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper15getGcReadWeakFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getGcReadWeakFn()"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper19getExceptionThrowFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getExceptionThrowFn()"},
    {"_ZN12_GLOBAL__N_116CallObjCEndCatchD1Ev", "(anonymous namespace)::CallObjCEndCatch::~CallObjCEndCatch()"},
    {"_ZN12_GLOBAL__N_116CallObjCEndCatchD0Ev", "(anonymous namespace)::CallObjCEndCatch::~CallObjCEndCatch()"},
    {"_ZN12_GLOBAL__N_116CallObjCEndCatch4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallObjCEndCatch::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper14getSyncEnterFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getSyncEnterFn()"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper13getSyncExitFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getSyncExitFn()"},
    {"_ZN12_GLOBAL__N_112CallSyncExitD1Ev", "(anonymous namespace)::CallSyncExit::~CallSyncExit()"},
    {"_ZN12_GLOBAL__N_112CallSyncExitD0Ev", "(anonymous namespace)::CallSyncExit::~CallSyncExit()"},
    {"_ZN12_GLOBAL__N_112CallSyncExit4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallSyncExit::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper24getEnumerationMutationFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getEnumerationMutationFn()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac14GetClassGlobalERKSs", "(anonymous namespace)::CGObjCNonFragileABIMac::GetClassGlobal(std::string const&)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac12EmitClassRefERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang17ObjCInterfaceDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitClassRef(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCInterfaceDecl const*)"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper15getCopyStructFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getCopyStructFn()"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper16getSetPropertyFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getSetPropertyFn()"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelper16getGetPropertyFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getGetPropertyFn()"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac24LegacyDispatchedSelectorEN5clang8SelectorE", "(anonymous namespace)::CGObjCNonFragileABIMac::LegacyDispatchedSelector(clang::Selector)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac21EmitLegacyMessageSendERN5clang7CodeGen15CodeGenFunctionENS2_15ReturnValueSlotENS1_8QualTypeEPN4llvm5ValueES9_S6_bRKNS7_11SmallVectorISt4pairINS2_6RValueES6_ELj16EEEPKNS1_14ObjCMethodDeclERKNS_21ObjCCommonTypesHelperE", "(anonymous namespace)::CGObjCCommonMac::EmitLegacyMessageSend(clang::CodeGen::CodeGenFunction&, clang::CodeGen::ReturnValueSlot, clang::QualType, llvm::Value*, llvm::Value*, clang::QualType, bool, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&, clang::ObjCMethodDecl const*, (anonymous namespace)::ObjCCommonTypesHelper const&)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac12EmitSelectorERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEN5clang8SelectorEb", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitSelector(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::Selector, bool)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac15EmitMessageSendERN5clang7CodeGen15CodeGenFunctionENS2_15ReturnValueSlotENS1_8QualTypeENS1_8SelectorEPN4llvm5ValueES6_bRKNS8_11SmallVectorISt4pairINS2_6RValueES6_ELj16EEE", "(anonymous namespace)::CGObjCNonFragileABIMac::EmitMessageSend(clang::CodeGen::CodeGenFunction&, clang::CodeGen::ReturnValueSlot, clang::QualType, clang::Selector, llvm::Value*, clang::QualType, bool, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&)"},
    {"_ZNK12_GLOBAL__N_121ObjCCommonTypesHelper21getMessageSendSuperFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getMessageSendSuperFn() const"},
    {"_ZNK12_GLOBAL__N_121ObjCCommonTypesHelper16getMessageSendFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getMessageSendFn() const"},
    {"_ZNK12_GLOBAL__N_121ObjCCommonTypesHelper22getMessageSendSuperFn2Ev", "(anonymous namespace)::ObjCCommonTypesHelper::getMessageSendSuperFn2() const"},
    {"_ZNK12_GLOBAL__N_121ObjCCommonTypesHelper21getMessageSendFpretFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getMessageSendFpretFn() const"},
    {"_ZNK12_GLOBAL__N_121ObjCCommonTypesHelper21getMessageSendStretFnEv", "(anonymous namespace)::ObjCCommonTypesHelper::getMessageSendStretFn() const"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac24BuildClassRoTInitializerEjjjPKN5clang22ObjCImplementationDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::BuildClassRoTInitializer(unsigned int, unsigned int, unsigned int, clang::ObjCImplementationDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac18BuildClassMetaDataERSsPN4llvm8ConstantES4_S4_b", "(anonymous namespace)::CGObjCNonFragileABIMac::BuildClassMetaData(std::string&, llvm::Constant*, llvm::Constant*, llvm::Constant*, bool)"},
    {"_Z25hasObjCExceptionAttributeRN5clang10ASTContextEPKNS_17ObjCInterfaceDeclE", "hasObjCExceptionAttribute(clang::ASTContext&, clang::ObjCInterfaceDecl const*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac18GetInterfaceEHTypeEPKN5clang17ObjCInterfaceDeclEb", "(anonymous namespace)::CGObjCNonFragileABIMac::GetInterfaceEHType(clang::ObjCInterfaceDecl const*, bool)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac15BuildIvarLayoutEPKN5clang22ObjCImplementationDeclEb", "(anonymous namespace)::CGObjCCommonMac::BuildIvarLayout(clang::ObjCImplementationDecl const*, bool)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac17GetMethodConstantEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::CGObjCNonFragileABIMac::GetMethodConstant(clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac16GetMethodVarTypeEPKN5clang9FieldDeclE", "(anonymous namespace)::CGObjCCommonMac::GetMethodVarType(clang::FieldDecl const*)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac19GetMethodDefinitionEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::CGObjCCommonMac::GetMethodDefinition(clang::ObjCMethodDecl const*)"},
    {"_ZSt4sortIPN12_GLOBAL__N_115CGObjCCommonMac7GC_IVAREEvT_S4_", "void std::sort<(anonymous namespace)::CGObjCCommonMac::GC_IVAR*>((anonymous namespace)::CGObjCCommonMac::GC_IVAR*, (anonymous namespace)::CGObjCCommonMac::GC_IVAR*)"},
    {"_ZSt16__introsort_loopIPN12_GLOBAL__N_115CGObjCCommonMac7GC_IVARElEvT_S4_T0_", "void std::__introsort_loop<(anonymous namespace)::CGObjCCommonMac::GC_IVAR*, long>((anonymous namespace)::CGObjCCommonMac::GC_IVAR*, (anonymous namespace)::CGObjCCommonMac::GC_IVAR*, long)"},
    {"_ZSt16__insertion_sortIPN12_GLOBAL__N_115CGObjCCommonMac7GC_IVAREEvT_S4_", "void std::__insertion_sort<(anonymous namespace)::CGObjCCommonMac::GC_IVAR*>((anonymous namespace)::CGObjCCommonMac::GC_IVAR*, (anonymous namespace)::CGObjCCommonMac::GC_IVAR*)"},
    {"_ZN12_GLOBAL__N_122CGObjCNonFragileABIMac18AddModuleClassListERKSt6vectorIPN4llvm11GlobalValueESaIS4_EEPKcSA_", "(anonymous namespace)::CGObjCNonFragileABIMac::AddModuleClassList(std::vector<llvm::GlobalValue*, std::allocator<llvm::GlobalValue*>> const&, char const*, char const*)"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMac13EmitImageInfoEv", "(anonymous namespace)::CGObjCCommonMac::EmitImageInfo()"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMacD2Ev", "(anonymous namespace)::CGObjCCommonMac::~CGObjCCommonMac()"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMacD1Ev", "(anonymous namespace)::CGObjCCommonMac::~CGObjCCommonMac()"},
    {"_ZN12_GLOBAL__N_115CGObjCCommonMacD0Ev", "(anonymous namespace)::CGObjCCommonMac::~CGObjCCommonMac()"},
    {"_ZN12_GLOBAL__N_121ObjCCommonTypesHelperC2ERN5clang7CodeGen13CodeGenModuleE", "(anonymous namespace)::ObjCCommonTypesHelper::ObjCCommonTypesHelper(clang::CodeGen::CodeGenModule&)"},
    {"_ZN12_GLOBAL__N_19CGObjCMacD1Ev", "(anonymous namespace)::CGObjCMac::~CGObjCMac()"},
    {"_ZN12_GLOBAL__N_19CGObjCMacD0Ev", "(anonymous namespace)::CGObjCMac::~CGObjCMac()"},
    {"_ZN12_GLOBAL__N_19CGObjCMac18ModuleInitFunctionEv", "(anonymous namespace)::CGObjCMac::ModuleInitFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCMac11GetSelectorERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEN5clang8SelectorEb", "(anonymous namespace)::CGObjCMac::GetSelector(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::Selector, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac11GetSelectorERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::CGObjCMac::GetSelector(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac9GetEHTypeEN5clang8QualTypeE", "(anonymous namespace)::CGObjCMac::GetEHType(clang::QualType)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac16GenerateCategoryEPKN5clang20ObjCCategoryImplDeclE", "(anonymous namespace)::CGObjCMac::GenerateCategory(clang::ObjCCategoryImplDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac13GenerateClassEPKN5clang22ObjCImplementationDeclE", "(anonymous namespace)::CGObjCMac::GenerateClass(clang::ObjCImplementationDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac19GenerateMessageSendERN5clang7CodeGen15CodeGenFunctionENS2_15ReturnValueSlotENS1_8QualTypeENS1_8SelectorEPN4llvm5ValueERKNS8_11SmallVectorISt4pairINS2_6RValueES6_ELj16EEEPKNS1_17ObjCInterfaceDeclEPKNS1_14ObjCMethodDeclE", "(anonymous namespace)::CGObjCMac::GenerateMessageSend(clang::CodeGen::CodeGenFunction&, clang::CodeGen::ReturnValueSlot, clang::QualType, clang::Selector, llvm::Value*, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&, clang::ObjCInterfaceDecl const*, clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac24GenerateMessageSendSuperERN5clang7CodeGen15CodeGenFunctionENS2_15ReturnValueSlotENS1_8QualTypeENS1_8SelectorEPKNS1_17ObjCInterfaceDeclEbPN4llvm5ValueEbRKNSB_11SmallVectorISt4pairINS2_6RValueES6_ELj16EEEPKNS1_14ObjCMethodDeclE", "(anonymous namespace)::CGObjCMac::GenerateMessageSendSuper(clang::CodeGen::CodeGenFunction&, clang::CodeGen::ReturnValueSlot, clang::QualType, clang::Selector, clang::ObjCInterfaceDecl const*, bool, llvm::Value*, bool, llvm::SmallVector<std::pair<clang::CodeGen::RValue, clang::QualType>, 16u> const&, clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac19GenerateProtocolRefERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang16ObjCProtocolDeclE", "(anonymous namespace)::CGObjCMac::GenerateProtocolRef(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCProtocolDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac22GetPropertyGetFunctionEv", "(anonymous namespace)::CGObjCMac::GetPropertyGetFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCMac22GetPropertySetFunctionEv", "(anonymous namespace)::CGObjCMac::GetPropertySetFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCMac20GetGetStructFunctionEv", "(anonymous namespace)::CGObjCMac::GetGetStructFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCMac20GetSetStructFunctionEv", "(anonymous namespace)::CGObjCMac::GetSetStructFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCMac8GetClassERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang17ObjCInterfaceDeclE", "(anonymous namespace)::CGObjCMac::GetClass(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCInterfaceDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac27EnumerationMutationFunctionEv", "(anonymous namespace)::CGObjCMac::EnumerationMutationFunction()"},
    {"_ZN12_GLOBAL__N_19CGObjCMac20EmitSynchronizedStmtERN5clang7CodeGen15CodeGenFunctionERKNS1_22ObjCAtSynchronizedStmtE", "(anonymous namespace)::CGObjCMac::EmitSynchronizedStmt(clang::CodeGen::CodeGenFunction&, clang::ObjCAtSynchronizedStmt const&)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac11EmitTryStmtERN5clang7CodeGen15CodeGenFunctionERKNS1_13ObjCAtTryStmtE", "(anonymous namespace)::CGObjCMac::EmitTryStmt(clang::CodeGen::CodeGenFunction&, clang::ObjCAtTryStmt const&)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac13EmitThrowStmtERN5clang7CodeGen15CodeGenFunctionERKNS1_15ObjCAtThrowStmtE", "(anonymous namespace)::CGObjCMac::EmitThrowStmt(clang::CodeGen::CodeGenFunction&, clang::ObjCAtThrowStmt const&)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac16EmitObjCWeakReadERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "(anonymous namespace)::CGObjCMac::EmitObjCWeakRead(clang::CodeGen::CodeGenFunction&, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac18EmitObjCWeakAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_", "(anonymous namespace)::CGObjCMac::EmitObjCWeakAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac20EmitObjCGlobalAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_b", "(anonymous namespace)::CGObjCMac::EmitObjCGlobalAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac18EmitObjCIvarAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_S7_", "(anonymous namespace)::CGObjCMac::EmitObjCIvarAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac24EmitObjCStrongCastAssignERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_", "(anonymous namespace)::CGObjCMac::EmitObjCStrongCastAssign(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac20EmitObjCValueForIvarERN5clang7CodeGen15CodeGenFunctionENS1_8QualTypeEPN4llvm5ValueEPKNS1_12ObjCIvarDeclEj", "(anonymous namespace)::CGObjCMac::EmitObjCValueForIvar(clang::CodeGen::CodeGenFunction&, clang::QualType, llvm::Value*, clang::ObjCIvarDecl const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac14EmitIvarOffsetERN5clang7CodeGen15CodeGenFunctionEPKNS1_17ObjCInterfaceDeclEPKNS1_12ObjCIvarDeclE", "(anonymous namespace)::CGObjCMac::EmitIvarOffset(clang::CodeGen::CodeGenFunction&, clang::ObjCInterfaceDecl const*, clang::ObjCIvarDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac24EmitGCMemmoveCollectableERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_S7_", "(anonymous namespace)::CGObjCMac::EmitGCMemmoveCollectable(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac17GetOrEmitProtocolEPKN5clang16ObjCProtocolDeclE", "(anonymous namespace)::CGObjCMac::GetOrEmitProtocol(clang::ObjCProtocolDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac20GetOrEmitProtocolRefEPKN5clang16ObjCProtocolDeclE", "(anonymous namespace)::CGObjCMac::GetOrEmitProtocolRef(clang::ObjCProtocolDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac28GetMethodDescriptionConstantEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::CGObjCMac::GetMethodDescriptionConstant(clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac16EmitProtocolListEN4llvm5TwineEPKPN5clang16ObjCProtocolDeclES7_", "(anonymous namespace)::CGObjCMac::EmitProtocolList(llvm::Twine, clang::ObjCProtocolDecl* const*, clang::ObjCProtocolDecl* const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac18EmitMethodDescListEN4llvm5TwineEPKcRKSt6vectorIPNS1_8ConstantESaIS7_EE", "(anonymous namespace)::CGObjCMac::EmitMethodDescList(llvm::Twine, char const*, std::vector<llvm::Constant*, std::allocator<llvm::Constant*>> const&)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac25EmitTryOrSynchronizedStmtERN5clang7CodeGen15CodeGenFunctionERKNS1_4StmtE", "(anonymous namespace)::CGObjCMac::EmitTryOrSynchronizedStmt(clang::CodeGen::CodeGenFunction&, clang::Stmt const&)"},
    {"_ZN12_GLOBAL__N_115ObjCTypesHelper22getExceptionTryEnterFnEv", "(anonymous namespace)::ObjCTypesHelper::getExceptionTryEnterFn()"},
    {"_ZN12_GLOBAL__N_115ObjCTypesHelper11getSetJmpFnEv", "(anonymous namespace)::ObjCTypesHelper::getSetJmpFn()"},
    {"_ZN12_GLOBAL__N_115ObjCTypesHelper21getExceptionExtractFnEv", "(anonymous namespace)::ObjCTypesHelper::getExceptionExtractFn()"},
    {"_ZN12_GLOBAL__N_19CGObjCMac12EmitClassRefERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEPKN5clang17ObjCInterfaceDeclE", "(anonymous namespace)::CGObjCMac::EmitClassRef(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::ObjCInterfaceDecl const*)"},
    {"_ZN12_GLOBAL__N_121PerformFragileFinallyD1Ev", "(anonymous namespace)::PerformFragileFinally::~PerformFragileFinally()"},
    {"_ZN12_GLOBAL__N_121PerformFragileFinallyD0Ev", "(anonymous namespace)::PerformFragileFinally::~PerformFragileFinally()"},
    {"_ZN12_GLOBAL__N_121PerformFragileFinally4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::PerformFragileFinally::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac12EmitSelectorERN4llvm9IRBuilderILb0ENS1_14ConstantFolderENS1_24IRBuilderDefaultInserterILb0EEEEEN5clang8SelectorEb", "(anonymous namespace)::CGObjCMac::EmitSelector(llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>&, clang::Selector, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac17GetMethodConstantEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::CGObjCMac::GetMethodConstant(clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac12EmitIvarListEPKN5clang22ObjCImplementationDeclEb", "(anonymous namespace)::CGObjCMac::EmitIvarList(clang::ObjCImplementationDecl const*, bool)"},
    {"_ZN12_GLOBAL__N_19CGObjCMac14EmitMethodListEN4llvm5TwineEPKcRKSt6vectorIPNS1_8ConstantESaIS7_EE", "(anonymous namespace)::CGObjCMac::EmitMethodList(llvm::Twine, char const*, std::vector<llvm::Constant*, std::allocator<llvm::Constant*>> const&)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEPNS_14GlobalVariableENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::IdentifierInfo*, llvm::GlobalVariable*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<llvm::GlobalVariable*>>::InsertIntoBucket(clang::IdentifierInfo* const&, llvm::GlobalVariable* const&, std::pair<clang::IdentifierInfo*, llvm::GlobalVariable*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEPNS_14GlobalVariableENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::IdentifierInfo*, llvm::GlobalVariable*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<llvm::GlobalVariable*>>::grow(unsigned int)"},
    {"_ZN4llvm9StringMapIPNS_14GlobalVariableENS_15MallocAllocatorEE16GetOrCreateValueIS2_EERNS_14StringMapEntryIS2_EENS_9StringRefET_", "llvm::StringMapEntry<llvm::GlobalVariable*>& llvm::StringMap<llvm::GlobalVariable*, llvm::MallocAllocator>::GetOrCreateValue<llvm::GlobalVariable*>(llvm::StringRef, llvm::GlobalVariable*)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEPNS_14GlobalVariableENS_12DenseMapInfoIS2_EENS5_IS4_EEE16InsertIntoBucketERKS2_RKS4_PSt4pairIS2_S4_E", "llvm::DenseMap<clang::Selector, llvm::GlobalVariable*, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<llvm::GlobalVariable*>>::InsertIntoBucket(clang::Selector const&, llvm::GlobalVariable* const&, std::pair<clang::Selector, llvm::GlobalVariable*>*)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEPNS_14GlobalVariableENS_12DenseMapInfoIS2_EENS5_IS4_EEE4growEj", "llvm::DenseMap<clang::Selector, llvm::GlobalVariable*, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<llvm::GlobalVariable*>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang9FieldDeclEE6appendINS1_11DeclContext22specific_decl_iteratorIS2_EEEEvT_S9_", "void llvm::SmallVectorImpl<clang::FieldDecl*>::append<clang::DeclContext::specific_decl_iterator<clang::FieldDecl>>(clang::DeclContext::specific_decl_iterator<clang::FieldDecl>, clang::DeclContext::specific_decl_iterator<clang::FieldDecl>)"},
    {"_ZN4llvm8DenseMapIPKN5clang14ObjCMethodDeclEPNS_8FunctionENS_12DenseMapInfoIS4_EENS7_IS6_EEE6insertERKSt4pairIS4_S6_E", "llvm::DenseMap<clang::ObjCMethodDecl const*, llvm::Function*, llvm::DenseMapInfo<clang::ObjCMethodDecl const*>, llvm::DenseMapInfo<llvm::Function*>>::insert(std::pair<clang::ObjCMethodDecl const*, llvm::Function*> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang14ObjCMethodDeclEPNS_8FunctionENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::ObjCMethodDecl const*, llvm::Function*, llvm::DenseMapInfo<clang::ObjCMethodDecl const*>, llvm::DenseMapInfo<llvm::Function*>>::InsertIntoBucket(clang::ObjCMethodDecl const* const&, llvm::Function* const&, std::pair<clang::ObjCMethodDecl const*, llvm::Function*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang14ObjCMethodDeclEPNS_8FunctionENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::ObjCMethodDecl const*, llvm::Function*, llvm::DenseMapInfo<clang::ObjCMethodDecl const*>, llvm::DenseMapInfo<llvm::Function*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEcNS_12DenseMapInfoIS3_EENS4_IcEEE6insertERKSt4pairIS3_cE", "llvm::DenseMap<clang::IdentifierInfo*, char, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<char>>::insert(std::pair<clang::IdentifierInfo*, char> const&)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEcNS_12DenseMapInfoIS3_EENS4_IcEEE16InsertIntoBucketERKS3_RKcPSt4pairIS3_cE", "llvm::DenseMap<clang::IdentifierInfo*, char, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<char>>::InsertIntoBucket(clang::IdentifierInfo* const&, char const&, std::pair<clang::IdentifierInfo*, char>*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEcNS_12DenseMapInfoIS3_EENS4_IcEEE4growEj", "llvm::DenseMap<clang::IdentifierInfo*, char, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZN4llvm9SetVectorISsSt6vectorISsSaISsEENS_8SmallSetISsLj16EEEED2Ev", "llvm::SetVector<std::string, std::vector<std::string, std::allocator<std::string>>, llvm::SmallSet<std::string, 16u>>::~SetVector()"},
    {"_ZNSt6vectorIPN5clang14IdentifierInfoESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::IdentifierInfo*, std::allocator<clang::IdentifierInfo*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::IdentifierInfo**, std::vector<clang::IdentifierInfo*, std::allocator<clang::IdentifierInfo*>>>, clang::IdentifierInfo* const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateGEPIPPNS_5ValueEEES7_S7_T_S9_RKNS_5TwineE", "llvm::Value* llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateGEP<llvm::Value**>(llvm::Value*, llvm::Value**, llvm::Value**, llvm::Twine const&)"},
    {"_ZN4llvm8SmallSetISsLj16EE6insertERKSs", "llvm::SmallSet<std::string, 16u>::insert(std::string const&)"},
    {"_ZN5clang7CodeGen13CodeGenModule23GetAddrOfRTTIDescriptorENS_8QualTypeEb", "clang::CodeGen::CodeGenModule::GetAddrOfRTTIDescriptor(clang::QualType, bool)"},
    {"_ZN12_GLOBAL__N_111RTTIBuilder13BuildTypeInfoEN5clang8QualTypeEb", "(anonymous namespace)::RTTIBuilder::BuildTypeInfo(clang::QualType, bool)"},
    {"_ZN5clang7CodeGen13CodeGenModule29EmitFundamentalRTTIDescriptorENS_8QualTypeE", "clang::CodeGen::CodeGenModule::EmitFundamentalRTTIDescriptor(clang::QualType)"},
    {"_ZN5clang7CodeGen13CodeGenModule30EmitFundamentalRTTIDescriptorsEv", "clang::CodeGen::CodeGenModule::EmitFundamentalRTTIDescriptors()"},
    {"_Z18getTypeInfoLinkageRN5clang7CodeGen13CodeGenModuleENS_8QualTypeE", "getTypeInfoLinkage(clang::CodeGen::CodeGenModule&, clang::QualType)"},
    {"_Z23CanUseSingleInheritancePKN5clang13CXXRecordDeclE", "CanUseSingleInheritance(clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_111RTTIBuilder20BuildPointerTypeInfoEN5clang8QualTypeE", "(anonymous namespace)::RTTIBuilder::BuildPointerTypeInfo(clang::QualType)"},
    {"_Z27ContainsIncompleteClassTypeN5clang8QualTypeE", "ContainsIncompleteClassType(clang::QualType)"},
    {"_Z28ComputeVMIClassTypeInfoFlagsPKN5clang16CXXBaseSpecifierERN12_GLOBAL__N_19SeenBasesE", "ComputeVMIClassTypeInfoFlags(clang::CXXBaseSpecifier const*, (anonymous namespace)::SeenBases&)"},
    {"_ZN5clang7CodeGen14CGBitFieldInfo8MakeInfoERNS0_12CodeGenTypesEPKNS_9FieldDeclEyyyj", "clang::CodeGen::CGBitFieldInfo::MakeInfo(clang::CodeGen::CodeGenTypes&, clang::FieldDecl const*, unsigned long long, unsigned long long, unsigned long long, unsigned int)"},
    {"_ZN5clang7CodeGen14CGBitFieldInfo8MakeInfoERNS0_12CodeGenTypesEPKNS_9FieldDeclEyy", "clang::CodeGen::CGBitFieldInfo::MakeInfo(clang::CodeGen::CodeGenTypes&, clang::FieldDecl const*, unsigned long long, unsigned long long)"},
    {"_ZN5clang7CodeGen12CodeGenTypes19ComputeRecordLayoutEPKNS_10RecordDeclE", "clang::CodeGen::CodeGenTypes::ComputeRecordLayout(clang::RecordDecl const*)"},
    {"_ZNK5clang7CodeGen14CGRecordLayout4dumpEv", "clang::CodeGen::CGRecordLayout::dump() const"},
    {"_ZNK5clang7CodeGen14CGRecordLayout5printERN4llvm11raw_ostreamE", "clang::CodeGen::CGRecordLayout::print(llvm::raw_ostream&) const"},
    {"_ZNK5clang7CodeGen14CGBitFieldInfo5printERN4llvm11raw_ostreamE", "clang::CodeGen::CGBitFieldInfo::print(llvm::raw_ostream&) const"},
    {"_ZNK5clang7CodeGen14CGBitFieldInfo4dumpEv", "clang::CodeGen::CGBitFieldInfo::dump() const"},
    {"_ZN4llvm25array_pod_sort_comparatorISt4pairIjPKN5clang7CodeGen14CGBitFieldInfoEEEEiPKvS9_", "int llvm::array_pod_sort_comparator<std::pair<unsigned int, clang::CodeGen::CGBitFieldInfo const*>>(void const*, void const*)"},
    {"_ZN12_GLOBAL__N_121CGRecordLayoutBuilder12LayoutFieldsEPKN5clang10RecordDeclE", "(anonymous namespace)::CGRecordLayoutBuilder::LayoutFields(clang::RecordDecl const*)"},
    {"_ZN12_GLOBAL__N_121CGRecordLayoutBuilder18LayoutVirtualBasesEPKN5clang13CXXRecordDeclERKNS1_15ASTRecordLayoutE", "(anonymous namespace)::CGRecordLayoutBuilder::LayoutVirtualBases(clang::CXXRecordDecl const*, clang::ASTRecordLayout const&)"},
    {"_ZN12_GLOBAL__N_121CGRecordLayoutBuilder17LayoutVirtualBaseEPKN5clang13CXXRecordDeclEy", "(anonymous namespace)::CGRecordLayoutBuilder::LayoutVirtualBase(clang::CXXRecordDecl const*, unsigned long long)"},
    {"_ZN12_GLOBAL__N_121CGRecordLayoutBuilder20LayoutNonVirtualBaseEPKN5clang13CXXRecordDeclEy", "(anonymous namespace)::CGRecordLayoutBuilder::LayoutNonVirtualBase(clang::CXXRecordDecl const*, unsigned long long)"},
    {"_ZNSt6vectorISt4pairIjPKN5clang7CodeGen14CGBitFieldInfoEESaIS6_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS6_S8_EERKS6_", "std::vector<std::pair<unsigned int, clang::CodeGen::CGBitFieldInfo const*>, std::allocator<std::pair<unsigned int, clang::CodeGen::CGBitFieldInfo const*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<unsigned int, clang::CodeGen::CGBitFieldInfo const*>*, std::vector<std::pair<unsigned int, clang::CodeGen::CGBitFieldInfo const*>, std::allocator<std::pair<unsigned int, clang::CodeGen::CGBitFieldInfo const*>>>>, std::pair<unsigned int, clang::CodeGen::CGBitFieldInfo const*> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang9FieldDeclENS1_7CodeGen14CGBitFieldInfoENS_12DenseMapInfoIS4_EENS7_IS6_EEE6insertERKSt4pairIS4_S6_E", "llvm::DenseMap<clang::FieldDecl const*, clang::CodeGen::CGBitFieldInfo, llvm::DenseMapInfo<clang::FieldDecl const*>, llvm::DenseMapInfo<clang::CodeGen::CGBitFieldInfo>>::insert(std::pair<clang::FieldDecl const*, clang::CodeGen::CGBitFieldInfo> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang9FieldDeclENS1_7CodeGen14CGBitFieldInfoENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::FieldDecl const*, clang::CodeGen::CGBitFieldInfo, llvm::DenseMapInfo<clang::FieldDecl const*>, llvm::DenseMapInfo<clang::CodeGen::CGBitFieldInfo>>::InsertIntoBucket(clang::FieldDecl const* const&, clang::CodeGen::CGBitFieldInfo const&, std::pair<clang::FieldDecl const*, clang::CodeGen::CGBitFieldInfo>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang9FieldDeclENS1_7CodeGen14CGBitFieldInfoENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::FieldDecl const*, clang::CodeGen::CGBitFieldInfo, llvm::DenseMapInfo<clang::FieldDecl const*>, llvm::DenseMapInfo<clang::CodeGen::CGBitFieldInfo>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang9FieldDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE6insertERKSt4pairIS4_jE", "llvm::DenseMap<clang::FieldDecl const*, unsigned int, llvm::DenseMapInfo<clang::FieldDecl const*>, llvm::DenseMapInfo<unsigned int>>::insert(std::pair<clang::FieldDecl const*, unsigned int> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang9FieldDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::FieldDecl const*, unsigned int, llvm::DenseMapInfo<clang::FieldDecl const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::FieldDecl const* const&, unsigned int const&, std::pair<clang::FieldDecl const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang9FieldDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::FieldDecl const*, unsigned int, llvm::DenseMapInfo<clang::FieldDecl const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE6insertERKSt4pairIS4_jE", "llvm::DenseMap<clang::CXXRecordDecl const*, unsigned int, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<unsigned int>>::insert(std::pair<clang::CXXRecordDecl const*, unsigned int> const&)"},
    {"_ZN5clang7CodeGen14CGRecordLayoutC2EPKN4llvm10StructTypeES5_b", "clang::CodeGen::CGRecordLayout::CGRecordLayout(llvm::StructType const*, llvm::StructType const*, bool)"},
    {"_ZNSt6vectorIPKN4llvm4TypeESaIS3_EEaSERKS5_", "std::vector<llvm::Type const*, std::allocator<llvm::Type const*>>::operator=(std::vector<llvm::Type const*, std::allocator<llvm::Type const*>> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairIPKN5clang9FieldDeclENS2_7CodeGen14CGBitFieldInfoEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<clang::FieldDecl const*, clang::CodeGen::CGBitFieldInfo>, false>::grow(unsigned long)"},
    {"_ZN5clang7CodeGen15CodeGenFunction13EmitStopPointEPKNS_4StmtE", "clang::CodeGen::CodeGenFunction::EmitStopPoint(clang::Stmt const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction8EmitStmtEPKNS_4StmtE", "clang::CodeGen::CodeGenFunction::EmitStmt(clang::Stmt const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitSimpleStmtEPKNS_4StmtE", "clang::CodeGen::CodeGenFunction::EmitSimpleStmt(clang::Stmt const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20EmitIndirectGotoStmtERKNS_16IndirectGotoStmtE", "clang::CodeGen::CodeGenFunction::EmitIndirectGotoStmt(clang::IndirectGotoStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction10EmitIfStmtERKNS_6IfStmtE", "clang::CodeGen::CodeGenFunction::EmitIfStmt(clang::IfStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction13EmitWhileStmtERKNS_9WhileStmtE", "clang::CodeGen::CodeGenFunction::EmitWhileStmt(clang::WhileStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction10EmitDoStmtERKNS_6DoStmtE", "clang::CodeGen::CodeGenFunction::EmitDoStmt(clang::DoStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction11EmitForStmtERKNS_7ForStmtE", "clang::CodeGen::CodeGenFunction::EmitForStmt(clang::ForStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitReturnStmtERKNS_10ReturnStmtE", "clang::CodeGen::CodeGenFunction::EmitReturnStmt(clang::ReturnStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14EmitSwitchStmtERKNS_10SwitchStmtE", "clang::CodeGen::CodeGenFunction::EmitSwitchStmt(clang::SwitchStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction11EmitAsmStmtERKNS_7AsmStmtE", "clang::CodeGen::CodeGenFunction::EmitAsmStmt(clang::AsmStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitCompoundStmtERKNS_12CompoundStmtEbNS0_12AggValueSlotE", "clang::CodeGen::CodeGenFunction::EmitCompoundStmt(clang::CompoundStmt const&, bool, clang::CodeGen::AggValueSlot)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12EmitDeclStmtERKNS_8DeclStmtE", "clang::CodeGen::CodeGenFunction::EmitDeclStmt(clang::DeclStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction13EmitLabelStmtERKNS_9LabelStmtE", "clang::CodeGen::CodeGenFunction::EmitLabelStmt(clang::LabelStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12EmitGotoStmtERKNS_8GotoStmtE", "clang::CodeGen::CodeGenFunction::EmitGotoStmt(clang::GotoStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction13EmitBreakStmtERKNS_9BreakStmtE", "clang::CodeGen::CodeGenFunction::EmitBreakStmt(clang::BreakStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitContinueStmtERKNS_12ContinueStmtE", "clang::CodeGen::CodeGenFunction::EmitContinueStmt(clang::ContinueStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15EmitDefaultStmtERKNS_11DefaultStmtE", "clang::CodeGen::CodeGenFunction::EmitDefaultStmt(clang::DefaultStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12EmitCaseStmtERKNS_8CaseStmtE", "clang::CodeGen::CodeGenFunction::EmitCaseStmt(clang::CaseStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction9EmitLabelERKNS_9LabelStmtE", "clang::CodeGen::CodeGenFunction::EmitLabel(clang::LabelStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24SimplifyForwardingBlocksEPN4llvm10BasicBlockE", "clang::CodeGen::CodeGenFunction::SimplifyForwardingBlocks(llvm::BasicBlock*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction9EmitBlockEPN4llvm10BasicBlockEb", "clang::CodeGen::CodeGenFunction::EmitBlock(llvm::BasicBlock*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction10EmitBranchEPN4llvm10BasicBlockE", "clang::CodeGen::CodeGenFunction::EmitBranch(llvm::BasicBlock*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction19getJumpDestForLabelEPKNS_9LabelStmtE", "clang::CodeGen::CodeGenFunction::getJumpDestForLabel(clang::LabelStmt const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitReturnOfRValueENS0_6RValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitReturnOfRValue(clang::CodeGen::RValue, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17EmitCaseStmtRangeERKNS_8CaseStmtE", "clang::CodeGen::CodeGenFunction::EmitCaseStmtRange(clang::CaseStmt const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction18EmitAsmInputLValueERKNS_7AsmStmtERKNS_10TargetInfo14ConstraintInfoENS0_6LValueENS_8QualTypeERSs", "clang::CodeGen::CodeGenFunction::EmitAsmInputLValue(clang::AsmStmt const&, clang::TargetInfo::ConstraintInfo const&, clang::CodeGen::LValue, clang::QualType, std::string&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12EmitAsmInputERKNS_7AsmStmtERKNS_10TargetInfo14ConstraintInfoEPKNS_4ExprERSs", "clang::CodeGen::CodeGenFunction::EmitAsmInput(clang::AsmStmt const&, clang::TargetInfo::ConstraintInfo const&, clang::Expr const*, std::string&)"},
    {"_Z18SimplifyConstraintPKcRKN5clang10TargetInfoEPN4llvm15SmallVectorImplINS2_14ConstraintInfoEEE", "SimplifyConstraint(char const*, clang::TargetInfo const&, llvm::SmallVectorImpl<clang::TargetInfo::ConstraintInfo>*)"},
    {"_Z22AddVariableConstraintsRKSsRKN5clang4ExprERKNS1_10TargetInfoERNS1_7CodeGen13CodeGenModuleERKNS1_7AsmStmtE", "AddVariableConstraints(std::string const&, clang::Expr const&, clang::TargetInfo const&, clang::CodeGen::CodeGenModule&, clang::AsmStmt const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE12CreateSwitchEPNS_5ValueEPNS_10BasicBlockEj", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateSwitch(llvm::Value*, llvm::BasicBlock*, unsigned int)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateCallIN9__gnu_cxx17__normal_iteratorIPPNS_5ValueESt6vectorIS9_SaIS9_EEEEEEPNS_8CallInstES9_T_SH_RKNS_5TwineE", "llvm::CallInst* llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateCall<__gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>>(llvm::Value*, __gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>, __gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>, llvm::Twine const&)"},
    {"_ZNSt6vectorIN5clang7CodeGen6LValueESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::CodeGen::LValue, std::allocator<clang::CodeGen::LValue>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::CodeGen::LValue*, std::vector<clang::CodeGen::LValue, std::allocator<clang::CodeGen::LValue>>>, clang::CodeGen::LValue const&)"},
    {"_ZNSt6vectorIN5clang8QualTypeESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<clang::QualType, std::allocator<clang::QualType>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::QualType*, std::vector<clang::QualType, std::allocator<clang::QualType>>>, clang::QualType const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclEPNS_5ValueENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::VarDecl const*, llvm::Value*, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<llvm::Value*>>::InsertIntoBucket(clang::VarDecl const* const&, llvm::Value* const&, std::pair<clang::VarDecl const*, llvm::Value*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclEPNS_5ValueENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::VarDecl const*, llvm::Value*, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<llvm::Value*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang9LabelStmtENS1_7CodeGen15CodeGenFunction8JumpDestENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::LabelStmt const*, clang::CodeGen::CodeGenFunction::JumpDest, llvm::DenseMapInfo<clang::LabelStmt const*>, llvm::DenseMapInfo<clang::CodeGen::CodeGenFunction::JumpDest>>::InsertIntoBucket(clang::LabelStmt const* const&, clang::CodeGen::CodeGenFunction::JumpDest const&, std::pair<clang::LabelStmt const*, clang::CodeGen::CodeGenFunction::JumpDest>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang9LabelStmtENS1_7CodeGen15CodeGenFunction8JumpDestENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::LabelStmt const*, clang::CodeGen::CodeGenFunction::JumpDest, llvm::DenseMapInfo<clang::LabelStmt const*>, llvm::DenseMapInfo<clang::CodeGen::CodeGenFunction::JumpDest>>::grow(unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitCXXTemporaryEPKNS_12CXXTemporaryEPN4llvm5ValueE", "clang::CodeGen::CodeGenFunction::EmitCXXTemporary(clang::CXXTemporary const*, llvm::Value*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20EmitExprWithCleanupsEPKNS_16ExprWithCleanupsENS0_12AggValueSlotE", "clang::CodeGen::CodeGenFunction::EmitExprWithCleanups(clang::ExprWithCleanups const*, clang::CodeGen::AggValueSlot)"},
    {"_ZN5clang7CodeGen15CodeGenFunction26EmitExprWithCleanupsLValueEPKNS_16ExprWithCleanupsE", "clang::CodeGen::CodeGenFunction::EmitExprWithCleanupsLValue(clang::ExprWithCleanups const*)"},
    {"_ZN5clang7CodeGen12EHScopeStack19ConditionalCleanup2IN12_GLOBAL__N_116DestroyTemporaryEPKNS_17CXXDestructorDeclEPN4llvm5ValueEED1Ev", "clang::CodeGen::EHScopeStack::ConditionalCleanup2<(anonymous namespace)::DestroyTemporary, clang::CXXDestructorDecl const*, llvm::Value*>::~ConditionalCleanup2()"},
    {"_ZN5clang7CodeGen12EHScopeStack19ConditionalCleanup2IN12_GLOBAL__N_116DestroyTemporaryEPKNS_17CXXDestructorDeclEPN4llvm5ValueEED0Ev", "clang::CodeGen::EHScopeStack::ConditionalCleanup2<(anonymous namespace)::DestroyTemporary, clang::CXXDestructorDecl const*, llvm::Value*>::~ConditionalCleanup2()"},
    {"_ZN5clang7CodeGen12EHScopeStack19ConditionalCleanup2IN12_GLOBAL__N_116DestroyTemporaryEPKNS_17CXXDestructorDeclEPN4llvm5ValueEE4EmitERNS0_15CodeGenFunctionEb", "clang::CodeGen::EHScopeStack::ConditionalCleanup2<(anonymous namespace)::DestroyTemporary, clang::CXXDestructorDecl const*, llvm::Value*>::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN5clang7CodeGen12EHScopeStack21UnconditionalCleanup2IN12_GLOBAL__N_116DestroyTemporaryEPKNS_17CXXDestructorDeclEPN4llvm5ValueEED1Ev", "clang::CodeGen::EHScopeStack::UnconditionalCleanup2<(anonymous namespace)::DestroyTemporary, clang::CXXDestructorDecl const*, llvm::Value*>::~UnconditionalCleanup2()"},
    {"_ZN5clang7CodeGen12EHScopeStack21UnconditionalCleanup2IN12_GLOBAL__N_116DestroyTemporaryEPKNS_17CXXDestructorDeclEPN4llvm5ValueEED0Ev", "clang::CodeGen::EHScopeStack::UnconditionalCleanup2<(anonymous namespace)::DestroyTemporary, clang::CXXDestructorDecl const*, llvm::Value*>::~UnconditionalCleanup2()"},
    {"_ZN5clang7CodeGen12EHScopeStack21UnconditionalCleanup2IN12_GLOBAL__N_116DestroyTemporaryEPKNS_17CXXDestructorDeclEPN4llvm5ValueEE4EmitERNS0_15CodeGenFunctionEb", "clang::CodeGen::EHScopeStack::UnconditionalCleanup2<(anonymous namespace)::DestroyTemporary, clang::CXXDestructorDecl const*, llvm::Value*>::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN5clang7CodeGen14CodeGenVTables17EmitVTTDefinitionEPN4llvm14GlobalVariableENS2_11GlobalValue12LinkageTypesEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenVTables::EmitVTTDefinition(llvm::GlobalVariable*, llvm::GlobalValue::LinkageTypes, clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_110VTTBuilderC1ERN5clang7CodeGen13CodeGenModuleEPKNS1_13CXXRecordDeclEb", "(anonymous namespace)::VTTBuilder::VTTBuilder(clang::CodeGen::CodeGenModule&, clang::CXXRecordDecl const*, bool)"},
    {"_ZN5clang7CodeGen14CodeGenVTables12GetAddrOfVTTEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenVTables::GetAddrOfVTT(clang::CXXRecordDecl const*)"},
    {"_ZN5clang7CodeGen14CodeGenVTables17needsVTTParameterENS0_10GlobalDeclE", "clang::CodeGen::CodeGenVTables::needsVTTParameter(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen14CodeGenVTables14getSubVTTIndexEPKNS_13CXXRecordDeclENS0_13BaseSubobjectE", "clang::CodeGen::CodeGenVTables::getSubVTTIndex(clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject)"},
    {"_ZN5clang7CodeGen14CodeGenVTables31getSecondaryVirtualPointerIndexEPKNS_13CXXRecordDeclENS0_13BaseSubobjectE", "clang::CodeGen::CodeGenVTables::getSecondaryVirtualPointerIndex(clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject)"},
    {"_ZN12_GLOBAL__N_110VTTBuilder9LayoutVTTEN5clang7CodeGen13BaseSubobjectEb", "(anonymous namespace)::VTTBuilder::LayoutVTT(clang::CodeGen::BaseSubobject, bool)"},
    {"_ZN12_GLOBAL__N_110VTTBuilder16AddVTablePointerEN5clang7CodeGen13BaseSubobjectEPN4llvm8ConstantEPKNS1_13CXXRecordDeclERKNS4_8DenseMapIS3_yNS4_12DenseMapInfoIS3_EENSB_IyEEEE", "(anonymous namespace)::VTTBuilder::AddVTablePointer(clang::CodeGen::BaseSubobject, llvm::Constant*, clang::CXXRecordDecl const*, llvm::DenseMap<clang::CodeGen::BaseSubobject, unsigned long long, llvm::DenseMapInfo<clang::CodeGen::BaseSubobject>, llvm::DenseMapInfo<unsigned long long>> const&)"},
    {"_ZN12_GLOBAL__N_110VTTBuilder17LayoutVirtualVTTsEPKN5clang13CXXRecordDeclERN4llvm11SmallPtrSetIS4_Lj4EEE", "(anonymous namespace)::VTTBuilder::LayoutVirtualVTTs(clang::CXXRecordDecl const*, llvm::SmallPtrSet<clang::CXXRecordDecl const*, 4u>&)"},
    {"_ZN12_GLOBAL__N_110VTTBuilder30LayoutSecondaryVirtualPointersEN5clang7CodeGen13BaseSubobjectEbPN4llvm8ConstantEPKNS1_13CXXRecordDeclERKNS4_8DenseMapIS3_yNS4_12DenseMapInfoIS3_EENSB_IyEEEERNS4_11SmallPtrSetIS9_Lj4EEE", "(anonymous namespace)::VTTBuilder::LayoutSecondaryVirtualPointers(clang::CodeGen::BaseSubobject, bool, llvm::Constant*, clang::CXXRecordDecl const*, llvm::DenseMap<clang::CodeGen::BaseSubobject, unsigned long long, llvm::DenseMapInfo<clang::CodeGen::BaseSubobject>, llvm::DenseMapInfo<unsigned long long>> const&, llvm::SmallPtrSet<clang::CXXRecordDecl const*, 4u>&)"},
    {"_ZN4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclENS2_7CodeGen13BaseSubobjectEEyNS_12DenseMapInfoIS8_EENS9_IyEEE6insertERKS1_IS8_yE", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>, unsigned long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>>, llvm::DenseMapInfo<unsigned long long>>::insert(std::pair<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>, unsigned long long> const&)"},
    {"_ZN4llvm8DenseMapIN5clang7CodeGen13BaseSubobjectEyNS_12DenseMapInfoIS3_EENS4_IyEEE16FindAndConstructERKS3_", "llvm::DenseMap<clang::CodeGen::BaseSubobject, unsigned long long, llvm::DenseMapInfo<clang::CodeGen::BaseSubobject>, llvm::DenseMapInfo<unsigned long long>>::FindAndConstruct(clang::CodeGen::BaseSubobject const&)"},
    {"_ZN5clang7CodeGen14CodeGenVTables26ComputeMethodVTableIndicesEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenVTables::ComputeMethodVTableIndices(clang::CXXRecordDecl const*)"},
    {"_ZN5clang7CodeGen14CodeGenVTables29getNumVirtualFunctionPointersEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenVTables::getNumVirtualFunctionPointers(clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_127FindNearestOverriddenMethodEPKN5clang13CXXMethodDeclERN4llvm14SmallSetVectorIPKNS0_13CXXRecordDeclELj8EEE", "(anonymous namespace)::FindNearestOverriddenMethod(clang::CXXMethodDecl const*, llvm::SmallSetVector<clang::CXXRecordDecl const*, 8u>&)"},
    {"_ZN12_GLOBAL__N_133ComputeReturnAdjustmentBaseOffsetERN5clang10ASTContextEPKNS0_13CXXMethodDeclES5_", "(anonymous namespace)::ComputeReturnAdjustmentBaseOffset(clang::ASTContext&, clang::CXXMethodDecl const*, clang::CXXMethodDecl const*)"},
    {"_ZN5clang7CodeGen14CodeGenVTables20getMethodVTableIndexENS0_10GlobalDeclE", "clang::CodeGen::CodeGenVTables::getMethodVTableIndex(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen14CodeGenVTables24ShouldEmitVTableInThisTUEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenVTables::ShouldEmitVTableInThisTU(clang::CXXRecordDecl const*)"},
    {"_ZN5clang7CodeGen14CodeGenVTables26getVirtualBaseOffsetOffsetEPKNS_13CXXRecordDeclES4_", "clang::CodeGen::CodeGenVTables::getVirtualBaseOffsetOffset(clang::CXXRecordDecl const*, clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_126VCallAndVBaseOffsetBuilderC1EPKN5clang13CXXRecordDeclES4_PKNS_15FinalOverridersENS1_7CodeGen13BaseSubobjectEby", "(anonymous namespace)::VCallAndVBaseOffsetBuilder::VCallAndVBaseOffsetBuilder(clang::CXXRecordDecl const*, clang::CXXRecordDecl const*, (anonymous namespace)::FinalOverriders const*, clang::CodeGen::BaseSubobject, bool, unsigned long long)"},
    {"_ZN5clang7CodeGen14CodeGenVTables15getAddressPointENS0_13BaseSubobjectEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenVTables::getAddressPoint(clang::CodeGen::BaseSubobject, clang::CXXRecordDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule14GetAddrOfThunkENS0_10GlobalDeclERKNS_9ThunkInfoE", "clang::CodeGen::CodeGenModule::GetAddrOfThunk(clang::CodeGen::GlobalDecl, clang::ThunkInfo const&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction13GenerateThunkEPN4llvm8FunctionENS0_10GlobalDeclERKNS_9ThunkInfoE", "clang::CodeGen::CodeGenFunction::GenerateThunk(llvm::Function*, clang::CodeGen::GlobalDecl, clang::ThunkInfo const&)"},
    {"_Z21PerformTypeAdjustmentRN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueExx", "PerformTypeAdjustment(clang::CodeGen::CodeGenFunction&, llvm::Value*, long long, long long)"},
    {"_ZN5clang7CodeGen14CodeGenVTables9EmitThunkENS0_10GlobalDeclERKNS_9ThunkInfoEb", "clang::CodeGen::CodeGenVTables::EmitThunk(clang::CodeGen::GlobalDecl, clang::ThunkInfo const&, bool)"},
    {"_ZN5clang7CodeGen14CodeGenVTables33MaybeEmitThunkAvailableExternallyENS0_10GlobalDeclERKNS_9ThunkInfoE", "clang::CodeGen::CodeGenVTables::MaybeEmitThunkAvailableExternally(clang::CodeGen::GlobalDecl, clang::ThunkInfo const&)"},
    {"_ZN5clang7CodeGen14CodeGenVTables10EmitThunksENS0_10GlobalDeclE", "clang::CodeGen::CodeGenVTables::EmitThunks(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen14CodeGenVTables31ComputeVTableRelatedInformationEPKNS_13CXXRecordDeclEb", "clang::CodeGen::CodeGenVTables::ComputeVTableRelatedInformation(clang::CXXRecordDecl const*, bool)"},
    {"_ZN12_GLOBAL__N_113VTableBuilderC1ERN5clang7CodeGen14CodeGenVTablesEPKNS1_13CXXRecordDeclEybS7_", "(anonymous namespace)::VTableBuilder::VTableBuilder(clang::CodeGen::CodeGenVTables&, clang::CXXRecordDecl const*, unsigned long long, bool, clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_113VTableBuilderD1Ev", "(anonymous namespace)::VTableBuilder::~VTableBuilder()"},
    {"_ZN5clang7CodeGen14CodeGenVTables23CreateVTableInitializerEPKNS_13CXXRecordDeclEPKyjRKN4llvm11SmallVectorISt4pairIyNS_9ThunkInfoEELj1EEE", "clang::CodeGen::CodeGenVTables::CreateVTableInitializer(clang::CXXRecordDecl const*, unsigned long long const*, unsigned int, llvm::SmallVector<std::pair<unsigned long long, clang::ThunkInfo>, 1u> const&)"},
    {"_ZN5clang7CodeGen14CodeGenVTables15GetAddrOfVTableEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenVTables::GetAddrOfVTable(clang::CXXRecordDecl const*)"},
    {"_ZN5clang7CodeGen14CodeGenVTables20EmitVTableDefinitionEPN4llvm14GlobalVariableENS2_11GlobalValue12LinkageTypesEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenVTables::EmitVTableDefinition(llvm::GlobalVariable*, llvm::GlobalValue::LinkageTypes, clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_113VTableBuilder10dumpLayoutERN4llvm11raw_ostreamE", "(anonymous namespace)::VTableBuilder::dumpLayout(llvm::raw_ostream&)"},
    {"_ZN5clang7CodeGen14CodeGenVTables26GenerateConstructionVTableEPKNS_13CXXRecordDeclERKNS0_13BaseSubobjectEbRN4llvm8DenseMapIS5_yNS8_12DenseMapInfoIS5_EENSA_IyEEEE", "clang::CodeGen::CodeGenVTables::GenerateConstructionVTable(clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject const&, bool, llvm::DenseMap<clang::CodeGen::BaseSubobject, unsigned long long, llvm::DenseMapInfo<clang::CodeGen::BaseSubobject>, llvm::DenseMapInfo<unsigned long long>>&)"},
    {"_ZN5clang7CodeGen14CodeGenVTables17GenerateClassDataEN4llvm11GlobalValue12LinkageTypesEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenVTables::GenerateClassData(llvm::GlobalValue::LinkageTypes, clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_113VTableBuilder32LayoutPrimaryAndSecondaryVTablesEN5clang7CodeGen13BaseSubobjectEbby", "(anonymous namespace)::VTableBuilder::LayoutPrimaryAndSecondaryVTables(clang::CodeGen::BaseSubobject, bool, bool, unsigned long long)"},
    {"_ZN12_GLOBAL__N_113VTableBuilder28DeterminePrimaryVirtualBasesEPKN5clang13CXXRecordDeclEyRN4llvm11SmallPtrSetIS4_Lj4EEE", "(anonymous namespace)::VTableBuilder::DeterminePrimaryVirtualBases(clang::CXXRecordDecl const*, unsigned long long, llvm::SmallPtrSet<clang::CXXRecordDecl const*, 4u>&)"},
    {"_ZN12_GLOBAL__N_113VTableBuilder28LayoutVTablesForVirtualBasesEPKN5clang13CXXRecordDeclERN4llvm11SmallPtrSetIS4_Lj4EEE", "(anonymous namespace)::VTableBuilder::LayoutVTablesForVirtualBases(clang::CXXRecordDecl const*, llvm::SmallPtrSet<clang::CXXRecordDecl const*, 4u>&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEN12_GLOBAL__N_114VCallOffsetMapENS_12DenseMapInfoIS4_EENS7_IS6_EEEixERKS4_", "llvm::DenseMap<clang::CXXRecordDecl const*, (anonymous namespace)::VCallOffsetMap, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<(anonymous namespace)::VCallOffsetMap>>::operator[](clang::CXXRecordDecl const* const&)"},
    {"_ZN12_GLOBAL__N_113VTableBuilder10AddMethodsEN5clang7CodeGen13BaseSubobjectEyPKNS1_13CXXRecordDeclEyRN4llvm14SmallSetVectorIS6_Lj8EEE", "(anonymous namespace)::VTableBuilder::AddMethods(clang::CodeGen::BaseSubobject, unsigned long long, clang::CXXRecordDecl const*, unsigned long long, llvm::SmallSetVector<clang::CXXRecordDecl const*, 8u>&)"},
    {"_ZN12_GLOBAL__N_113VTableBuilder22LayoutSecondaryVTablesEN5clang7CodeGen13BaseSubobjectEby", "(anonymous namespace)::VTableBuilder::LayoutSecondaryVTables(clang::CodeGen::BaseSubobject, bool, unsigned long long)"},
    {"_ZN12_GLOBAL__N_113VTableBuilder21ComputeThisAdjustmentEPKN5clang13CXXMethodDeclEyNS_15FinalOverriders13OverriderInfoE", "(anonymous namespace)::VTableBuilder::ComputeThisAdjustment(clang::CXXMethodDecl const*, unsigned long long, (anonymous namespace)::FinalOverriders::OverriderInfo)"},
    {"_ZN12_GLOBAL__N_114VCallOffsetMap26MethodsCanShareVCallOffsetEPKN5clang13CXXMethodDeclES4_", "(anonymous namespace)::VCallOffsetMap::MethodsCanShareVCallOffset(clang::CXXMethodDecl const*, clang::CXXMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_117ComputeBaseOffsetERN5clang10ASTContextEPKNS0_13CXXRecordDeclERKNS0_11CXXBasePathE", "(anonymous namespace)::ComputeBaseOffset(clang::ASTContext&, clang::CXXRecordDecl const*, clang::CXXBasePath const&)"},
    {"_ZNK4llvm8DenseMapISt4pairIPKN5clang13CXXMethodDeclEyEN12_GLOBAL__N_115FinalOverriders13OverriderInfoENS_12DenseMapInfoIS6_EENSA_IS9_EEE15LookupBucketForERKS6_RPS1_IS6_S9_E", "llvm::DenseMap<std::pair<clang::CXXMethodDecl const*, unsigned long long>, (anonymous namespace)::FinalOverriders::OverriderInfo, llvm::DenseMapInfo<std::pair<clang::CXXMethodDecl const*, unsigned long long>>, llvm::DenseMapInfo<(anonymous namespace)::FinalOverriders::OverriderInfo>>::LookupBucketFor(std::pair<clang::CXXMethodDecl const*, unsigned long long> const&, std::pair<std::pair<clang::CXXMethodDecl const*, unsigned long long>, (anonymous namespace)::FinalOverriders::OverriderInfo>*&) const"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclEN12_GLOBAL__N_113VTableBuilder10MethodInfoENS_12DenseMapInfoIS4_EENS8_IS7_EEE6insertERKSt4pairIS4_S7_E", "llvm::DenseMap<clang::CXXMethodDecl const*, (anonymous namespace)::VTableBuilder::MethodInfo, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<(anonymous namespace)::VTableBuilder::MethodInfo>>::insert(std::pair<clang::CXXMethodDecl const*, (anonymous namespace)::VTableBuilder::MethodInfo> const&)"},
    {"_ZN12_GLOBAL__N_130OverridesIndirectMethodInBasesEPKN5clang13CXXMethodDeclERN4llvm14SmallSetVectorIPKNS0_13CXXRecordDeclELj8EEE", "(anonymous namespace)::OverridesIndirectMethodInBases(clang::CXXMethodDecl const*, llvm::SmallSetVector<clang::CXXRecordDecl const*, 8u>&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclEN12_GLOBAL__N_113VTableBuilder10MethodInfoENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::CXXMethodDecl const*, (anonymous namespace)::VTableBuilder::MethodInfo, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<(anonymous namespace)::VTableBuilder::MethodInfo>>::InsertIntoBucket(clang::CXXMethodDecl const* const&, (anonymous namespace)::VTableBuilder::MethodInfo const&, std::pair<clang::CXXMethodDecl const*, (anonymous namespace)::VTableBuilder::MethodInfo>*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN12_GLOBAL__N_115VTableComponentELb0EE4growEm", "llvm::SmallVectorTemplateBase<(anonymous namespace)::VTableComponent, false>::grow(unsigned long)"},
    {"_ZN12_GLOBAL__N_115FinalOverriders18ComputeBaseOffsetsEN5clang7CodeGen13BaseSubobjectEbyRN4llvm8DenseMapISt4pairIPKNS1_13CXXRecordDeclEjEyNS4_12DenseMapInfoISA_EENSB_IyEEEESF_RNS5_IS9_jNSB_IS9_EENSB_IjEEEE", "(anonymous namespace)::FinalOverriders::ComputeBaseOffsets(clang::CodeGen::BaseSubobject, bool, unsigned long long, llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, unsigned int>, unsigned long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, unsigned int>>, llvm::DenseMapInfo<unsigned long long>>&, llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, unsigned int>, unsigned long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, unsigned int>>, llvm::DenseMapInfo<unsigned long long>>&, llvm::DenseMap<clang::CXXRecordDecl const*, unsigned int, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<unsigned int>>&)"},
    {"_ZN12_GLOBAL__N_126VCallAndVBaseOffsetBuilder23AddVCallAndVBaseOffsetsEN5clang7CodeGen13BaseSubobjectEby", "(anonymous namespace)::VCallAndVBaseOffsetBuilder::AddVCallAndVBaseOffsets(clang::CodeGen::BaseSubobject, bool, unsigned long long)"},
    {"_ZN12_GLOBAL__N_126VCallAndVBaseOffsetBuilder15AddVBaseOffsetsEPKN5clang13CXXRecordDeclEy", "(anonymous namespace)::VCallAndVBaseOffsetBuilder::AddVBaseOffsets(clang::CXXRecordDecl const*, unsigned long long)"},
    {"_ZN12_GLOBAL__N_126VCallAndVBaseOffsetBuilder15AddVCallOffsetsEN5clang7CodeGen13BaseSubobjectEy", "(anonymous namespace)::VCallAndVBaseOffsetBuilder::AddVCallOffsets(clang::CodeGen::BaseSubobject, unsigned long long)"},
    {"_ZN12_GLOBAL__N_127ComputeAllOverriddenMethodsEPKN5clang13CXXMethodDeclERN4llvm11SmallPtrSetIS3_Lj8EEE", "(anonymous namespace)::ComputeAllOverriddenMethods(clang::CXXMethodDecl const*, llvm::SmallPtrSet<clang::CXXMethodDecl const*, 8u>&)"},
    {"_ZN4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclES5_ExNS_12DenseMapInfoIS6_EENS7_IxEEE6insertERKS1_IS6_xE", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>, long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>>, llvm::DenseMapInfo<long long>>::insert(std::pair<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>, long long> const&)"},
    {"_ZN4llvm15SmallVectorImplISt4pairIyN5clang9ThunkInfoEEE6appendINS_16DenseMapIteratorIyS3_NS_12DenseMapInfoIyEENS8_IS3_EELb1EEEEEvT_SC_", "void llvm::SmallVectorImpl<std::pair<unsigned long long, clang::ThunkInfo>>::append<llvm::DenseMapIterator<unsigned long long, clang::ThunkInfo, llvm::DenseMapInfo<unsigned long long>, llvm::DenseMapInfo<clang::ThunkInfo>, true>>(llvm::DenseMapIterator<unsigned long long, clang::ThunkInfo, llvm::DenseMapInfo<unsigned long long>, llvm::DenseMapInfo<clang::ThunkInfo>, true>, llvm::DenseMapIterator<unsigned long long, clang::ThunkInfo, llvm::DenseMapInfo<unsigned long long>, llvm::DenseMapInfo<clang::ThunkInfo>, true>)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEPNS_14GlobalVariableENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::CXXRecordDecl const*, llvm::GlobalVariable*, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<llvm::GlobalVariable*>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, llvm::GlobalVariable* const&, std::pair<clang::CXXRecordDecl const*, llvm::GlobalVariable*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEPNS_14GlobalVariableENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, llvm::GlobalVariable*, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<llvm::GlobalVariable*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIN5clang7CodeGen13BaseSubobjectEyNS_12DenseMapInfoIS3_EENS4_IyEEE6insertERKSt4pairIS3_yE", "llvm::DenseMap<clang::CodeGen::BaseSubobject, unsigned long long, llvm::DenseMapInfo<clang::CodeGen::BaseSubobject>, llvm::DenseMapInfo<unsigned long long>>::insert(std::pair<clang::CodeGen::BaseSubobject, unsigned long long> const&)"},
    {"_ZN4llvm8DenseMapIN5clang7CodeGen13BaseSubobjectEyNS_12DenseMapInfoIS3_EENS4_IyEEE16InsertIntoBucketERKS3_RKyPSt4pairIS3_yE", "llvm::DenseMap<clang::CodeGen::BaseSubobject, unsigned long long, llvm::DenseMapInfo<clang::CodeGen::BaseSubobject>, llvm::DenseMapInfo<unsigned long long>>::InsertIntoBucket(clang::CodeGen::BaseSubobject const&, unsigned long long const&, std::pair<clang::CodeGen::BaseSubobject, unsigned long long>*)"},
    {"_ZN4llvm8DenseMapIN5clang7CodeGen13BaseSubobjectEyNS_12DenseMapInfoIS3_EENS4_IyEEE4growEj", "llvm::DenseMap<clang::CodeGen::BaseSubobject, unsigned long long, llvm::DenseMapInfo<clang::CodeGen::BaseSubobject>, llvm::DenseMapInfo<unsigned long long>>::grow(unsigned int)"},
    {"_ZNK4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclES5_ExNS_12DenseMapInfoIS6_EENS7_IxEEE15LookupBucketForERKS6_RPS1_IS6_xE", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>, long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>>, llvm::DenseMapInfo<long long>>::LookupBucketFor(std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*> const&, std::pair<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>, long long>*&) const"},
    {"_ZNK4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclENS2_7CodeGen13BaseSubobjectEEyNS_12DenseMapInfoIS8_EENS9_IyEEE15LookupBucketForERKS8_RPS1_IS8_yE", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>, unsigned long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>>, llvm::DenseMapInfo<unsigned long long>>::LookupBucketFor(std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject> const&, std::pair<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>, unsigned long long>*&) const"},
    {"_ZN4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclENS2_7CodeGen13BaseSubobjectEEyNS_12DenseMapInfoIS8_EENS9_IyEEE16InsertIntoBucketERKS8_RKyPS1_IS8_yE", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>, unsigned long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>>, llvm::DenseMapInfo<unsigned long long>>::InsertIntoBucket(std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject> const&, unsigned long long const&, std::pair<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>, unsigned long long>*)"},
    {"_ZN4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclENS2_7CodeGen13BaseSubobjectEEyNS_12DenseMapInfoIS8_EENS9_IyEEE4growEj", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>, unsigned long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, clang::CodeGen::BaseSubobject>>, llvm::DenseMapInfo<unsigned long long>>::grow(unsigned int)"},
    {"_ZSt16__introsort_loopIPSt4pairIyN5clang9ThunkInfoEElEvT_S5_T0_", "void std::__introsort_loop<std::pair<unsigned long long, clang::ThunkInfo>*, long>(std::pair<unsigned long long, clang::ThunkInfo>*, std::pair<unsigned long long, clang::ThunkInfo>*, long)"},
    {"_ZSt22__final_insertion_sortIPSt4pairIyN5clang9ThunkInfoEEEvT_S5_", "void std::__final_insertion_sort<std::pair<unsigned long long, clang::ThunkInfo>*>(std::pair<unsigned long long, clang::ThunkInfo>*, std::pair<unsigned long long, clang::ThunkInfo>*)"},
    {"_ZSt16__insertion_sortIPSt4pairIyN5clang9ThunkInfoEEEvT_S5_", "void std::__insertion_sort<std::pair<unsigned long long, clang::ThunkInfo>*>(std::pair<unsigned long long, clang::ThunkInfo>*, std::pair<unsigned long long, clang::ThunkInfo>*)"},
    {"_ZSt21__unguarded_partitionIPSt4pairIyN5clang9ThunkInfoEES3_ET_S5_S5_T0_", "std::pair<unsigned long long, clang::ThunkInfo>* std::__unguarded_partition<std::pair<unsigned long long, clang::ThunkInfo>*, std::pair<unsigned long long, clang::ThunkInfo>>(std::pair<unsigned long long, clang::ThunkInfo>*, std::pair<unsigned long long, clang::ThunkInfo>*, std::pair<unsigned long long, clang::ThunkInfo>)"},
    {"_ZSt8__medianISt4pairIyN5clang9ThunkInfoEEERKT_S6_S6_S6_", "std::pair<unsigned long long, clang::ThunkInfo> const& std::__median<std::pair<unsigned long long, clang::ThunkInfo>>(std::pair<unsigned long long, clang::ThunkInfo> const&, std::pair<unsigned long long, clang::ThunkInfo> const&, std::pair<unsigned long long, clang::ThunkInfo> const&)"},
    {"_ZSt13__heap_selectIPSt4pairIyN5clang9ThunkInfoEEEvT_S5_S5_", "void std::__heap_select<std::pair<unsigned long long, clang::ThunkInfo>*>(std::pair<unsigned long long, clang::ThunkInfo>*, std::pair<unsigned long long, clang::ThunkInfo>*, std::pair<unsigned long long, clang::ThunkInfo>*)"},
    {"_ZSt13__adjust_heapIPSt4pairIyN5clang9ThunkInfoEElS3_EvT_T0_S6_T1_", "void std::__adjust_heap<std::pair<unsigned long long, clang::ThunkInfo>*, long, std::pair<unsigned long long, clang::ThunkInfo>>(std::pair<unsigned long long, clang::ThunkInfo>*, long, long, std::pair<unsigned long long, clang::ThunkInfo>)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairIyN5clang9ThunkInfoEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<unsigned long long, clang::ThunkInfo>, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS_11SmallVectorISt4pairIyNS1_9ThunkInfoEELj1EEENS_12DenseMapInfoIS4_EENSA_IS9_EEE16FindAndConstructERKS4_", "llvm::DenseMap<clang::CXXRecordDecl const*, llvm::SmallVector<std::pair<unsigned long long, clang::ThunkInfo>, 1u>, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<std::pair<unsigned long long, clang::ThunkInfo>, 1u>>>::FindAndConstruct(clang::CXXRecordDecl const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS_11SmallVectorISt4pairIyNS1_9ThunkInfoEELj1EEENS_12DenseMapInfoIS4_EENSA_IS9_EEE16InsertIntoBucketERKS4_RKS9_PS6_IS4_S9_E", "llvm::DenseMap<clang::CXXRecordDecl const*, llvm::SmallVector<std::pair<unsigned long long, clang::ThunkInfo>, 1u>, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<std::pair<unsigned long long, clang::ThunkInfo>, 1u>>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, llvm::SmallVector<std::pair<unsigned long long, clang::ThunkInfo>, 1u> const&, std::pair<clang::CXXRecordDecl const*, llvm::SmallVector<std::pair<unsigned long long, clang::ThunkInfo>, 1u>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS_11SmallVectorISt4pairIyNS1_9ThunkInfoEELj1EEENS_12DenseMapInfoIS4_EENSA_IS9_EEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, llvm::SmallVector<std::pair<unsigned long long, clang::ThunkInfo>, 1u>, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<std::pair<unsigned long long, clang::ThunkInfo>, 1u>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplISt4pairIyN5clang9ThunkInfoEEEaSERKS5_", "llvm::SmallVectorImpl<std::pair<unsigned long long, clang::ThunkInfo>>::operator=(llvm::SmallVectorImpl<std::pair<unsigned long long, clang::ThunkInfo>> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclENS_11SmallVectorINS1_9ThunkInfoELj1EEENS_12DenseMapInfoIS4_EENS8_IS7_EEE6insertERKSt4pairIS4_S7_E", "llvm::DenseMap<clang::CXXMethodDecl const*, llvm::SmallVector<clang::ThunkInfo, 1u>, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::ThunkInfo, 1u>>>::insert(std::pair<clang::CXXMethodDecl const*, llvm::SmallVector<clang::ThunkInfo, 1u>> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclENS_11SmallVectorINS1_9ThunkInfoELj1EEENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::CXXMethodDecl const*, llvm::SmallVector<clang::ThunkInfo, 1u>, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::ThunkInfo, 1u>>>::InsertIntoBucket(clang::CXXMethodDecl const* const&, llvm::SmallVector<clang::ThunkInfo, 1u> const&, std::pair<clang::CXXMethodDecl const*, llvm::SmallVector<clang::ThunkInfo, 1u>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclENS_11SmallVectorINS1_9ThunkInfoELj1EEENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::CXXMethodDecl const*, llvm::SmallVector<clang::ThunkInfo, 1u>, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::ThunkInfo, 1u>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIN5clang9ThunkInfoEEaSERKS3_", "llvm::SmallVectorImpl<clang::ThunkInfo>::operator=(llvm::SmallVectorImpl<clang::ThunkInfo> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang9ThunkInfoELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::ThunkInfo, false>::grow(unsigned long)"},
    {"_ZNSt6vectorIPKN5clang13CXXRecordDeclESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<clang::CXXRecordDecl const*, std::allocator<clang::CXXRecordDecl const*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::CXXRecordDecl const**, std::vector<clang::CXXRecordDecl const*, std::allocator<clang::CXXRecordDecl const*>>>, clang::CXXRecordDecl const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS_14PointerIntPairIPyLj1EbNS_21PointerLikeTypeTraitsIS6_EEEENS_12DenseMapInfoIS4_EENSA_IS9_EEE16InsertIntoBucketERKS4_RKS9_PSt4pairIS4_S9_E", "llvm::DenseMap<clang::CXXRecordDecl const*, llvm::PointerIntPair<unsigned long long*, 1u, bool, llvm::PointerLikeTypeTraits<unsigned long long*>>, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<llvm::PointerIntPair<unsigned long long*, 1u, bool, llvm::PointerLikeTypeTraits<unsigned long long*>>>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, llvm::PointerIntPair<unsigned long long*, 1u, bool, llvm::PointerLikeTypeTraits<unsigned long long*>> const&, std::pair<clang::CXXRecordDecl const*, llvm::PointerIntPair<unsigned long long*, 1u, bool, llvm::PointerLikeTypeTraits<unsigned long long*>>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS_14PointerIntPairIPyLj1EbNS_21PointerLikeTypeTraitsIS6_EEEENS_12DenseMapInfoIS4_EENSA_IS9_EEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, llvm::PointerIntPair<unsigned long long*, 1u, bool, llvm::PointerLikeTypeTraits<unsigned long long*>>, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<llvm::PointerIntPair<unsigned long long*, 1u, bool, llvm::PointerLikeTypeTraits<unsigned long long*>>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclES5_ExNS_12DenseMapInfoIS6_EENS7_IxEEE16InsertIntoBucketERKS6_RKxPS1_IS6_xE", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>, long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>>, llvm::DenseMapInfo<long long>>::InsertIntoBucket(std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*> const&, long long const&, std::pair<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>, long long>*)"},
    {"_ZN4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclES5_ExNS_12DenseMapInfoIS6_EENS7_IxEEE4growEj", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>, long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, clang::CXXRecordDecl const*>>, llvm::DenseMapInfo<long long>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEyNS_12DenseMapInfoIS4_EENS5_IyEEE16InsertIntoBucketERKS4_RKyPSt4pairIS4_yE", "llvm::DenseMap<clang::CXXRecordDecl const*, unsigned long long, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<unsigned long long>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, unsigned long long const&, std::pair<clang::CXXRecordDecl const*, unsigned long long>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEyNS_12DenseMapInfoIS4_EENS5_IyEEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, unsigned long long, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<unsigned long long>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIN5clang7CodeGen10GlobalDeclExNS_12DenseMapInfoIS3_EENS4_IxEEE16InsertIntoBucketERKS3_RKxPSt4pairIS3_xE", "llvm::DenseMap<clang::CodeGen::GlobalDecl, long long, llvm::DenseMapInfo<clang::CodeGen::GlobalDecl>, llvm::DenseMapInfo<long long>>::InsertIntoBucket(clang::CodeGen::GlobalDecl const&, long long const&, std::pair<clang::CodeGen::GlobalDecl, long long>*)"},
    {"_ZN4llvm8DenseMapIN5clang7CodeGen10GlobalDeclExNS_12DenseMapInfoIS3_EENS4_IxEEE4growEj", "llvm::DenseMap<clang::CodeGen::GlobalDecl, long long, llvm::DenseMapInfo<clang::CodeGen::GlobalDecl>, llvm::DenseMapInfo<long long>>::grow(unsigned int)"},
    {"_ZNSt8_Rb_treeIySt4pairIKyN5clang7CodeGen13BaseSubobjectEESt10_Select1stIS5_ESt4lessIyESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<unsigned long long, std::pair<unsigned long long const, clang::CodeGen::BaseSubobject>, std::_Select1st<std::pair<unsigned long long const, clang::CodeGen::BaseSubobject>>, std::less<unsigned long long>, std::allocator<std::pair<unsigned long long const, clang::CodeGen::BaseSubobject>>>::_M_erase(std::_Rb_tree_node<std::pair<unsigned long long const, clang::CodeGen::BaseSubobject>>*)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsPKN5clang13CXXMethodDeclEESt10_Select1stIS6_ESt4lessISsESaIS6_EE8_M_eraseEPSt13_Rb_tree_nodeIS6_E", "std::_Rb_tree<std::string, std::pair<std::string const, clang::CXXMethodDecl const*>, std::_Select1st<std::pair<std::string const, clang::CXXMethodDecl const*>>, std::less<std::string>, std::allocator<std::pair<std::string const, clang::CXXMethodDecl const*>>>::_M_erase(std::_Rb_tree_node<std::pair<std::string const, clang::CXXMethodDecl const*>>*)"},
    {"_ZSt16__introsort_loopIPN5clang9ThunkInfoElEvT_S3_T0_", "void std::__introsort_loop<clang::ThunkInfo*, long>(clang::ThunkInfo*, clang::ThunkInfo*, long)"},
    {"_ZSt22__final_insertion_sortIPN5clang9ThunkInfoEEvT_S3_", "void std::__final_insertion_sort<clang::ThunkInfo*>(clang::ThunkInfo*, clang::ThunkInfo*)"},
    {"_ZSt16__insertion_sortIPN5clang9ThunkInfoEEvT_S3_", "void std::__insertion_sort<clang::ThunkInfo*>(clang::ThunkInfo*, clang::ThunkInfo*)"},
    {"_ZSt21__unguarded_partitionIPN5clang9ThunkInfoES1_ET_S3_S3_T0_", "clang::ThunkInfo* std::__unguarded_partition<clang::ThunkInfo*, clang::ThunkInfo>(clang::ThunkInfo*, clang::ThunkInfo*, clang::ThunkInfo)"},
    {"_ZSt8__medianIN5clang9ThunkInfoEERKT_S4_S4_S4_", "clang::ThunkInfo const& std::__median<clang::ThunkInfo>(clang::ThunkInfo const&, clang::ThunkInfo const&, clang::ThunkInfo const&)"},
    {"_ZSt13__heap_selectIPN5clang9ThunkInfoEEvT_S3_S3_", "void std::__heap_select<clang::ThunkInfo*>(clang::ThunkInfo*, clang::ThunkInfo*, clang::ThunkInfo*)"},
    {"_ZSt13__adjust_heapIPN5clang9ThunkInfoElS1_EvT_T0_S4_T1_", "void std::__adjust_heap<clang::ThunkInfo*, long, clang::ThunkInfo>(clang::ThunkInfo*, long, long, clang::ThunkInfo)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclENS_11SmallVectorINS1_9ThunkInfoELj1EEENS_12DenseMapInfoIS4_EENS8_IS7_EEE16FindAndConstructERKS4_", "llvm::DenseMap<clang::CXXMethodDecl const*, llvm::SmallVector<clang::ThunkInfo, 1u>, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::ThunkInfo, 1u>>>::FindAndConstruct(clang::CXXMethodDecl const* const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsPKN5clang13CXXMethodDeclEESt10_Select1stIS6_ESt4lessISsESaIS6_EE16_M_insert_uniqueERKS6_", "std::_Rb_tree<std::string, std::pair<std::string const, clang::CXXMethodDecl const*>, std::_Select1st<std::pair<std::string const, clang::CXXMethodDecl const*>>, std::less<std::string>, std::allocator<std::pair<std::string const, clang::CXXMethodDecl const*>>>::_M_insert_unique(std::pair<std::string const, clang::CXXMethodDecl const*> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsPKN5clang13CXXMethodDeclEESt10_Select1stIS6_ESt4lessISsESaIS6_EE9_M_insertEPSt18_Rb_tree_node_baseSE_RKS6_", "std::_Rb_tree<std::string, std::pair<std::string const, clang::CXXMethodDecl const*>, std::_Select1st<std::pair<std::string const, clang::CXXMethodDecl const*>>, std::less<std::string>, std::allocator<std::pair<std::string const, clang::CXXMethodDecl const*>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<std::string const, clang::CXXMethodDecl const*> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsxESt10_Select1stIS2_ESt4lessISsESaIS2_EE8_M_eraseEPSt13_Rb_tree_nodeIS2_E", "std::_Rb_tree<std::string, std::pair<std::string const, long long>, std::_Select1st<std::pair<std::string const, long long>>, std::less<std::string>, std::allocator<std::pair<std::string const, long long>>>::_M_erase(std::_Rb_tree_node<std::pair<std::string const, long long>>*)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsxESt10_Select1stIS2_ESt4lessISsESaIS2_EE16_M_insert_uniqueERKS2_", "std::_Rb_tree<std::string, std::pair<std::string const, long long>, std::_Select1st<std::pair<std::string const, long long>>, std::less<std::string>, std::allocator<std::pair<std::string const, long long>>>::_M_insert_unique(std::pair<std::string const, long long> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsxESt10_Select1stIS2_ESt4lessISsESaIS2_EE9_M_insertEPSt18_Rb_tree_node_baseSA_RKS2_", "std::_Rb_tree<std::string, std::pair<std::string const, long long>, std::_Select1st<std::pair<std::string const, long long>>, std::less<std::string>, std::allocator<std::pair<std::string const, long long>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<std::string const, long long> const&)"},
    {"_ZNK5clang15ASTRecordLayout25getVBaseClassOffsetInBitsEPKNS_13CXXRecordDeclE", "clang::ASTRecordLayout::getVBaseClassOffsetInBits(clang::CXXRecordDecl const*) const"},
    {"_ZSt6__findIPN5clang9ThunkInfoES1_ET_S3_S3_RKT0_St26random_access_iterator_tag", "clang::ThunkInfo* std::__find<clang::ThunkInfo*, clang::ThunkInfo>(clang::ThunkInfo*, clang::ThunkInfo*, clang::ThunkInfo const&, std::random_access_iterator_tag)"},
    {"_ZN4llvm8DenseMapIyN5clang9ThunkInfoENS_12DenseMapInfoIyEENS3_IS2_EEE16InsertIntoBucketERKyRKS2_PSt4pairIyS2_E", "llvm::DenseMap<unsigned long long, clang::ThunkInfo, llvm::DenseMapInfo<unsigned long long>, llvm::DenseMapInfo<clang::ThunkInfo>>::InsertIntoBucket(unsigned long long const&, clang::ThunkInfo const&, std::pair<unsigned long long, clang::ThunkInfo>*)"},
    {"_ZN4llvm8DenseMapIyN5clang9ThunkInfoENS_12DenseMapInfoIyEENS3_IS2_EEE4growEj", "llvm::DenseMap<unsigned long long, clang::ThunkInfo, llvm::DenseMapInfo<unsigned long long>, llvm::DenseMapInfo<clang::ThunkInfo>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclExNS_12DenseMapInfoIS4_EENS5_IxEEE8CopyFromERKS8_", "llvm::DenseMap<clang::CXXRecordDecl const*, long long, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<long long>>::CopyFrom(llvm::DenseMap<clang::CXXRecordDecl const*, long long, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<long long>> const&)"},
    {"_ZN4llvm15SmallVectorImplISt4pairIPKN5clang13CXXMethodDeclExEEaSERKS7_", "llvm::SmallVectorImpl<std::pair<clang::CXXMethodDecl const*, long long>>::operator=(llvm::SmallVectorImpl<std::pair<clang::CXXMethodDecl const*, long long>> const&)"},
    {"_ZNK4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclEjEyNS_12DenseMapInfoIS6_EENS7_IyEEE15LookupBucketForERKS6_RPS1_IS6_yE", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, unsigned int>, unsigned long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, unsigned int>>, llvm::DenseMapInfo<unsigned long long>>::LookupBucketFor(std::pair<clang::CXXRecordDecl const*, unsigned int> const&, std::pair<std::pair<clang::CXXRecordDecl const*, unsigned int>, unsigned long long>*&) const"},
    {"_ZN4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclEjEyNS_12DenseMapInfoIS6_EENS7_IyEEE16InsertIntoBucketERKS6_RKyPS1_IS6_yE", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, unsigned int>, unsigned long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, unsigned int>>, llvm::DenseMapInfo<unsigned long long>>::InsertIntoBucket(std::pair<clang::CXXRecordDecl const*, unsigned int> const&, unsigned long long const&, std::pair<std::pair<clang::CXXRecordDecl const*, unsigned int>, unsigned long long>*)"},
    {"_ZN4llvm8DenseMapISt4pairIPKN5clang13CXXRecordDeclEjEyNS_12DenseMapInfoIS6_EENS7_IyEEE4growEj", "llvm::DenseMap<std::pair<clang::CXXRecordDecl const*, unsigned int>, unsigned long long, llvm::DenseMapInfo<std::pair<clang::CXXRecordDecl const*, unsigned int>>, llvm::DenseMapInfo<unsigned long long>>::grow(unsigned int)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE26CreateConstInBoundsGEP1_64EPNS_5ValueEyRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateConstInBoundsGEP1_64(llvm::Value*, unsigned long long, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE17CreateInBoundsGEPEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateInBoundsGEP(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclExNS_12DenseMapInfoIS4_EENS5_IxEEE6insertERKSt4pairIS4_xE", "llvm::DenseMap<clang::CXXRecordDecl const*, long long, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<long long>>::insert(std::pair<clang::CXXRecordDecl const*, long long> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclExNS_12DenseMapInfoIS4_EENS5_IxEEE16InsertIntoBucketERKS4_RKxPSt4pairIS4_xE", "llvm::DenseMap<clang::CXXRecordDecl const*, long long, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<long long>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, long long const&, std::pair<clang::CXXRecordDecl const*, long long>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclExNS_12DenseMapInfoIS4_EENS5_IxEEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, long long, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<long long>>::grow(unsigned int)"},
    {"_ZN5clang15BackendConsumer21InlineAsmDiagHandler2ERKN4llvm12SMDiagnosticENS_14SourceLocationE", "clang::BackendConsumer::InlineAsmDiagHandler2(llvm::SMDiagnostic const&, clang::SourceLocation)"},
    {"_ZN5clang13CodeGenActionC1Ej", "clang::CodeGenAction::CodeGenAction(unsigned int)"},
    {"_ZN5clang13CodeGenActionC2Ej", "clang::CodeGenAction::CodeGenAction(unsigned int)"},
    {"_ZN5clang13CodeGenActionD0Ev", "clang::CodeGenAction::~CodeGenAction()"},
    {"_ZN5clang13CodeGenActionD1Ev", "clang::CodeGenAction::~CodeGenAction()"},
    {"_ZN5clang13CodeGenActionD2Ev", "clang::CodeGenAction::~CodeGenAction()"},
    {"_ZNK5clang13CodeGenAction12hasIRSupportEv", "clang::CodeGenAction::hasIRSupport() const"},
    {"_ZN5clang13CodeGenAction19EndSourceFileActionEv", "clang::CodeGenAction::EndSourceFileAction()"},
    {"_ZN5clang13CodeGenAction10takeModuleEv", "clang::CodeGenAction::takeModule()"},
    {"_ZN5clang13CodeGenAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::CodeGenAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_Z15GetOutputStreamRN5clang16CompilerInstanceEN4llvm9StringRefENS_13BackendActionE", "GetOutputStream(clang::CompilerInstance&, llvm::StringRef, clang::BackendAction)"},
    {"_ZN5clang13CodeGenAction13ExecuteActionEv", "clang::CodeGenAction::ExecuteAction()"},
    {"_ZN5clang18EmitAssemblyActionC1Ev", "clang::EmitAssemblyAction::EmitAssemblyAction()"},
    {"_ZN5clang18EmitAssemblyActionC2Ev", "clang::EmitAssemblyAction::EmitAssemblyAction()"},
    {"_ZN5clang12EmitBCActionC1Ev", "clang::EmitBCAction::EmitBCAction()"},
    {"_ZN5clang12EmitBCActionC2Ev", "clang::EmitBCAction::EmitBCAction()"},
    {"_ZN5clang14EmitLLVMActionC1Ev", "clang::EmitLLVMAction::EmitLLVMAction()"},
    {"_ZN5clang14EmitLLVMActionC2Ev", "clang::EmitLLVMAction::EmitLLVMAction()"},
    {"_ZN5clang18EmitLLVMOnlyActionC1Ev", "clang::EmitLLVMOnlyAction::EmitLLVMOnlyAction()"},
    {"_ZN5clang18EmitLLVMOnlyActionC2Ev", "clang::EmitLLVMOnlyAction::EmitLLVMOnlyAction()"},
    {"_ZN5clang21EmitCodeGenOnlyActionC1Ev", "clang::EmitCodeGenOnlyAction::EmitCodeGenOnlyAction()"},
    {"_ZN5clang21EmitCodeGenOnlyActionC2Ev", "clang::EmitCodeGenOnlyAction::EmitCodeGenOnlyAction()"},
    {"_ZN5clang13EmitObjActionC1Ev", "clang::EmitObjAction::EmitObjAction()"},
    {"_ZN5clang13EmitObjActionC2Ev", "clang::EmitObjAction::EmitObjAction()"},
    {"_ZN4llvm7ParseIREPNS_12MemoryBufferERNS_12SMDiagnosticERNS_11LLVMContextE", "llvm::ParseIR(llvm::MemoryBuffer*, llvm::SMDiagnostic&, llvm::LLVMContext&)"},
    {"_ZN5clang13EmitObjActionD1Ev", "clang::EmitObjAction::~EmitObjAction()"},
    {"_ZN5clang13EmitObjActionD0Ev", "clang::EmitObjAction::~EmitObjAction()"},
    {"_ZN5clang21EmitCodeGenOnlyActionD1Ev", "clang::EmitCodeGenOnlyAction::~EmitCodeGenOnlyAction()"},
    {"_ZN5clang21EmitCodeGenOnlyActionD0Ev", "clang::EmitCodeGenOnlyAction::~EmitCodeGenOnlyAction()"},
    {"_ZN5clang18EmitLLVMOnlyActionD1Ev", "clang::EmitLLVMOnlyAction::~EmitLLVMOnlyAction()"},
    {"_ZN5clang18EmitLLVMOnlyActionD0Ev", "clang::EmitLLVMOnlyAction::~EmitLLVMOnlyAction()"},
    {"_ZN5clang14EmitLLVMActionD1Ev", "clang::EmitLLVMAction::~EmitLLVMAction()"},
    {"_ZN5clang14EmitLLVMActionD0Ev", "clang::EmitLLVMAction::~EmitLLVMAction()"},
    {"_ZN5clang12EmitBCActionD1Ev", "clang::EmitBCAction::~EmitBCAction()"},
    {"_ZN5clang12EmitBCActionD0Ev", "clang::EmitBCAction::~EmitBCAction()"},
    {"_ZN5clang18EmitAssemblyActionD1Ev", "clang::EmitAssemblyAction::~EmitAssemblyAction()"},
    {"_ZN5clang18EmitAssemblyActionD0Ev", "clang::EmitAssemblyAction::~EmitAssemblyAction()"},
    {"_ZN5clang15BackendConsumerD1Ev", "clang::BackendConsumer::~BackendConsumer()"},
    {"_ZN5clang15BackendConsumerD0Ev", "clang::BackendConsumer::~BackendConsumer()"},
    {"_ZN5clang15BackendConsumer10InitializeERNS_10ASTContextE", "clang::BackendConsumer::Initialize(clang::ASTContext&)"},
    {"_ZN5clang15BackendConsumer18HandleTopLevelDeclENS_12DeclGroupRefE", "clang::BackendConsumer::HandleTopLevelDecl(clang::DeclGroupRef)"},
    {"_ZN5clang15BackendConsumer21HandleTranslationUnitERNS_10ASTContextE", "clang::BackendConsumer::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN5clang15BackendConsumer23HandleTagDeclDefinitionEPNS_7TagDeclE", "clang::BackendConsumer::HandleTagDeclDefinition(clang::TagDecl*)"},
    {"_ZN5clang15BackendConsumer27CompleteTentativeDefinitionEPNS_7VarDeclE", "clang::BackendConsumer::CompleteTentativeDefinition(clang::VarDecl*)"},
    {"_ZN5clang15BackendConsumer12HandleVTableEPNS_13CXXRecordDeclEb", "clang::BackendConsumer::HandleVTable(clang::CXXRecordDecl*, bool)"},
    {"_ZN5clang20PrettyStackTraceDeclD1Ev", "clang::PrettyStackTraceDecl::~PrettyStackTraceDecl()"},
    {"_ZN5clang20PrettyStackTraceDeclD0Ev", "clang::PrettyStackTraceDecl::~PrettyStackTraceDecl()"},
    {"_ZN5clang15BackendConsumer20InlineAsmDiagHandlerERKN4llvm12SMDiagnosticEPvj", "clang::BackendConsumer::InlineAsmDiagHandler(llvm::SMDiagnostic const&, void*, unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunctionC1ERNS0_13CodeGenModuleE", "clang::CodeGen::CodeGenFunction::CodeGenFunction(clang::CodeGen::CodeGenModule&)"},
    {"_ZN5clang7CodeGen15CodeGenFunctionC2ERNS0_13CodeGenModuleE", "clang::CodeGen::CodeGenFunction::CodeGenFunction(clang::CodeGen::CodeGenModule&)"},
    {"_ZNK5clang7CodeGen15CodeGenFunction10getContextEv", "clang::CodeGen::CodeGenFunction::getContext() const"},
    {"_ZN5clang7CodeGen15CodeGenFunction17ConvertTypeForMemENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::ConvertTypeForMem(clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction11ConvertTypeENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::ConvertType(clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20hasAggregateLLVMTypeENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::hasAggregateLLVMType(clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction15EmitReturnBlockEv", "clang::CodeGen::CodeGenFunction::EmitReturnBlock()"},
    {"_ZN5clang7CodeGen15CodeGenFunction14FinishFunctionENS_14SourceLocationE", "clang::CodeGen::CodeGenFunction::FinishFunction(clang::SourceLocation)"},
    {"_ZN5clang7CodeGen15CodeGenFunction27EmitFunctionInstrumentationEPKc", "clang::CodeGen::CodeGenFunction::EmitFunctionInstrumentation(char const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction24ShouldInstrumentFunctionEv", "clang::CodeGen::CodeGenFunction::ShouldInstrumentFunction()"},
    {"_ZN5clang7CodeGen15CodeGenFunction13StartFunctionENS0_10GlobalDeclENS_8QualTypeEPN4llvm8FunctionERKNS4_11SmallVectorISt4pairIPKNS_7VarDeclES3_ELj16EEENS_14SourceLocationE", "clang::CodeGen::CodeGenFunction::StartFunction(clang::CodeGen::GlobalDecl, clang::QualType, llvm::Function*, llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u> const&, clang::SourceLocation)"},
    {"_ZN5clang7CodeGen15CodeGenFunction11EmitVLASizeENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitVLASize(clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitFunctionBodyERN4llvm11SmallVectorISt4pairIPKNS_7VarDeclENS_8QualTypeEELj16EEE", "clang::CodeGen::CodeGenFunction::EmitFunctionBody(llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u>&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction12GenerateCodeENS0_10GlobalDeclEPN4llvm8FunctionE", "clang::CodeGen::CodeGenFunction::GenerateCode(clang::CodeGen::GlobalDecl, llvm::Function*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction13ContainsLabelEPKNS_4StmtEb", "clang::CodeGen::CodeGenFunction::ContainsLabel(clang::Stmt const*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction28ConstantFoldsToSimpleIntegerEPKNS_4ExprE", "clang::CodeGen::CodeGenFunction::ConstantFoldsToSimpleInteger(clang::Expr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20EmitBranchOnBoolExprEPKNS_4ExprEPN4llvm10BasicBlockES7_", "clang::CodeGen::CodeGenFunction::EmitBranchOnBoolExpr(clang::Expr const*, llvm::BasicBlock*, llvm::BasicBlock*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16ErrorUnsupportedEPKNS_4StmtEPKcb", "clang::CodeGen::CodeGenFunction::ErrorUnsupported(clang::Stmt const*, char const*, bool)"},
    {"_ZN5clang7CodeGen15CodeGenFunction22EmitNullInitializationEPN4llvm5ValueENS_8QualTypeE", "clang::CodeGen::CodeGenFunction::EmitNullInitialization(llvm::Value*, clang::QualType)"},
    {"_ZN5clang7CodeGen15CodeGenFunction10GetVLASizeEPKNS_17VariableArrayTypeE", "clang::CodeGen::CodeGenFunction::GetVLASize(clang::VariableArrayType const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction14GetAddrOfLabelEPKNS_9LabelStmtE", "clang::CodeGen::CodeGenFunction::GetAddrOfLabel(clang::LabelStmt const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction20GetIndirectGotoBlockEv", "clang::CodeGen::CodeGenFunction::GetIndirectGotoBlock()"},
    {"_ZN5clang7CodeGen15CodeGenFunction13EmitVAListRefEPKNS_4ExprE", "clang::CodeGen::CodeGenFunction::EmitVAListRef(clang::Expr const*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction23EmitDeclRefExprDbgValueEPKNS_11DeclRefExprEPN4llvm8ConstantE", "clang::CodeGen::CodeGenFunction::EmitDeclRefExprDbgValue(clang::DeclRefExpr const*, llvm::Constant*)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateMulEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateMul(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ExprEPNS_5ValueENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::Expr const*, llvm::Value*, llvm::DenseMapInfo<clang::Expr const*>, llvm::DenseMapInfo<llvm::Value*>>::InsertIntoBucket(clang::Expr const* const&, llvm::Value* const&, std::pair<clang::Expr const*, llvm::Value*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ExprEPNS_5ValueENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::Expr const*, llvm::Value*, llvm::DenseMapInfo<clang::Expr const*>, llvm::DenseMapInfo<llvm::Value*>>::grow(unsigned int)"},
    {"_ZN5clang7CodeGen13CodeGenModuleC1ERNS_10ASTContextERKNS_14CodeGenOptionsERN4llvm6ModuleERKNS7_10DataLayoutERNS_10DiagnosticE", "clang::CodeGen::CodeGenModule::CodeGenModule(clang::ASTContext&, clang::CodeGenOptions const&, llvm::Module&, llvm::DataLayout const&, clang::Diagnostic&)"},
    {"_ZN5clang7CodeGen13CodeGenModuleC2ERNS_10ASTContextERKNS_14CodeGenOptionsERN4llvm6ModuleERKNS7_10DataLayoutERNS_10DiagnosticE", "clang::CodeGen::CodeGenModule::CodeGenModule(clang::ASTContext&, clang::CodeGenOptions const&, llvm::Module&, llvm::DataLayout const&, clang::Diagnostic&)"},
    {"_ZN5clang7CodeGen13CodeGenModuleD1Ev", "clang::CodeGen::CodeGenModule::~CodeGenModule()"},
    {"_ZN5clang7CodeGen13CodeGenModuleD2Ev", "clang::CodeGen::CodeGenModule::~CodeGenModule()"},
    {"_ZN5clang7CodeGen13CodeGenModule17createObjCRuntimeEv", "clang::CodeGen::CodeGenModule::createObjCRuntime()"},
    {"_ZN5clang7CodeGen13CodeGenModule7ReleaseEv", "clang::CodeGen::CodeGenModule::Release()"},
    {"_ZN5clang7CodeGen13CodeGenModule12EmitDeferredEv", "clang::CodeGen::CodeGenModule::EmitDeferred()"},
    {"_ZN5clang7CodeGen13CodeGenModule13AddGlobalCtorEPN4llvm8FunctionEi", "clang::CodeGen::CodeGenModule::AddGlobalCtor(llvm::Function*, int)"},
    {"_ZN5clang7CodeGen13CodeGenModule12EmitCtorListERKSt6vectorISt4pairIPN4llvm8ConstantEiESaIS7_EEPKc", "clang::CodeGen::CodeGenModule::EmitCtorList(std::vector<std::pair<llvm::Constant*, int>, std::allocator<std::pair<llvm::Constant*, int>>> const&, char const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule15EmitAnnotationsEv", "clang::CodeGen::CodeGenModule::EmitAnnotations()"},
    {"_ZN5clang7CodeGen13CodeGenModule12EmitLLVMUsedEv", "clang::CodeGen::CodeGenModule::EmitLLVMUsed()"},
    {"_ZN5clang7CodeGen13CodeGenModule16EmitDeclMetadataEv", "clang::CodeGen::CodeGenModule::EmitDeclMetadata()"},
    {"_ZN5clang7CodeGen13CodeGenModule11getTBAAInfoENS_8QualTypeE", "clang::CodeGen::CodeGenModule::getTBAAInfo(clang::QualType)"},
    {"_ZN5clang7CodeGen13CodeGenModule19DecorateInstructionEPN4llvm11InstructionEPNS2_6MDNodeE", "clang::CodeGen::CodeGenModule::DecorateInstruction(llvm::Instruction*, llvm::MDNode*)"},
    {"_ZNK5clang7CodeGen13CodeGenModule14isTargetDarwinEv", "clang::CodeGen::CodeGenModule::isTargetDarwin() const"},
    {"_ZN5clang7CodeGen13CodeGenModule16ErrorUnsupportedEPKNS_4StmtEPKcb", "clang::CodeGen::CodeGenModule::ErrorUnsupported(clang::Stmt const*, char const*, bool)"},
    {"_ZN5clang7CodeGen13CodeGenModule16ErrorUnsupportedEPKNS_4DeclEPKcb", "clang::CodeGen::CodeGenModule::ErrorUnsupported(clang::Decl const*, char const*, bool)"},
    {"_ZNK5clang7CodeGen13CodeGenModule19setGlobalVisibilityEPN4llvm11GlobalValueEPKNS_9NamedDeclE", "clang::CodeGen::CodeGenModule::setGlobalVisibility(llvm::GlobalValue*, clang::NamedDecl const*) const"},
    {"_ZNK5clang7CodeGen13CodeGenModule17setTypeVisibilityEPN4llvm11GlobalValueEPKNS_13CXXRecordDeclENS1_18TypeVisibilityKindE", "clang::CodeGen::CodeGenModule::setTypeVisibility(llvm::GlobalValue*, clang::CXXRecordDecl const*, clang::CodeGen::CodeGenModule::TypeVisibilityKind) const"},
    {"_ZN5clang7CodeGen13CodeGenModule14getMangledNameENS0_10GlobalDeclE", "clang::CodeGen::CodeGenModule::getMangledName(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen13CodeGenModule19getBlockMangledNameENS0_10GlobalDeclERNS_12MangleBufferEPKNS_9BlockDeclE", "clang::CodeGen::CodeGenModule::getBlockMangledName(clang::CodeGen::GlobalDecl, clang::MangleBuffer&, clang::BlockDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule14GetGlobalValueEN4llvm9StringRefE", "clang::CodeGen::CodeGenModule::GetGlobalValue(llvm::StringRef)"},
    {"_ZN5clang7CodeGen13CodeGenModule13AddGlobalDtorEPN4llvm8FunctionEi", "clang::CodeGen::CodeGenModule::AddGlobalDtor(llvm::Function*, int)"},
    {"_ZN5clang7CodeGen13CodeGenModule18getFunctionLinkageEPKNS_12FunctionDeclE", "clang::CodeGen::CodeGenModule::getFunctionLinkage(clang::FunctionDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule31SetFunctionDefinitionAttributesEPKNS_12FunctionDeclEPN4llvm11GlobalValueE", "clang::CodeGen::CodeGenModule::SetFunctionDefinitionAttributes(clang::FunctionDecl const*, llvm::GlobalValue*)"},
    {"_ZN5clang7CodeGen13CodeGenModule19SetCommonAttributesEPKNS_4DeclEPN4llvm11GlobalValueE", "clang::CodeGen::CodeGenModule::SetCommonAttributes(clang::Decl const*, llvm::GlobalValue*)"},
    {"_ZN5clang7CodeGen13CodeGenModule25SetLLVMFunctionAttributesEPKNS_4DeclERKNS0_14CGFunctionInfoEPN4llvm8FunctionE", "clang::CodeGen::CodeGenModule::SetLLVMFunctionAttributes(clang::Decl const*, clang::CodeGen::CGFunctionInfo const&, llvm::Function*)"},
    {"_ZN5clang7CodeGen13CodeGenModule38SetLLVMFunctionAttributesForDefinitionEPKNS_4DeclEPN4llvm8FunctionE", "clang::CodeGen::CodeGenModule::SetLLVMFunctionAttributesForDefinition(clang::Decl const*, llvm::Function*)"},
    {"_ZN5clang7CodeGen13CodeGenModule13AddUsedGlobalEPN4llvm11GlobalValueE", "clang::CodeGen::CodeGenModule::AddUsedGlobal(llvm::GlobalValue*)"},
    {"_ZN5clang7CodeGen13CodeGenModule29SetInternalFunctionAttributesEPKNS_4DeclEPN4llvm8FunctionERKNS0_14CGFunctionInfoE", "clang::CodeGen::CodeGenModule::SetInternalFunctionAttributes(clang::Decl const*, llvm::Function*, clang::CodeGen::CGFunctionInfo const&)"},
    {"_ZN5clang7CodeGen13CodeGenModule21SetFunctionAttributesENS0_10GlobalDeclEPN4llvm8FunctionEb", "clang::CodeGen::CodeGenModule::SetFunctionAttributes(clang::CodeGen::GlobalDecl, llvm::Function*, bool)"},
    {"_ZN5clang7CodeGen13CodeGenModule16getVTableLinkageEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenModule::getVTableLinkage(clang::CXXRecordDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule20EmitGlobalDefinitionENS0_10GlobalDeclE", "clang::CodeGen::CodeGenModule::EmitGlobalDefinition(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen13CodeGenModule16EmitAnnotateAttrEPN4llvm11GlobalValueEPKNS_12AnnotateAttrEj", "clang::CodeGen::CodeGenModule::EmitAnnotateAttr(llvm::GlobalValue*, clang::AnnotateAttr const*, unsigned int)"},
    {"_ZN5clang7CodeGen13CodeGenModule18MayDeferGenerationEPKNS_9ValueDeclE", "clang::CodeGen::CodeGenModule::MayDeferGeneration(clang::ValueDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule19GetWeakRefReferenceEPKNS_9ValueDeclE", "clang::CodeGen::CodeGenModule::GetWeakRefReference(clang::ValueDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule23GetOrCreateLLVMFunctionEN4llvm9StringRefEPKNS2_4TypeENS0_10GlobalDeclEb", "clang::CodeGen::CodeGenModule::GetOrCreateLLVMFunction(llvm::StringRef, llvm::Type const*, clang::CodeGen::GlobalDecl, bool)"},
    {"_ZN5clang7CodeGen13CodeGenModule21GetOrCreateLLVMGlobalEN4llvm9StringRefEPKNS2_11PointerTypeEPKNS_7VarDeclEb", "clang::CodeGen::CodeGenModule::GetOrCreateLLVMGlobal(llvm::StringRef, llvm::PointerType const*, clang::VarDecl const*, bool)"},
    {"_ZN5clang7CodeGen13CodeGenModule10EmitGlobalENS0_10GlobalDeclE", "clang::CodeGen::CodeGenModule::EmitGlobal(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen13CodeGenModule19EmitAliasDefinitionENS0_10GlobalDeclE", "clang::CodeGen::CodeGenModule::EmitAliasDefinition(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen13CodeGenModule28EmitGlobalFunctionDefinitionENS0_10GlobalDeclE", "clang::CodeGen::CodeGenModule::EmitGlobalFunctionDefinition(clang::CodeGen::GlobalDecl)"},
    {"_ZN5clang7CodeGen13CodeGenModule23EmitGlobalVarDefinitionEPKNS_7VarDeclE", "clang::CodeGen::CodeGenModule::EmitGlobalVarDefinition(clang::VarDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule17GetAddrOfFunctionENS0_10GlobalDeclEPKN4llvm4TypeEb", "clang::CodeGen::CodeGenModule::GetAddrOfFunction(clang::CodeGen::GlobalDecl, llvm::Type const*, bool)"},
    {"_ZN5clang7CodeGen13CodeGenModule21CreateRuntimeFunctionEPKN4llvm12FunctionTypeENS2_9StringRefE", "clang::CodeGen::CodeGenModule::CreateRuntimeFunction(llvm::FunctionType const*, llvm::StringRef)"},
    {"_Z20DeclIsConstantGlobalRN5clang10ASTContextEPKNS_7VarDeclE", "DeclIsConstantGlobal(clang::ASTContext&, clang::VarDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule33CreateOrReplaceCXXRuntimeVariableEN4llvm9StringRefEPKNS2_4TypeENS2_11GlobalValue12LinkageTypesE", "clang::CodeGen::CodeGenModule::CreateOrReplaceCXXRuntimeVariable(llvm::StringRef, llvm::Type const*, llvm::GlobalValue::LinkageTypes)"},
    {"_ZN5clang7CodeGen13CodeGenModule18GetAddrOfGlobalVarEPKNS_7VarDeclEPKN4llvm4TypeE", "clang::CodeGen::CodeGenModule::GetAddrOfGlobalVar(clang::VarDecl const*, llvm::Type const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule21CreateRuntimeVariableEPKN4llvm4TypeENS2_9StringRefE", "clang::CodeGen::CodeGenModule::CreateRuntimeVariable(llvm::Type const*, llvm::StringRef)"},
    {"_ZN5clang7CodeGen13CodeGenModule23EmitTentativeDefinitionEPKNS_7VarDeclE", "clang::CodeGen::CodeGenModule::EmitTentativeDefinition(clang::VarDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule10EmitVTableEPNS_13CXXRecordDeclEb", "clang::CodeGen::CodeGenModule::EmitVTable(clang::CXXRecordDecl*, bool)"},
    {"_ZNK5clang7CodeGen13CodeGenModule22GetTargetTypeStoreSizeEPKN4llvm4TypeE", "clang::CodeGen::CodeGenModule::GetTargetTypeStoreSize(llvm::Type const*) const"},
    {"_ZN5clang7CodeGen13CodeGenModule27GetLLVMLinkageVarDefinitionEPKNS_7VarDeclEPN4llvm14GlobalVariableE", "clang::CodeGen::CodeGenModule::GetLLVMLinkageVarDefinition(clang::VarDecl const*, llvm::GlobalVariable*)"},
    {"_ZN5clang7CodeGen13CodeGenModule21getBuiltinLibFunctionEPKNS_12FunctionDeclEj", "clang::CodeGen::CodeGenModule::getBuiltinLibFunction(clang::FunctionDecl const*, unsigned int)"},
    {"_ZN5clang7CodeGen13CodeGenModule12getIntrinsicEjPPKN4llvm4TypeEj", "clang::CodeGen::CodeGenModule::getIntrinsic(unsigned int, llvm::Type const**, unsigned int)"},
    {"_ZN5clang7CodeGen13CodeGenModule25GetAddrOfConstantCFStringEPKNS_13StringLiteralE", "clang::CodeGen::CodeGenModule::GetAddrOfConstantCFString(clang::StringLiteral const*)"},
    {"_Z24GetConstantCFStringEntryRN4llvm9StringMapIPNS_8ConstantENS_15MallocAllocatorEEEPKN5clang13StringLiteralEbRbRj", "GetConstantCFStringEntry(llvm::StringMap<llvm::Constant*, llvm::MallocAllocator>&, clang::StringLiteral const*, bool, bool&, unsigned int&)"},
    {"_ZN5clang7CodeGen13CodeGenModule23GetAddrOfConstantStringEPKNS_13StringLiteralE", "clang::CodeGen::CodeGenModule::GetAddrOfConstantString(clang::StringLiteral const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule25GetStringForStringLiteralEPKNS_13StringLiteralE", "clang::CodeGen::CodeGenModule::GetStringForStringLiteral(clang::StringLiteral const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule34GetAddrOfConstantStringFromLiteralEPKNS_13StringLiteralE", "clang::CodeGen::CodeGenModule::GetAddrOfConstantStringFromLiteral(clang::StringLiteral const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule23GetAddrOfConstantStringERKSsPKc", "clang::CodeGen::CodeGenModule::GetAddrOfConstantString(std::string const&, char const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule37GetAddrOfConstantStringFromObjCEncodeEPKNS_14ObjCEncodeExprE", "clang::CodeGen::CodeGenModule::GetAddrOfConstantStringFromObjCEncode(clang::ObjCEncodeExpr const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule24GetAddrOfConstantCStringERKSsPKc", "clang::CodeGen::CodeGenModule::GetAddrOfConstantCString(std::string const&, char const*)"},
    {"_Z21GenerateStringLiteralRKSsbRN5clang7CodeGen13CodeGenModuleEPKc", "GenerateStringLiteral(std::string const&, bool, clang::CodeGen::CodeGenModule&, char const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule31EmitObjCPropertyImplementationsEPKNS_22ObjCImplementationDeclE", "clang::CodeGen::CodeGenModule::EmitObjCPropertyImplementations(clang::ObjCImplementationDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule27EmitObjCIvarInitializationsEPNS_22ObjCImplementationDeclE", "clang::CodeGen::CodeGenModule::EmitObjCIvarInitializations(clang::ObjCImplementationDecl*)"},
    {"_ZN5clang7CodeGen13CodeGenModule13EmitNamespaceEPKNS_13NamespaceDeclE", "clang::CodeGen::CodeGenModule::EmitNamespace(clang::NamespaceDecl const*)"},
    {"_ZN5clang7CodeGen13CodeGenModule16EmitTopLevelDeclEPNS_4DeclE", "clang::CodeGen::CodeGenModule::EmitTopLevelDecl(clang::Decl*)"},
    {"_ZN5clang7CodeGen13CodeGenModule15EmitLinkageSpecEPKNS_15LinkageSpecDeclE", "clang::CodeGen::CodeGenModule::EmitLinkageSpec(clang::LinkageSpecDecl const*)"},
    {"_Z22EmitGlobalDeclMetadataRN5clang7CodeGen13CodeGenModuleERPN4llvm11NamedMDNodeENS0_10GlobalDeclEPNS3_11GlobalValueE", "EmitGlobalDeclMetadata(clang::CodeGen::CodeGenModule&, llvm::NamedMDNode*&, clang::CodeGen::GlobalDecl, llvm::GlobalValue*)"},
    {"_ZN5clang7CodeGen15CodeGenFunction16EmitDeclMetadataEv", "clang::CodeGen::CodeGenFunction::EmitDeclMetadata()"},
    {"_ZN5clang7CodeGen13CodeGenModule21getBlockObjectDisposeEv", "clang::CodeGen::CodeGenModule::getBlockObjectDispose()"},
    {"_ZN5clang7CodeGen13CodeGenModule20getBlockObjectAssignEv", "clang::CodeGen::CodeGenModule::getBlockObjectAssign()"},
    {"_ZN5clang7CodeGen13CodeGenModule24getNSConcreteGlobalBlockEv", "clang::CodeGen::CodeGenModule::getNSConcreteGlobalBlock()"},
    {"_ZN5clang7CodeGen13CodeGenModule23getNSConcreteStackBlockEv", "clang::CodeGen::CodeGenModule::getNSConcreteStackBlock()"},
    {"_ZNK5clang4Decl7getAttrINS_11SectionAttrEEEPT_v", "clang::SectionAttr* clang::Decl::getAttr<clang::SectionAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_9AliasAttrEEEPT_v", "clang::AliasAttr* clang::Decl::getAttr<clang::AliasAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_12AnnotateAttrEEEPT_v", "clang::AnnotateAttr* clang::Decl::getAttr<clang::AnnotateAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_12NoCommonAttrEEEPT_v", "clang::NoCommonAttr* clang::Decl::getAttr<clang::NoCommonAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_10CommonAttrEEEPT_v", "clang::CommonAttr* clang::Decl::getAttr<clang::CommonAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_15ConstructorAttrEEEPT_v", "clang::ConstructorAttr* clang::Decl::getAttr<clang::ConstructorAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_14DestructorAttrEEEPT_v", "clang::DestructorAttr* clang::Decl::getAttr<clang::DestructorAttr>() const"},
    {"_ZN4llvm9StringMapIPNS_8ConstantENS_15MallocAllocatorEE16GetOrCreateValueIS2_EERNS_14StringMapEntryIS2_EENS_9StringRefET_", "llvm::StringMapEntry<llvm::Constant*>& llvm::StringMap<llvm::Constant*, llvm::MallocAllocator>::GetOrCreateValue<llvm::Constant*>(llvm::StringRef, llvm::Constant*)"},
    {"_ZN4llvm9StringMapIN5clang7CodeGen10GlobalDeclENS_15MallocAllocatorEE16GetOrCreateValueIS3_EERNS_14StringMapEntryIS3_EENS_9StringRefET_", "llvm::StringMapEntry<clang::CodeGen::GlobalDecl>& llvm::StringMap<clang::CodeGen::GlobalDecl, llvm::MallocAllocator>::GetOrCreateValue<clang::CodeGen::GlobalDecl>(llvm::StringRef, clang::CodeGen::GlobalDecl)"},
    {"_ZNSt6vectorIN5clang7CodeGen10GlobalDeclESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::CodeGen::GlobalDecl, std::allocator<clang::CodeGen::GlobalDecl>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::CodeGen::GlobalDecl*, std::vector<clang::CodeGen::GlobalDecl, std::allocator<clang::CodeGen::GlobalDecl>>>, clang::CodeGen::GlobalDecl const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::Decl const*, unsigned int, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::Decl const* const&, unsigned int const&, std::pair<clang::Decl const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::Decl const*, unsigned int, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZNSt6vectorISt4pairIPN4llvm8ConstantEiESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<std::pair<llvm::Constant*, int>, std::allocator<std::pair<llvm::Constant*, int>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, int>*, std::vector<std::pair<llvm::Constant*, int>, std::allocator<std::pair<llvm::Constant*, int>>>>, std::pair<llvm::Constant*, int> const&)"},
    {"_ZN4llvm8DenseMapIN5clang7CodeGen10GlobalDeclENS_9StringRefENS_12DenseMapInfoIS3_EENS5_IS4_EEE16InsertIntoBucketERKS3_RKS4_PSt4pairIS3_S4_E", "llvm::DenseMap<clang::CodeGen::GlobalDecl, llvm::StringRef, llvm::DenseMapInfo<clang::CodeGen::GlobalDecl>, llvm::DenseMapInfo<llvm::StringRef>>::InsertIntoBucket(clang::CodeGen::GlobalDecl const&, llvm::StringRef const&, std::pair<clang::CodeGen::GlobalDecl, llvm::StringRef>*)"},
    {"_ZN4llvm8DenseMapIN5clang7CodeGen10GlobalDeclENS_9StringRefENS_12DenseMapInfoIS3_EENS5_IS4_EEE4growEj", "llvm::DenseMap<clang::CodeGen::GlobalDecl, llvm::StringRef, llvm::DenseMapInfo<clang::CodeGen::GlobalDecl>, llvm::DenseMapInfo<llvm::StringRef>>::grow(unsigned int)"},
    {"_ZN5clang7CodeGen15CodeGenFunctionD2Ev", "clang::CodeGen::CodeGenFunction::~CodeGenFunction()"},
    {"_ZN5clang7CodeGen14CodeGenVTablesD2Ev", "clang::CodeGen::CodeGenVTables::~CodeGenVTables()"},
    {"_ZN5clang7CodeGen14CodeGenVTablesC2ERNS0_13CodeGenModuleE", "clang::CodeGen::CodeGenVTables::CodeGenVTables(clang::CodeGen::CodeGenModule&)"},
    {"_ZN5clang7CodeGen11CodeGenTBAAC1ERNS_10ASTContextERN4llvm11LLVMContextERKNS_11LangOptionsERNS_13MangleContextE", "clang::CodeGen::CodeGenTBAA::CodeGenTBAA(clang::ASTContext&, llvm::LLVMContext&, clang::LangOptions const&, clang::MangleContext&)"},
    {"_ZN5clang7CodeGen11CodeGenTBAAC2ERNS_10ASTContextERN4llvm11LLVMContextERKNS_11LangOptionsERNS_13MangleContextE", "clang::CodeGen::CodeGenTBAA::CodeGenTBAA(clang::ASTContext&, llvm::LLVMContext&, clang::LangOptions const&, clang::MangleContext&)"},
    {"_ZN5clang7CodeGen11CodeGenTBAAD1Ev", "clang::CodeGen::CodeGenTBAA::~CodeGenTBAA()"},
    {"_ZN5clang7CodeGen11CodeGenTBAAD2Ev", "clang::CodeGen::CodeGenTBAA::~CodeGenTBAA()"},
    {"_ZN5clang7CodeGen11CodeGenTBAA7getRootEv", "clang::CodeGen::CodeGenTBAA::getRoot()"},
    {"_ZN5clang7CodeGen11CodeGenTBAA23getTBAAInfoForNamedTypeEN4llvm9StringRefEPNS2_6MDNodeEb", "clang::CodeGen::CodeGenTBAA::getTBAAInfoForNamedType(llvm::StringRef, llvm::MDNode*, bool)"},
    {"_ZN5clang7CodeGen11CodeGenTBAA7getCharEv", "clang::CodeGen::CodeGenTBAA::getChar()"},
    {"_ZN5clang7CodeGen11CodeGenTBAA11getTBAAInfoENS_8QualTypeE", "clang::CodeGen::CodeGenTBAA::getTBAAInfo(clang::QualType)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeEPNS_6MDNodeENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::Type const*, llvm::MDNode*, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<llvm::MDNode*>>::InsertIntoBucket(clang::Type const* const&, llvm::MDNode* const&, std::pair<clang::Type const*, llvm::MDNode*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeEPNS_6MDNodeENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::Type const*, llvm::MDNode*, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<llvm::MDNode*>>::grow(unsigned int)"},
    {"_ZN5clang7CodeGen12CodeGenTypesC1ERNS_10ASTContextERN4llvm6ModuleERKNS4_10DataLayoutERKNS_7ABIInfoERNS0_8CGCXXABIE", "clang::CodeGen::CodeGenTypes::CodeGenTypes(clang::ASTContext&, llvm::Module&, llvm::DataLayout const&, clang::ABIInfo const&, clang::CodeGen::CGCXXABI&)"},
    {"_ZN5clang7CodeGen12CodeGenTypesC2ERNS_10ASTContextERN4llvm6ModuleERKNS4_10DataLayoutERKNS_7ABIInfoERNS0_8CGCXXABIE", "clang::CodeGen::CodeGenTypes::CodeGenTypes(clang::ASTContext&, llvm::Module&, llvm::DataLayout const&, clang::ABIInfo const&, clang::CodeGen::CGCXXABI&)"},
    {"_ZN5clang7CodeGen12CodeGenTypesD1Ev", "clang::CodeGen::CodeGenTypes::~CodeGenTypes()"},
    {"_ZN5clang7CodeGen12CodeGenTypesD2Ev", "clang::CodeGen::CodeGenTypes::~CodeGenTypes()"},
    {"_ZN5clang7CodeGen12CodeGenTypes26HandleLateResolvedPointersEv", "clang::CodeGen::CodeGenTypes::HandleLateResolvedPointers()"},
    {"_ZN5clang7CodeGen12CodeGenTypes11ConvertTypeENS_8QualTypeEb", "clang::CodeGen::CodeGenTypes::ConvertType(clang::QualType, bool)"},
    {"_ZN5clang7CodeGen12CodeGenTypes20ConvertTypeRecursiveENS_8QualTypeE", "clang::CodeGen::CodeGenTypes::ConvertTypeRecursive(clang::QualType)"},
    {"_ZN5clang7CodeGen12CodeGenTypes14ConvertNewTypeENS_8QualTypeE", "clang::CodeGen::CodeGenTypes::ConvertNewType(clang::QualType)"},
    {"_ZN5clang7CodeGen12CodeGenTypes17ConvertTypeForMemENS_8QualTypeEb", "clang::CodeGen::CodeGenTypes::ConvertTypeForMem(clang::QualType, bool)"},
    {"_ZN5clang7CodeGen12CodeGenTypes22VerifyFuncTypeCompleteEPKNS_4TypeE", "clang::CodeGen::CodeGenTypes::VerifyFuncTypeComplete(clang::Type const*)"},
    {"_ZN5clang7CodeGen12CodeGenTypes19UpdateCompletedTypeEPKNS_7TagDeclE", "clang::CodeGen::CodeGenTypes::UpdateCompletedType(clang::TagDecl const*)"},
    {"_ZN5clang7CodeGen12CodeGenTypes18ConvertTagDeclTypeEPKNS_7TagDeclE", "clang::CodeGen::CodeGenTypes::ConvertTagDeclType(clang::TagDecl const*)"},
    {"_ZN5clang7CodeGen12CodeGenTypes17getCGRecordLayoutEPKNS_10RecordDeclE", "clang::CodeGen::CodeGenTypes::getCGRecordLayout(clang::RecordDecl const*)"},
    {"_ZN5clang7CodeGen12CodeGenTypes19isZeroInitializableENS_8QualTypeE", "clang::CodeGen::CodeGenTypes::isZeroInitializable(clang::QualType)"},
    {"_ZN5clang7CodeGen12CodeGenTypes19isZeroInitializableEPKNS_13CXXRecordDeclE", "clang::CodeGen::CodeGenTypes::isZeroInitializable(clang::CXXRecordDecl const*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeENS_12PATypeHolderENS_12DenseMapInfoIS4_EENS6_IS5_EEED1Ev", "llvm::DenseMap<clang::Type const*, llvm::PATypeHolder, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<llvm::PATypeHolder>>::~DenseMap()"},
    {"_ZN4llvm10FoldingSetIN5clang7CodeGen14CGFunctionInfoEED1Ev", "llvm::FoldingSet<clang::CodeGen::CGFunctionInfo>::~FoldingSet()"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeENS_12PATypeHolderENS_12DenseMapInfoIS4_EENS6_IS5_EEE6insertERKSt4pairIS4_S5_E", "llvm::DenseMap<clang::Type const*, llvm::PATypeHolder, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<llvm::PATypeHolder>>::insert(std::pair<clang::Type const*, llvm::PATypeHolder> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeEPNS1_7CodeGen14CGRecordLayoutENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::Type const*, clang::CodeGen::CGRecordLayout*, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<clang::CodeGen::CGRecordLayout*>>::InsertIntoBucket(clang::Type const* const&, clang::CodeGen::CGRecordLayout* const&, std::pair<clang::Type const*, clang::CodeGen::CGRecordLayout*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeEPNS1_7CodeGen14CGRecordLayoutENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::Type const*, clang::CodeGen::CGRecordLayout*, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<clang::CodeGen::CGRecordLayout*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang17ObjCInterfaceTypeEPKNS_4TypeENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::ObjCInterfaceType const*, llvm::Type const*, llvm::DenseMapInfo<clang::ObjCInterfaceType const*>, llvm::DenseMapInfo<llvm::Type const*>>::InsertIntoBucket(clang::ObjCInterfaceType const* const&, llvm::Type const* const&, std::pair<clang::ObjCInterfaceType const*, llvm::Type const*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang17ObjCInterfaceTypeEPKNS_4TypeENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::ObjCInterfaceType const*, llvm::Type const*, llvm::DenseMapInfo<clang::ObjCInterfaceType const*>, llvm::DenseMapInfo<llvm::Type const*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeENS_12PATypeHolderENS_12DenseMapInfoIS4_EENS6_IS5_EEE16InsertIntoBucketERKS4_RKS5_PSt4pairIS4_S5_E", "llvm::DenseMap<clang::Type const*, llvm::PATypeHolder, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<llvm::PATypeHolder>>::InsertIntoBucket(clang::Type const* const&, llvm::PATypeHolder const&, std::pair<clang::Type const*, llvm::PATypeHolder>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeENS_12PATypeHolderENS_12DenseMapInfoIS4_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::Type const*, llvm::PATypeHolder, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<llvm::PATypeHolder>>::grow(unsigned int)"},
    {"_ZN4llvm10FoldingSetIN5clang7CodeGen14CGFunctionInfoEED0Ev", "llvm::FoldingSet<clang::CodeGen::CGFunctionInfo>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang7CodeGen14CGFunctionInfoEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::CodeGen::CGFunctionInfo>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang7CodeGen14CGFunctionInfoEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::CodeGen::CGFunctionInfo>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang7CodeGen14CGFunctionInfoEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::CodeGen::CGFunctionInfo>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang7CodeGen14CGFunctionInfo7ProfileERN4llvm16FoldingSetNodeIDE", "clang::CodeGen::CGFunctionInfo::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang7CodeGen14CGRecordLayoutD2Ev", "clang::CodeGen::CGRecordLayout::~CGRecordLayout()"},
    {"_ZN5clang7CodeGen19CreateItaniumCXXABIERNS0_13CodeGenModuleE", "clang::CodeGen::CreateItaniumCXXABI(clang::CodeGen::CodeGenModule&)"},
    {"_ZN5clang7CodeGen15CreateARMCXXABIERNS0_13CodeGenModuleE", "clang::CodeGen::CreateARMCXXABI(clang::CodeGen::CodeGenModule&)"},
    {"_ZN12_GLOBAL__N_19ARMCXXABID1Ev", "(anonymous namespace)::ARMCXXABI::~ARMCXXABI()"},
    {"_ZN12_GLOBAL__N_19ARMCXXABID0Ev", "(anonymous namespace)::ARMCXXABI::~ARMCXXABI()"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI24ConvertMemberPointerTypeEPKN5clang17MemberPointerTypeE", "(anonymous namespace)::ItaniumCXXABI::ConvertMemberPointerType(clang::MemberPointerType const*)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI31EmitLoadOfMemberFunctionPointerERN5clang7CodeGen15CodeGenFunctionERPN4llvm5ValueES7_PKNS1_17MemberPointerTypeE", "(anonymous namespace)::ItaniumCXXABI::EmitLoadOfMemberFunctionPointer(clang::CodeGen::CodeGenFunction&, llvm::Value*&, llvm::Value*, clang::MemberPointerType const*)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI28EmitMemberDataPointerAddressERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_PKNS1_17MemberPointerTypeE", "(anonymous namespace)::ItaniumCXXABI::EmitMemberDataPointerAddress(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, clang::MemberPointerType const*)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI27EmitMemberPointerConversionERN5clang7CodeGen15CodeGenFunctionEPKNS1_8CastExprEPN4llvm5ValueE", "(anonymous namespace)::ItaniumCXXABI::EmitMemberPointerConversion(clang::CodeGen::CodeGenFunction&, clang::CastExpr const*, llvm::Value*)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI27EmitMemberPointerConversionEPN4llvm8ConstantEPKN5clang8CastExprE", "(anonymous namespace)::ItaniumCXXABI::EmitMemberPointerConversion(llvm::Constant*, clang::CastExpr const*)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI19isZeroInitializableEPKN5clang17MemberPointerTypeE", "(anonymous namespace)::ItaniumCXXABI::isZeroInitializable(clang::MemberPointerType const*)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI21EmitNullMemberPointerEPKN5clang17MemberPointerTypeE", "(anonymous namespace)::ItaniumCXXABI::EmitNullMemberPointer(clang::MemberPointerType const*)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI17EmitMemberPointerEPKN5clang13CXXMethodDeclE", "(anonymous namespace)::ItaniumCXXABI::EmitMemberPointer(clang::CXXMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI21EmitMemberDataPointerEPKN5clang17MemberPointerTypeENS1_9CharUnitsE", "(anonymous namespace)::ItaniumCXXABI::EmitMemberDataPointer(clang::MemberPointerType const*, clang::CharUnits)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI27EmitMemberPointerComparisonERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_PKNS1_17MemberPointerTypeEb", "(anonymous namespace)::ItaniumCXXABI::EmitMemberPointerComparison(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, clang::MemberPointerType const*, bool)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI26EmitMemberPointerIsNotNullERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueEPKNS1_17MemberPointerTypeE", "(anonymous namespace)::ItaniumCXXABI::EmitMemberPointerIsNotNull(clang::CodeGen::CodeGenFunction&, llvm::Value*, clang::MemberPointerType const*)"},
    {"_ZN12_GLOBAL__N_19ARMCXXABI25BuildConstructorSignatureEPKN5clang18CXXConstructorDeclENS1_11CXXCtorTypeERNS1_7CanQualINS1_4TypeEEERN4llvm15SmallVectorImplIS8_EE", "(anonymous namespace)::ARMCXXABI::BuildConstructorSignature(clang::CXXConstructorDecl const*, clang::CXXCtorType, clang::CanQual<clang::Type>&, llvm::SmallVectorImpl<clang::CanQual<clang::Type>>&)"},
    {"_ZN12_GLOBAL__N_19ARMCXXABI24BuildDestructorSignatureEPKN5clang17CXXDestructorDeclENS1_11CXXDtorTypeERNS1_7CanQualINS1_4TypeEEERN4llvm15SmallVectorImplIS8_EE", "(anonymous namespace)::ARMCXXABI::BuildDestructorSignature(clang::CXXDestructorDecl const*, clang::CXXDtorType, clang::CanQual<clang::Type>&, llvm::SmallVectorImpl<clang::CanQual<clang::Type>>&)"},
    {"_ZN12_GLOBAL__N_19ARMCXXABI27BuildInstanceFunctionParamsERN5clang7CodeGen15CodeGenFunctionERNS1_8QualTypeERN4llvm11SmallVectorISt4pairIPKNS1_7VarDeclES5_ELj16EEE", "(anonymous namespace)::ARMCXXABI::BuildInstanceFunctionParams(clang::CodeGen::CodeGenFunction&, clang::QualType&, llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u>&)"},
    {"_ZN12_GLOBAL__N_19ARMCXXABI26EmitInstanceFunctionPrologERN5clang7CodeGen15CodeGenFunctionE", "(anonymous namespace)::ARMCXXABI::EmitInstanceFunctionProlog(clang::CodeGen::CodeGenFunction&)"},
    {"_ZN12_GLOBAL__N_19ARMCXXABI19EmitReturnFromThunkERN5clang7CodeGen15CodeGenFunctionENS2_6RValueENS1_8QualTypeE", "(anonymous namespace)::ARMCXXABI::EmitReturnFromThunk(clang::CodeGen::CodeGenFunction&, clang::CodeGen::RValue, clang::QualType)"},
    {"_ZN12_GLOBAL__N_19ARMCXXABI18GetArrayCookieSizeEPKN5clang10CXXNewExprE", "(anonymous namespace)::ARMCXXABI::GetArrayCookieSize(clang::CXXNewExpr const*)"},
    {"_ZN12_GLOBAL__N_19ARMCXXABI21InitializeArrayCookieERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_PKNS1_10CXXNewExprENS1_8QualTypeE", "(anonymous namespace)::ARMCXXABI::InitializeArrayCookie(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, clang::CXXNewExpr const*, clang::QualType)"},
    {"_ZN12_GLOBAL__N_19ARMCXXABI15ReadArrayCookieERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueEPKNS1_13CXXDeleteExprENS1_8QualTypeERS7_SC_RNS1_9CharUnitsE", "(anonymous namespace)::ARMCXXABI::ReadArrayCookie(clang::CodeGen::CodeGenFunction&, llvm::Value*, clang::CXXDeleteExpr const*, clang::QualType, llvm::Value*&, llvm::Value*&, clang::CharUnits&)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI15EmitGuardedInitERN5clang7CodeGen15CodeGenFunctionERKNS1_7VarDeclEPN4llvm14GlobalVariableE", "(anonymous namespace)::ItaniumCXXABI::EmitGuardedInit(clang::CodeGen::CodeGenFunction&, clang::VarDecl const&, llvm::GlobalVariable*)"},
    {"_ZN12_GLOBAL__N_114CallGuardAbortD1Ev", "(anonymous namespace)::CallGuardAbort::~CallGuardAbort()"},
    {"_ZN12_GLOBAL__N_114CallGuardAbortD0Ev", "(anonymous namespace)::CallGuardAbort::~CallGuardAbort()"},
    {"_ZN12_GLOBAL__N_114CallGuardAbort4EmitERN5clang7CodeGen15CodeGenFunctionEb", "(anonymous namespace)::CallGuardAbort::Emit(clang::CodeGen::CodeGenFunction&, bool)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI26EmitInstanceFunctionPrologERN5clang7CodeGen15CodeGenFunctionE", "(anonymous namespace)::ItaniumCXXABI::EmitInstanceFunctionProlog(clang::CodeGen::CodeGenFunction&)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI27BuildInstanceFunctionParamsERN5clang7CodeGen15CodeGenFunctionERNS1_8QualTypeERN4llvm11SmallVectorISt4pairIPKNS1_7VarDeclES5_ELj16EEE", "(anonymous namespace)::ItaniumCXXABI::BuildInstanceFunctionParams(clang::CodeGen::CodeGenFunction&, clang::QualType&, llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u>&)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI24BuildDestructorSignatureEPKN5clang17CXXDestructorDeclENS1_11CXXDtorTypeERNS1_7CanQualINS1_4TypeEEERN4llvm15SmallVectorImplIS8_EE", "(anonymous namespace)::ItaniumCXXABI::BuildDestructorSignature(clang::CXXDestructorDecl const*, clang::CXXDtorType, clang::CanQual<clang::Type>&, llvm::SmallVectorImpl<clang::CanQual<clang::Type>>&)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI25BuildConstructorSignatureEPKN5clang18CXXConstructorDeclENS1_11CXXCtorTypeERNS1_7CanQualINS1_4TypeEEERN4llvm15SmallVectorImplIS8_EE", "(anonymous namespace)::ItaniumCXXABI::BuildConstructorSignature(clang::CXXConstructorDecl const*, clang::CXXCtorType, clang::CanQual<clang::Type>&, llvm::SmallVectorImpl<clang::CanQual<clang::Type>>&)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABID1Ev", "(anonymous namespace)::ItaniumCXXABI::~ItaniumCXXABI()"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABID0Ev", "(anonymous namespace)::ItaniumCXXABI::~ItaniumCXXABI()"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI18GetArrayCookieSizeEPKN5clang10CXXNewExprE", "(anonymous namespace)::ItaniumCXXABI::GetArrayCookieSize(clang::CXXNewExpr const*)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI21InitializeArrayCookieERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueES7_PKNS1_10CXXNewExprENS1_8QualTypeE", "(anonymous namespace)::ItaniumCXXABI::InitializeArrayCookie(clang::CodeGen::CodeGenFunction&, llvm::Value*, llvm::Value*, clang::CXXNewExpr const*, clang::QualType)"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABI15ReadArrayCookieERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueEPKNS1_13CXXDeleteExprENS1_8QualTypeERS7_SC_RNS1_9CharUnitsE", "(anonymous namespace)::ItaniumCXXABI::ReadArrayCookie(clang::CodeGen::CodeGenFunction&, llvm::Value*, clang::CXXDeleteExpr const*, clang::QualType, llvm::Value*&, llvm::Value*&, clang::CharUnits&)"},
    {"_ZN5clang7CodeGen15CodeGenFunction17GetAddrOfLocalVarEPKNS_7VarDeclE", "clang::CodeGen::CodeGenFunction::GetAddrOfLocalVar(clang::VarDecl const*)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE8CreateOrEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateOr(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE11CreateBinOpENS_11Instruction9BinaryOpsEPNS_5ValueES8_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateBinOp(llvm::Instruction::BinaryOps, llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE12CreateNSWSubEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateNSWSub(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE12CreateNSWAddEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateNSWAdd(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE12CreateSelectEPNS_5ValueES6_S6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateSelect(llvm::Value*, llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE17CreateInsertValueEPNS_5ValueES6_jRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateInsertValue(llvm::Value*, llvm::Value*, unsigned int, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateAShrEPNS_5ValueES6_RKNS_5TwineEb", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateAShr(llvm::Value*, llvm::Value*, llvm::Twine const&, bool)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateSubEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateSub(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN5clang7CodeGen21CreateMicrosoftCXXABIERNS0_13CodeGenModuleE", "clang::CodeGen::CreateMicrosoftCXXABI(clang::CodeGen::CodeGenModule&)"},
    {"_ZN12_GLOBAL__N_115MicrosoftCXXABID1Ev", "(anonymous namespace)::MicrosoftCXXABI::~MicrosoftCXXABI()"},
    {"_ZN12_GLOBAL__N_115MicrosoftCXXABID0Ev", "(anonymous namespace)::MicrosoftCXXABI::~MicrosoftCXXABI()"},
    {"_ZN12_GLOBAL__N_115MicrosoftCXXABI25BuildConstructorSignatureEPKN5clang18CXXConstructorDeclENS1_11CXXCtorTypeERNS1_7CanQualINS1_4TypeEEERN4llvm15SmallVectorImplIS8_EE", "(anonymous namespace)::MicrosoftCXXABI::BuildConstructorSignature(clang::CXXConstructorDecl const*, clang::CXXCtorType, clang::CanQual<clang::Type>&, llvm::SmallVectorImpl<clang::CanQual<clang::Type>>&)"},
    {"_ZN12_GLOBAL__N_115MicrosoftCXXABI24BuildDestructorSignatureEPKN5clang17CXXDestructorDeclENS1_11CXXDtorTypeERNS1_7CanQualINS1_4TypeEEERN4llvm15SmallVectorImplIS8_EE", "(anonymous namespace)::MicrosoftCXXABI::BuildDestructorSignature(clang::CXXDestructorDecl const*, clang::CXXDtorType, clang::CanQual<clang::Type>&, llvm::SmallVectorImpl<clang::CanQual<clang::Type>>&)"},
    {"_ZN12_GLOBAL__N_115MicrosoftCXXABI27BuildInstanceFunctionParamsERN5clang7CodeGen15CodeGenFunctionERNS1_8QualTypeERN4llvm11SmallVectorISt4pairIPKNS1_7VarDeclES5_ELj16EEE", "(anonymous namespace)::MicrosoftCXXABI::BuildInstanceFunctionParams(clang::CodeGen::CodeGenFunction&, clang::QualType&, llvm::SmallVector<std::pair<clang::VarDecl const*, clang::QualType>, 16u>&)"},
    {"_ZN12_GLOBAL__N_115MicrosoftCXXABI26EmitInstanceFunctionPrologERN5clang7CodeGen15CodeGenFunctionE", "(anonymous namespace)::MicrosoftCXXABI::EmitInstanceFunctionProlog(clang::CodeGen::CodeGenFunction&)"},
    {"_ZN5clang17CreateLLVMCodeGenERNS_10DiagnosticERKSsRKNS_14CodeGenOptionsERN4llvm11LLVMContextE", "clang::CreateLLVMCodeGen(clang::Diagnostic&, std::string const&, clang::CodeGenOptions const&, llvm::LLVMContext&)"},
    {"_ZN12_GLOBAL__N_117CodeGeneratorImplD1Ev", "(anonymous namespace)::CodeGeneratorImpl::~CodeGeneratorImpl()"},
    {"_ZN12_GLOBAL__N_117CodeGeneratorImplD0Ev", "(anonymous namespace)::CodeGeneratorImpl::~CodeGeneratorImpl()"},
    {"_ZN12_GLOBAL__N_117CodeGeneratorImpl10InitializeERN5clang10ASTContextE", "(anonymous namespace)::CodeGeneratorImpl::Initialize(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_117CodeGeneratorImpl18HandleTopLevelDeclEN5clang12DeclGroupRefE", "(anonymous namespace)::CodeGeneratorImpl::HandleTopLevelDecl(clang::DeclGroupRef)"},
    {"_ZN12_GLOBAL__N_117CodeGeneratorImpl21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::CodeGeneratorImpl::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_117CodeGeneratorImpl23HandleTagDeclDefinitionEPN5clang7TagDeclE", "(anonymous namespace)::CodeGeneratorImpl::HandleTagDeclDefinition(clang::TagDecl*)"},
    {"_ZN12_GLOBAL__N_117CodeGeneratorImpl27CompleteTentativeDefinitionEPN5clang7VarDeclE", "(anonymous namespace)::CodeGeneratorImpl::CompleteTentativeDefinition(clang::VarDecl*)"},
    {"_ZN12_GLOBAL__N_117CodeGeneratorImpl12HandleVTableEPN5clang13CXXRecordDeclEb", "(anonymous namespace)::CodeGeneratorImpl::HandleVTable(clang::CXXRecordDecl*, bool)"},
    {"_ZN12_GLOBAL__N_117CodeGeneratorImpl9GetModuleEv", "(anonymous namespace)::CodeGeneratorImpl::GetModule()"},
    {"_ZN12_GLOBAL__N_117CodeGeneratorImpl13ReleaseModuleEv", "(anonymous namespace)::CodeGeneratorImpl::ReleaseModule()"},
    {"_ZN5clang13CodeGeneratorD1Ev", "clang::CodeGenerator::~CodeGenerator()"},
    {"_ZN5clang13CodeGeneratorD0Ev", "clang::CodeGenerator::~CodeGenerator()"},
    {"_ZN5clang7ABIInfoD0Ev", "clang::ABIInfo::~ABIInfo()"},
    {"_ZN5clang7ABIInfoD1Ev", "clang::ABIInfo::~ABIInfo()"},
    {"_ZN5clang7ABIInfoD2Ev", "clang::ABIInfo::~ABIInfo()"},
    {"_ZNK5clang7ABIInfo10getContextEv", "clang::ABIInfo::getContext() const"},
    {"_ZNK5clang7ABIInfo12getVMContextEv", "clang::ABIInfo::getVMContext() const"},
    {"_ZNK5clang7ABIInfo13getDataLayoutEv", "clang::ABIInfo::getDataLayout() const"},
    {"_ZNK5clang10ABIArgInfo4dumpEv", "clang::ABIArgInfo::dump() const"},
    {"_ZN5clang17TargetCodeGenInfoD0Ev", "clang::TargetCodeGenInfo::~TargetCodeGenInfo()"},
    {"_ZN5clang17TargetCodeGenInfoD1Ev", "clang::TargetCodeGenInfo::~TargetCodeGenInfo()"},
    {"_ZN5clang17TargetCodeGenInfoD2Ev", "clang::TargetCodeGenInfo::~TargetCodeGenInfo()"},
    {"_ZN5clang7CodeGen13CodeGenModule20getTargetCodeGenInfoEv", "clang::CodeGen::CodeGenModule::getTargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_123X86_64TargetCodeGenInfoD1Ev", "(anonymous namespace)::X86_64TargetCodeGenInfo::~X86_64TargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_123X86_64TargetCodeGenInfoD0Ev", "(anonymous namespace)::X86_64TargetCodeGenInfo::~X86_64TargetCodeGenInfo()"},
    {"_ZNK12_GLOBAL__N_123X86_64TargetCodeGenInfo22getDwarfEHStackPointerERN5clang7CodeGen13CodeGenModuleE", "(anonymous namespace)::X86_64TargetCodeGenInfo::getDwarfEHStackPointer(clang::CodeGen::CodeGenModule&) const"},
    {"_ZNK12_GLOBAL__N_123X86_64TargetCodeGenInfo23initDwarfEHRegSizeTableERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "(anonymous namespace)::X86_64TargetCodeGenInfo::initDwarfEHRegSizeTable(clang::CodeGen::CodeGenFunction&, llvm::Value*) const"},
    {"_ZN12_GLOBAL__N_113X86_64ABIInfoD1Ev", "(anonymous namespace)::X86_64ABIInfo::~X86_64ABIInfo()"},
    {"_ZN12_GLOBAL__N_113X86_64ABIInfoD0Ev", "(anonymous namespace)::X86_64ABIInfo::~X86_64ABIInfo()"},
    {"_ZNK12_GLOBAL__N_113X86_64ABIInfo11computeInfoERN5clang7CodeGen14CGFunctionInfoE", "(anonymous namespace)::X86_64ABIInfo::computeInfo(clang::CodeGen::CGFunctionInfo&) const"},
    {"_ZNK12_GLOBAL__N_113X86_64ABIInfo9EmitVAArgEPN4llvm5ValueEN5clang8QualTypeERNS4_7CodeGen15CodeGenFunctionE", "(anonymous namespace)::X86_64ABIInfo::EmitVAArg(llvm::Value*, clang::QualType, clang::CodeGen::CodeGenFunction&) const"},
    {"_ZNK12_GLOBAL__N_113X86_64ABIInfo20classifyArgumentTypeEN5clang8QualTypeERjS3_", "(anonymous namespace)::X86_64ABIInfo::classifyArgumentType(clang::QualType, unsigned int&, unsigned int&) const"},
    {"_Z19EmitVAArgFromMemoryPN4llvm5ValueEN5clang8QualTypeERNS2_7CodeGen15CodeGenFunctionE", "EmitVAArgFromMemory(llvm::Value*, clang::QualType, clang::CodeGen::CodeGenFunction&)"},
    {"_ZNK12_GLOBAL__N_113X86_64ABIInfo8classifyEN5clang8QualTypeEyRNS0_5ClassES4_", "(anonymous namespace)::X86_64ABIInfo::classify(clang::QualType, unsigned long long, (anonymous namespace)::X86_64ABIInfo::Class&, (anonymous namespace)::X86_64ABIInfo::Class&) const"},
    {"_ZNK12_GLOBAL__N_113X86_64ABIInfo17getIndirectResultEN5clang8QualTypeE", "(anonymous namespace)::X86_64ABIInfo::getIndirectResult(clang::QualType) const"},
    {"_ZNK12_GLOBAL__N_113X86_64ABIInfo22GetINTEGERTypeAtOffsetEPKN4llvm4TypeEjN5clang8QualTypeEj", "(anonymous namespace)::X86_64ABIInfo::GetINTEGERTypeAtOffset(llvm::Type const*, unsigned int, clang::QualType, unsigned int) const"},
    {"_ZNK12_GLOBAL__N_113X86_64ABIInfo18GetSSETypeAtOffsetEPKN4llvm4TypeEjN5clang8QualTypeEj", "(anonymous namespace)::X86_64ABIInfo::GetSSETypeAtOffset(llvm::Type const*, unsigned int, clang::QualType, unsigned int) const"},
    {"_ZNK12_GLOBAL__N_113X86_64ABIInfo19Get16ByteVectorTypeEN5clang8QualTypeE", "(anonymous namespace)::X86_64ABIInfo::Get16ByteVectorType(clang::QualType) const"},
    {"_Z26GetX86_64ByValArgumentPairPKN4llvm4TypeES2_RKNS_10DataLayoutE", "GetX86_64ByValArgumentPair(llvm::Type const*, llvm::Type const*, llvm::DataLayout const&)"},
    {"_Z21BitsContainNoUserDataN5clang8QualTypeEjjRNS_10ASTContextE", "BitsContainNoUserData(clang::QualType, unsigned int, unsigned int, clang::ASTContext&)"},
    {"_Z21ContainsFloatAtOffsetPKN4llvm4TypeEjRKNS_10DataLayoutE", "ContainsFloatAtOffset(llvm::Type const*, unsigned int, llvm::DataLayout const&)"},
    {"_ZN12_GLOBAL__N_126WinX86_64TargetCodeGenInfoD1Ev", "(anonymous namespace)::WinX86_64TargetCodeGenInfo::~WinX86_64TargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_126WinX86_64TargetCodeGenInfoD0Ev", "(anonymous namespace)::WinX86_64TargetCodeGenInfo::~WinX86_64TargetCodeGenInfo()"},
    {"_ZNK12_GLOBAL__N_126WinX86_64TargetCodeGenInfo22getDwarfEHStackPointerERN5clang7CodeGen13CodeGenModuleE", "(anonymous namespace)::WinX86_64TargetCodeGenInfo::getDwarfEHStackPointer(clang::CodeGen::CodeGenModule&) const"},
    {"_ZNK12_GLOBAL__N_126WinX86_64TargetCodeGenInfo23initDwarfEHRegSizeTableERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "(anonymous namespace)::WinX86_64TargetCodeGenInfo::initDwarfEHRegSizeTable(clang::CodeGen::CodeGenFunction&, llvm::Value*) const"},
    {"_ZN12_GLOBAL__N_116WinX86_64ABIInfoD1Ev", "(anonymous namespace)::WinX86_64ABIInfo::~WinX86_64ABIInfo()"},
    {"_ZN12_GLOBAL__N_116WinX86_64ABIInfoD0Ev", "(anonymous namespace)::WinX86_64ABIInfo::~WinX86_64ABIInfo()"},
    {"_ZNK12_GLOBAL__N_116WinX86_64ABIInfo11computeInfoERN5clang7CodeGen14CGFunctionInfoE", "(anonymous namespace)::WinX86_64ABIInfo::computeInfo(clang::CodeGen::CGFunctionInfo&) const"},
    {"_ZNK12_GLOBAL__N_116WinX86_64ABIInfo9EmitVAArgEPN4llvm5ValueEN5clang8QualTypeERNS4_7CodeGen15CodeGenFunctionE", "(anonymous namespace)::WinX86_64ABIInfo::EmitVAArg(llvm::Value*, clang::QualType, clang::CodeGen::CodeGenFunction&) const"},
    {"_ZNK12_GLOBAL__N_116WinX86_64ABIInfo8classifyEN5clang8QualTypeE", "(anonymous namespace)::WinX86_64ABIInfo::classify(clang::QualType) const"},
    {"_ZN12_GLOBAL__N_123X86_32TargetCodeGenInfoD1Ev", "(anonymous namespace)::X86_32TargetCodeGenInfo::~X86_32TargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_123X86_32TargetCodeGenInfoD0Ev", "(anonymous namespace)::X86_32TargetCodeGenInfo::~X86_32TargetCodeGenInfo()"},
    {"_ZNK12_GLOBAL__N_123X86_32TargetCodeGenInfo19SetTargetAttributesEPKN5clang4DeclEPN4llvm11GlobalValueERNS1_7CodeGen13CodeGenModuleE", "(anonymous namespace)::X86_32TargetCodeGenInfo::SetTargetAttributes(clang::Decl const*, llvm::GlobalValue*, clang::CodeGen::CodeGenModule&) const"},
    {"_ZNK12_GLOBAL__N_123X86_32TargetCodeGenInfo22getDwarfEHStackPointerERN5clang7CodeGen13CodeGenModuleE", "(anonymous namespace)::X86_32TargetCodeGenInfo::getDwarfEHStackPointer(clang::CodeGen::CodeGenModule&) const"},
    {"_ZNK12_GLOBAL__N_123X86_32TargetCodeGenInfo23initDwarfEHRegSizeTableERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "(anonymous namespace)::X86_32TargetCodeGenInfo::initDwarfEHRegSizeTable(clang::CodeGen::CodeGenFunction&, llvm::Value*) const"},
    {"_ZN12_GLOBAL__N_113X86_32ABIInfoD1Ev", "(anonymous namespace)::X86_32ABIInfo::~X86_32ABIInfo()"},
    {"_ZN12_GLOBAL__N_113X86_32ABIInfoD0Ev", "(anonymous namespace)::X86_32ABIInfo::~X86_32ABIInfo()"},
    {"_ZNK12_GLOBAL__N_113X86_32ABIInfo11computeInfoERN5clang7CodeGen14CGFunctionInfoE", "(anonymous namespace)::X86_32ABIInfo::computeInfo(clang::CodeGen::CGFunctionInfo&) const"},
    {"_ZNK12_GLOBAL__N_113X86_32ABIInfo9EmitVAArgEPN4llvm5ValueEN5clang8QualTypeERNS4_7CodeGen15CodeGenFunctionE", "(anonymous namespace)::X86_32ABIInfo::EmitVAArg(llvm::Value*, clang::QualType, clang::CodeGen::CodeGenFunction&) const"},
    {"_Z25isRecordWithSSEVectorTypeRN5clang10ASTContextENS_8QualTypeE", "isRecordWithSSEVectorType(clang::ASTContext&, clang::QualType)"},
    {"_Z21isSingleElementStructN5clang8QualTypeERNS_10ASTContextE", "isSingleElementStruct(clang::QualType, clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_113X86_32ABIInfo26shouldReturnTypeInRegisterEN5clang8QualTypeERNS1_10ASTContextE", "(anonymous namespace)::X86_32ABIInfo::shouldReturnTypeInRegister(clang::QualType, clang::ASTContext&)"},
    {"_Z12isEmptyFieldRN5clang10ASTContextEPKNS_9FieldDeclEb", "isEmptyField(clang::ASTContext&, clang::FieldDecl const*, bool)"},
    {"_Z13isEmptyRecordRN5clang10ASTContextENS_8QualTypeEb", "isEmptyRecord(clang::ASTContext&, clang::QualType, bool)"},
    {"_ZN12_GLOBAL__N_123MSP430TargetCodeGenInfoD1Ev", "(anonymous namespace)::MSP430TargetCodeGenInfo::~MSP430TargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_123MSP430TargetCodeGenInfoD0Ev", "(anonymous namespace)::MSP430TargetCodeGenInfo::~MSP430TargetCodeGenInfo()"},
    {"_ZNK12_GLOBAL__N_123MSP430TargetCodeGenInfo19SetTargetAttributesEPKN5clang4DeclEPN4llvm11GlobalValueERNS1_7CodeGen13CodeGenModuleE", "(anonymous namespace)::MSP430TargetCodeGenInfo::SetTargetAttributes(clang::Decl const*, llvm::GlobalValue*, clang::CodeGen::CodeGenModule&) const"},
    {"_ZN12_GLOBAL__N_114DefaultABIInfoD1Ev", "(anonymous namespace)::DefaultABIInfo::~DefaultABIInfo()"},
    {"_ZN12_GLOBAL__N_114DefaultABIInfoD0Ev", "(anonymous namespace)::DefaultABIInfo::~DefaultABIInfo()"},
    {"_ZNK12_GLOBAL__N_114DefaultABIInfo11computeInfoERN5clang7CodeGen14CGFunctionInfoE", "(anonymous namespace)::DefaultABIInfo::computeInfo(clang::CodeGen::CGFunctionInfo&) const"},
    {"_ZNK12_GLOBAL__N_114DefaultABIInfo9EmitVAArgEPN4llvm5ValueEN5clang8QualTypeERNS4_7CodeGen15CodeGenFunctionE", "(anonymous namespace)::DefaultABIInfo::EmitVAArg(llvm::Value*, clang::QualType, clang::CodeGen::CodeGenFunction&) const"},
    {"_ZN12_GLOBAL__N_123MBlazeTargetCodeGenInfoD1Ev", "(anonymous namespace)::MBlazeTargetCodeGenInfo::~MBlazeTargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_123MBlazeTargetCodeGenInfoD0Ev", "(anonymous namespace)::MBlazeTargetCodeGenInfo::~MBlazeTargetCodeGenInfo()"},
    {"_ZNK12_GLOBAL__N_123MBlazeTargetCodeGenInfo19SetTargetAttributesEPKN5clang4DeclEPN4llvm11GlobalValueERNS1_7CodeGen13CodeGenModuleE", "(anonymous namespace)::MBlazeTargetCodeGenInfo::SetTargetAttributes(clang::Decl const*, llvm::GlobalValue*, clang::CodeGen::CodeGenModule&) const"},
    {"_ZN12_GLOBAL__N_113MBlazeABIInfoD1Ev", "(anonymous namespace)::MBlazeABIInfo::~MBlazeABIInfo()"},
    {"_ZN12_GLOBAL__N_113MBlazeABIInfoD0Ev", "(anonymous namespace)::MBlazeABIInfo::~MBlazeABIInfo()"},
    {"_ZNK12_GLOBAL__N_113MBlazeABIInfo11computeInfoERN5clang7CodeGen14CGFunctionInfoE", "(anonymous namespace)::MBlazeABIInfo::computeInfo(clang::CodeGen::CGFunctionInfo&) const"},
    {"_ZNK12_GLOBAL__N_113MBlazeABIInfo9EmitVAArgEPN4llvm5ValueEN5clang8QualTypeERNS4_7CodeGen15CodeGenFunctionE", "(anonymous namespace)::MBlazeABIInfo::EmitVAArg(llvm::Value*, clang::QualType, clang::CodeGen::CodeGenFunction&) const"},
    {"_ZN12_GLOBAL__N_124SystemZTargetCodeGenInfoD1Ev", "(anonymous namespace)::SystemZTargetCodeGenInfo::~SystemZTargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_124SystemZTargetCodeGenInfoD0Ev", "(anonymous namespace)::SystemZTargetCodeGenInfo::~SystemZTargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_114SystemZABIInfoD1Ev", "(anonymous namespace)::SystemZABIInfo::~SystemZABIInfo()"},
    {"_ZN12_GLOBAL__N_114SystemZABIInfoD0Ev", "(anonymous namespace)::SystemZABIInfo::~SystemZABIInfo()"},
    {"_ZNK12_GLOBAL__N_114SystemZABIInfo11computeInfoERN5clang7CodeGen14CGFunctionInfoE", "(anonymous namespace)::SystemZABIInfo::computeInfo(clang::CodeGen::CGFunctionInfo&) const"},
    {"_ZNK12_GLOBAL__N_114SystemZABIInfo9EmitVAArgEPN4llvm5ValueEN5clang8QualTypeERNS4_7CodeGen15CodeGenFunctionE", "(anonymous namespace)::SystemZABIInfo::EmitVAArg(llvm::Value*, clang::QualType, clang::CodeGen::CodeGenFunction&) const"},
    {"_ZN12_GLOBAL__N_122PPC32TargetCodeGenInfoD1Ev", "(anonymous namespace)::PPC32TargetCodeGenInfo::~PPC32TargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_122PPC32TargetCodeGenInfoD0Ev", "(anonymous namespace)::PPC32TargetCodeGenInfo::~PPC32TargetCodeGenInfo()"},
    {"_ZNK12_GLOBAL__N_122PPC32TargetCodeGenInfo22getDwarfEHStackPointerERN5clang7CodeGen13CodeGenModuleE", "(anonymous namespace)::PPC32TargetCodeGenInfo::getDwarfEHStackPointer(clang::CodeGen::CodeGenModule&) const"},
    {"_ZNK12_GLOBAL__N_122PPC32TargetCodeGenInfo23initDwarfEHRegSizeTableERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "(anonymous namespace)::PPC32TargetCodeGenInfo::initDwarfEHRegSizeTable(clang::CodeGen::CodeGenFunction&, llvm::Value*) const"},
    {"_ZN12_GLOBAL__N_124DefaultTargetCodeGenInfoD1Ev", "(anonymous namespace)::DefaultTargetCodeGenInfo::~DefaultTargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_124DefaultTargetCodeGenInfoD0Ev", "(anonymous namespace)::DefaultTargetCodeGenInfo::~DefaultTargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_120ARMTargetCodeGenInfoD1Ev", "(anonymous namespace)::ARMTargetCodeGenInfo::~ARMTargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_120ARMTargetCodeGenInfoD0Ev", "(anonymous namespace)::ARMTargetCodeGenInfo::~ARMTargetCodeGenInfo()"},
    {"_ZNK12_GLOBAL__N_120ARMTargetCodeGenInfo22getDwarfEHStackPointerERN5clang7CodeGen13CodeGenModuleE", "(anonymous namespace)::ARMTargetCodeGenInfo::getDwarfEHStackPointer(clang::CodeGen::CodeGenModule&) const"},
    {"_ZN12_GLOBAL__N_110ARMABIInfoD1Ev", "(anonymous namespace)::ARMABIInfo::~ARMABIInfo()"},
    {"_ZN12_GLOBAL__N_110ARMABIInfoD0Ev", "(anonymous namespace)::ARMABIInfo::~ARMABIInfo()"},
    {"_ZNK12_GLOBAL__N_110ARMABIInfo11computeInfoERN5clang7CodeGen14CGFunctionInfoE", "(anonymous namespace)::ARMABIInfo::computeInfo(clang::CodeGen::CGFunctionInfo&) const"},
    {"_ZNK12_GLOBAL__N_110ARMABIInfo9EmitVAArgEPN4llvm5ValueEN5clang8QualTypeERNS4_7CodeGen15CodeGenFunctionE", "(anonymous namespace)::ARMABIInfo::EmitVAArg(llvm::Value*, clang::QualType, clang::CodeGen::CodeGenFunction&) const"},
    {"_Z17isIntegerLikeTypeN5clang8QualTypeERNS_10ASTContextERN4llvm11LLVMContextE", "isIntegerLikeType(clang::QualType, clang::ASTContext&, llvm::LLVMContext&)"},
    {"_ZN12_GLOBAL__N_121MIPSTargetCodeGenInfoD1Ev", "(anonymous namespace)::MIPSTargetCodeGenInfo::~MIPSTargetCodeGenInfo()"},
    {"_ZN12_GLOBAL__N_121MIPSTargetCodeGenInfoD0Ev", "(anonymous namespace)::MIPSTargetCodeGenInfo::~MIPSTargetCodeGenInfo()"},
    {"_ZNK12_GLOBAL__N_121MIPSTargetCodeGenInfo22getDwarfEHStackPointerERN5clang7CodeGen13CodeGenModuleE", "(anonymous namespace)::MIPSTargetCodeGenInfo::getDwarfEHStackPointer(clang::CodeGen::CodeGenModule&) const"},
    {"_ZNK12_GLOBAL__N_121MIPSTargetCodeGenInfo23initDwarfEHRegSizeTableERN5clang7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "(anonymous namespace)::MIPSTargetCodeGenInfo::initDwarfEHRegSizeTable(clang::CodeGen::CodeGenFunction&, llvm::Value*) const"},
    {"_ZNK5clang17TargetCodeGenInfo19SetTargetAttributesEPKNS_4DeclEPN4llvm11GlobalValueERNS_7CodeGen13CodeGenModuleE", "clang::TargetCodeGenInfo::SetTargetAttributes(clang::Decl const*, llvm::GlobalValue*, clang::CodeGen::CodeGenModule&) const"},
    {"_ZNK5clang17TargetCodeGenInfo21extendPointerWithSExtEv", "clang::TargetCodeGenInfo::extendPointerWithSExt() const"},
    {"_ZNK5clang17TargetCodeGenInfo22getDwarfEHStackPointerERNS_7CodeGen13CodeGenModuleE", "clang::TargetCodeGenInfo::getDwarfEHStackPointer(clang::CodeGen::CodeGenModule&) const"},
    {"_ZNK5clang17TargetCodeGenInfo23initDwarfEHRegSizeTableERNS_7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "clang::TargetCodeGenInfo::initDwarfEHRegSizeTable(clang::CodeGen::CodeGenFunction&, llvm::Value*) const"},
    {"_ZNK5clang17TargetCodeGenInfo19decodeReturnAddressERNS_7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "clang::TargetCodeGenInfo::decodeReturnAddress(clang::CodeGen::CodeGenFunction&, llvm::Value*) const"},
    {"_ZNK5clang17TargetCodeGenInfo19encodeReturnAddressERNS_7CodeGen15CodeGenFunctionEPN4llvm5ValueE", "clang::TargetCodeGenInfo::encodeReturnAddress(clang::CodeGen::CodeGenFunction&, llvm::Value*) const"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE26CreateConstInBoundsGEP1_32EPNS_5ValueEjRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateConstInBoundsGEP1_32(llvm::Value*, unsigned int, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE11CreateStoreEPNS_5ValueES6_b", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateStore(llvm::Value*, llvm::Value*, bool)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateLoadEPNS_5ValueEPKc", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateLoad(llvm::Value*, char const*)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateAndEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateAnd(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE12CreateCondBrEPNS_5ValueEPNS_10BasicBlockES8_", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateCondBr(llvm::Value*, llvm::BasicBlock*, llvm::BasicBlock*)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateGEPEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateGEP(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateLoadEPNS_5ValueERKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateLoad(llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE18CreateConstGEP1_32EPNS_5ValueEjRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateConstGEP1_32(llvm::Value*, unsigned int, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreateAddEPNS_5ValueES6_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateAdd(llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE9CreatePHIEPKNS_4TypeERKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreatePHI(llvm::Type const*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateCastENS_11Instruction7CastOpsEPNS_5ValueEPKNS_4TypeERKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateCast(llvm::Instruction::CastOps, llvm::Value*, llvm::Type const*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE10CreateICmpENS_7CmpInst9PredicateEPNS_5ValueES8_RKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateICmp(llvm::CmpInst::Predicate, llvm::Value*, llvm::Value*, llvm::Twine const&)"},
    {"_ZN4llvm9IRBuilderILb0ENS_14ConstantFolderENS_24IRBuilderDefaultInserterILb0EEEE26CreateConstInBoundsGEP2_32EPNS_5ValueEjjRKNS_5TwineE", "llvm::IRBuilder<false, llvm::ConstantFolder, llvm::IRBuilderDefaultInserter<false>>::CreateConstInBoundsGEP2_32(llvm::Value*, unsigned int, unsigned int, llvm::Twine const&)"},
    {"_ZNK5clang4Decl7getAttrINS_19MSP430InterruptAttrEEEPT_v", "clang::MSP430InterruptAttr* clang::Decl::getAttr<clang::MSP430InterruptAttr>() const"},
    {"_ZN5clang8ParseASTERNS_12PreprocessorEPNS_11ASTConsumerERNS_10ASTContextEbbPNS_20CodeCompleteConsumerE", "clang::ParseAST(clang::Preprocessor&, clang::ASTConsumer*, clang::ASTContext&, bool, bool, clang::CodeCompleteConsumer*)"},
    {"_ZN5clang8ParseASTERNS_4SemaEb", "clang::ParseAST(clang::Sema&, bool)"},
    {"_ZN5clang6Parser23ParseCXXInlineMethodDefENS_15AccessSpecifierERNS_10DeclaratorERKNS0_18ParsedTemplateInfoERKNS_14VirtSpecifiersE", "clang::Parser::ParseCXXInlineMethodDef(clang::AccessSpecifier, clang::Declarator&, clang::Parser::ParsedTemplateInfo const&, clang::VirtSpecifiers const&)"},
    {"_ZN5clang6Parser21LateParsedDeclarationD0Ev", "clang::Parser::LateParsedDeclaration::~LateParsedDeclaration()"},
    {"_ZN5clang6Parser21LateParsedDeclarationD1Ev", "clang::Parser::LateParsedDeclaration::~LateParsedDeclaration()"},
    {"_ZN5clang6Parser21LateParsedDeclarationD2Ev", "clang::Parser::LateParsedDeclaration::~LateParsedDeclaration()"},
    {"_ZN5clang6Parser21LateParsedDeclaration28ParseLexedMethodDeclarationsEv", "clang::Parser::LateParsedDeclaration::ParseLexedMethodDeclarations()"},
    {"_ZN5clang6Parser21LateParsedDeclaration20ParseLexedMethodDefsEv", "clang::Parser::LateParsedDeclaration::ParseLexedMethodDefs()"},
    {"_ZN5clang6Parser15LateParsedClassC1EPS0_PNS0_12ParsingClassE", "clang::Parser::LateParsedClass::LateParsedClass(clang::Parser*, clang::Parser::ParsingClass*)"},
    {"_ZN5clang6Parser15LateParsedClassC2EPS0_PNS0_12ParsingClassE", "clang::Parser::LateParsedClass::LateParsedClass(clang::Parser*, clang::Parser::ParsingClass*)"},
    {"_ZN5clang6Parser15LateParsedClassD0Ev", "clang::Parser::LateParsedClass::~LateParsedClass()"},
    {"_ZN5clang6Parser15LateParsedClassD1Ev", "clang::Parser::LateParsedClass::~LateParsedClass()"},
    {"_ZN5clang6Parser15LateParsedClassD2Ev", "clang::Parser::LateParsedClass::~LateParsedClass()"},
    {"_ZN5clang6Parser15LateParsedClass28ParseLexedMethodDeclarationsEv", "clang::Parser::LateParsedClass::ParseLexedMethodDeclarations()"},
    {"_ZN5clang6Parser28ParseLexedMethodDeclarationsERNS0_12ParsingClassE", "clang::Parser::ParseLexedMethodDeclarations(clang::Parser::ParsingClass&)"},
    {"_ZN5clang6Parser15LateParsedClass20ParseLexedMethodDefsEv", "clang::Parser::LateParsedClass::ParseLexedMethodDefs()"},
    {"_ZN5clang6Parser20ParseLexedMethodDefsERNS0_12ParsingClassE", "clang::Parser::ParseLexedMethodDefs(clang::Parser::ParsingClass&)"},
    {"_ZN5clang6Parser27LateParsedMethodDeclaration28ParseLexedMethodDeclarationsEv", "clang::Parser::LateParsedMethodDeclaration::ParseLexedMethodDeclarations()"},
    {"_ZN5clang6Parser27ParseLexedMethodDeclarationERNS0_27LateParsedMethodDeclarationE", "clang::Parser::ParseLexedMethodDeclaration(clang::Parser::LateParsedMethodDeclaration&)"},
    {"_ZN5clang6Parser11LexedMethod20ParseLexedMethodDefsEv", "clang::Parser::LexedMethod::ParseLexedMethodDefs()"},
    {"_ZN5clang6Parser19ParseLexedMethodDefERNS0_11LexedMethodE", "clang::Parser::ParseLexedMethodDef(clang::Parser::LexedMethod&)"},
    {"_ZN5clang6Parser20ConsumeAndStoreUntilENS_3tok9TokenKindES2_RN4llvm11SmallVectorINS_5TokenELj4EEEbb", "clang::Parser::ConsumeAndStoreUntil(clang::tok::TokenKind, clang::tok::TokenKind, llvm::SmallVector<clang::Token, 4u>&, bool, bool)"},
    {"_ZN5clang6Parser11LexedMethodD1Ev", "clang::Parser::LexedMethod::~LexedMethod()"},
    {"_ZN5clang6Parser11LexedMethodD0Ev", "clang::Parser::LexedMethod::~LexedMethod()"},
    {"_ZN5clang6Parser27LateParsedMethodDeclarationD1Ev", "clang::Parser::LateParsedMethodDeclaration::~LateParsedMethodDeclaration()"},
    {"_ZN5clang6Parser27LateParsedMethodDeclarationD0Ev", "clang::Parser::LateParsedMethodDeclaration::~LateParsedMethodDeclaration()"},
    {"_ZN5clang6Parser13ParseTypeNameEPNS_11SourceRangeENS_10Declarator10TheContextE", "clang::Parser::ParseTypeName(clang::SourceRange*, clang::Declarator::TheContext)"},
    {"_ZN5clang6Parser27ParseSpecifierQualifierListERNS_8DeclSpecE", "clang::Parser::ParseSpecifierQualifierList(clang::DeclSpec&)"},
    {"_ZN5clang6Parser15ParseDeclaratorERNS_10DeclaratorE", "clang::Parser::ParseDeclarator(clang::Declarator&)"},
    {"_ZN5clang6Parser18ParseGNUAttributesERNS_16ParsedAttributesEPNS_14SourceLocationE", "clang::Parser::ParseGNUAttributes(clang::ParsedAttributes&, clang::SourceLocation*)"},
    {"_ZN5clang6Parser22isDeclarationSpecifierEb", "clang::Parser::isDeclarationSpecifier(bool)"},
    {"_ZN5clang6Parser22ParseMicrosoftDeclSpecERNS_16ParsedAttributesE", "clang::Parser::ParseMicrosoftDeclSpec(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser28ParseMicrosoftTypeAttributesERNS_16ParsedAttributesE", "clang::Parser::ParseMicrosoftTypeAttributes(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser26ParseBorlandTypeAttributesERNS_16ParsedAttributesE", "clang::Parser::ParseBorlandTypeAttributes(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser28DiagnoseProhibitedAttributesERNS0_25ParsedAttributesWithRangeE", "clang::Parser::DiagnoseProhibitedAttributes(clang::Parser::ParsedAttributesWithRange&)"},
    {"_ZN5clang6Parser16ParseDeclarationERNS_15ASTOwningVectorIPNS_4StmtELj32EEEjRNS_14SourceLocationERNS0_25ParsedAttributesWithRangeE", "clang::Parser::ParseDeclaration(clang::ASTOwningVector<clang::Stmt*, 32u>&, unsigned int, clang::SourceLocation&, clang::Parser::ParsedAttributesWithRange&)"},
    {"_ZN5clang6Parser22ParseSimpleDeclarationERNS_15ASTOwningVectorIPNS_4StmtELj32EEEjRNS_14SourceLocationERNS_16ParsedAttributesEb", "clang::Parser::ParseSimpleDeclaration(clang::ASTOwningVector<clang::Stmt*, 32u>&, unsigned int, clang::SourceLocation&, clang::ParsedAttributes&, bool)"},
    {"_ZN5clang6Parser26ParseDeclarationSpecifiersERNS_8DeclSpecERKNS0_18ParsedTemplateInfoENS_15AccessSpecifierENS0_15DeclSpecContextE", "clang::Parser::ParseDeclarationSpecifiers(clang::DeclSpec&, clang::Parser::ParsedTemplateInfo const&, clang::AccessSpecifier, clang::Parser::DeclSpecContext)"},
    {"_ZN5clang6Parser39getDeclSpecContextFromDeclaratorContextEj", "clang::Parser::getDeclSpecContextFromDeclaratorContext(unsigned int)"},
    {"_ZN5clang6Parser14ParseDeclGroupERNS0_15ParsingDeclSpecEjbPNS_14SourceLocationE", "clang::Parser::ParseDeclGroup(clang::Parser::ParsingDeclSpec&, unsigned int, bool, clang::SourceLocation*)"},
    {"_ZN5clang6Parser31ParseDeclarationAfterDeclaratorERNS_10DeclaratorERKNS0_18ParsedTemplateInfoE", "clang::Parser::ParseDeclarationAfterDeclarator(clang::Declarator&, clang::Parser::ParsedTemplateInfo const&)"},
    {"_ZN5clang6Parser16ParseImplicitIntERNS_8DeclSpecEPNS_12CXXScopeSpecERKNS0_18ParsedTemplateInfoENS_15AccessSpecifierE", "clang::Parser::ParseImplicitInt(clang::DeclSpec&, clang::CXXScopeSpec*, clang::Parser::ParsedTemplateInfo const&, clang::AccessSpecifier)"},
    {"_ZN5clang6Parser18ParseEnumSpecifierENS_14SourceLocationERNS_8DeclSpecERKNS0_18ParsedTemplateInfoENS_15AccessSpecifierE", "clang::Parser::ParseEnumSpecifier(clang::SourceLocation, clang::DeclSpec&, clang::Parser::ParsedTemplateInfo const&, clang::AccessSpecifier)"},
    {"_ZN5clang6Parser23isConstructorDeclaratorEv", "clang::Parser::isConstructorDeclarator()"},
    {"_ZN5clang6Parser20ParseTypeofSpecifierERNS_8DeclSpecE", "clang::Parser::ParseTypeofSpecifier(clang::DeclSpec&)"},
    {"_ZN5clang6Parser26ParseOptionalTypeSpecifierERNS_8DeclSpecERbRPKcRjRKNS0_18ParsedTemplateInfoEb", "clang::Parser::ParseOptionalTypeSpecifier(clang::DeclSpec&, bool&, char const*&, unsigned int&, clang::Parser::ParsedTemplateInfo const&, bool)"},
    {"_ZN5clang6Parser22ParseStructDeclarationERNS_8DeclSpecERNS0_13FieldCallbackE", "clang::Parser::ParseStructDeclaration(clang::DeclSpec&, clang::Parser::FieldCallback&)"},
    {"_ZN5clang6Parser20ParseStructUnionBodyENS_14SourceLocationEjPNS_4DeclE", "clang::Parser::ParseStructUnionBody(clang::SourceLocation, unsigned int, clang::Decl*)"},
    {"_ZZN5clang6Parser20ParseStructUnionBodyENS_14SourceLocationEjPNS_4DeclEEN14CFieldCallbackD1Ev", "clang::Parser::ParseStructUnionBody(clang::SourceLocation, unsigned int, clang::Decl*)::CFieldCallback::~CFieldCallback()"},
    {"_ZN5clang6Parser13ParseEnumBodyENS_14SourceLocationEPNS_4DeclE", "clang::Parser::ParseEnumBody(clang::SourceLocation, clang::Decl*)"},
    {"_ZNK5clang6Parser15isTypeQualifierEv", "clang::Parser::isTypeQualifier() const"},
    {"_ZNK5clang6Parser24isKnownToBeTypeSpecifierERKNS_5TokenE", "clang::Parser::isKnownToBeTypeSpecifier(clang::Token const&) const"},
    {"_ZN5clang6Parser24isTypeSpecifierQualifierEv", "clang::Parser::isTypeSpecifierQualifier()"},
    {"_ZN5clang6Parser25ParseTypeQualifierListOptERNS_8DeclSpecEbb", "clang::Parser::ParseTypeQualifierListOpt(clang::DeclSpec&, bool, bool)"},
    {"_ZN5clang6Parser23ParseDeclaratorInternalERNS_10DeclaratorEMS0_FvS2_E", "clang::Parser::ParseDeclaratorInternal(clang::Declarator&, void (clang::Parser::*)(clang::Declarator&))"},
    {"_ZN5clang6Parser21ParseDirectDeclaratorERNS_10DeclaratorE", "clang::Parser::ParseDirectDeclarator(clang::Declarator&)"},
    {"_ZN5clang6Parser20ParseParenDeclaratorERNS_10DeclaratorE", "clang::Parser::ParseParenDeclarator(clang::Declarator&)"},
    {"_ZN5clang6Parser23ParseFunctionDeclaratorENS_14SourceLocationERNS_10DeclaratorERNS_16ParsedAttributesEb", "clang::Parser::ParseFunctionDeclarator(clang::SourceLocation, clang::Declarator&, clang::ParsedAttributes&, bool)"},
    {"_ZN5clang6Parser22ParseBracketDeclaratorERNS_10DeclaratorE", "clang::Parser::ParseBracketDeclarator(clang::Declarator&)"},
    {"_ZN5clang6Parser37ParseFunctionDeclaratorIdentifierListENS_14SourceLocationEPNS_14IdentifierInfoES1_RNS_10DeclaratorE", "clang::Parser::ParseFunctionDeclaratorIdentifierList(clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::Declarator&)"},
    {"_ZN5clang6Parser30TryAltiVecVectorTokenOutOfLineEv", "clang::Parser::TryAltiVecVectorTokenOutOfLine()"},
    {"_ZN5clang6Parser24TryAltiVecTokenOutOfLineERNS_8DeclSpecENS_14SourceLocationERPKcRjRb", "clang::Parser::TryAltiVecTokenOutOfLine(clang::DeclSpec&, clang::SourceLocation, char const*&, unsigned int&, bool&)"},
    {"_ZZN5clang6Parser20ParseStructUnionBodyENS_14SourceLocationEjPNS_4DeclEEN14CFieldCallback6invokeERNS_15FieldDeclaratorE", "clang::Parser::ParseStructUnionBody(clang::SourceLocation, unsigned int, clang::Decl*)::CFieldCallback::invoke(clang::FieldDeclarator&)"},
    {"_ZZN5clang6Parser20ParseStructUnionBodyENS_14SourceLocationEjPNS_4DeclEEN14CFieldCallbackD0Ev", "clang::Parser::ParseStructUnionBody(clang::SourceLocation, unsigned int, clang::Decl*)::CFieldCallback::~CFieldCallback()"},
    {"_ZN4llvm15SmallVectorImplIPN5clang4DeclEE6insertIPS3_EES6_S6_T_S7_", "clang::Decl** llvm::SmallVectorImpl<clang::Decl*>::insert<clang::Decl**>(clang::Decl**, clang::Decl**, clang::Decl**)"},
    {"_ZN5clang6Parser14ParseNamespaceEjRNS_14SourceLocationES1_", "clang::Parser::ParseNamespace(unsigned int, clang::SourceLocation&, clang::SourceLocation)"},
    {"_ZN5clang6Parser19ParseNamespaceAliasENS_14SourceLocationES1_PNS_14IdentifierInfoERS1_", "clang::Parser::ParseNamespaceAlias(clang::SourceLocation, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation&)"},
    {"_ZN5clang6Parser12ParseLinkageERNS0_15ParsingDeclSpecEj", "clang::Parser::ParseLinkage(clang::Parser::ParsingDeclSpec&, unsigned int)"},
    {"_ZN5clang6Parser32ParseUsingDirectiveOrDeclarationEjRKNS0_18ParsedTemplateInfoERNS_14SourceLocationERNS0_25ParsedAttributesWithRangeE", "clang::Parser::ParseUsingDirectiveOrDeclaration(unsigned int, clang::Parser::ParsedTemplateInfo const&, clang::SourceLocation&, clang::Parser::ParsedAttributesWithRange&)"},
    {"_ZN5clang6Parser19ParseUsingDirectiveEjNS_14SourceLocationERS1_RNS_16ParsedAttributesE", "clang::Parser::ParseUsingDirective(unsigned int, clang::SourceLocation, clang::SourceLocation&, clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser21ParseUsingDeclarationEjRKNS0_18ParsedTemplateInfoENS_14SourceLocationERS4_NS_15AccessSpecifierE", "clang::Parser::ParseUsingDeclaration(unsigned int, clang::Parser::ParsedTemplateInfo const&, clang::SourceLocation, clang::SourceLocation&, clang::AccessSpecifier)"},
    {"_ZN5clang6Parser28ParseStaticAssertDeclarationERNS_14SourceLocationE", "clang::Parser::ParseStaticAssertDeclaration(clang::SourceLocation&)"},
    {"_ZN5clang6Parser22ParseDecltypeSpecifierERNS_8DeclSpecE", "clang::Parser::ParseDecltypeSpecifier(clang::DeclSpec&)"},
    {"_ZN5clang6Parser14ParseClassNameERNS_14SourceLocationEPNS_12CXXScopeSpecE", "clang::Parser::ParseClassName(clang::SourceLocation&, clang::CXXScopeSpec*)"},
    {"_ZN5clang6Parser19ParseClassSpecifierENS_3tok9TokenKindENS_14SourceLocationERNS_8DeclSpecERKNS0_18ParsedTemplateInfoENS_15AccessSpecifierEb", "clang::Parser::ParseClassSpecifier(clang::tok::TokenKind, clang::SourceLocation, clang::DeclSpec&, clang::Parser::ParsedTemplateInfo const&, clang::AccessSpecifier, bool)"},
    {"_ZNK5clang6Parser25isCXX0XClassVirtSpecifierEv", "clang::Parser::isCXX0XClassVirtSpecifier() const"},
    {"_ZN5clang6Parser27ParseCXXMemberSpecificationENS_14SourceLocationEjPNS_4DeclE", "clang::Parser::ParseCXXMemberSpecification(clang::SourceLocation, unsigned int, clang::Decl*)"},
    {"_ZN5clang6Parser15ParseBaseClauseEPNS_4DeclE", "clang::Parser::ParseBaseClause(clang::Decl*)"},
    {"_ZN5clang6Parser18ParseBaseSpecifierEPNS_4DeclE", "clang::Parser::ParseBaseSpecifier(clang::Decl*)"},
    {"_ZNK5clang6Parser27getAccessSpecifierIfPresentEv", "clang::Parser::getAccessSpecifierIfPresent() const"},
    {"_ZN5clang6Parser31HandleMemberFunctionDefaultArgsERNS_10DeclaratorEPNS_4DeclE", "clang::Parser::HandleMemberFunctionDefaultArgs(clang::Declarator&, clang::Decl*)"},
    {"_ZNK5clang6Parser20isCXX0XVirtSpecifierEv", "clang::Parser::isCXX0XVirtSpecifier() const"},
    {"_ZN5clang6Parser34ParseOptionalCXX0XVirtSpecifierSeqERNS_14VirtSpecifiersE", "clang::Parser::ParseOptionalCXX0XVirtSpecifierSeq(clang::VirtSpecifiers&)"},
    {"_ZN5clang6Parser39ParseOptionalCXX0XClassVirtSpecifierSeqERNS_19ClassVirtSpecifiersE", "clang::Parser::ParseOptionalCXX0XClassVirtSpecifierSeq(clang::ClassVirtSpecifiers&)"},
    {"_ZN5clang6Parser30ParseCXXClassMemberDeclarationENS_15AccessSpecifierERKNS0_18ParsedTemplateInfoEPNS0_21ParsingDeclRAIIObjectE", "clang::Parser::ParseCXXClassMemberDeclaration(clang::AccessSpecifier, clang::Parser::ParsedTemplateInfo const&, clang::Parser::ParsingDeclRAIIObject*)"},
    {"_ZN5clang6Parser27ParseConstructorInitializerEPNS_4DeclE", "clang::Parser::ParseConstructorInitializer(clang::Decl*)"},
    {"_ZN5clang6Parser19ParseMemInitializerEPNS_4DeclE", "clang::Parser::ParseMemInitializer(clang::Decl*)"},
    {"_ZN5clang6Parser27ParseExceptionSpecificationERNS_14SourceLocationERN4llvm15SmallVectorImplINS_9OpaquePtrINS_8QualTypeEEEEERNS4_INS_11SourceRangeEEERb", "clang::Parser::ParseExceptionSpecification(clang::SourceLocation&, llvm::SmallVectorImpl<clang::OpaquePtr<clang::QualType>>&, llvm::SmallVectorImpl<clang::SourceRange>&, bool&)"},
    {"_ZN5clang6Parser23ParseTrailingReturnTypeEv", "clang::Parser::ParseTrailingReturnType()"},
    {"_ZN5clang6Parser16PushParsingClassEPNS_4DeclEb", "clang::Parser::PushParsingClass(clang::Decl*, bool)"},
    {"_ZN5clang6Parser23DeallocateParsedClassesEPNS0_12ParsingClassE", "clang::Parser::DeallocateParsedClasses(clang::Parser::ParsingClass*)"},
    {"_ZN5clang6Parser15PopParsingClassEv", "clang::Parser::PopParsingClass()"},
    {"_ZN5clang6Parser20ParseCXX0XAttributesERNS0_25ParsedAttributesWithRangeEPNS_14SourceLocationE", "clang::Parser::ParseCXX0XAttributes(clang::Parser::ParsedAttributesWithRange&, clang::SourceLocation*)"},
    {"_ZN5clang6Parser23ParseCXX0XAlignArgumentENS_14SourceLocationE", "clang::Parser::ParseCXX0XAlignArgument(clang::SourceLocation)"},
    {"_ZN5clang6Parser24ParseMicrosoftAttributesERNS_16ParsedAttributesEPNS_14SourceLocationE", "clang::Parser::ParseMicrosoftAttributes(clang::ParsedAttributes&, clang::SourceLocation*)"},
    {"_ZNSt5dequeIPN5clang6Parser12ParsingClassESaIS3_EE9push_backERKS3_", "std::deque<clang::Parser::ParsingClass*, std::allocator<clang::Parser::ParsingClass*>>::push_back(clang::Parser::ParsingClass* const&)"},
    {"_ZNSt5dequeIPN5clang6Parser12ParsingClassESaIS3_EE17_M_reallocate_mapEmb", "std::deque<clang::Parser::ParsingClass*, std::allocator<clang::Parser::ParsingClass*>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang6Parser25LateParsedDefaultArgumentELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::Parser::LateParsedDefaultArgument, false>::grow(unsigned long)"},
    {"_ZN5clang6Parser15ParseExpressionEv", "clang::Parser::ParseExpression()"},
    {"_ZN5clang6Parser25ParseAssignmentExpressionEv", "clang::Parser::ParseAssignmentExpression()"},
    {"_ZN5clang6Parser26ParseRHSOfBinaryExpressionENS_12ActionResultIPNS_4ExprELb1EEENS_4prec5LevelE", "clang::Parser::ParseRHSOfBinaryExpression(clang::ActionResult<clang::Expr*, true>, clang::prec::Level)"},
    {"_ZN5clang6Parser28ParseExpressionWithLeadingAtENS_14SourceLocationE", "clang::Parser::ParseExpressionWithLeadingAt(clang::SourceLocation)"},
    {"_ZN5clang6Parser35ParseExpressionWithLeadingExtensionENS_14SourceLocationE", "clang::Parser::ParseExpressionWithLeadingExtension(clang::SourceLocation)"},
    {"_ZN5clang6Parser19ParseCastExpressionEbbNS_9OpaquePtrINS_8QualTypeEEE", "clang::Parser::ParseCastExpression(bool, bool, clang::OpaquePtr<clang::QualType>)"},
    {"_ZN5clang6Parser43ParseAssignmentExprWithObjCMessageExprStartENS_14SourceLocationES1_NS_9OpaquePtrINS_8QualTypeEEEPNS_4ExprE", "clang::Parser::ParseAssignmentExprWithObjCMessageExprStart(clang::SourceLocation, clang::SourceLocation, clang::OpaquePtr<clang::QualType>, clang::Expr*)"},
    {"_ZN5clang6Parser28ParsePostfixExpressionSuffixENS_12ActionResultIPNS_4ExprELb1EEE", "clang::Parser::ParsePostfixExpressionSuffix(clang::ActionResult<clang::Expr*, true>)"},
    {"_ZN5clang6Parser23ParseConstantExpressionEv", "clang::Parser::ParseConstantExpression()"},
    {"_ZN5clang6Parser19ParseCastExpressionEbbRbNS_9OpaquePtrINS_8QualTypeEEE", "clang::Parser::ParseCastExpression(bool, bool, bool&, clang::OpaquePtr<clang::QualType>)"},
    {"_ZN5clang6Parser20ParseParenExpressionERNS0_16ParenParseOptionEbNS_9OpaquePtrINS_8QualTypeEEERS5_RNS_14SourceLocationE", "clang::Parser::ParseParenExpression(clang::Parser::ParenParseOption&, bool, clang::OpaquePtr<clang::QualType>, clang::OpaquePtr<clang::QualType>&, clang::SourceLocation&)"},
    {"_ZN5clang6Parser28ParseStringLiteralExpressionEv", "clang::Parser::ParseStringLiteralExpression()"},
    {"_ZN5clang6Parser29ParseBuiltinPrimaryExpressionEv", "clang::Parser::ParseBuiltinPrimaryExpression()"},
    {"_ZN5clang6Parser28ParseSizeofAlignofExpressionEv", "clang::Parser::ParseSizeofAlignofExpression()"},
    {"_ZN5clang6Parser27ParseBlockLiteralExpressionEv", "clang::Parser::ParseBlockLiteralExpression()"},
    {"_ZN5clang6Parser19ParseExpressionListERN4llvm15SmallVectorImplIPNS_4ExprEEERNS2_INS_14SourceLocationEEEMNS_4SemaEFvPNS_5ScopeES4_PS4_jES4_", "clang::Parser::ParseExpressionList(llvm::SmallVectorImpl<clang::Expr*>&, llvm::SmallVectorImpl<clang::SourceLocation>&, void (clang::Sema::*)(clang::Scope*, clang::Expr*, clang::Expr**, unsigned int), clang::Expr*)"},
    {"_ZN5clang6Parser33ParseExprAfterTypeofSizeofAlignofERKNS_5TokenERbRNS_9OpaquePtrINS_8QualTypeEEERNS_11SourceRangeE", "clang::Parser::ParseExprAfterTypeofSizeofAlignof(clang::Token const&, bool&, clang::OpaquePtr<clang::QualType>&, clang::SourceRange&)"},
    {"_ZN5clang6Parser30ParseCompoundLiteralExpressionENS_9OpaquePtrINS_8QualTypeEEENS_14SourceLocationES4_", "clang::Parser::ParseCompoundLiteralExpression(clang::OpaquePtr<clang::QualType>, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang6Parser12ParseBlockIdEv", "clang::Parser::ParseBlockId()"},
    {"_ZN5clang6Parser30ParseOptionalCXXScopeSpecifierERNS_12CXXScopeSpecENS_9OpaquePtrINS_8QualTypeEEEbPb", "clang::Parser::ParseOptionalCXXScopeSpecifier(clang::CXXScopeSpec&, clang::OpaquePtr<clang::QualType>, bool, bool*)"},
    {"_ZN5clang6Parser26ParseUnqualifiedIdOperatorERNS_12CXXScopeSpecEbNS_9OpaquePtrINS_8QualTypeEEERNS_13UnqualifiedIdE", "clang::Parser::ParseUnqualifiedIdOperator(clang::CXXScopeSpec&, bool, clang::OpaquePtr<clang::QualType>, clang::UnqualifiedId&)"},
    {"_ZN5clang6Parser20ParseCXXIdExpressionEb", "clang::Parser::ParseCXXIdExpression(bool)"},
    {"_ZN5clang6Parser18ParseUnqualifiedIdERNS_12CXXScopeSpecEbbbNS_9OpaquePtrINS_8QualTypeEEERNS_13UnqualifiedIdE", "clang::Parser::ParseUnqualifiedId(clang::CXXScopeSpec&, bool, bool, bool, clang::OpaquePtr<clang::QualType>, clang::UnqualifiedId&)"},
    {"_ZN5clang6Parser13ParseCXXCastsEv", "clang::Parser::ParseCXXCasts()"},
    {"_ZN5clang6Parser14ParseCXXTypeidEv", "clang::Parser::ParseCXXTypeid()"},
    {"_ZN5clang6Parser14ParseCXXUuidofEv", "clang::Parser::ParseCXXUuidof()"},
    {"_ZN5clang6Parser24ParseCXXPseudoDestructorEPNS_4ExprENS_14SourceLocationENS_3tok9TokenKindERNS_12CXXScopeSpecENS_9OpaquePtrINS_8QualTypeEEE", "clang::Parser::ParseCXXPseudoDestructor(clang::Expr*, clang::SourceLocation, clang::tok::TokenKind, clang::CXXScopeSpec&, clang::OpaquePtr<clang::QualType>)"},
    {"_ZN5clang6Parser28ParseUnqualifiedIdTemplateIdERNS_12CXXScopeSpecEPNS_14IdentifierInfoENS_14SourceLocationEbNS_9OpaquePtrINS_8QualTypeEEERNS_13UnqualifiedIdEbS5_", "clang::Parser::ParseUnqualifiedIdTemplateId(clang::CXXScopeSpec&, clang::IdentifierInfo*, clang::SourceLocation, bool, clang::OpaquePtr<clang::QualType>, clang::UnqualifiedId&, bool, clang::SourceLocation)"},
    {"_ZN5clang6Parser19ParseCXXBoolLiteralEv", "clang::Parser::ParseCXXBoolLiteral()"},
    {"_ZN5clang6Parser20ParseThrowExpressionEv", "clang::Parser::ParseThrowExpression()"},
    {"_ZN5clang6Parser12ParseCXXThisEv", "clang::Parser::ParseCXXThis()"},
    {"_ZN5clang6Parser31ParseCXXTypeConstructExpressionERKNS_8DeclSpecE", "clang::Parser::ParseCXXTypeConstructExpression(clang::DeclSpec const&)"},
    {"_ZN5clang6Parser17ParseCXXConditionERNS_12ActionResultIPNS_4ExprELb1EEERPNS_4DeclENS_14SourceLocationEb", "clang::Parser::ParseCXXCondition(clang::ActionResult<clang::Expr*, true>&, clang::Decl*&, clang::SourceLocation, bool)"},
    {"_ZNK5clang6Parser24isCXXSimpleTypeSpecifierEv", "clang::Parser::isCXXSimpleTypeSpecifier() const"},
    {"_ZN5clang6Parser27ParseCXXSimpleTypeSpecifierERNS_8DeclSpecE", "clang::Parser::ParseCXXSimpleTypeSpecifier(clang::DeclSpec&)"},
    {"_ZN5clang6Parser24ParseCXXTypeSpecifierSeqERNS_8DeclSpecE", "clang::Parser::ParseCXXTypeSpecifierSeq(clang::DeclSpec&)"},
    {"_ZN5clang6Parser21ParseCXXNewExpressionEbNS_14SourceLocationE", "clang::Parser::ParseCXXNewExpression(bool, clang::SourceLocation)"},
    {"_ZN5clang6Parser27ParseExpressionListOrTypeIdERN4llvm15SmallVectorImplIPNS_4ExprEEERNS_10DeclaratorE", "clang::Parser::ParseExpressionListOrTypeId(llvm::SmallVectorImpl<clang::Expr*>&, clang::Declarator&)"},
    {"_ZN5clang6Parser24ParseDirectNewDeclaratorERNS_10DeclaratorE", "clang::Parser::ParseDirectNewDeclarator(clang::Declarator&)"},
    {"_ZN5clang6Parser24ParseCXXDeleteExpressionEbNS_14SourceLocationE", "clang::Parser::ParseCXXDeleteExpression(bool, clang::SourceLocation)"},
    {"_ZN5clang6Parser19ParseUnaryTypeTraitEv", "clang::Parser::ParseUnaryTypeTrait()"},
    {"_ZN5clang6Parser20ParseBinaryTypeTraitEv", "clang::Parser::ParseBinaryTypeTrait()"},
    {"_ZN5clang6Parser32ParseCXXAmbiguousParenExpressionERNS0_16ParenParseOptionERNS_9OpaquePtrINS_8QualTypeEEENS_14SourceLocationERS7_", "clang::Parser::ParseCXXAmbiguousParenExpression(clang::Parser::ParenParseOption&, clang::OpaquePtr<clang::QualType>&, clang::SourceLocation, clang::SourceLocation&)"},
    {"_ZN5clang6Parser39ParseInitializerWithPotentialDesignatorEv", "clang::Parser::ParseInitializerWithPotentialDesignator()"},
    {"_ZN5clang6Parser21ParseBraceInitializerEv", "clang::Parser::ParseBraceInitializer()"},
    {"_ZN5clang6Parser21ParseObjCAtDirectivesEv", "clang::Parser::ParseObjCAtDirectives()"},
    {"_ZN5clang6Parser27ParseObjCAtClassDeclarationENS_14SourceLocationE", "clang::Parser::ParseObjCAtClassDeclaration(clang::SourceLocation)"},
    {"_ZN5clang6Parser31ParseObjCAtInterfaceDeclarationENS_14SourceLocationERNS_16ParsedAttributesE", "clang::Parser::ParseObjCAtInterfaceDeclaration(clang::SourceLocation, clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser30ParseObjCAtProtocolDeclarationENS_14SourceLocationERNS_16ParsedAttributesE", "clang::Parser::ParseObjCAtProtocolDeclaration(clang::SourceLocation, clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser36ParseObjCAtImplementationDeclarationENS_14SourceLocationE", "clang::Parser::ParseObjCAtImplementationDeclaration(clang::SourceLocation)"},
    {"_ZN5clang6Parser25ParseObjCAtEndDeclarationENS_11SourceRangeE", "clang::Parser::ParseObjCAtEndDeclaration(clang::SourceRange)"},
    {"_ZN5clang6Parser27ParseObjCAtAliasDeclarationENS_14SourceLocationE", "clang::Parser::ParseObjCAtAliasDeclaration(clang::SourceLocation)"},
    {"_ZN5clang6Parser27ParseObjCPropertySynthesizeENS_14SourceLocationE", "clang::Parser::ParseObjCPropertySynthesize(clang::SourceLocation)"},
    {"_ZN5clang6Parser24ParseObjCPropertyDynamicENS_14SourceLocationE", "clang::Parser::ParseObjCPropertyDynamic(clang::SourceLocation)"},
    {"_ZN5clang6Parser27ParseObjCProtocolReferencesERN4llvm15SmallVectorImplIPNS_4DeclEEERNS2_INS_14SourceLocationEEEbRS7_SA_", "clang::Parser::ParseObjCProtocolReferences(llvm::SmallVectorImpl<clang::Decl*>&, llvm::SmallVectorImpl<clang::SourceLocation>&, bool, clang::SourceLocation&, clang::SourceLocation&)"},
    {"_ZN5clang6Parser31ParseObjCClassInstanceVariablesEPNS_4DeclENS_3tok15ObjCKeywordKindENS_14SourceLocationE", "clang::Parser::ParseObjCClassInstanceVariables(clang::Decl*, clang::tok::ObjCKeywordKind, clang::SourceLocation)"},
    {"_ZN5clang6Parser26ParseObjCInterfaceDeclListEPNS_4DeclENS_3tok15ObjCKeywordKindE", "clang::Parser::ParseObjCInterfaceDeclList(clang::Decl*, clang::tok::ObjCKeywordKind)"},
    {"_ZN5clang6Parser24ParseObjCMethodPrototypeEPNS_4DeclENS_3tok15ObjCKeywordKindE", "clang::Parser::ParseObjCMethodPrototype(clang::Decl*, clang::tok::ObjCKeywordKind)"},
    {"_ZN5clang6Parser19ParseObjCMethodDeclENS_14SourceLocationENS_3tok9TokenKindEPNS_4DeclENS2_15ObjCKeywordKindE", "clang::Parser::ParseObjCMethodDecl(clang::SourceLocation, clang::tok::TokenKind, clang::Decl*, clang::tok::ObjCKeywordKind)"},
    {"_ZN5clang6Parser26ParseObjCPropertyAttributeERNS_12ObjCDeclSpecEPNS_4DeclE", "clang::Parser::ParseObjCPropertyAttribute(clang::ObjCDeclSpec&, clang::Decl*)"},
    {"_ZN5clang6Parser22ParseObjCSelectorPieceERNS_14SourceLocationE", "clang::Parser::ParseObjCSelectorPiece(clang::SourceLocation&)"},
    {"_ZNK5clang6Parser18isTokIdentifier_inEv", "clang::Parser::isTokIdentifier_in() const"},
    {"_ZN5clang6Parser26ParseObjCTypeQualifierListERNS_12ObjCDeclSpecEb", "clang::Parser::ParseObjCTypeQualifierList(clang::ObjCDeclSpec&, bool)"},
    {"_ZN5clang6Parser17ParseObjCTypeNameERNS_12ObjCDeclSpecEb", "clang::Parser::ParseObjCTypeName(clang::ObjCDeclSpec&, bool)"},
    {"_ZN5clang6Parser27ParseObjCProtocolQualifiersERNS_8DeclSpecE", "clang::Parser::ParseObjCProtocolQualifiers(clang::DeclSpec&)"},
    {"_ZZN5clang6Parser31ParseObjCClassInstanceVariablesEPNS_4DeclENS_3tok15ObjCKeywordKindENS_14SourceLocationEEN16ObjCIvarCallbackD1Ev", "clang::Parser::ParseObjCClassInstanceVariables(clang::Decl*, clang::tok::ObjCKeywordKind, clang::SourceLocation)::ObjCIvarCallback::~ObjCIvarCallback()"},
    {"_ZN5clang6Parser24FinishPendingObjCActionsEv", "clang::Parser::FinishPendingObjCActions()"},
    {"_ZN5clang6Parser18ParseObjCThrowStmtENS_14SourceLocationE", "clang::Parser::ParseObjCThrowStmt(clang::SourceLocation)"},
    {"_ZN5clang6Parser25ParseObjCSynchronizedStmtENS_14SourceLocationE", "clang::Parser::ParseObjCSynchronizedStmt(clang::SourceLocation)"},
    {"_ZN5clang6Parser16ParseObjCTryStmtENS_14SourceLocationE", "clang::Parser::ParseObjCTryStmt(clang::SourceLocation)"},
    {"_ZN5clang6Parser25ParseObjCMethodDefinitionEv", "clang::Parser::ParseObjCMethodDefinition()"},
    {"_ZN5clang6Parser20ParseObjCAtStatementENS_14SourceLocationE", "clang::Parser::ParseObjCAtStatement(clang::SourceLocation)"},
    {"_ZN5clang6Parser21ParseObjCAtExpressionENS_14SourceLocationE", "clang::Parser::ParseObjCAtExpression(clang::SourceLocation)"},
    {"_ZN5clang6Parser22ParseObjCStringLiteralENS_14SourceLocationE", "clang::Parser::ParseObjCStringLiteral(clang::SourceLocation)"},
    {"_ZN5clang6Parser25ParseObjCEncodeExpressionENS_14SourceLocationE", "clang::Parser::ParseObjCEncodeExpression(clang::SourceLocation)"},
    {"_ZN5clang6Parser27ParseObjCProtocolExpressionENS_14SourceLocationE", "clang::Parser::ParseObjCProtocolExpression(clang::SourceLocation)"},
    {"_ZN5clang6Parser27ParseObjCSelectorExpressionENS_14SourceLocationE", "clang::Parser::ParseObjCSelectorExpression(clang::SourceLocation)"},
    {"_ZN5clang6Parser26ParseObjCXXMessageReceiverERbRPv", "clang::Parser::ParseObjCXXMessageReceiver(bool&, void*&)"},
    {"_ZN5clang6Parser29isSimpleObjCMessageExpressionEv", "clang::Parser::isSimpleObjCMessageExpression()"},
    {"_ZN5clang6Parser43isStartOfObjCClassMessageMissingOpenBracketEv", "clang::Parser::isStartOfObjCClassMessageMissingOpenBracket()"},
    {"_ZN5clang6Parser26ParseObjCMessageExpressionEv", "clang::Parser::ParseObjCMessageExpression()"},
    {"_ZN5clang6Parser30ParseObjCMessageExpressionBodyENS_14SourceLocationES1_NS_9OpaquePtrINS_8QualTypeEEEPNS_4ExprE", "clang::Parser::ParseObjCMessageExpressionBody(clang::SourceLocation, clang::SourceLocation, clang::OpaquePtr<clang::QualType>, clang::Expr*)"},
    {"_ZZN5clang6Parser31ParseObjCClassInstanceVariablesEPNS_4DeclENS_3tok15ObjCKeywordKindENS_14SourceLocationEEN16ObjCIvarCallback6invokeERNS_15FieldDeclaratorE", "clang::Parser::ParseObjCClassInstanceVariables(clang::Decl*, clang::tok::ObjCKeywordKind, clang::SourceLocation)::ObjCIvarCallback::invoke(clang::FieldDeclarator&)"},
    {"_ZZN5clang6Parser31ParseObjCClassInstanceVariablesEPNS_4DeclENS_3tok15ObjCKeywordKindENS_14SourceLocationEEN16ObjCIvarCallbackD0Ev", "clang::Parser::ParseObjCClassInstanceVariables(clang::Decl*, clang::tok::ObjCKeywordKind, clang::SourceLocation)::ObjCIvarCallback::~ObjCIvarCallback()"},
    {"_ZN5clang6Parser20ObjCPropertyCallbackD1Ev", "clang::Parser::ObjCPropertyCallback::~ObjCPropertyCallback()"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang15DeclaratorChunk9ParamInfoELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::DeclaratorChunk::ParamInfo, false>::grow(unsigned long)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang4Sema11ObjCArgInfoELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::Sema::ObjCArgInfo, false>::grow(unsigned long)"},
    {"_ZN5clang6Parser20ObjCPropertyCallback6invokeERNS_15FieldDeclaratorE", "clang::Parser::ObjCPropertyCallback::invoke(clang::FieldDeclarator&)"},
    {"_ZN5clang6Parser20ObjCPropertyCallbackD0Ev", "clang::Parser::ObjCPropertyCallback::~ObjCPropertyCallback()"},
    {"_ZN5clang6Parser18HandlePragmaUnusedEv", "clang::Parser::HandlePragmaUnused()"},
    {"_ZN5clang26PragmaGCCVisibilityHandler12HandlePragmaERNS_12PreprocessorENS_20PragmaIntroducerKindERNS_5TokenE", "clang::PragmaGCCVisibilityHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN5clang17PragmaPackHandler12HandlePragmaERNS_12PreprocessorENS_20PragmaIntroducerKindERNS_5TokenE", "clang::PragmaPackHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN5clang18PragmaAlignHandler12HandlePragmaERNS_12PreprocessorENS_20PragmaIntroducerKindERNS_5TokenE", "clang::PragmaAlignHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_Z16ParseAlignPragmaRN5clang4SemaERNS_12PreprocessorERNS_5TokenEb", "ParseAlignPragma(clang::Sema&, clang::Preprocessor&, clang::Token&, bool)"},
    {"_ZN5clang20PragmaOptionsHandler12HandlePragmaERNS_12PreprocessorENS_20PragmaIntroducerKindERNS_5TokenE", "clang::PragmaOptionsHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN5clang19PragmaUnusedHandler12HandlePragmaERNS_12PreprocessorENS_20PragmaIntroducerKindERNS_5TokenE", "clang::PragmaUnusedHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN5clang17PragmaWeakHandler12HandlePragmaERNS_12PreprocessorENS_20PragmaIntroducerKindERNS_5TokenE", "clang::PragmaWeakHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN5clang18PragmaAlignHandlerD1Ev", "clang::PragmaAlignHandler::~PragmaAlignHandler()"},
    {"_ZN5clang18PragmaAlignHandlerD0Ev", "clang::PragmaAlignHandler::~PragmaAlignHandler()"},
    {"_ZN5clang26PragmaGCCVisibilityHandlerD1Ev", "clang::PragmaGCCVisibilityHandler::~PragmaGCCVisibilityHandler()"},
    {"_ZN5clang26PragmaGCCVisibilityHandlerD0Ev", "clang::PragmaGCCVisibilityHandler::~PragmaGCCVisibilityHandler()"},
    {"_ZN5clang20PragmaOptionsHandlerD1Ev", "clang::PragmaOptionsHandler::~PragmaOptionsHandler()"},
    {"_ZN5clang20PragmaOptionsHandlerD0Ev", "clang::PragmaOptionsHandler::~PragmaOptionsHandler()"},
    {"_ZN5clang17PragmaPackHandlerD1Ev", "clang::PragmaPackHandler::~PragmaPackHandler()"},
    {"_ZN5clang17PragmaPackHandlerD0Ev", "clang::PragmaPackHandler::~PragmaPackHandler()"},
    {"_ZN5clang19PragmaUnusedHandlerD1Ev", "clang::PragmaUnusedHandler::~PragmaUnusedHandler()"},
    {"_ZN5clang19PragmaUnusedHandlerD0Ev", "clang::PragmaUnusedHandler::~PragmaUnusedHandler()"},
    {"_ZN5clang17PragmaWeakHandlerD1Ev", "clang::PragmaWeakHandler::~PragmaWeakHandler()"},
    {"_ZN5clang17PragmaWeakHandlerD0Ev", "clang::PragmaWeakHandler::~PragmaWeakHandler()"},
    {"_ZN5clang6Parser27ParseStatementOrDeclarationERNS_15ASTOwningVectorIPNS_4StmtELj32EEEb", "clang::Parser::ParseStatementOrDeclaration(clang::ASTOwningVector<clang::Stmt*, 32u>&, bool)"},
    {"_ZN5clang6Parser21ParseLabeledStatementERNS_16ParsedAttributesE", "clang::Parser::ParseLabeledStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser18ParseCaseStatementERNS_16ParsedAttributesE", "clang::Parser::ParseCaseStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser21ParseDefaultStatementERNS_16ParsedAttributesE", "clang::Parser::ParseDefaultStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser22ParseCompoundStatementERNS_16ParsedAttributesEb", "clang::Parser::ParseCompoundStatement(clang::ParsedAttributes&, bool)"},
    {"_ZN5clang6Parser16ParseIfStatementERNS_16ParsedAttributesE", "clang::Parser::ParseIfStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser20ParseSwitchStatementERNS_16ParsedAttributesE", "clang::Parser::ParseSwitchStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser19ParseWhileStatementERNS_16ParsedAttributesE", "clang::Parser::ParseWhileStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser16ParseDoStatementERNS_16ParsedAttributesE", "clang::Parser::ParseDoStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser17ParseForStatementERNS_16ParsedAttributesE", "clang::Parser::ParseForStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser18ParseGotoStatementERNS_16ParsedAttributesE", "clang::Parser::ParseGotoStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser22ParseContinueStatementERNS_16ParsedAttributesE", "clang::Parser::ParseContinueStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser19ParseBreakStatementERNS_16ParsedAttributesE", "clang::Parser::ParseBreakStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser20ParseReturnStatementERNS_16ParsedAttributesE", "clang::Parser::ParseReturnStatement(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser17ParseAsmStatementERb", "clang::Parser::ParseAsmStatement(bool&)"},
    {"_ZN5clang6Parser16ParseCXXTryBlockERNS_16ParsedAttributesE", "clang::Parser::ParseCXXTryBlock(clang::ParsedAttributes&)"},
    {"_ZN5clang6Parser26ParseCompoundStatementBodyEb", "clang::Parser::ParseCompoundStatementBody(bool)"},
    {"_ZN5clang6Parser25ParseParenExprOrConditionERNS_12ActionResultIPNS_4ExprELb1EEERPNS_4DeclENS_14SourceLocationEb", "clang::Parser::ParseParenExprOrCondition(clang::ActionResult<clang::Expr*, true>&, clang::Decl*&, clang::SourceLocation, bool)"},
    {"_ZN5clang6Parser31FuzzyParseMicrosoftAsmStatementENS_14SourceLocationE", "clang::Parser::FuzzyParseMicrosoftAsmStatement(clang::SourceLocation)"},
    {"_ZN5clang6Parser19ParseAsmOperandsOptERN4llvm15SmallVectorImplIPNS_14IdentifierInfoEEERNS2_IPNS_4ExprEEESA_", "clang::Parser::ParseAsmOperandsOpt(llvm::SmallVectorImpl<clang::IdentifierInfo*>&, llvm::SmallVectorImpl<clang::Expr*>&, llvm::SmallVectorImpl<clang::Expr*>&)"},
    {"_ZN5clang6Parser26ParseFunctionStatementBodyEPNS_4DeclE", "clang::Parser::ParseFunctionStatementBody(clang::Decl*)"},
    {"_ZN5clang6Parser40trySkippingFunctionBodyForCodeCompletionEv", "clang::Parser::trySkippingFunctionBodyForCodeCompletion()"},
    {"_ZN5clang6Parser21ParseFunctionTryBlockEPNS_4DeclE", "clang::Parser::ParseFunctionTryBlock(clang::Decl*)"},
    {"_ZN5clang6Parser22ParseCXXTryBlockCommonENS_14SourceLocationE", "clang::Parser::ParseCXXTryBlockCommon(clang::SourceLocation)"},
    {"_ZN5clang6Parser18ParseCXXCatchBlockEv", "clang::Parser::ParseCXXCatchBlock()"},
    {"_ZN5clang6Parser36ParseDeclarationStartingWithTemplateEjRNS_14SourceLocationENS_15AccessSpecifierE", "clang::Parser::ParseDeclarationStartingWithTemplate(unsigned int, clang::SourceLocation&, clang::AccessSpecifier)"},
    {"_ZN5clang6Parser26ParseExplicitInstantiationENS_14SourceLocationES1_RS1_", "clang::Parser::ParseExplicitInstantiation(clang::SourceLocation, clang::SourceLocation, clang::SourceLocation&)"},
    {"_ZN5clang6Parser40ParseTemplateDeclarationOrSpecializationEjRNS_14SourceLocationENS_15AccessSpecifierE", "clang::Parser::ParseTemplateDeclarationOrSpecialization(unsigned int, clang::SourceLocation&, clang::AccessSpecifier)"},
    {"_ZN5clang6Parser23ParseTemplateParametersEjRN4llvm15SmallVectorImplIPNS_4DeclEEERNS_14SourceLocationES8_", "clang::Parser::ParseTemplateParameters(unsigned int, llvm::SmallVectorImpl<clang::Decl*>&, clang::SourceLocation&, clang::SourceLocation&)"},
    {"_ZN5clang6Parser35ParseSingleDeclarationAfterTemplateEjRKNS0_18ParsedTemplateInfoERNS0_21ParsingDeclRAIIObjectERNS_14SourceLocationENS_15AccessSpecifierE", "clang::Parser::ParseSingleDeclarationAfterTemplate(unsigned int, clang::Parser::ParsedTemplateInfo const&, clang::Parser::ParsingDeclRAIIObject&, clang::SourceLocation&, clang::AccessSpecifier)"},
    {"_ZN5clang6Parser26ParseTemplateParameterListEjRN4llvm15SmallVectorImplIPNS_4DeclEEE", "clang::Parser::ParseTemplateParameterList(unsigned int, llvm::SmallVectorImpl<clang::Decl*>&)"},
    {"_ZN5clang6Parser22ParseTemplateParameterEjj", "clang::Parser::ParseTemplateParameter(unsigned int, unsigned int)"},
    {"_ZN5clang6Parser30isStartOfTemplateTypeParameterEv", "clang::Parser::isStartOfTemplateTypeParameter()"},
    {"_ZN5clang6Parser18ParseTypeParameterEjj", "clang::Parser::ParseTypeParameter(unsigned int, unsigned int)"},
    {"_ZN5clang6Parser30ParseTemplateTemplateParameterEjj", "clang::Parser::ParseTemplateTemplateParameter(unsigned int, unsigned int)"},
    {"_ZN5clang6Parser29ParseNonTypeTemplateParameterEjj", "clang::Parser::ParseNonTypeTemplateParameter(unsigned int, unsigned int)"},
    {"_ZN5clang6Parser29ParseTemplateTemplateArgumentEv", "clang::Parser::ParseTemplateTemplateArgument()"},
    {"_ZN5clang6Parser32ParseTemplateIdAfterTemplateNameENS_9OpaquePtrINS_12TemplateNameEEENS_14SourceLocationEPKNS_12CXXScopeSpecEbRS4_RN4llvm11SmallVectorINS_22ParsedTemplateArgumentELj16EEES8_", "clang::Parser::ParseTemplateIdAfterTemplateName(clang::OpaquePtr<clang::TemplateName>, clang::SourceLocation, clang::CXXScopeSpec const*, bool, clang::SourceLocation&, llvm::SmallVector<clang::ParsedTemplateArgument, 16u>&, clang::SourceLocation&)"},
    {"_ZN5clang6Parser25ParseTemplateArgumentListERN4llvm11SmallVectorINS_22ParsedTemplateArgumentELj16EEE", "clang::Parser::ParseTemplateArgumentList(llvm::SmallVector<clang::ParsedTemplateArgument, 16u>&)"},
    {"_ZN5clang6Parser23AnnotateTemplateIdTokenENS_9OpaquePtrINS_12TemplateNameEEENS_16TemplateNameKindEPKNS_12CXXScopeSpecERNS_13UnqualifiedIdENS_14SourceLocationEb", "clang::Parser::AnnotateTemplateIdToken(clang::OpaquePtr<clang::TemplateName>, clang::TemplateNameKind, clang::CXXScopeSpec const*, clang::UnqualifiedId&, clang::SourceLocation, bool)"},
    {"_ZN5clang6Parser29AnnotateTemplateIdTokenAsTypeEPKNS_12CXXScopeSpecE", "clang::Parser::AnnotateTemplateIdTokenAsType(clang::CXXScopeSpec const*)"},
    {"_ZN5clang6Parser21ParseTemplateArgumentEv", "clang::Parser::ParseTemplateArgument()"},
    {"_ZN5clang6Parser22IsTemplateArgumentListEj", "clang::Parser::IsTemplateArgumentList(unsigned int)"},
    {"_ZNK5clang6Parser18ParsedTemplateInfo14getSourceRangeEv", "clang::Parser::ParsedTemplateInfo::getSourceRange() const"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang22ParsedTemplateArgumentELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::ParsedTemplateArgument, false>::grow(unsigned long)"},
    {"_ZN5clang6Parser25isCXXDeclarationStatementEv", "clang::Parser::isCXXDeclarationStatement()"},
    {"_ZN5clang6Parser22isCXXSimpleDeclarationEv", "clang::Parser::isCXXSimpleDeclaration()"},
    {"_ZN5clang6Parser25isCXXDeclarationSpecifierEv", "clang::Parser::isCXXDeclarationSpecifier()"},
    {"_ZN5clang6Parser25TryParseSimpleDeclarationEv", "clang::Parser::TryParseSimpleDeclaration()"},
    {"_ZN5clang6Parser23TryParseTypeofSpecifierEv", "clang::Parser::TryParseTypeofSpecifier()"},
    {"_ZN5clang6Parser26TryParseProtocolQualifiersEv", "clang::Parser::TryParseProtocolQualifiers()"},
    {"_ZN5clang6Parser26TryParseInitDeclaratorListEv", "clang::Parser::TryParseInitDeclaratorList()"},
    {"_ZN5clang6Parser18TryParseDeclaratorEbb", "clang::Parser::TryParseDeclarator(bool, bool)"},
    {"_ZN5clang6Parser25isCXXConditionDeclarationEv", "clang::Parser::isCXXConditionDeclaration()"},
    {"_ZN5clang6Parser11isCXXTypeIdENS0_25TentativeCXXTypeIdContextERb", "clang::Parser::isCXXTypeId(clang::Parser::TentativeCXXTypeIdContext, bool&)"},
    {"_ZN5clang6Parser25isCXX0XAttributeSpecifierEbPNS_3tok9TokenKindE", "clang::Parser::isCXX0XAttributeSpecifier(bool, clang::tok::TokenKind*)"},
    {"_ZN5clang6Parser26TryParseFunctionDeclaratorEv", "clang::Parser::TryParseFunctionDeclarator()"},
    {"_ZN5clang6Parser23isCXXFunctionDeclaratorEb", "clang::Parser::isCXXFunctionDeclarator(bool)"},
    {"_ZN5clang6Parser25TryParseBracketDeclaratorEv", "clang::Parser::TryParseBracketDeclarator()"},
    {"_ZN5clang6Parser33isExpressionOrTypeSpecifierSimpleENS_3tok9TokenKindE", "clang::Parser::isExpressionOrTypeSpecifierSimple(clang::tok::TokenKind)"},
    {"_ZN5clang6Parser28TryParseDeclarationSpecifierEv", "clang::Parser::TryParseDeclarationSpecifier()"},
    {"_ZN5clang6Parser34TryParseParameterDeclarationClauseEv", "clang::Parser::TryParseParameterDeclarationClause()"},
    {"_ZN5clang6ParserC1ERNS_12PreprocessorERNS_4SemaE", "clang::Parser::Parser(clang::Preprocessor&, clang::Sema&)"},
    {"_ZN5clang6ParserC2ERNS_12PreprocessorERNS_4SemaE", "clang::Parser::Parser(clang::Preprocessor&, clang::Sema&)"},
    {"_ZNK5clang27PrettyStackTraceParserEntry5printERN4llvm11raw_ostreamE", "clang::PrettyStackTraceParserEntry::print(llvm::raw_ostream&) const"},
    {"_ZN5clang6Parser4DiagENS_14SourceLocationEj", "clang::Parser::Diag(clang::SourceLocation, unsigned int)"},
    {"_ZN5clang6Parser4DiagERKNS_5TokenEj", "clang::Parser::Diag(clang::Token const&, unsigned int)"},
    {"_ZN5clang6Parser18SuggestParenthesesENS_14SourceLocationEjNS_11SourceRangeE", "clang::Parser::SuggestParentheses(clang::SourceLocation, unsigned int, clang::SourceRange)"},
    {"_ZN5clang6Parser19MatchRHSPunctuationENS_3tok9TokenKindENS_14SourceLocationE", "clang::Parser::MatchRHSPunctuation(clang::tok::TokenKind, clang::SourceLocation)"},
    {"_ZN5clang6Parser16ExpectAndConsumeENS_3tok9TokenKindEjPKcS2_", "clang::Parser::ExpectAndConsume(clang::tok::TokenKind, unsigned int, char const*, clang::tok::TokenKind)"},
    {"_ZN5clang6Parser20ExpectAndConsumeSemiEj", "clang::Parser::ExpectAndConsumeSemi(unsigned int)"},
    {"_ZN5clang6Parser9SkipUntilEPKNS_3tok9TokenKindEjbbb", "clang::Parser::SkipUntil(clang::tok::TokenKind const*, unsigned int, bool, bool, bool)"},
    {"_ZN5clang6Parser10EnterScopeEj", "clang::Parser::EnterScope(unsigned int)"},
    {"_ZN5clang6Parser9ExitScopeEv", "clang::Parser::ExitScope()"},
    {"_ZN5clang6ParserD0Ev", "clang::Parser::~Parser()"},
    {"_ZN5clang6ParserD1Ev", "clang::Parser::~Parser()"},
    {"_ZN5clang6ParserD2Ev", "clang::Parser::~Parser()"},
    {"_ZN5clang6Parser10InitializeEv", "clang::Parser::Initialize()"},
    {"_ZN5clang6Parser17ParseTopLevelDeclERNS_9OpaquePtrINS_12DeclGroupRefEEE", "clang::Parser::ParseTopLevelDecl(clang::OpaquePtr<clang::DeclGroupRef>&)"},
    {"_ZN5clang6Parser24ParseExternalDeclarationERNS0_25ParsedAttributesWithRangeEPNS0_15ParsingDeclSpecE", "clang::Parser::ParseExternalDeclaration(clang::Parser::ParsedAttributesWithRange&, clang::Parser::ParsingDeclSpec*)"},
    {"_ZN5clang6Parser20ParseTranslationUnitEv", "clang::Parser::ParseTranslationUnit()"},
    {"_ZN5clang6Parser14ParseSimpleAsmEPNS_14SourceLocationE", "clang::Parser::ParseSimpleAsm(clang::SourceLocation*)"},
    {"_ZN5clang6Parser36ParseDeclarationOrFunctionDefinitionERNS0_15ParsingDeclSpecENS_15AccessSpecifierE", "clang::Parser::ParseDeclarationOrFunctionDefinition(clang::Parser::ParsingDeclSpec&, clang::AccessSpecifier)"},
    {"_ZN5clang6Parser36ParseDeclarationOrFunctionDefinitionERNS_16ParsedAttributesENS_15AccessSpecifierE", "clang::Parser::ParseDeclarationOrFunctionDefinition(clang::ParsedAttributes&, clang::AccessSpecifier)"},
    {"_ZNK5clang6Parser28isDeclarationAfterDeclaratorEv", "clang::Parser::isDeclarationAfterDeclarator() const"},
    {"_ZN5clang6Parser27isStartOfFunctionDefinitionERKNS0_17ParsingDeclaratorE", "clang::Parser::isStartOfFunctionDefinition(clang::Parser::ParsingDeclarator const&)"},
    {"_ZN5clang6Parser23ParseFunctionDefinitionERNS0_17ParsingDeclaratorERKNS0_18ParsedTemplateInfoE", "clang::Parser::ParseFunctionDefinition(clang::Parser::ParsingDeclarator&, clang::Parser::ParsedTemplateInfo const&)"},
    {"_ZN5clang6Parser25ParseKNRParamDeclarationsERNS_10DeclaratorE", "clang::Parser::ParseKNRParamDeclarations(clang::Declarator&)"},
    {"_ZN5clang6Parser21ParseAsmStringLiteralEv", "clang::Parser::ParseAsmStringLiteral()"},
    {"_ZN5clang6Parser27TryAnnotateTypeOrScopeTokenEb", "clang::Parser::TryAnnotateTypeOrScopeToken(bool)"},
    {"_ZN5clang6Parser24TryAnnotateCXXScopeTokenEb", "clang::Parser::TryAnnotateCXXScopeToken(bool)"},
    {"_ZN5clang6Parser32isTokenEqualOrMistypedEqualEqualEj", "clang::Parser::isTokenEqualOrMistypedEqualEqual(unsigned int)"},
    {"_ZN5clang6Parser22CodeCompletionRecoveryEv", "clang::Parser::CodeCompletionRecovery()"},
    {"_ZN5clang6Parser13FieldCallback7_anchorEv", "clang::Parser::FieldCallback::_anchor()"},
    {"_ZN5clang6Parser21CodeCompleteDirectiveEb", "clang::Parser::CodeCompleteDirective(bool)"},
    {"_ZN5clang6Parser34CodeCompleteInConditionalExclusionEv", "clang::Parser::CodeCompleteInConditionalExclusion()"},
    {"_ZN5clang6Parser21CodeCompleteMacroNameEb", "clang::Parser::CodeCompleteMacroName(bool)"},
    {"_ZN5clang6Parser34CodeCompletePreprocessorExpressionEv", "clang::Parser::CodeCompletePreprocessorExpression()"},
    {"_ZN5clang6Parser25CodeCompleteMacroArgumentEPNS_14IdentifierInfoEPNS_9MacroInfoEj", "clang::Parser::CodeCompleteMacroArgument(clang::IdentifierInfo*, clang::MacroInfo*, unsigned int)"},
    {"_ZN5clang6Parser27CodeCompleteNaturalLanguageEv", "clang::Parser::CodeCompleteNaturalLanguage()"},
    {"_ZN5clang6Parser15ConsumeAnyTokenEv", "clang::Parser::ConsumeAnyToken()"},
    {"_ZN5clang5Scope4InitEPS0_j", "clang::Scope::Init(clang::Scope*, unsigned int)"},
    {"_ZN5clang27PrettyStackTraceParserEntryD1Ev", "clang::PrettyStackTraceParserEntry::~PrettyStackTraceParserEntry()"},
    {"_ZN5clang27PrettyStackTraceParserEntryD0Ev", "clang::PrettyStackTraceParserEntry::~PrettyStackTraceParserEntry()"},
    {"_ZN5clang6Parser13FieldCallbackD1Ev", "clang::Parser::FieldCallback::~FieldCallback()"},
    {"_ZN5clang6Parser13FieldCallbackD0Ev", "clang::Parser::FieldCallback::~FieldCallback()"},
    {"_ZNSt11_Deque_baseIPN5clang6Parser12ParsingClassESaIS3_EE17_M_initialize_mapEm", "std::_Deque_base<clang::Parser::ParsingClass*, std::allocator<clang::Parser::ParsingClass*>>::_M_initialize_map(unsigned long)"},
    {"_ZNSt5dequeIPN5clang6Parser12ParsingClassESaIS3_EEC2ERKS5_", "std::deque<clang::Parser::ParsingClass*, std::allocator<clang::Parser::ParsingClass*>>::deque(std::deque<clang::Parser::ParsingClass*, std::allocator<clang::Parser::ParsingClass*>> const&)"},
    {"_ZN4llvm15SmallVectorImplIN5clang5TokenEE6insertEPS2_RKS2_", "llvm::SmallVectorImpl<clang::Token>::insert(clang::Token*, clang::Token const&)"},
    {"_ZN5clang4sema21AnalysisBasedWarnings6PolicyC1Ev", "clang::sema::AnalysisBasedWarnings::Policy::Policy()"},
    {"_ZN5clang4sema21AnalysisBasedWarnings6PolicyC2Ev", "clang::sema::AnalysisBasedWarnings::Policy::Policy()"},
    {"_ZN5clang4sema21AnalysisBasedWarningsC1ERNS_4SemaE", "clang::sema::AnalysisBasedWarnings::AnalysisBasedWarnings(clang::Sema&)"},
    {"_ZN5clang4sema21AnalysisBasedWarningsC2ERNS_4SemaE", "clang::sema::AnalysisBasedWarnings::AnalysisBasedWarnings(clang::Sema&)"},
    {"_ZN5clang4sema21AnalysisBasedWarnings13IssueWarningsENS1_6PolicyEPKNS_4DeclENS_8QualTypeE", "clang::sema::AnalysisBasedWarnings::IssueWarnings(clang::sema::AnalysisBasedWarnings::Policy, clang::Decl const*, clang::QualType)"},
    {"_ZN12_GLOBAL__N_122UninitValsDiagReporterD1Ev", "(anonymous namespace)::UninitValsDiagReporter::~UninitValsDiagReporter()"},
    {"_ZN5clang4sema21AnalysisBasedWarnings13IssueWarningsENS1_6PolicyEPKNS_9BlockExprE", "clang::sema::AnalysisBasedWarnings::IssueWarnings(clang::sema::AnalysisBasedWarnings::Policy, clang::BlockExpr const*)"},
    {"_ZN5clang4sema21AnalysisBasedWarnings13IssueWarningsENS1_6PolicyEPKNS_14ObjCMethodDeclE", "clang::sema::AnalysisBasedWarnings::IssueWarnings(clang::sema::AnalysisBasedWarnings::Policy, clang::ObjCMethodDecl const*)"},
    {"_ZN5clang4sema21AnalysisBasedWarnings13IssueWarningsENS1_6PolicyEPKNS_12FunctionDeclE", "clang::sema::AnalysisBasedWarnings::IssueWarnings(clang::sema::AnalysisBasedWarnings::Policy, clang::FunctionDecl const*)"},
    {"_ZN12_GLOBAL__N_122UninitValsDiagReporterD0Ev", "(anonymous namespace)::UninitValsDiagReporter::~UninitValsDiagReporter()"},
    {"_ZN12_GLOBAL__N_122UninitValsDiagReporter25handleUseOfUninitVariableEPKN5clang4ExprEPKNS1_7VarDeclE", "(anonymous namespace)::UninitValsDiagReporter::handleUseOfUninitVariable(clang::Expr const*, clang::VarDecl const*)"},
    {"_ZSt16__introsort_loopIPPKN5clang4ExprElN12_GLOBAL__N_18SLocSortEEvT_S7_T0_T1_", "void std::__introsort_loop<clang::Expr const**, long, (anonymous namespace)::SLocSort>(clang::Expr const**, clang::Expr const**, long, (anonymous namespace)::SLocSort)"},
    {"_ZSt16__insertion_sortIPPKN5clang4ExprEN12_GLOBAL__N_18SLocSortEEvT_S7_T0_", "void std::__insertion_sort<clang::Expr const**, (anonymous namespace)::SLocSort>(clang::Expr const**, clang::Expr const**, (anonymous namespace)::SLocSort)"},
    {"_ZSt25__unguarded_linear_insertIPPKN5clang4ExprES3_N12_GLOBAL__N_18SLocSortEEvT_T0_T1_", "void std::__unguarded_linear_insert<clang::Expr const**, clang::Expr const*, (anonymous namespace)::SLocSort>(clang::Expr const**, clang::Expr const*, (anonymous namespace)::SLocSort)"},
    {"_ZSt13__adjust_heapIPPKN5clang4ExprElS3_N12_GLOBAL__N_18SLocSortEEvT_T0_S8_T1_T2_", "void std::__adjust_heap<clang::Expr const**, long, clang::Expr const*, (anonymous namespace)::SLocSort>(clang::Expr const**, long, long, clang::Expr const*, (anonymous namespace)::SLocSort)"},
    {"_ZN12_GLOBAL__N_122UnreachableCodeHandlerD1Ev", "(anonymous namespace)::UnreachableCodeHandler::~UnreachableCodeHandler()"},
    {"_ZN12_GLOBAL__N_122UnreachableCodeHandlerD0Ev", "(anonymous namespace)::UnreachableCodeHandler::~UnreachableCodeHandler()"},
    {"_ZN12_GLOBAL__N_122UnreachableCodeHandler17HandleUnreachableEN5clang14SourceLocationENS1_11SourceRangeES3_", "(anonymous namespace)::UnreachableCodeHandler::HandleUnreachable(clang::SourceLocation, clang::SourceRange, clang::SourceRange)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclEPNS_11SmallVectorIPKNS1_4ExprELj2EEENS_12DenseMapInfoIS4_EENSB_ISA_EEE16InsertIntoBucketERKS4_RKSA_PSt4pairIS4_SA_E", "llvm::DenseMap<clang::VarDecl const*, llvm::SmallVector<clang::Expr const*, 2u>*, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::Expr const*, 2u>*>>::InsertIntoBucket(clang::VarDecl const* const&, llvm::SmallVector<clang::Expr const*, 2u>* const&, std::pair<clang::VarDecl const*, llvm::SmallVector<clang::Expr const*, 2u>*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclEPNS_11SmallVectorIPKNS1_4ExprELj2EEENS_12DenseMapInfoIS4_EENSB_ISA_EEE4growEj", "llvm::DenseMap<clang::VarDecl const*, llvm::SmallVector<clang::Expr const*, 2u>*, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::Expr const*, 2u>*>>::grow(unsigned int)"},
    {"_ZN5clang22UninitVariablesHandler25handleUseOfUninitVariableEPKNS_4ExprEPKNS_7VarDeclE", "clang::UninitVariablesHandler::handleUseOfUninitVariable(clang::Expr const*, clang::VarDecl const*)"},
    {"_ZN5clang14reachable_code8CallbackD1Ev", "clang::reachable_code::Callback::~Callback()"},
    {"_ZN5clang14reachable_code8CallbackD0Ev", "clang::reachable_code::Callback::~Callback()"},
    {"_ZSt6__findIPKPN5clang8CFGBlockES2_ET_S5_S5_RKT0_St26random_access_iterator_tag", "clang::CFGBlock* const* std::__find<clang::CFGBlock* const*, clang::CFGBlock*>(clang::CFGBlock* const*, clang::CFGBlock* const*, clang::CFGBlock* const&, std::random_access_iterator_tag)"},
    {"_ZN5clang13AttributeListC1ERN4llvm16BumpPtrAllocatorEPNS_14IdentifierInfoENS_14SourceLocationES5_S6_S5_S6_PPNS_4ExprEjbb", "clang::AttributeList::AttributeList(llvm::BumpPtrAllocator&, clang::IdentifierInfo*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::Expr**, unsigned int, bool, bool)"},
    {"_ZN5clang13AttributeListC2ERN4llvm16BumpPtrAllocatorEPNS_14IdentifierInfoENS_14SourceLocationES5_S6_S5_S6_PPNS_4ExprEjbb", "clang::AttributeList::AttributeList(llvm::BumpPtrAllocator&, clang::IdentifierInfo*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::Expr**, unsigned int, bool, bool)"},
    {"_ZN5clang13AttributeList7getKindEPKNS_14IdentifierInfoE", "clang::AttributeList::getKind(clang::IdentifierInfo const*)"},
    {"_ZNK5clang21CodeCompletionContext22wantConstructorResultsEv", "clang::CodeCompletionContext::wantConstructorResults() const"},
    {"_ZN5clang20CodeCompletionString5ChunkC1ENS0_9ChunkKindEPKc", "clang::CodeCompletionString::Chunk::Chunk(clang::CodeCompletionString::ChunkKind, char const*)"},
    {"_ZN5clang20CodeCompletionString5ChunkC2ENS0_9ChunkKindEPKc", "clang::CodeCompletionString::Chunk::Chunk(clang::CodeCompletionString::ChunkKind, char const*)"},
    {"_ZN5clang20CodeCompletionString5Chunk10CreateTextEPKc", "clang::CodeCompletionString::Chunk::CreateText(char const*)"},
    {"_ZN5clang20CodeCompletionString5Chunk14CreateOptionalEPS0_", "clang::CodeCompletionString::Chunk::CreateOptional(clang::CodeCompletionString*)"},
    {"_ZN5clang20CodeCompletionString5Chunk17CreatePlaceholderEPKc", "clang::CodeCompletionString::Chunk::CreatePlaceholder(char const*)"},
    {"_ZN5clang20CodeCompletionString5Chunk17CreateInformativeEPKc", "clang::CodeCompletionString::Chunk::CreateInformative(char const*)"},
    {"_ZN5clang20CodeCompletionString5Chunk16CreateResultTypeEPKc", "clang::CodeCompletionString::Chunk::CreateResultType(char const*)"},
    {"_ZN5clang20CodeCompletionString5Chunk22CreateCurrentParameterEPKc", "clang::CodeCompletionString::Chunk::CreateCurrentParameter(char const*)"},
    {"_ZN5clang20CodeCompletionStringC1EPKNS0_5ChunkEjj18CXAvailabilityKind", "clang::CodeCompletionString::CodeCompletionString(clang::CodeCompletionString::Chunk const*, unsigned int, unsigned int, CXAvailabilityKind)"},
    {"_ZN5clang20CodeCompletionStringC2EPKNS0_5ChunkEjj18CXAvailabilityKind", "clang::CodeCompletionString::CodeCompletionString(clang::CodeCompletionString::Chunk const*, unsigned int, unsigned int, CXAvailabilityKind)"},
    {"_ZNK5clang20CodeCompletionString11getAsStringEv", "clang::CodeCompletionString::getAsString() const"},
    {"_ZNK5clang20CodeCompletionString12getTypedTextEv", "clang::CodeCompletionString::getTypedText() const"},
    {"_ZN5clang23CodeCompletionAllocator10CopyStringEN4llvm9StringRefE", "clang::CodeCompletionAllocator::CopyString(llvm::StringRef)"},
    {"_ZN5clang21CodeCompletionBuilder10TakeStringEv", "clang::CodeCompletionBuilder::TakeString()"},
    {"_ZN5clang20CodeCompletionResult19getPriorityFromDeclEPNS_9NamedDeclE", "clang::CodeCompletionResult::getPriorityFromDecl(clang::NamedDecl*)"},
    {"_ZNK5clang20CodeCompleteConsumer17OverloadCandidate11getFunctionEv", "clang::CodeCompleteConsumer::OverloadCandidate::getFunction() const"},
    {"_ZNK5clang20CodeCompleteConsumer17OverloadCandidate15getFunctionTypeEv", "clang::CodeCompleteConsumer::OverloadCandidate::getFunctionType() const"},
    {"_ZN5clang20CodeCompleteConsumerD0Ev", "clang::CodeCompleteConsumer::~CodeCompleteConsumer()"},
    {"_ZN5clang20CodeCompleteConsumerD1Ev", "clang::CodeCompleteConsumer::~CodeCompleteConsumer()"},
    {"_ZN5clang20CodeCompleteConsumerD2Ev", "clang::CodeCompleteConsumer::~CodeCompleteConsumer()"},
    {"_ZN5clang28PrintingCodeCompleteConsumer26ProcessCodeCompleteResultsERNS_4SemaENS_21CodeCompletionContextEPNS_20CodeCompletionResultEj", "clang::PrintingCodeCompleteConsumer::ProcessCodeCompleteResults(clang::Sema&, clang::CodeCompletionContext, clang::CodeCompletionResult*, unsigned int)"},
    {"_ZN5clang28PrintingCodeCompleteConsumer25ProcessOverloadCandidatesERNS_4SemaEjPNS_20CodeCompleteConsumer17OverloadCandidateEj", "clang::PrintingCodeCompleteConsumer::ProcessOverloadCandidates(clang::Sema&, unsigned int, clang::CodeCompleteConsumer::OverloadCandidate*, unsigned int)"},
    {"_ZN5clang20CodeCompletionResult32computeCursorKindAndAvailabilityEv", "clang::CodeCompletionResult::computeCursorKindAndAvailability()"},
    {"_ZN5clangltERKNS_20CodeCompletionResultES2_", "clang::operator<(clang::CodeCompletionResult const&, clang::CodeCompletionResult const&)"},
    {"_Z14getOrderedNameRKN5clang20CodeCompletionResultERSs", "getOrderedName(clang::CodeCompletionResult const&, std::string&)"},
    {"_ZNK5clang4Decl7getAttrINS_15UnavailableAttrEEEPT_v", "clang::UnavailableAttr* clang::Decl::getAttr<clang::UnavailableAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_14DeprecatedAttrEEEPT_v", "clang::DeprecatedAttr* clang::Decl::getAttr<clang::DeprecatedAttr>() const"},
    {"_ZN5clang28PrintingCodeCompleteConsumerD1Ev", "clang::PrintingCodeCompleteConsumer::~PrintingCodeCompleteConsumer()"},
    {"_ZN5clang28PrintingCodeCompleteConsumerD0Ev", "clang::PrintingCodeCompleteConsumer::~PrintingCodeCompleteConsumer()"},
    {"_ZSt21__inplace_stable_sortIPN5clang20CodeCompletionResultEEvT_S3_", "void std::__inplace_stable_sort<clang::CodeCompletionResult*>(clang::CodeCompletionResult*, clang::CodeCompletionResult*)"},
    {"_ZSt22__stable_sort_adaptiveIPN5clang20CodeCompletionResultES2_lEvT_S3_T0_T1_", "void std::__stable_sort_adaptive<clang::CodeCompletionResult*, clang::CodeCompletionResult*, long>(clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*, long)"},
    {"_ZSt24__merge_sort_with_bufferIPN5clang20CodeCompletionResultES2_EvT_S3_T0_", "void std::__merge_sort_with_buffer<clang::CodeCompletionResult*, clang::CodeCompletionResult*>(clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*)"},
    {"_ZSt16__merge_adaptiveIPN5clang20CodeCompletionResultElS2_EvT_S3_S3_T0_S4_T1_S4_", "void std::__merge_adaptive<clang::CodeCompletionResult*, long, clang::CodeCompletionResult*>(clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*, long, long, clang::CodeCompletionResult*, long)"},
    {"_ZSt5mergeIPN5clang20CodeCompletionResultES2_S2_ET1_T_S4_T0_S5_S3_", "clang::CodeCompletionResult* std::merge<clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*>(clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*)"},
    {"_ZSt16__merge_backwardIPN5clang20CodeCompletionResultES2_S2_ET1_T_S4_T0_S5_S3_", "clang::CodeCompletionResult* std::__merge_backward<clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*>(clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*)"},
    {"_ZSt17__rotate_adaptiveIPN5clang20CodeCompletionResultES2_lET_S3_S3_S3_T1_S4_T0_S4_", "clang::CodeCompletionResult* std::__rotate_adaptive<clang::CodeCompletionResult*, clang::CodeCompletionResult*, long>(clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*, long, long, clang::CodeCompletionResult*, long)"},
    {"_ZSt8__rotateIPN5clang20CodeCompletionResultEEvT_S3_S3_St26random_access_iterator_tag", "void std::__rotate<clang::CodeCompletionResult*>(clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*, std::random_access_iterator_tag)"},
    {"_ZSt16__insertion_sortIPN5clang20CodeCompletionResultEEvT_S3_", "void std::__insertion_sort<clang::CodeCompletionResult*>(clang::CodeCompletionResult*, clang::CodeCompletionResult*)"},
    {"_ZSt22__merge_without_bufferIPN5clang20CodeCompletionResultElEvT_S3_S3_T0_S4_", "void std::__merge_without_buffer<clang::CodeCompletionResult*, long>(clang::CodeCompletionResult*, clang::CodeCompletionResult*, clang::CodeCompletionResult*, long, long)"},
    {"_ZN5clang13UnqualifiedId13setTemplateIdEPNS_20TemplateIdAnnotationE", "clang::UnqualifiedId::setTemplateId(clang::TemplateIdAnnotation*)"},
    {"_ZN5clang13UnqualifiedId24setConstructorTemplateIdEPNS_20TemplateIdAnnotationE", "clang::UnqualifiedId::setConstructorTemplateId(clang::TemplateIdAnnotation*)"},
    {"_ZN5clang15DeclaratorChunk11getFunctionERKNS_16ParsedAttributesEbbNS_14SourceLocationEPNS0_9ParamInfoEjjbS4_bS4_bPNS_9OpaquePtrINS_8QualTypeEEEPNS_11SourceRangeEjS4_S4_RNS_10DeclaratorES9_", "clang::DeclaratorChunk::getFunction(clang::ParsedAttributes const&, bool, bool, clang::SourceLocation, clang::DeclaratorChunk::ParamInfo*, unsigned int, unsigned int, bool, clang::SourceLocation, bool, clang::SourceLocation, bool, clang::OpaquePtr<clang::QualType>*, clang::SourceRange*, unsigned int, clang::SourceLocation, clang::SourceLocation, clang::Declarator&, clang::OpaquePtr<clang::QualType>)"},
    {"_ZNK5clang8DeclSpec19getParsedSpecifiersEv", "clang::DeclSpec::getParsedSpecifiers() const"},
    {"_ZN5clang8DeclSpec16getSpecifierNameENS0_3SCSE", "clang::DeclSpec::getSpecifierName(clang::DeclSpec::SCS)"},
    {"_ZN5clang8DeclSpec16getSpecifierNameENS_18TypeSpecifierWidthE", "clang::DeclSpec::getSpecifierName(clang::TypeSpecifierWidth)"},
    {"_ZN5clang8DeclSpec16getSpecifierNameENS0_3TSCE", "clang::DeclSpec::getSpecifierName(clang::DeclSpec::TSC)"},
    {"_ZN5clang8DeclSpec16getSpecifierNameENS_17TypeSpecifierSignE", "clang::DeclSpec::getSpecifierName(clang::TypeSpecifierSign)"},
    {"_ZN5clang8DeclSpec16getSpecifierNameENS_17TypeSpecifierTypeE", "clang::DeclSpec::getSpecifierName(clang::TypeSpecifierType)"},
    {"_ZN5clang8DeclSpec16getSpecifierNameENS0_2TQE", "clang::DeclSpec::getSpecifierName(clang::DeclSpec::TQ)"},
    {"_ZN5clang8DeclSpec19SetStorageClassSpecENS0_3SCSENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetStorageClassSpec(clang::DeclSpec::SCS, clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec25SetStorageClassSpecThreadENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetStorageClassSpecThread(clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec16SetTypeSpecWidthENS_18TypeSpecifierWidthENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetTypeSpecWidth(clang::TypeSpecifierWidth, clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec18SetTypeSpecComplexENS0_3TSCENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetTypeSpecComplex(clang::DeclSpec::TSC, clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec15SetTypeSpecSignENS_17TypeSpecifierSignENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetTypeSpecSign(clang::TypeSpecifierSign, clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec15SetTypeSpecTypeENS_17TypeSpecifierTypeENS_14SourceLocationERPKcRjNS_9OpaquePtrINS_8QualTypeEEE", "clang::DeclSpec::SetTypeSpecType(clang::TypeSpecifierType, clang::SourceLocation, char const*&, unsigned int&, clang::OpaquePtr<clang::QualType>)"},
    {"_ZN5clang8DeclSpec15SetTypeSpecTypeENS_17TypeSpecifierTypeENS_14SourceLocationERPKcRjPNS_4ExprE", "clang::DeclSpec::SetTypeSpecType(clang::TypeSpecifierType, clang::SourceLocation, char const*&, unsigned int&, clang::Expr*)"},
    {"_ZN5clang8DeclSpec15SetTypeSpecTypeENS_17TypeSpecifierTypeENS_14SourceLocationERPKcRjPNS_4DeclEb", "clang::DeclSpec::SetTypeSpecType(clang::TypeSpecifierType, clang::SourceLocation, char const*&, unsigned int&, clang::Decl*, bool)"},
    {"_ZN5clang8DeclSpec15SetTypeSpecTypeENS_17TypeSpecifierTypeENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetTypeSpecType(clang::TypeSpecifierType, clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec20SetTypeAltiVecVectorEbNS_14SourceLocationERPKcRj", "clang::DeclSpec::SetTypeAltiVecVector(bool, clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec19SetTypeAltiVecPixelEbNS_14SourceLocationERPKcRj", "clang::DeclSpec::SetTypeAltiVecPixel(bool, clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec16SetTypeSpecErrorEv", "clang::DeclSpec::SetTypeSpecError()"},
    {"_ZN5clang8DeclSpec11SetTypeQualENS0_2TQENS_14SourceLocationERPKcRjRKNS_11LangOptionsE", "clang::DeclSpec::SetTypeQual(clang::DeclSpec::TQ, clang::SourceLocation, char const*&, unsigned int&, clang::LangOptions const&)"},
    {"_ZN5clang8DeclSpec21SetFunctionSpecInlineENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetFunctionSpecInline(clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec22SetFunctionSpecVirtualENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetFunctionSpecVirtual(clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec23SetFunctionSpecExplicitENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetFunctionSpecExplicit(clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec13SetFriendSpecENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetFriendSpec(clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec16SetConstexprSpecENS_14SourceLocationERPKcRj", "clang::DeclSpec::SetConstexprSpec(clang::SourceLocation, char const*&, unsigned int&)"},
    {"_ZN5clang8DeclSpec21setProtocolQualifiersEPKPNS_4DeclEjPNS_14SourceLocationES5_", "clang::DeclSpec::setProtocolQualifiers(clang::Decl* const*, unsigned int, clang::SourceLocation*, clang::SourceLocation)"},
    {"_ZN5clang8DeclSpec23SaveWrittenBuiltinSpecsEv", "clang::DeclSpec::SaveWrittenBuiltinSpecs()"},
    {"_ZN5clang8DeclSpec29SaveStorageSpecifierAsWrittenEv", "clang::DeclSpec::SaveStorageSpecifierAsWritten()"},
    {"_ZN5clang8DeclSpec6FinishERNS_10DiagnosticERNS_12PreprocessorE", "clang::DeclSpec::Finish(clang::Diagnostic&, clang::Preprocessor&)"},
    {"_ZN5clang8DeclSpec21isMissingDeclaratorOkEv", "clang::DeclSpec::isMissingDeclaratorOk()"},
    {"_ZN5clang13UnqualifiedId5clearEv", "clang::UnqualifiedId::clear()"},
    {"_ZN5clang13UnqualifiedId21setOperatorFunctionIdENS_14SourceLocationENS_22OverloadedOperatorKindEPS1_", "clang::UnqualifiedId::setOperatorFunctionId(clang::SourceLocation, clang::OverloadedOperatorKind, clang::SourceLocation*)"},
    {"_ZN5clang14VirtSpecifiers12SetSpecifierENS0_9SpecifierENS_14SourceLocationERPKc", "clang::VirtSpecifiers::SetSpecifier(clang::VirtSpecifiers::Specifier, clang::SourceLocation, char const*&)"},
    {"_ZN5clang14VirtSpecifiers16getSpecifierNameENS0_9SpecifierE", "clang::VirtSpecifiers::getSpecifierName(clang::VirtSpecifiers::Specifier)"},
    {"_ZN5clang19ClassVirtSpecifiers12SetSpecifierENS0_9SpecifierENS_14SourceLocationERPKc", "clang::ClassVirtSpecifiers::SetSpecifier(clang::ClassVirtSpecifiers::Specifier, clang::SourceLocation, char const*&)"},
    {"_ZN5clang19ClassVirtSpecifiers16getSpecifierNameENS0_9SpecifierE", "clang::ClassVirtSpecifiers::getSpecifierName(clang::ClassVirtSpecifiers::Specifier)"},
    {"_ZN5clang18IdentifierResolver10IdDeclInfo10RemoveDeclEPNS_9NamedDeclE", "clang::IdentifierResolver::IdDeclInfo::RemoveDecl(clang::NamedDecl*)"},
    {"_ZN5clang18IdentifierResolver10IdDeclInfo11ReplaceDeclEPNS_9NamedDeclES3_", "clang::IdentifierResolver::IdDeclInfo::ReplaceDecl(clang::NamedDecl*, clang::NamedDecl*)"},
    {"_ZN5clang18IdentifierResolverC1ERKNS_11LangOptionsE", "clang::IdentifierResolver::IdentifierResolver(clang::LangOptions const&)"},
    {"_ZN5clang18IdentifierResolverC2ERKNS_11LangOptionsE", "clang::IdentifierResolver::IdentifierResolver(clang::LangOptions const&)"},
    {"_ZN5clang18IdentifierResolverD1Ev", "clang::IdentifierResolver::~IdentifierResolver()"},
    {"_ZN5clang18IdentifierResolverD2Ev", "clang::IdentifierResolver::~IdentifierResolver()"},
    {"_ZNK5clang18IdentifierResolver13isDeclInScopeEPNS_4DeclEPNS_11DeclContextERNS_10ASTContextEPNS_5ScopeE", "clang::IdentifierResolver::isDeclInScope(clang::Decl*, clang::DeclContext*, clang::ASTContext&, clang::Scope*) const"},
    {"_ZN5clang18IdentifierResolver7AddDeclEPNS_9NamedDeclE", "clang::IdentifierResolver::AddDecl(clang::NamedDecl*)"},
    {"_ZN5clang18IdentifierResolver13IdDeclInfoMapixENS_15DeclarationNameE", "clang::IdentifierResolver::IdDeclInfoMap::operator[](clang::DeclarationName)"},
    {"_ZN5clang18IdentifierResolver10RemoveDeclEPNS_9NamedDeclE", "clang::IdentifierResolver::RemoveDecl(clang::NamedDecl*)"},
    {"_ZN5clang18IdentifierResolver11ReplaceDeclEPNS_9NamedDeclES2_", "clang::IdentifierResolver::ReplaceDecl(clang::NamedDecl*, clang::NamedDecl*)"},
    {"_ZN5clang18IdentifierResolver5beginENS_15DeclarationNameE", "clang::IdentifierResolver::begin(clang::DeclarationName)"},
    {"_ZN5clang18IdentifierResolver24AddDeclToIdentifierChainEPNS_14IdentifierInfoEPNS_9NamedDeclE", "clang::IdentifierResolver::AddDeclToIdentifierChain(clang::IdentifierInfo*, clang::NamedDecl*)"},
    {"_ZN5clang18IdentifierResolver8iterator17incrementSlowCaseEv", "clang::IdentifierResolver::iterator::incrementSlowCase()"},
    {"_ZN5clang4Sema20DiagnoseInvalidJumpsEPNS_4StmtE", "clang::Sema::DiagnoseInvalidJumps(clang::Stmt*)"},
    {"_ZN4llvm15SmallVectorImplIN12_GLOBAL__N_116JumpScopeChecker9GotoScopeEE9push_backERKS3_", "llvm::SmallVectorImpl<(anonymous namespace)::JumpScopeChecker::GotoScope>::push_back((anonymous namespace)::JumpScopeChecker::GotoScope const&)"},
    {"_ZN12_GLOBAL__N_116JumpScopeChecker21BuildScopeInformationEPN5clang4StmtEj", "(anonymous namespace)::JumpScopeChecker::BuildScopeInformation(clang::Stmt*, unsigned int)"},
    {"_ZN12_GLOBAL__N_116JumpScopeChecker9CheckJumpEPN5clang4StmtES3_NS1_14SourceLocationEj", "(anonymous namespace)::JumpScopeChecker::CheckJump(clang::Stmt*, clang::Stmt*, clang::SourceLocation, unsigned int)"},
    {"_ZN12_GLOBAL__N_116JumpScopeChecker21BuildScopeInformationEPN5clang4DeclERj", "(anonymous namespace)::JumpScopeChecker::BuildScopeInformation(clang::Decl*, unsigned int&)"},
    {"_ZN4llvm8DenseMapIjPN5clang9LabelStmtENS_12DenseMapInfoIjEENS4_IS3_EEE16InsertIntoBucketERKjRKS3_PSt4pairIjS3_E", "llvm::DenseMap<unsigned int, clang::LabelStmt*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<clang::LabelStmt*>>::InsertIntoBucket(unsigned int const&, clang::LabelStmt* const&, std::pair<unsigned int, clang::LabelStmt*>*)"},
    {"_ZN4llvm8DenseMapIjPN5clang9LabelStmtENS_12DenseMapInfoIjEENS4_IS3_EEE4growEj", "llvm::DenseMap<unsigned int, clang::LabelStmt*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<clang::LabelStmt*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIjPN5clang16IndirectGotoStmtENS_12DenseMapInfoIjEENS4_IS3_EEE16InsertIntoBucketERKjRKS3_PSt4pairIjS3_E", "llvm::DenseMap<unsigned int, clang::IndirectGotoStmt*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<clang::IndirectGotoStmt*>>::InsertIntoBucket(unsigned int const&, clang::IndirectGotoStmt* const&, std::pair<unsigned int, clang::IndirectGotoStmt*>*)"},
    {"_ZN4llvm8DenseMapIjPN5clang16IndirectGotoStmtENS_12DenseMapInfoIjEENS4_IS3_EEE4growEj", "llvm::DenseMap<unsigned int, clang::IndirectGotoStmt*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<clang::IndirectGotoStmt*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang4StmtEjNS_12DenseMapInfoIS3_EENS4_IjEEE16InsertIntoBucketERKS3_RKjPSt4pairIS3_jE", "llvm::DenseMap<clang::Stmt*, unsigned int, llvm::DenseMapInfo<clang::Stmt*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::Stmt* const&, unsigned int const&, std::pair<clang::Stmt*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPN5clang4StmtEjNS_12DenseMapInfoIS3_EENS4_IjEEE4growEj", "llvm::DenseMap<clang::Stmt*, unsigned int, llvm::DenseMapInfo<clang::Stmt*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN5clang4sema17FunctionScopeInfoD0Ev", "clang::sema::FunctionScopeInfo::~FunctionScopeInfo()"},
    {"_ZN5clang4sema17FunctionScopeInfoD1Ev", "clang::sema::FunctionScopeInfo::~FunctionScopeInfo()"},
    {"_ZN5clang4sema17FunctionScopeInfoD2Ev", "clang::sema::FunctionScopeInfo::~FunctionScopeInfo()"},
    {"_ZN5clang4sema17FunctionScopeInfo5ClearEv", "clang::sema::FunctionScopeInfo::Clear()"},
    {"_ZN5clang4sema14BlockScopeInfoD0Ev", "clang::sema::BlockScopeInfo::~BlockScopeInfo()"},
    {"_ZN5clang4sema14BlockScopeInfoD1Ev", "clang::sema::BlockScopeInfo::~BlockScopeInfo()"},
    {"_ZN5clang4sema14BlockScopeInfoD2Ev", "clang::sema::BlockScopeInfo::~BlockScopeInfo()"},
    {"_ZN5clang4Sema25ActOnTranslationUnitScopeEPNS_5ScopeE", "clang::Sema::ActOnTranslationUnitScope(clang::Scope*)"},
    {"_ZN5clang4SemaC1ERNS_12PreprocessorERNS_10ASTContextERNS_11ASTConsumerEbPNS_20CodeCompleteConsumerE", "clang::Sema::Sema(clang::Preprocessor&, clang::ASTContext&, clang::ASTConsumer&, bool, clang::CodeCompleteConsumer*)"},
    {"_ZN5clang4SemaC2ERNS_12PreprocessorERNS_10ASTContextERNS_11ASTConsumerEbPNS_20CodeCompleteConsumerE", "clang::Sema::Sema(clang::Preprocessor&, clang::ASTContext&, clang::ASTConsumer&, bool, clang::CodeCompleteConsumer*)"},
    {"_ZN5clang4Sema10InitializeEv", "clang::Sema::Initialize()"},
    {"_ZN5clang4SemaD1Ev", "clang::Sema::~Sema()"},
    {"_ZN5clang4SemaD2Ev", "clang::Sema::~Sema()"},
    {"_ZN5clang4Sema17ImpCastExprToTypeERPNS_4ExprENS_8QualTypeENS_8CastKindENS_13ExprValueKindEPKN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEE", "clang::Sema::ImpCastExprToType(clang::Expr*&, clang::QualType, clang::CastKind, clang::ExprValueKind, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u> const*)"},
    {"_ZN5clang4Sema12CastCategoryEPNS_4ExprE", "clang::Sema::CastCategory(clang::Expr*)"},
    {"_ZN5clang4Sema25ActOnEndOfTranslationUnitEv", "clang::Sema::ActOnEndOfTranslationUnit()"},
    {"_Z22ShouldRemoveFromUnusedPN5clang4SemaEPKNS_14DeclaratorDeclE", "ShouldRemoveFromUnused(clang::Sema*, clang::DeclaratorDecl const*)"},
    {"_ZN5clang4Sema4DiagENS_14SourceLocationEj", "clang::Sema::Diag(clang::SourceLocation, unsigned int)"},
    {"_ZN5clang4Sema21SemaDiagnosticBuilderD1Ev", "clang::Sema::SemaDiagnosticBuilder::~SemaDiagnosticBuilder()"},
    {"_ZN5clang4Sema27getFunctionLevelDeclContextEv", "clang::Sema::getFunctionLevelDeclContext()"},
    {"_ZN5clang4Sema18getCurFunctionDeclEv", "clang::Sema::getCurFunctionDecl()"},
    {"_ZN5clang4Sema16getCurMethodDeclEv", "clang::Sema::getCurMethodDecl()"},
    {"_ZN5clang4Sema26getCurFunctionOrMethodDeclEv", "clang::Sema::getCurFunctionOrMethodDecl()"},
    {"_ZN5clang4Sema21SemaDiagnosticBuilderD2Ev", "clang::Sema::SemaDiagnosticBuilder::~SemaDiagnosticBuilder()"},
    {"_ZN5clang4Sema4DiagENS_14SourceLocationERKNS_17PartialDiagnosticE", "clang::Sema::Diag(clang::SourceLocation, clang::PartialDiagnostic const&)"},
    {"_ZN5clang4Sema18getScopeForContextEPNS_11DeclContextE", "clang::Sema::getScopeForContext(clang::DeclContext*)"},
    {"_ZN5clang4Sema17PushFunctionScopeEv", "clang::Sema::PushFunctionScope()"},
    {"_ZN5clang4Sema14PushBlockScopeEPNS_5ScopeEPNS_9BlockDeclE", "clang::Sema::PushBlockScope(clang::Scope*, clang::BlockDecl*)"},
    {"_ZN5clang4Sema23PopFunctionOrBlockScopeEv", "clang::Sema::PopFunctionOrBlockScope()"},
    {"_ZNK5clang4Sema26hasAnyErrorsInThisFunctionEv", "clang::Sema::hasAnyErrorsInThisFunction() const"},
    {"_ZN5clang4Sema11getCurBlockEv", "clang::Sema::getCurBlock()"},
    {"_ZN5clang18ExternalSemaSourceD0Ev", "clang::ExternalSemaSource::~ExternalSemaSource()"},
    {"_ZN5clang18ExternalSemaSourceD1Ev", "clang::ExternalSemaSource::~ExternalSemaSource()"},
    {"_ZN5clang18ExternalSemaSourceD2Ev", "clang::ExternalSemaSource::~ExternalSemaSource()"},
    {"_ZN5clang18ExternalSemaSource14ReadMethodPoolENS_8SelectorE", "clang::ExternalSemaSource::ReadMethodPool(clang::Selector)"},
    {"_ZNK5clang25PrettyDeclStackTraceEntry5printERN4llvm11raw_ostreamE", "clang::PrettyDeclStackTraceEntry::print(llvm::raw_ostream&) const"},
    {"_ZN5clang4sema21TemplateDeductionInfo23addSuppressedDiagnosticENS_14SourceLocationERKNS_17PartialDiagnosticE", "clang::sema::TemplateDeductionInfo::addSuppressedDiagnostic(clang::SourceLocation, clang::PartialDiagnostic const&)"},
    {"_ZNK5clang17PartialDiagnostic4EmitERKNS_17DiagnosticBuilderE", "clang::PartialDiagnostic::Emit(clang::DiagnosticBuilder const&) const"},
    {"_ZN5clang25PrettyDeclStackTraceEntryD1Ev", "clang::PrettyDeclStackTraceEntry::~PrettyDeclStackTraceEntry()"},
    {"_ZN5clang25PrettyDeclStackTraceEntryD0Ev", "clang::PrettyDeclStackTraceEntry::~PrettyDeclStackTraceEntry()"},
    {"_ZSt9__find_ifIPPKN5clang14DeclaratorDeclESt9binder1stISt26pointer_to_binary_functionIPNS0_4SemaES3_bEEET_SB_SB_T0_St26random_access_iterator_tag", "clang::DeclaratorDecl const** std::__find_if<clang::DeclaratorDecl const**, std::binder1st<std::pointer_to_binary_function<clang::Sema*, clang::DeclaratorDecl const*, bool>>>(clang::DeclaratorDecl const**, clang::DeclaratorDecl const**, std::binder1st<std::pointer_to_binary_function<clang::Sema*, clang::DeclaratorDecl const*, bool>>, std::random_access_iterator_tag)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang4Sema33ExpressionEvaluationContextRecordELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::Sema::ExpressionEvaluationContextRecord, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIPN5clang4DeclENS_11SmallVectorISt4pairINS1_14SourceLocationENS1_17PartialDiagnosticEELj1EEENS_12DenseMapInfoIS3_EENSA_IS9_EEED2Ev", "llvm::DenseMap<clang::Decl*, llvm::SmallVector<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, 1u>, llvm::DenseMapInfo<clang::Decl*>, llvm::DenseMapInfo<llvm::SmallVector<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, 1u>>>::~DenseMap()"},
    {"_ZNSt11_Deque_baseISt4pairIPN5clang9ValueDeclENS1_14SourceLocationEESaIS5_EE17_M_initialize_mapEm", "std::_Deque_base<std::pair<clang::ValueDecl*, clang::SourceLocation>, std::allocator<std::pair<clang::ValueDecl*, clang::SourceLocation>>>::_M_initialize_map(unsigned long)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEPNS1_9LabelStmtENS_12DenseMapInfoIS3_EENS6_IS5_EEE16shrink_and_clearEv", "llvm::DenseMap<clang::IdentifierInfo*, clang::LabelStmt*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::LabelStmt*>>::shrink_and_clear()"},
    {"_ZN5clang4sema14BlockScopeInfoC2ERNS_10DiagnosticEPNS_5ScopeEPNS_9BlockDeclE", "clang::sema::BlockScopeInfo::BlockScopeInfo(clang::Diagnostic&, clang::Scope*, clang::BlockDecl*)"},
    {"_ZN5clang17PartialDiagnostic11freeStorageEv", "clang::PartialDiagnostic::freeStorage()"},
    {"_ZN5clang17PartialDiagnosticC2ERKNS_14DiagnosticInfoERNS0_16StorageAllocatorE", "clang::PartialDiagnostic::PartialDiagnostic(clang::DiagnosticInfo const&, clang::PartialDiagnostic::StorageAllocator&)"},
    {"_ZNK5clang17PartialDiagnostic9AddStringEN4llvm9StringRefE", "clang::PartialDiagnostic::AddString(llvm::StringRef) const"},
    {"_ZNK5clang17PartialDiagnostic10getStorageEv", "clang::PartialDiagnostic::getStorage() const"},
    {"_ZN5clang17PartialDiagnostic16StorageAllocator8AllocateEv", "clang::PartialDiagnostic::StorageAllocator::Allocate()"},
    {"_ZN5clang17PartialDiagnostic7StorageaSERKS1_", "clang::PartialDiagnostic::Storage::operator=(clang::PartialDiagnostic::Storage const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairIN5clang14SourceLocationENS2_17PartialDiagnosticEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, false>::grow(unsigned long)"},
    {"_ZN5clang4Sema24SetMemberAccessSpecifierEPNS_9NamedDeclES2_NS_15AccessSpecifierE", "clang::Sema::SetMemberAccessSpecifier(clang::NamedDecl*, clang::NamedDecl*, clang::AccessSpecifier)"},
    {"_ZN5clang4Sema24HandleDelayedAccessCheckERNS_4sema17DelayedDiagnosticEPNS_4DeclE", "clang::Sema::HandleDelayedAccessCheck(clang::sema::DelayedDiagnostic&, clang::Decl*)"},
    {"_ZN12_GLOBAL__N_116EffectiveContextC1EPN5clang11DeclContextE", "(anonymous namespace)::EffectiveContext::EffectiveContext(clang::DeclContext*)"},
    {"_Z20CheckEffectiveAccessRN5clang4SemaERKN12_GLOBAL__N_116EffectiveContextENS_14SourceLocationERNS2_12AccessTargetE", "CheckEffectiveAccess(clang::Sema&, (anonymous namespace)::EffectiveContext const&, clang::SourceLocation, (anonymous namespace)::AccessTarget&)"},
    {"_ZN5clang4Sema26HandleDependentAccessCheckERKNS_19DependentDiagnosticERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::HandleDependentAccessCheck(clang::DependentDiagnostic const&, clang::MultiLevelTemplateArgumentList const&)"},
    {"_Z11CheckAccessRN5clang4SemaENS_14SourceLocationERN12_GLOBAL__N_112AccessTargetE", "CheckAccess(clang::Sema&, clang::SourceLocation, (anonymous namespace)::AccessTarget&)"},
    {"_ZN5clang4Sema27CheckUnresolvedLookupAccessEPNS_20UnresolvedLookupExprENS_14DeclAccessPairE", "clang::Sema::CheckUnresolvedLookupAccess(clang::UnresolvedLookupExpr*, clang::DeclAccessPair)"},
    {"_ZN5clang4Sema27CheckUnresolvedMemberAccessEPNS_20UnresolvedMemberExprENS_14DeclAccessPairE", "clang::Sema::CheckUnresolvedMemberAccess(clang::UnresolvedMemberExpr*, clang::DeclAccessPair)"},
    {"_ZN5clang4Sema21CheckDestructorAccessENS_14SourceLocationEPNS_17CXXDestructorDeclERKNS_17PartialDiagnosticE", "clang::Sema::CheckDestructorAccess(clang::SourceLocation, clang::CXXDestructorDecl*, clang::PartialDiagnostic const&)"},
    {"_ZN5clang4Sema22CheckConstructorAccessENS_14SourceLocationEPNS_18CXXConstructorDeclERKNS_17InitializedEntityENS_15AccessSpecifierEb", "clang::Sema::CheckConstructorAccess(clang::SourceLocation, clang::CXXConstructorDecl*, clang::InitializedEntity const&, clang::AccessSpecifier, bool)"},
    {"_ZN5clang4Sema23CheckDirectMemberAccessENS_14SourceLocationEPNS_9NamedDeclERKNS_17PartialDiagnosticE", "clang::Sema::CheckDirectMemberAccess(clang::SourceLocation, clang::NamedDecl*, clang::PartialDiagnostic const&)"},
    {"_ZN5clang4Sema21CheckAllocationAccessENS_14SourceLocationENS_11SourceRangeEPNS_13CXXRecordDeclENS_14DeclAccessPairE", "clang::Sema::CheckAllocationAccess(clang::SourceLocation, clang::SourceRange, clang::CXXRecordDecl*, clang::DeclAccessPair)"},
    {"_ZN5clang4Sema25CheckMemberOperatorAccessENS_14SourceLocationEPNS_4ExprES3_NS_14DeclAccessPairE", "clang::Sema::CheckMemberOperatorAccess(clang::SourceLocation, clang::Expr*, clang::Expr*, clang::DeclAccessPair)"},
    {"_ZN5clang4Sema26CheckAddressOfMemberAccessEPNS_4ExprENS_14DeclAccessPairE", "clang::Sema::CheckAddressOfMemberAccess(clang::Expr*, clang::DeclAccessPair)"},
    {"_ZN5clang4Sema20CheckBaseClassAccessENS_14SourceLocationENS_8QualTypeES2_RKNS_11CXXBasePathEjbb", "clang::Sema::CheckBaseClassAccess(clang::SourceLocation, clang::QualType, clang::QualType, clang::CXXBasePath const&, unsigned int, bool, bool)"},
    {"_ZN5clang4Sema17CheckLookupAccessERKNS_12LookupResultE", "clang::Sema::CheckLookupAccess(clang::LookupResult const&)"},
    {"_ZN5clang4Sema33ActOnStartSuppressingAccessChecksEv", "clang::Sema::ActOnStartSuppressingAccessChecks()"},
    {"_ZN5clang4Sema32ActOnStopSuppressingAccessChecksEv", "clang::Sema::ActOnStopSuppressingAccessChecks()"},
    {"_Z18FindDeclaringClassPN5clang9NamedDeclE", "FindDeclaringClass(clang::NamedDecl*)"},
    {"_Z9HasAccessRN5clang4SemaERKN12_GLOBAL__N_116EffectiveContextEPKNS_13CXXRecordDeclENS_15AccessSpecifierERKNS2_12AccessTargetE", "HasAccess(clang::Sema&, (anonymous namespace)::EffectiveContext const&, clang::CXXRecordDecl const*, clang::AccessSpecifier, (anonymous namespace)::AccessTarget const&)"},
    {"_Z12FindBestPathRN5clang4SemaERKN12_GLOBAL__N_116EffectiveContextERNS2_12AccessTargetENS_15AccessSpecifierERNS_12CXXBasePathsE", "FindBestPath(clang::Sema&, (anonymous namespace)::EffectiveContext const&, (anonymous namespace)::AccessTarget&, clang::AccessSpecifier, clang::CXXBasePaths&)"},
    {"_Z13GetFriendKindRN5clang4SemaERKN12_GLOBAL__N_116EffectiveContextEPKNS_13CXXRecordDeclE", "GetFriendKind(clang::Sema&, (anonymous namespace)::EffectiveContext const&, clang::CXXRecordDecl const*)"},
    {"_Z13MatchesFriendRN5clang4SemaERKN12_GLOBAL__N_116EffectiveContextEPKNS_13CXXRecordDeclE", "MatchesFriend(clang::Sema&, (anonymous namespace)::EffectiveContext const&, clang::CXXRecordDecl const*)"},
    {"_Z18MightInstantiateToRN5clang4SemaEPNS_12FunctionDeclES3_", "MightInstantiateTo(clang::Sema&, clang::FunctionDecl*, clang::FunctionDecl*)"},
    {"_Z22IsDerivedFromInclusivePKN5clang13CXXRecordDeclES2_", "IsDerivedFromInclusive(clang::CXXRecordDecl const*, clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_122ProtectedFriendContext14findFriendshipEPKN5clang13CXXRecordDeclEj", "(anonymous namespace)::ProtectedFriendContext::findFriendship(clang::CXXRecordDecl const*, unsigned int)"},
    {"_ZSt6__findIPKPN5clang13CXXRecordDeclEPKS1_ET_S7_S7_RKT0_St26random_access_iterator_tag", "clang::CXXRecordDecl* const* std::__find<clang::CXXRecordDecl* const*, clang::CXXRecordDecl const*>(clang::CXXRecordDecl* const*, clang::CXXRecordDecl* const*, clang::CXXRecordDecl const* const&, std::random_access_iterator_tag)"},
    {"_ZN5clang4Sema17FreePackedContextEv", "clang::Sema::FreePackedContext()"},
    {"_ZN5clang4Sema31AddAlignmentAttributesForRecordEPNS_10RecordDeclE", "clang::Sema::AddAlignmentAttributesForRecord(clang::RecordDecl*)"},
    {"_ZN5clang4Sema23ActOnPragmaOptionsAlignENS0_22PragmaOptionsAlignKindENS_14SourceLocationES2_", "clang::Sema::ActOnPragmaOptionsAlign(clang::Sema::PragmaOptionsAlignKind, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN12_GLOBAL__N_115PragmaPackStack4pushEPN5clang14IdentifierInfoE", "(anonymous namespace)::PragmaPackStack::push(clang::IdentifierInfo*)"},
    {"_ZN5clang4Sema15ActOnPragmaPackENS0_14PragmaPackKindEPNS_14IdentifierInfoEPNS_4ExprENS_14SourceLocationES6_S6_", "clang::Sema::ActOnPragmaPack(clang::Sema::PragmaPackKind, clang::IdentifierInfo*, clang::Expr*, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema17ActOnPragmaUnusedERKNS_5TokenEPNS_5ScopeENS_14SourceLocationE", "clang::Sema::ActOnPragmaUnused(clang::Token const&, clang::Scope*, clang::SourceLocation)"},
    {"_ZN5clang4Sema28AddPushedVisibilityAttributeEPNS_4DeclE", "clang::Sema::AddPushedVisibilityAttribute(clang::Decl*)"},
    {"_ZN5clang4Sema14FreeVisContextEv", "clang::Sema::FreeVisContext()"},
    {"_ZN5clang4Sema21ActOnPragmaVisibilityEbPKNS_14IdentifierInfoENS_14SourceLocationE", "clang::Sema::ActOnPragmaVisibility(bool, clang::IdentifierInfo const*, clang::SourceLocation)"},
    {"_ZN5clang4Sema19PopPragmaVisibilityEv", "clang::Sema::PopPragmaVisibility()"},
    {"_ZN5clang4Sema27PushNamespaceVisibilityAttrEPKNS_14VisibilityAttrE", "clang::Sema::PushNamespaceVisibilityAttr(clang::VisibilityAttr const*)"},
    {"_ZN5clang4Decl7addAttrEPNS_4AttrE", "clang::Decl::addAttr(clang::Attr*)"},
    {"_ZNSt6vectorISt4pairIjN5clang14SourceLocationEESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<std::pair<unsigned int, clang::SourceLocation>, std::allocator<std::pair<unsigned int, clang::SourceLocation>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<unsigned int, clang::SourceLocation>*, std::vector<std::pair<unsigned int, clang::SourceLocation>, std::allocator<std::pair<unsigned int, clang::SourceLocation>>>>, std::pair<unsigned int, clang::SourceLocation> const&)"},
    {"_ZN5clang15InheritableAttrD1Ev", "clang::InheritableAttr::~InheritableAttr()"},
    {"_ZN5clang15InheritableAttrD0Ev", "clang::InheritableAttr::~InheritableAttr()"},
    {"_ZN4llvm11SmallVectorIPN5clang4AttrELj2EEC2EjRKS3_", "llvm::SmallVector<clang::Attr*, 2u>::SmallVector(unsigned int, clang::Attr* const&)"},
    {"_ZN5clang4Sema17ActOnCXXNamedCastENS_14SourceLocationENS_3tok9TokenKindES1_NS_9OpaquePtrINS_8QualTypeEEES1_S1_PNS_4ExprES1_", "clang::Sema::ActOnCXXNamedCast(clang::SourceLocation, clang::tok::TokenKind, clang::SourceLocation, clang::OpaquePtr<clang::QualType>, clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema17BuildCXXNamedCastENS_14SourceLocationENS_3tok9TokenKindEPNS_14TypeSourceInfoEPNS_4ExprENS_11SourceRangeES8_", "clang::Sema::BuildCXXNamedCast(clang::SourceLocation, clang::tok::TokenKind, clang::TypeSourceInfo*, clang::Expr*, clang::SourceRange, clang::SourceRange)"},
    {"_ZN5clang4Sema18CXXCheckCStyleCastENS_11SourceRangeENS_8QualTypeERNS_13ExprValueKindERPNS_4ExprERNS_8CastKindERN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEEb", "clang::Sema::CXXCheckCStyleCast(clang::SourceRange, clang::QualType, clang::ExprValueKind&, clang::Expr*&, clang::CastKind&, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u>&, bool)"},
    {"_Z12TryConstCastRN5clang4SemaEPNS_4ExprENS_8QualTypeEbRj", "TryConstCast(clang::Sema&, clang::Expr*, clang::QualType, bool, unsigned int&)"},
    {"_Z13TryStaticCastRN5clang4SemaERPNS_4ExprENS_8QualTypeEbRKNS_11SourceRangeERjRNS_8CastKindERN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEE", "TryStaticCast(clang::Sema&, clang::Expr*&, clang::QualType, bool, clang::SourceRange const&, unsigned int&, clang::CastKind&, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u>&)"},
    {"_Z18TryReinterpretCastRN5clang4SemaEPNS_4ExprENS_8QualTypeEbRKNS_11SourceRangeERjRNS_8CastKindE", "TryReinterpretCast(clang::Sema&, clang::Expr*, clang::QualType, bool, clang::SourceRange const&, unsigned int&, clang::CastKind&)"},
    {"_Z18CastsAwayConstnessRN5clang4SemaENS_8QualTypeES2_", "CastsAwayConstness(clang::Sema&, clang::QualType, clang::QualType)"},
    {"_Z17TryStaticDowncastRN5clang4SemaENS_7CanQualINS_4TypeEEES4_bRKNS_11SourceRangeENS_8QualTypeES8_RjRNS_8CastKindERN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEE", "TryStaticDowncast(clang::Sema&, clang::CanQual<clang::Type>, clang::CanQual<clang::Type>, bool, clang::SourceRange const&, clang::QualType, clang::QualType, unsigned int&, clang::CastKind&, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u>&)"},
    {"_Z25NoteAllOverloadCandidatesPN5clang4ExprERNS_4SemaE", "NoteAllOverloadCandidates(clang::Expr*, clang::Sema&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang10QualifiersELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::Qualifiers, false>::grow(unsigned long)"},
    {"_ZN5clang4Sema18computeDeclContextENS_8QualTypeE", "clang::Sema::computeDeclContext(clang::QualType)"},
    {"_ZN5clang4Sema18computeDeclContextERKNS_12CXXScopeSpecEb", "clang::Sema::computeDeclContext(clang::CXXScopeSpec const&, bool)"},
    {"_ZN5clang4Sema25getCurrentInstantiationOfEPNS_19NestedNameSpecifierE", "clang::Sema::getCurrentInstantiationOf(clang::NestedNameSpecifier*)"},
    {"_ZN5clang4Sema25isDependentScopeSpecifierERKNS_12CXXScopeSpecE", "clang::Sema::isDependentScopeSpecifier(clang::CXXScopeSpec const&)"},
    {"_ZN5clang4Sema23isUnknownSpecializationERKNS_12CXXScopeSpecE", "clang::Sema::isUnknownSpecialization(clang::CXXScopeSpec const&)"},
    {"_ZN5clang4Sema26RequireCompleteDeclContextERNS_12CXXScopeSpecEPNS_11DeclContextE", "clang::Sema::RequireCompleteDeclContext(clang::CXXScopeSpec&, clang::DeclContext*)"},
    {"_ZN5clang4Sema28ActOnCXXGlobalScopeSpecifierEPNS_5ScopeENS_14SourceLocationE", "clang::Sema::ActOnCXXGlobalScopeSpecifier(clang::Scope*, clang::SourceLocation)"},
    {"_ZN5clang4Sema31isAcceptableNestedNameSpecifierEPNS_9NamedDeclE", "clang::Sema::isAcceptableNestedNameSpecifier(clang::NamedDecl*)"},
    {"_ZN5clang4Sema25FindFirstQualifierInScopeEPNS_5ScopeEPNS_19NestedNameSpecifierE", "clang::Sema::FindFirstQualifierInScope(clang::Scope*, clang::NestedNameSpecifier*)"},
    {"_ZN5clang4Sema28isNonTypeNestedNameSpecifierEPNS_5ScopeERNS_12CXXScopeSpecENS_14SourceLocationERNS_14IdentifierInfoENS_9OpaquePtrINS_8QualTypeEEE", "clang::Sema::isNonTypeNestedNameSpecifier(clang::Scope*, clang::CXXScopeSpec&, clang::SourceLocation, clang::IdentifierInfo&, clang::OpaquePtr<clang::QualType>)"},
    {"_ZN5clang4Sema27BuildCXXNestedNameSpecifierEPNS_5ScopeERNS_12CXXScopeSpecENS_14SourceLocationES5_RNS_14IdentifierInfoENS_8QualTypeEPNS_9NamedDeclEbb", "clang::Sema::BuildCXXNestedNameSpecifier(clang::Scope*, clang::CXXScopeSpec&, clang::SourceLocation, clang::SourceLocation, clang::IdentifierInfo&, clang::QualType, clang::NamedDecl*, bool, bool)"},
    {"_ZN5clang4Sema27ActOnCXXNestedNameSpecifierEPNS_5ScopeERNS_12CXXScopeSpecENS_14SourceLocationES5_RNS_14IdentifierInfoENS_9OpaquePtrINS_8QualTypeEEEb", "clang::Sema::ActOnCXXNestedNameSpecifier(clang::Scope*, clang::CXXScopeSpec&, clang::SourceLocation, clang::SourceLocation, clang::IdentifierInfo&, clang::OpaquePtr<clang::QualType>, bool)"},
    {"_ZN5clang4Sema25IsInvalidUnlessNestedNameEPNS_5ScopeERNS_12CXXScopeSpecERNS_14IdentifierInfoENS_9OpaquePtrINS_8QualTypeEEEb", "clang::Sema::IsInvalidUnlessNestedName(clang::Scope*, clang::CXXScopeSpec&, clang::IdentifierInfo&, clang::OpaquePtr<clang::QualType>, bool)"},
    {"_ZN5clang4Sema27ActOnCXXNestedNameSpecifierEPNS_5ScopeERKNS_12CXXScopeSpecENS_9OpaquePtrINS_8QualTypeEEENS_11SourceRangeENS_14SourceLocationE", "clang::Sema::ActOnCXXNestedNameSpecifier(clang::Scope*, clang::CXXScopeSpec const&, clang::OpaquePtr<clang::QualType>, clang::SourceRange, clang::SourceLocation)"},
    {"_ZN5clang4Sema26ShouldEnterDeclaratorScopeEPNS_5ScopeERKNS_12CXXScopeSpecE", "clang::Sema::ShouldEnterDeclaratorScope(clang::Scope*, clang::CXXScopeSpec const&)"},
    {"_ZN5clang4Sema28ActOnCXXEnterDeclaratorScopeEPNS_5ScopeERNS_12CXXScopeSpecE", "clang::Sema::ActOnCXXEnterDeclaratorScope(clang::Scope*, clang::CXXScopeSpec&)"},
    {"_ZN5clang4Sema27ActOnCXXExitDeclaratorScopeEPNS_5ScopeERKNS_12CXXScopeSpecE", "clang::Sema::ActOnCXXExitDeclaratorScope(clang::Scope*, clang::CXXScopeSpec const&)"},
    {"_ZNK5clang4Sema30getLocationOfStringLiteralByteEPKNS_13StringLiteralEj", "clang::Sema::getLocationOfStringLiteralByte(clang::StringLiteral const*, unsigned int) const"},
    {"_ZN5clang4Sema19CheckablePrintfAttrEPKNS_10FormatAttrEPNS_8CallExprE", "clang::Sema::CheckablePrintfAttr(clang::FormatAttr const*, clang::CallExpr*)"},
    {"_ZN5clang4Sema24CheckBuiltinFunctionCallEjPNS_8CallExprE", "clang::Sema::CheckBuiltinFunctionCall(unsigned int, clang::CallExpr*)"},
    {"_ZN5clang4Sema22SemaBuiltinConstantArgEPNS_8CallExprEiRN4llvm6APSIntE", "clang::Sema::SemaBuiltinConstantArg(clang::CallExpr*, int, llvm::APSInt&)"},
    {"_ZN5clang4Sema15CheckObjCStringEPNS_4ExprE", "clang::Sema::CheckObjCString(clang::Expr*)"},
    {"_ZN5clang4Sema18SemaBuiltinVAStartEPNS_8CallExprE", "clang::Sema::SemaBuiltinVAStart(clang::CallExpr*)"},
    {"_ZN5clang4Sema27SemaBuiltinUnorderedCompareEPNS_8CallExprE", "clang::Sema::SemaBuiltinUnorderedCompare(clang::CallExpr*)"},
    {"_ZN5clang4Sema27SemaBuiltinFPClassificationEPNS_8CallExprEj", "clang::Sema::SemaBuiltinFPClassification(clang::CallExpr*, unsigned int)"},
    {"_ZN5clang4Sema24SemaBuiltinShuffleVectorEPNS_8CallExprE", "clang::Sema::SemaBuiltinShuffleVector(clang::CallExpr*)"},
    {"_ZN5clang4Sema19SemaBuiltinPrefetchEPNS_8CallExprE", "clang::Sema::SemaBuiltinPrefetch(clang::CallExpr*)"},
    {"_ZN5clang4Sema21SemaBuiltinObjectSizeEPNS_8CallExprE", "clang::Sema::SemaBuiltinObjectSize(clang::CallExpr*)"},
    {"_ZN5clang4Sema18SemaBuiltinLongjmpEPNS_8CallExprE", "clang::Sema::SemaBuiltinLongjmp(clang::CallExpr*)"},
    {"_ZN5clang4Sema27SemaBuiltinAtomicOverloadedENS_12ActionResultIPNS_4ExprELb1EEE", "clang::Sema::SemaBuiltinAtomicOverloaded(clang::ActionResult<clang::Expr*, true>)"},
    {"_ZN5clang4Sema27CheckARMBuiltinFunctionCallEjPNS_8CallExprE", "clang::Sema::CheckARMBuiltinFunctionCall(unsigned int, clang::CallExpr*)"},
    {"_ZN5clang4Sema17CheckFunctionCallEPNS_12FunctionDeclEPNS_8CallExprE", "clang::Sema::CheckFunctionCall(clang::FunctionDecl*, clang::CallExpr*)"},
    {"_ZN5clang4Sema25CheckPrintfScanfArgumentsEPKNS_8CallExprEbjjb", "clang::Sema::CheckPrintfScanfArguments(clang::CallExpr const*, bool, unsigned int, unsigned int, bool)"},
    {"_ZN5clang4Sema21CheckNonNullArgumentsEPKNS_11NonNullAttrEPKNS_8CallExprE", "clang::Sema::CheckNonNullArguments(clang::NonNullAttr const*, clang::CallExpr const*)"},
    {"_ZN5clang4Sema14CheckBlockCallEPNS_9NamedDeclEPNS_8CallExprE", "clang::Sema::CheckBlockCall(clang::NamedDecl*, clang::CallExpr*)"},
    {"_ZN5clang4Sema22SemaCheckStringLiteralEPKNS_4ExprEPKNS_8CallExprEbjjb", "clang::Sema::SemaCheckStringLiteral(clang::Expr const*, clang::CallExpr const*, bool, unsigned int, unsigned int, bool)"},
    {"_ZN5clang4Sema17CheckFormatStringEPKNS_13StringLiteralEPKNS_4ExprEPKNS_8CallExprEbjjb", "clang::Sema::CheckFormatString(clang::StringLiteral const*, clang::Expr const*, clang::CallExpr const*, bool, unsigned int, unsigned int, bool)"},
    {"_ZN12_GLOBAL__N_118CheckFormatHandler14DoneProcessingEv", "(anonymous namespace)::CheckFormatHandler::DoneProcessing()"},
    {"_ZN12_GLOBAL__N_118CheckPrintfHandlerD1Ev", "(anonymous namespace)::CheckPrintfHandler::~CheckPrintfHandler()"},
    {"_ZN12_GLOBAL__N_117CheckScanfHandlerD1Ev", "(anonymous namespace)::CheckScanfHandler::~CheckScanfHandler()"},
    {"_ZN5clang4Sema20CheckReturnStackAddrEPNS_4ExprENS_8QualTypeENS_14SourceLocationE", "clang::Sema::CheckReturnStackAddr(clang::Expr*, clang::QualType, clang::SourceLocation)"},
    {"_Z8EvalAddrPN5clang4ExprERN4llvm15SmallVectorImplIPNS_11DeclRefExprEEE", "EvalAddr(clang::Expr*, llvm::SmallVectorImpl<clang::DeclRefExpr*>&)"},
    {"_Z7EvalValPN5clang4ExprERN4llvm15SmallVectorImplIPNS_11DeclRefExprEEE", "EvalVal(clang::Expr*, llvm::SmallVectorImpl<clang::DeclRefExpr*>&)"},
    {"_ZN5clang4Sema20CheckFloatComparisonENS_14SourceLocationEPNS_4ExprES3_", "clang::Sema::CheckFloatComparison(clang::SourceLocation, clang::Expr*, clang::Expr*)"},
    {"_ZN5clang4Sema24CheckImplicitConversionsEPNS_4ExprENS_14SourceLocationE", "clang::Sema::CheckImplicitConversions(clang::Expr*, clang::SourceLocation)"},
    {"_ZN12_GLOBAL__N_126AnalyzeImplicitConversionsERN5clang4SemaEPNS0_4ExprENS0_14SourceLocationE", "(anonymous namespace)::AnalyzeImplicitConversions(clang::Sema&, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema27CheckBitFieldInitializationENS_14SourceLocationEPNS_9FieldDeclEPNS_4ExprE", "clang::Sema::CheckBitFieldInitialization(clang::SourceLocation, clang::FieldDecl*, clang::Expr*)"},
    {"_ZN12_GLOBAL__N_125AnalyzeBitFieldAssignmentERN5clang4SemaEPNS0_9FieldDeclEPNS0_4ExprENS0_14SourceLocationE", "(anonymous namespace)::AnalyzeBitFieldAssignment(clang::Sema&, clang::FieldDecl*, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema24CheckParmsForFunctionDefEPPNS_11ParmVarDeclES3_b", "clang::Sema::CheckParmsForFunctionDef(clang::ParmVarDecl**, clang::ParmVarDecl**, bool)"},
    {"_ZN5clang4Sema14CheckCastAlignEPNS_4ExprENS_8QualTypeENS_11SourceRangeE", "clang::Sema::CheckCastAlign(clang::Expr*, clang::QualType, clang::SourceRange)"},
    {"_ZN12_GLOBAL__N_124CheckConditionalOperatorERN5clang4SemaEPNS0_19ConditionalOperatorENS0_8QualTypeE", "(anonymous namespace)::CheckConditionalOperator(clang::Sema&, clang::ConditionalOperator*, clang::QualType)"},
    {"_ZN12_GLOBAL__N_123CheckImplicitConversionERN5clang4SemaEPNS0_4ExprENS0_8QualTypeENS0_14SourceLocationEPb", "(anonymous namespace)::CheckImplicitConversion(clang::Sema&, clang::Expr*, clang::QualType, clang::SourceLocation, bool*)"},
    {"_ZN12_GLOBAL__N_130CheckTrivialUnsignedComparisonERN5clang4SemaEPNS0_14BinaryOperatorE", "(anonymous namespace)::CheckTrivialUnsignedComparison(clang::Sema&, clang::BinaryOperator*)"},
    {"_ZN12_GLOBAL__N_112GetExprRangeERN5clang10ASTContextEPNS0_4ExprEj", "(anonymous namespace)::GetExprRange(clang::ASTContext&, clang::Expr*, unsigned int)"},
    {"_ZN12_GLOBAL__N_113GetValueRangeERN5clang10ASTContextERNS0_7APValueENS0_8QualTypeEj", "(anonymous namespace)::GetValueRange(clang::ASTContext&, clang::APValue&, clang::QualType, unsigned int)"},
    {"_ZN12_GLOBAL__N_18IntRange14forValueOfTypeERN5clang10ASTContextENS1_8QualTypeE", "(anonymous namespace)::IntRange::forValueOfType(clang::ASTContext&, clang::QualType)"},
    {"_ZN12_GLOBAL__N_113GetValueRangeERN5clang10ASTContextERN4llvm6APSIntEj", "(anonymous namespace)::GetValueRange(clang::ASTContext&, llvm::APSInt&, unsigned int)"},
    {"_ZN12_GLOBAL__N_16IsZeroERN5clang4SemaEPNS0_4ExprE", "(anonymous namespace)::IsZero(clang::Sema&, clang::Expr*)"},
    {"_ZN12_GLOBAL__N_115DiagnoseImpCastERN5clang4SemaEPNS0_4ExprENS0_8QualTypeENS0_14SourceLocationEj", "(anonymous namespace)::DiagnoseImpCast(clang::Sema&, clang::Expr*, clang::QualType, clang::SourceLocation, unsigned int)"},
    {"_ZN12_GLOBAL__N_120IsSameFloatAfterCastERKN5clang7APValueERKN4llvm12fltSemanticsES7_", "(anonymous namespace)::IsSameFloatAfterCast(clang::APValue const&, llvm::fltSemantics const&, llvm::fltSemantics const&)"},
    {"_ZN12_GLOBAL__N_123CheckConditionalOperandERN5clang4SemaEPNS0_4ExprENS0_8QualTypeENS0_14SourceLocationERb", "(anonymous namespace)::CheckConditionalOperand(clang::Sema&, clang::Expr*, clang::QualType, clang::SourceLocation, bool&)"},
    {"_ZN12_GLOBAL__N_117CheckScanfHandlerD0Ev", "(anonymous namespace)::CheckScanfHandler::~CheckScanfHandler()"},
    {"_ZN12_GLOBAL__N_118CheckFormatHandler14HandleNullCharEPKc", "(anonymous namespace)::CheckFormatHandler::HandleNullChar(char const*)"},
    {"_ZN12_GLOBAL__N_118CheckFormatHandler21HandleInvalidPositionEPKcjN5clang21analyze_format_string15PositionContextE", "(anonymous namespace)::CheckFormatHandler::HandleInvalidPosition(char const*, unsigned int, clang::analyze_format_string::PositionContext)"},
    {"_ZN12_GLOBAL__N_118CheckFormatHandler18HandleZeroPositionEPKcj", "(anonymous namespace)::CheckFormatHandler::HandleZeroPosition(char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_118CheckFormatHandler25HandleIncompleteSpecifierEPKcj", "(anonymous namespace)::CheckFormatHandler::HandleIncompleteSpecifier(char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_117CheckScanfHandler37HandleInvalidScanfConversionSpecifierERKN5clang13analyze_scanf14ScanfSpecifierEPKcj", "(anonymous namespace)::CheckScanfHandler::HandleInvalidScanfConversionSpecifier(clang::analyze_scanf::ScanfSpecifier const&, char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_117CheckScanfHandler20HandleScanfSpecifierERKN5clang13analyze_scanf14ScanfSpecifierEPKcj", "(anonymous namespace)::CheckScanfHandler::HandleScanfSpecifier(clang::analyze_scanf::ScanfSpecifier const&, char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_117CheckScanfHandler24HandleIncompleteScanListEPKcS2_", "(anonymous namespace)::CheckScanfHandler::HandleIncompleteScanList(char const*, char const*)"},
    {"_ZN12_GLOBAL__N_118CheckFormatHandler12CheckNumArgsERKN5clang21analyze_format_string15FormatSpecifierERKNS2_19ConversionSpecifierEPKcjj", "(anonymous namespace)::CheckFormatHandler::CheckNumArgs(clang::analyze_format_string::FormatSpecifier const&, clang::analyze_format_string::ConversionSpecifier const&, char const*, unsigned int, unsigned int)"},
    {"_ZN12_GLOBAL__N_118CheckFormatHandler32HandleInvalidConversionSpecifierEjN5clang14SourceLocationEPKcjS4_j", "(anonymous namespace)::CheckFormatHandler::HandleInvalidConversionSpecifier(unsigned int, clang::SourceLocation, char const*, unsigned int, char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_118CheckFormatHandlerD1Ev", "(anonymous namespace)::CheckFormatHandler::~CheckFormatHandler()"},
    {"_ZN12_GLOBAL__N_118CheckFormatHandlerD0Ev", "(anonymous namespace)::CheckFormatHandler::~CheckFormatHandler()"},
    {"_ZN12_GLOBAL__N_118CheckPrintfHandlerD0Ev", "(anonymous namespace)::CheckPrintfHandler::~CheckPrintfHandler()"},
    {"_ZN12_GLOBAL__N_118CheckPrintfHandler38HandleInvalidPrintfConversionSpecifierERKN5clang14analyze_printf15PrintfSpecifierEPKcj", "(anonymous namespace)::CheckPrintfHandler::HandleInvalidPrintfConversionSpecifier(clang::analyze_printf::PrintfSpecifier const&, char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_118CheckPrintfHandler21HandlePrintfSpecifierERKN5clang14analyze_printf15PrintfSpecifierEPKcj", "(anonymous namespace)::CheckPrintfHandler::HandlePrintfSpecifier(clang::analyze_printf::PrintfSpecifier const&, char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_118CheckPrintfHandler12HandleAmountERKN5clang21analyze_format_string14OptionalAmountEjPKcj", "(anonymous namespace)::CheckPrintfHandler::HandleAmount(clang::analyze_format_string::OptionalAmount const&, unsigned int, char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_118CheckPrintfHandler19HandleInvalidAmountERKN5clang14analyze_printf15PrintfSpecifierERKNS1_21analyze_format_string14OptionalAmountEjPKcj", "(anonymous namespace)::CheckPrintfHandler::HandleInvalidAmount(clang::analyze_printf::PrintfSpecifier const&, clang::analyze_format_string::OptionalAmount const&, unsigned int, char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_118CheckPrintfHandler10HandleFlagERKN5clang14analyze_printf15PrintfSpecifierERKNS1_21analyze_format_string12OptionalFlagEPKcj", "(anonymous namespace)::CheckPrintfHandler::HandleFlag(clang::analyze_printf::PrintfSpecifier const&, clang::analyze_format_string::OptionalFlag const&, char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_118CheckPrintfHandler17HandleIgnoredFlagERKN5clang14analyze_printf15PrintfSpecifierERKNS1_21analyze_format_string12OptionalFlagES9_PKcj", "(anonymous namespace)::CheckPrintfHandler::HandleIgnoredFlag(clang::analyze_printf::PrintfSpecifier const&, clang::analyze_format_string::OptionalFlag const&, clang::analyze_format_string::OptionalFlag const&, char const*, unsigned int)"},
    {"_ZNK5clang4Decl7getAttrINS_13FormatArgAttrEEEPT_v", "clang::FormatArgAttr* clang::Decl::getAttr<clang::FormatArgAttr>() const"},
    {"_ZN4llvm11SmallVectorItLj128EEC2EjRKt", "llvm::SmallVector<unsigned short, 128u>::SmallVector(unsigned int, unsigned short const&)"},
    {"_ZN5clang21analyze_format_string19FormatStringHandler38HandleInvalidPrintfConversionSpecifierERKNS_14analyze_printf15PrintfSpecifierEPKcj", "clang::analyze_format_string::FormatStringHandler::HandleInvalidPrintfConversionSpecifier(clang::analyze_printf::PrintfSpecifier const&, char const*, unsigned int)"},
    {"_ZN5clang21analyze_format_string19FormatStringHandler21HandlePrintfSpecifierERKNS_14analyze_printf15PrintfSpecifierEPKcj", "clang::analyze_format_string::FormatStringHandler::HandlePrintfSpecifier(clang::analyze_printf::PrintfSpecifier const&, char const*, unsigned int)"},
    {"_ZN5clang21analyze_format_string19FormatStringHandler37HandleInvalidScanfConversionSpecifierERKNS_13analyze_scanf14ScanfSpecifierEPKcj", "clang::analyze_format_string::FormatStringHandler::HandleInvalidScanfConversionSpecifier(clang::analyze_scanf::ScanfSpecifier const&, char const*, unsigned int)"},
    {"_ZN5clang21analyze_format_string19FormatStringHandler20HandleScanfSpecifierERKNS_13analyze_scanf14ScanfSpecifierEPKcj", "clang::analyze_format_string::FormatStringHandler::HandleScanfSpecifier(clang::analyze_scanf::ScanfSpecifier const&, char const*, unsigned int)"},
    {"_ZN5clang21analyze_format_string19FormatStringHandler24HandleIncompleteScanListEPKcS3_", "clang::analyze_format_string::FormatStringHandler::HandleIncompleteScanList(char const*, char const*)"},
    {"_ZN5clang21analyze_format_string19FormatStringHandler14HandleNullCharEPKc", "clang::analyze_format_string::FormatStringHandler::HandleNullChar(char const*)"},
    {"_ZN5clang21analyze_format_string19FormatStringHandler21HandleInvalidPositionEPKcjNS0_15PositionContextE", "clang::analyze_format_string::FormatStringHandler::HandleInvalidPosition(char const*, unsigned int, clang::analyze_format_string::PositionContext)"},
    {"_ZN5clang21analyze_format_string19FormatStringHandler18HandleZeroPositionEPKcj", "clang::analyze_format_string::FormatStringHandler::HandleZeroPosition(char const*, unsigned int)"},
    {"_ZN5clang21analyze_format_string19FormatStringHandler25HandleIncompleteSpecifierEPKcj", "clang::analyze_format_string::FormatStringHandler::HandleIncompleteSpecifier(char const*, unsigned int)"},
    {"_ZN5clang22getSimplifiedTypeClassENS_7CanQualINS_4TypeEEE", "clang::getSimplifiedTypeClass(clang::CanQual<clang::Type>)"},
    {"_ZN5clang16getDeclUsageTypeERNS_10ASTContextEPNS_9NamedDeclE", "clang::getDeclUsageType(clang::ASTContext&, clang::NamedDecl*)"},
    {"_Z23GetCompletionTypeStringN5clang8QualTypeERNS_10ASTContextERNS_23CodeCompletionAllocatorE", "GetCompletionTypeString(clang::QualType, clang::ASTContext&, clang::CodeCompletionAllocator&)"},
    {"_ZN5clang20CodeCompletionResult26CreateCodeCompletionStringERNS_4SemaERNS_23CodeCompletionAllocatorE", "clang::CodeCompletionResult::CreateCodeCompletionString(clang::Sema&, clang::CodeCompletionAllocator&)"},
    {"_Z18AddResultTypeChunkRN5clang10ASTContextEPNS_9NamedDeclERNS_21CodeCompletionBuilderE", "AddResultTypeChunk(clang::ASTContext&, clang::NamedDecl*, clang::CodeCompletionBuilder&)"},
    {"_Z30AddQualifierToCompletionStringRN5clang21CodeCompletionBuilderEPNS_19NestedNameSpecifierEbRNS_10ASTContextE", "AddQualifierToCompletionString(clang::CodeCompletionBuilder&, clang::NestedNameSpecifier*, bool, clang::ASTContext&)"},
    {"_Z17AddTypedNameChunkRN5clang10ASTContextEPNS_9NamedDeclERNS_21CodeCompletionBuilderE", "AddTypedNameChunk(clang::ASTContext&, clang::NamedDecl*, clang::CodeCompletionBuilder&)"},
    {"_Z26AddFunctionParameterChunksRN5clang10ASTContextEPNS_12FunctionDeclERNS_21CodeCompletionBuilderEjb", "AddFunctionParameterChunks(clang::ASTContext&, clang::FunctionDecl*, clang::CodeCompletionBuilder&, unsigned int, bool)"},
    {"_Z38AddFunctionTypeQualsToCompletionStringRN5clang21CodeCompletionBuilderEPNS_12FunctionDeclE", "AddFunctionTypeQualsToCompletionString(clang::CodeCompletionBuilder&, clang::FunctionDecl*)"},
    {"_Z26AddTemplateParameterChunksRN5clang10ASTContextEPNS_12TemplateDeclERNS_21CodeCompletionBuilderEjjb", "AddTemplateParameterChunks(clang::ASTContext&, clang::TemplateDecl*, clang::CodeCompletionBuilder&, unsigned int, unsigned int, bool)"},
    {"_Z23FormatFunctionParameterRN5clang10ASTContextEPNS_11ParmVarDeclEb", "FormatFunctionParameter(clang::ASTContext&, clang::ParmVarDecl*, bool)"},
    {"_Z16MaybeAddSentinelRN5clang10ASTContextEPNS_9NamedDeclERNS_21CodeCompletionBuilderE", "MaybeAddSentinel(clang::ASTContext&, clang::NamedDecl*, clang::CodeCompletionBuilder&)"},
    {"_ZNK5clang20CodeCompleteConsumer17OverloadCandidate21CreateSignatureStringEjRNS_4SemaERNS_23CodeCompletionAllocatorE", "clang::CodeCompleteConsumer::OverloadCandidate::CreateSignatureString(unsigned int, clang::Sema&, clang::CodeCompletionAllocator&) const"},
    {"_ZN5clang21getMacroUsagePriorityEN4llvm9StringRefERKNS_11LangOptionsEb", "clang::getMacroUsagePriority(llvm::StringRef, clang::LangOptions const&, bool)"},
    {"_ZN5clang20getCursorKindForDeclEPNS_4DeclE", "clang::getCursorKindForDecl(clang::Decl*)"},
    {"_ZN5clang4Sema24CodeCompleteOrdinaryNameEPNS_5ScopeENS0_23ParserCompletionContextE", "clang::Sema::CodeCompleteOrdinaryName(clang::Scope*, clang::Sema::ParserCompletionContext)"},
    {"_ZN12_GLOBAL__N_113ResultBuilder13EnterNewScopeEv", "(anonymous namespace)::ResultBuilder::EnterNewScope()"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder22IsOrdinaryNonValueNameEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsOrdinaryNonValueName(clang::NamedDecl*) const"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder14IsOrdinaryNameEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsOrdinaryName(clang::NamedDecl*) const"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder21IsOrdinaryNonTypeNameEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsOrdinaryNonTypeName(clang::NamedDecl*) const"},
    {"_Z21MaybeAddOverrideCallsRN5clang4SemaEPNS_11DeclContextERN12_GLOBAL__N_113ResultBuilderE", "MaybeAddOverrideCalls(clang::Sema&, clang::DeclContext*, (anonymous namespace)::ResultBuilder&)"},
    {"_Z22AddOrdinaryNameResultsN5clang4Sema23ParserCompletionContextEPNS_5ScopeERS0_RN12_GLOBAL__N_113ResultBuilderE", "AddOrdinaryNameResults(clang::Sema::ParserCompletionContext, clang::Scope*, clang::Sema&, (anonymous namespace)::ResultBuilder&)"},
    {"_ZN12_GLOBAL__N_113ResultBuilder9ExitScopeEv", "(anonymous namespace)::ResultBuilder::ExitScope()"},
    {"_Z24AddPrettyFunctionResultsRKN5clang11LangOptionsERN12_GLOBAL__N_113ResultBuilderE", "AddPrettyFunctionResults(clang::LangOptions const&, (anonymous namespace)::ResultBuilder&)"},
    {"_Z15AddMacroResultsRN5clang12PreprocessorERN12_GLOBAL__N_113ResultBuilderEb", "AddMacroResults(clang::Preprocessor&, (anonymous namespace)::ResultBuilder&, bool)"},
    {"_ZN12_GLOBAL__N_126CodeCompletionDeclConsumerD1Ev", "(anonymous namespace)::CodeCompletionDeclConsumer::~CodeCompletionDeclConsumer()"},
    {"_ZN5clang4Sema20CodeCompleteDeclSpecEPNS_5ScopeERNS_8DeclSpecEbb", "clang::Sema::CodeCompleteDeclSpec(clang::Scope*, clang::DeclSpec&, bool, bool)"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder21IsImpossibleToSatisfyEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsImpossibleToSatisfy(clang::NamedDecl*) const"},
    {"_Z26AddClassMessageCompletionsRN5clang4SemaEPNS_5ScopeENS_9OpaquePtrINS_8QualTypeEEEPPNS_14IdentifierInfoEjbbRN12_GLOBAL__N_113ResultBuilderE", "AddClassMessageCompletions(clang::Sema&, clang::Scope*, clang::OpaquePtr<clang::QualType>, clang::IdentifierInfo**, unsigned int, bool, bool, (anonymous namespace)::ResultBuilder&)"},
    {"_ZN5clang4Sema22CodeCompleteExpressionEPNS_5ScopeERKNS0_26CodeCompleteExpressionDataE", "clang::Sema::CodeCompleteExpression(clang::Scope*, clang::Sema::CodeCompleteExpressionData const&)"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder16IsObjCCollectionEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsObjCCollection(clang::NamedDecl*) const"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder23IsIntegralConstantValueEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsIntegralConstantValue(clang::NamedDecl*) const"},
    {"_ZN5clang4Sema29CodeCompletePostfixExpressionEPNS_5ScopeENS_12ActionResultIPNS_4ExprELb1EEE", "clang::Sema::CodeCompletePostfixExpression(clang::Scope*, clang::ActionResult<clang::Expr*, true>)"},
    {"_ZN5clang4Sema31CodeCompleteObjCInstanceMessageEPNS_5ScopeEPNS_4ExprEPPNS_14IdentifierInfoEjbPNS_17ObjCInterfaceDeclE", "clang::Sema::CodeCompleteObjCInstanceMessage(clang::Scope*, clang::Expr*, clang::IdentifierInfo**, unsigned int, bool, clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang4Sema31CodeCompleteMemberReferenceExprEPNS_5ScopeEPNS_4ExprENS_14SourceLocationEb", "clang::Sema::CodeCompleteMemberReferenceExpr(clang::Scope*, clang::Expr*, clang::SourceLocation, bool)"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder8IsMemberEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsMember(clang::NamedDecl*) const"},
    {"_Z17AddObjCPropertiesPN5clang17ObjCContainerDeclEbPNS_11DeclContextERN4llvm11SmallPtrSetIPNS_14IdentifierInfoELj16EEERN12_GLOBAL__N_113ResultBuilderE", "AddObjCProperties(clang::ObjCContainerDecl*, bool, clang::DeclContext*, llvm::SmallPtrSet<clang::IdentifierInfo*, 16u>&, (anonymous namespace)::ResultBuilder&)"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder10IsObjCIvarEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsObjCIvar(clang::NamedDecl*) const"},
    {"_ZN5clang4Sema15CodeCompleteTagEPNS_5ScopeEj", "clang::Sema::CodeCompleteTag(clang::Scope*, unsigned int)"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder6IsEnumEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsEnum(clang::NamedDecl*) const"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder7IsUnionEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsUnion(clang::NamedDecl*) const"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder15IsClassOrStructEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsClassOrStruct(clang::NamedDecl*) const"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder21IsNestedNameSpecifierEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsNestedNameSpecifier(clang::NamedDecl*) const"},
    {"_ZN5clang4Sema26CodeCompleteTypeQualifiersERNS_8DeclSpecE", "clang::Sema::CodeCompleteTypeQualifiers(clang::DeclSpec&)"},
    {"_ZN5clang4Sema16CodeCompleteCaseEPNS_5ScopeE", "clang::Sema::CodeCompleteCase(clang::Scope*)"},
    {"_Z24getRequiredQualificationRN5clang10ASTContextEPNS_11DeclContextES3_", "getRequiredQualification(clang::ASTContext&, clang::DeclContext*, clang::DeclContext*)"},
    {"_ZN12_GLOBAL__N_113ResultBuilder9AddResultEN5clang20CodeCompletionResultEPNS1_11DeclContextEPNS1_9NamedDeclEb", "(anonymous namespace)::ResultBuilder::AddResult(clang::CodeCompletionResult, clang::DeclContext*, clang::NamedDecl*, bool)"},
    {"_ZN5clang4Sema16CodeCompleteCallEPNS_5ScopeEPNS_4ExprEPS4_j", "clang::Sema::CodeCompleteCall(clang::Scope*, clang::Expr*, clang::Expr**, unsigned int)"},
    {"_ZN5clang4Sema23CodeCompleteInitializerEPNS_5ScopeEPNS_4DeclE", "clang::Sema::CodeCompleteInitializer(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema18CodeCompleteReturnEPNS_5ScopeE", "clang::Sema::CodeCompleteReturn(clang::Scope*)"},
    {"_ZN5clang4Sema25CodeCompleteAssignmentRHSEPNS_5ScopeEPNS_4ExprE", "clang::Sema::CodeCompleteAssignmentRHS(clang::Scope*, clang::Expr*)"},
    {"_ZN5clang4Sema23CodeCompleteQualifiedIdEPNS_5ScopeERNS_12CXXScopeSpecEb", "clang::Sema::CodeCompleteQualifiedId(clang::Scope*, clang::CXXScopeSpec&, bool)"},
    {"_ZN5clang4Sema17CodeCompleteUsingEPNS_5ScopeE", "clang::Sema::CodeCompleteUsing(clang::Scope*)"},
    {"_ZN5clang4Sema26CodeCompleteUsingDirectiveEPNS_5ScopeE", "clang::Sema::CodeCompleteUsingDirective(clang::Scope*)"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder18IsNamespaceOrAliasEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsNamespaceOrAlias(clang::NamedDecl*) const"},
    {"_ZN5clang4Sema25CodeCompleteNamespaceDeclEPNS_5ScopeE", "clang::Sema::CodeCompleteNamespaceDecl(clang::Scope*)"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder11IsNamespaceEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsNamespace(clang::NamedDecl*) const"},
    {"_ZN5clang4Sema30CodeCompleteNamespaceAliasDeclEPNS_5ScopeE", "clang::Sema::CodeCompleteNamespaceAliasDecl(clang::Scope*)"},
    {"_ZN5clang4Sema24CodeCompleteOperatorNameEPNS_5ScopeE", "clang::Sema::CodeCompleteOperatorName(clang::Scope*)"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder6IsTypeEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsType(clang::NamedDecl*) const"},
    {"_Z23AddTypeSpecifierResultsRKN5clang11LangOptionsERN12_GLOBAL__N_113ResultBuilderE", "AddTypeSpecifierResults(clang::LangOptions const&, (anonymous namespace)::ResultBuilder&)"},
    {"_ZN5clang4Sema34CodeCompleteConstructorInitializerEPNS_4DeclEPPNS_18CXXCtorInitializerEj", "clang::Sema::CodeCompleteConstructorInitializer(clang::Decl*, clang::CXXCtorInitializer**, unsigned int)"},
    {"_ZN5clang4Sema27CodeCompleteObjCAtDirectiveEPNS_5ScopeEPNS_4DeclEb", "clang::Sema::CodeCompleteObjCAtDirective(clang::Scope*, clang::Decl*, bool)"},
    {"_Z28AddObjCImplementationResultsRKN5clang11LangOptionsERN12_GLOBAL__N_113ResultBuilderEb", "AddObjCImplementationResults(clang::LangOptions const&, (anonymous namespace)::ResultBuilder&, bool)"},
    {"_Z23AddObjCInterfaceResultsRKN5clang11LangOptionsERN12_GLOBAL__N_113ResultBuilderEb", "AddObjCInterfaceResults(clang::LangOptions const&, (anonymous namespace)::ResultBuilder&, bool)"},
    {"_Z22AddObjCTopLevelResultsRN12_GLOBAL__N_113ResultBuilderEb", "AddObjCTopLevelResults((anonymous namespace)::ResultBuilder&, bool)"},
    {"_ZN5clang4Sema28CodeCompleteObjCAtVisibilityEPNS_5ScopeE", "clang::Sema::CodeCompleteObjCAtVisibility(clang::Scope*)"},
    {"_Z24AddObjCVisibilityResultsRKN5clang11LangOptionsERN12_GLOBAL__N_113ResultBuilderEb", "AddObjCVisibilityResults(clang::LangOptions const&, (anonymous namespace)::ResultBuilder&, bool)"},
    {"_ZN5clang4Sema27CodeCompleteObjCAtStatementEPNS_5ScopeE", "clang::Sema::CodeCompleteObjCAtStatement(clang::Scope*)"},
    {"_Z23AddObjCStatementResultsRN12_GLOBAL__N_113ResultBuilderEb", "AddObjCStatementResults((anonymous namespace)::ResultBuilder&, bool)"},
    {"_Z24AddObjCExpressionResultsRN12_GLOBAL__N_113ResultBuilderEb", "AddObjCExpressionResults((anonymous namespace)::ResultBuilder&, bool)"},
    {"_ZN5clang4Sema28CodeCompleteObjCAtExpressionEPNS_5ScopeE", "clang::Sema::CodeCompleteObjCAtExpression(clang::Scope*)"},
    {"_ZN5clang4Sema29CodeCompleteObjCPropertyFlagsEPNS_5ScopeERNS_12ObjCDeclSpecE", "clang::Sema::CodeCompleteObjCPropertyFlags(clang::Scope*, clang::ObjCDeclSpec&)"},
    {"_ZN5clang4Sema30CodeCompleteObjCPropertyGetterEPNS_5ScopeEPNS_4DeclE", "clang::Sema::CodeCompleteObjCPropertyGetter(clang::Scope*, clang::Decl*)"},
    {"_Z14AddObjCMethodsPN5clang17ObjCContainerDeclEb14ObjCMethodKindPPNS_14IdentifierInfoEjPNS_11DeclContextERN4llvm11SmallPtrSetINS_8SelectorELj16EEEbRN12_GLOBAL__N_113ResultBuilderEb", "AddObjCMethods(clang::ObjCContainerDecl*, bool, ObjCMethodKind, clang::IdentifierInfo**, unsigned int, clang::DeclContext*, llvm::SmallPtrSet<clang::Selector, 16u>&, bool, (anonymous namespace)::ResultBuilder&, bool)"},
    {"_ZN5clang4Sema30CodeCompleteObjCPropertySetterEPNS_5ScopeEPNS_4DeclE", "clang::Sema::CodeCompleteObjCPropertySetter(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema27CodeCompleteObjCPassingTypeEPNS_5ScopeERNS_12ObjCDeclSpecE", "clang::Sema::CodeCompleteObjCPassingType(clang::Scope*, clang::ObjCDeclSpec&)"},
    {"_ZN5clang4Sema31CodeCompleteObjCMessageReceiverEPNS_5ScopeE", "clang::Sema::CodeCompleteObjCMessageReceiver(clang::Scope*)"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder21IsObjCMessageReceiverEPN5clang9NamedDeclE", "(anonymous namespace)::ResultBuilder::IsObjCMessageReceiver(clang::NamedDecl*) const"},
    {"_Z22AddSuperSendCompletionRN5clang4SemaEbPPNS_14IdentifierInfoEjRN12_GLOBAL__N_113ResultBuilderE", "AddSuperSendCompletion(clang::Sema&, bool, clang::IdentifierInfo**, unsigned int, (anonymous namespace)::ResultBuilder&)"},
    {"_ZN5clang4Sema28CodeCompleteObjCSuperMessageEPNS_5ScopeENS_14SourceLocationEPPNS_14IdentifierInfoEjb", "clang::Sema::CodeCompleteObjCSuperMessage(clang::Scope*, clang::SourceLocation, clang::IdentifierInfo**, unsigned int, bool)"},
    {"_ZN5clang4Sema28CodeCompleteObjCClassMessageEPNS_5ScopeENS_9OpaquePtrINS_8QualTypeEEEPPNS_14IdentifierInfoEjbb", "clang::Sema::CodeCompleteObjCClassMessage(clang::Scope*, clang::OpaquePtr<clang::QualType>, clang::IdentifierInfo**, unsigned int, bool, bool)"},
    {"_Z38getPreferredArgumentTypeForMessageSendRN12_GLOBAL__N_113ResultBuilderEj", "getPreferredArgumentTypeForMessageSend((anonymous namespace)::ResultBuilder&, unsigned int)"},
    {"_ZN12_GLOBAL__N_113ResultBuilder14MaybeAddResultEN5clang20CodeCompletionResultEPNS1_11DeclContextE", "(anonymous namespace)::ResultBuilder::MaybeAddResult(clang::CodeCompletionResult, clang::DeclContext*)"},
    {"_ZN5clang4Sema29CodeCompleteObjCForCollectionEPNS_5ScopeENS_9OpaquePtrINS_12DeclGroupRefEEE", "clang::Sema::CodeCompleteObjCForCollection(clang::Scope*, clang::OpaquePtr<clang::DeclGroupRef>)"},
    {"_ZN5clang4Sema24CodeCompleteObjCSelectorEPNS_5ScopeEPPNS_14IdentifierInfoEj", "clang::Sema::CodeCompleteObjCSelector(clang::Scope*, clang::IdentifierInfo**, unsigned int)"},
    {"_Z24isAcceptableObjCSelectorN5clang8SelectorE14ObjCMethodKindPPNS_14IdentifierInfoEjb", "isAcceptableObjCSelector(clang::Selector, ObjCMethodKind, clang::IdentifierInfo**, unsigned int, bool)"},
    {"_ZN5clang4Sema34CodeCompleteObjCProtocolReferencesEPSt4pairIPNS_14IdentifierInfoENS_14SourceLocationEEj", "clang::Sema::CodeCompleteObjCProtocolReferences(std::pair<clang::IdentifierInfo*, clang::SourceLocation>*, unsigned int)"},
    {"_Z18AddProtocolResultsPN5clang11DeclContextES1_bRN12_GLOBAL__N_113ResultBuilderE", "AddProtocolResults(clang::DeclContext*, clang::DeclContext*, bool, (anonymous namespace)::ResultBuilder&)"},
    {"_ZN5clang4Sema28CodeCompleteObjCProtocolDeclEPNS_5ScopeE", "clang::Sema::CodeCompleteObjCProtocolDecl(clang::Scope*)"},
    {"_ZN5clang4Sema29CodeCompleteObjCInterfaceDeclEPNS_5ScopeE", "clang::Sema::CodeCompleteObjCInterfaceDecl(clang::Scope*)"},
    {"_Z19AddInterfaceResultsPN5clang11DeclContextES1_bbRN12_GLOBAL__N_113ResultBuilderE", "AddInterfaceResults(clang::DeclContext*, clang::DeclContext*, bool, bool, (anonymous namespace)::ResultBuilder&)"},
    {"_ZN5clang4Sema26CodeCompleteObjCSuperclassEPNS_5ScopeEPNS_14IdentifierInfoENS_14SourceLocationE", "clang::Sema::CodeCompleteObjCSuperclass(clang::Scope*, clang::IdentifierInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema34CodeCompleteObjCImplementationDeclEPNS_5ScopeE", "clang::Sema::CodeCompleteObjCImplementationDecl(clang::Scope*)"},
    {"_ZN5clang4Sema33CodeCompleteObjCInterfaceCategoryEPNS_5ScopeEPNS_14IdentifierInfoENS_14SourceLocationE", "clang::Sema::CodeCompleteObjCInterfaceCategory(clang::Scope*, clang::IdentifierInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema38CodeCompleteObjCImplementationCategoryEPNS_5ScopeEPNS_14IdentifierInfoENS_14SourceLocationE", "clang::Sema::CodeCompleteObjCImplementationCategory(clang::Scope*, clang::IdentifierInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema34CodeCompleteObjCPropertyDefinitionEPNS_5ScopeEPNS_4DeclE", "clang::Sema::CodeCompleteObjCPropertyDefinition(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema38CodeCompleteObjCPropertySynthesizeIvarEPNS_5ScopeEPNS_14IdentifierInfoEPNS_4DeclE", "clang::Sema::CodeCompleteObjCPropertySynthesizeIvar(clang::Scope*, clang::IdentifierInfo*, clang::Decl*)"},
    {"_ZN5clang4Sema26CodeCompleteObjCMethodDeclEPNS_5ScopeEbNS_9OpaquePtrINS_8QualTypeEEEPNS_4DeclE", "clang::Sema::CodeCompleteObjCMethodDecl(clang::Scope*, bool, clang::OpaquePtr<clang::QualType>, clang::Decl*)"},
    {"_Z24FindImplementableMethodsRN5clang10ASTContextEPNS_17ObjCContainerDeclEbNS_8QualTypeERN4llvm8DenseMapINS_8SelectorESt4pairIPNS_14ObjCMethodDeclEbENS5_12DenseMapInfoIS7_EENSC_ISB_EEEEb", "FindImplementableMethods(clang::ASTContext&, clang::ObjCContainerDecl*, bool, clang::QualType, llvm::DenseMap<clang::Selector, std::pair<clang::ObjCMethodDecl*, bool>, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<std::pair<clang::ObjCMethodDecl*, bool>>>&, bool)"},
    {"_ZN5clang4Sema34CodeCompleteObjCMethodDeclSelectorEPNS_5ScopeEbbNS_9OpaquePtrINS_8QualTypeEEEPPNS_14IdentifierInfoEj", "clang::Sema::CodeCompleteObjCMethodDeclSelector(clang::Scope*, bool, bool, clang::OpaquePtr<clang::QualType>, clang::IdentifierInfo**, unsigned int)"},
    {"_ZN5clang4Sema33CodeCompletePreprocessorDirectiveEb", "clang::Sema::CodeCompletePreprocessorDirective(bool)"},
    {"_ZN5clang4Sema46CodeCompleteInPreprocessorConditionalExclusionEPNS_5ScopeE", "clang::Sema::CodeCompleteInPreprocessorConditionalExclusion(clang::Scope*)"},
    {"_ZN5clang4Sema33CodeCompletePreprocessorMacroNameEb", "clang::Sema::CodeCompletePreprocessorMacroName(bool)"},
    {"_ZN5clang4Sema34CodeCompletePreprocessorExpressionEv", "clang::Sema::CodeCompletePreprocessorExpression()"},
    {"_ZN5clang4Sema37CodeCompletePreprocessorMacroArgumentEPNS_5ScopeEPNS_14IdentifierInfoEPNS_9MacroInfoEj", "clang::Sema::CodeCompletePreprocessorMacroArgument(clang::Scope*, clang::IdentifierInfo*, clang::MacroInfo*, unsigned int)"},
    {"_ZN5clang4Sema27CodeCompleteNaturalLanguageEv", "clang::Sema::CodeCompleteNaturalLanguage()"},
    {"_ZN5clang4Sema27GatherGlobalCodeCompletionsERNS_23CodeCompletionAllocatorERN4llvm15SmallVectorImplINS_20CodeCompletionResultEEE", "clang::Sema::GatherGlobalCodeCompletions(clang::CodeCompletionAllocator&, llvm::SmallVectorImpl<clang::CodeCompletionResult>&)"},
    {"_ZSt21__inplace_stable_sortIPN5clang17OverloadCandidateEN12_GLOBAL__N_125IsBetterOverloadCandidateEEvT_S5_T0_", "void std::__inplace_stable_sort<clang::OverloadCandidate*, (anonymous namespace)::IsBetterOverloadCandidate>(clang::OverloadCandidate*, clang::OverloadCandidate*, (anonymous namespace)::IsBetterOverloadCandidate)"},
    {"_ZSt22__stable_sort_adaptiveIPN5clang17OverloadCandidateES2_lN12_GLOBAL__N_125IsBetterOverloadCandidateEEvT_S5_T0_T1_T2_", "void std::__stable_sort_adaptive<clang::OverloadCandidate*, clang::OverloadCandidate*, long, (anonymous namespace)::IsBetterOverloadCandidate>(clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, long, (anonymous namespace)::IsBetterOverloadCandidate)"},
    {"_ZSt24__merge_sort_with_bufferIPN5clang17OverloadCandidateES2_N12_GLOBAL__N_125IsBetterOverloadCandidateEEvT_S5_T0_T1_", "void std::__merge_sort_with_buffer<clang::OverloadCandidate*, clang::OverloadCandidate*, (anonymous namespace)::IsBetterOverloadCandidate>(clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, (anonymous namespace)::IsBetterOverloadCandidate)"},
    {"_ZSt16__merge_adaptiveIPN5clang17OverloadCandidateElS2_N12_GLOBAL__N_125IsBetterOverloadCandidateEEvT_S5_S5_T0_S6_T1_S6_T2_", "void std::__merge_adaptive<clang::OverloadCandidate*, long, clang::OverloadCandidate*, (anonymous namespace)::IsBetterOverloadCandidate>(clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, long, long, clang::OverloadCandidate*, long, (anonymous namespace)::IsBetterOverloadCandidate)"},
    {"_ZSt5mergeIPN5clang17OverloadCandidateES2_S2_N12_GLOBAL__N_125IsBetterOverloadCandidateEET1_T_S6_T0_S7_S5_T2_", "clang::OverloadCandidate* std::merge<clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, (anonymous namespace)::IsBetterOverloadCandidate>(clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, (anonymous namespace)::IsBetterOverloadCandidate)"},
    {"_ZSt16__insertion_sortIPN5clang17OverloadCandidateEN12_GLOBAL__N_125IsBetterOverloadCandidateEEvT_S5_T0_", "void std::__insertion_sort<clang::OverloadCandidate*, (anonymous namespace)::IsBetterOverloadCandidate>(clang::OverloadCandidate*, clang::OverloadCandidate*, (anonymous namespace)::IsBetterOverloadCandidate)"},
    {"_ZSt22__merge_without_bufferIPN5clang17OverloadCandidateElN12_GLOBAL__N_125IsBetterOverloadCandidateEEvT_S5_S5_T0_S6_T1_", "void std::__merge_without_buffer<clang::OverloadCandidate*, long, (anonymous namespace)::IsBetterOverloadCandidate>(clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, long, long, (anonymous namespace)::IsBetterOverloadCandidate)"},
    {"_ZNK12_GLOBAL__N_113ResultBuilder17isInterestingDeclEPN5clang9NamedDeclERb", "(anonymous namespace)::ResultBuilder::isInterestingDecl(clang::NamedDecl*, bool&) const"},
    {"_ZN12_GLOBAL__N_113ResultBuilder17CheckHiddenResultERN5clang20CodeCompletionResultEPNS1_11DeclContextEPNS1_9NamedDeclE", "(anonymous namespace)::ResultBuilder::CheckHiddenResult(clang::CodeCompletionResult&, clang::DeclContext*, clang::NamedDecl*)"},
    {"_ZN12_GLOBAL__N_113ResultBuilder27AdjustResultPriorityForDeclERN5clang20CodeCompletionResultE", "(anonymous namespace)::ResultBuilder::AdjustResultPriorityForDecl(clang::CodeCompletionResult&)"},
    {"_ZN12_GLOBAL__N_113ResultBuilder26MaybeAddConstructorResultsEN5clang20CodeCompletionResultE", "(anonymous namespace)::ResultBuilder::MaybeAddConstructorResults(clang::CodeCompletionResult)"},
    {"_ZN12_GLOBAL__N_126CodeCompletionDeclConsumerD0Ev", "(anonymous namespace)::CodeCompletionDeclConsumer::~CodeCompletionDeclConsumer()"},
    {"_ZN12_GLOBAL__N_126CodeCompletionDeclConsumer9FoundDeclEPN5clang9NamedDeclES3_b", "(anonymous namespace)::CodeCompletionDeclConsumer::FoundDecl(clang::NamedDecl*, clang::NamedDecl*, bool)"},
    {"_Z16AddTypedefResultRN12_GLOBAL__N_113ResultBuilderE", "AddTypedefResult((anonymous namespace)::ResultBuilder&)"},
    {"_Z20AddStorageSpecifiersN5clang4Sema23ParserCompletionContextERKNS_11LangOptionsERN12_GLOBAL__N_113ResultBuilderE", "AddStorageSpecifiers(clang::Sema::ParserCompletionContext, clang::LangOptions const&, (anonymous namespace)::ResultBuilder&)"},
    {"_Z21AddFunctionSpecifiersN5clang4Sema23ParserCompletionContextERKNS_11LangOptionsERN12_GLOBAL__N_113ResultBuilderE", "AddFunctionSpecifiers(clang::Sema::ParserCompletionContext, clang::LangOptions const&, (anonymous namespace)::ResultBuilder&)"},
    {"_ZNSt8_Rb_treeIPN5clang13NamespaceDeclESt4pairIKS2_S2_ESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS5_ERKS5_", "std::_Rb_tree<clang::NamespaceDecl*, std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>, std::_Select1st<std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>>, std::less<clang::NamespaceDecl*>, std::allocator<std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>>, std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*> const&)"},
    {"_ZNSt8_Rb_treeIPN5clang13NamespaceDeclESt4pairIKS2_S2_ESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE16_M_insert_uniqueERKS5_", "std::_Rb_tree<clang::NamespaceDecl*, std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>, std::_Select1st<std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>>, std::less<clang::NamespaceDecl*>, std::allocator<std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>>>::_M_insert_unique(std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*> const&)"},
    {"_ZNSt17_Temporary_bufferIPN5clang17OverloadCandidateES1_ED2Ev", "std::_Temporary_buffer<clang::OverloadCandidate*, clang::OverloadCandidate>::~_Temporary_buffer()"},
    {"_ZSt17__rotate_adaptiveIPN5clang17OverloadCandidateES2_lET_S3_S3_S3_T1_S4_T0_S4_", "clang::OverloadCandidate* std::__rotate_adaptive<clang::OverloadCandidate*, clang::OverloadCandidate*, long>(clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, long, long, clang::OverloadCandidate*, long)"},
    {"_ZSt8__rotateIPN5clang17OverloadCandidateEEvT_S3_S3_St26random_access_iterator_tag", "void std::__rotate<clang::OverloadCandidate*>(clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, std::random_access_iterator_tag)"},
    {"_ZN4llvm15SmallVectorImplIN5clang26ImplicitConversionSequenceEEaSERKS3_", "llvm::SmallVectorImpl<clang::ImplicitConversionSequence>::operator=(llvm::SmallVectorImpl<clang::ImplicitConversionSequence> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang26ImplicitConversionSequenceELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::ImplicitConversionSequence, false>::grow(unsigned long)"},
    {"_ZSt4swapIN5clang17OverloadCandidateEEvRT_S3_", "void std::swap<clang::OverloadCandidate>(clang::OverloadCandidate&, clang::OverloadCandidate&)"},
    {"_ZNSt15__copy_backwardILb0ESt26random_access_iterator_tagE8__copy_bIPN5clang17OverloadCandidateES5_EET0_T_S7_S6_", "clang::OverloadCandidate* std::__copy_backward<false, std::random_access_iterator_tag>::__copy_b<clang::OverloadCandidate*, clang::OverloadCandidate*>(clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*)"},
    {"_ZNSt6__copyILb0ESt26random_access_iterator_tagE4copyIPN5clang17OverloadCandidateES5_EET0_T_S7_S6_", "clang::OverloadCandidate* std::__copy<false, std::random_access_iterator_tag>::copy<clang::OverloadCandidate*, clang::OverloadCandidate*>(clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*)"},
    {"_ZSt26__uninitialized_fill_n_auxIPN5clang17OverloadCandidateElS1_EvT_T0_RKT1_St12__false_type", "void std::__uninitialized_fill_n_aux<clang::OverloadCandidate*, long, clang::OverloadCandidate>(clang::OverloadCandidate*, long, clang::OverloadCandidate const&, std::__false_type)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang20CodeCompleteConsumer17OverloadCandidateELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::CodeCompleteConsumer::OverloadCandidate, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorESt4pairIPNS1_14ObjCMethodDeclEbENS_12DenseMapInfoIS2_EENS7_IS6_EEE16InsertIntoBucketERKS2_RKS6_PS3_IS2_S6_E", "llvm::DenseMap<clang::Selector, std::pair<clang::ObjCMethodDecl*, bool>, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<std::pair<clang::ObjCMethodDecl*, bool>>>::InsertIntoBucket(clang::Selector const&, std::pair<clang::ObjCMethodDecl*, bool> const&, std::pair<clang::Selector, std::pair<clang::ObjCMethodDecl*, bool>>*)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorESt4pairIPNS1_14ObjCMethodDeclEbENS_12DenseMapInfoIS2_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::Selector, std::pair<clang::ObjCMethodDecl*, bool>, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<std::pair<clang::ObjCMethodDecl*, bool>>>::grow(unsigned int)"},
    {"_ZNSt6vectorIN5clang20CodeCompletionResultESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<clang::CodeCompletionResult, std::allocator<clang::CodeCompletionResult>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::CodeCompletionResult*, std::vector<clang::CodeCompletionResult, std::allocator<clang::CodeCompletionResult>>>, clang::CodeCompletionResult const&)"},
    {"_ZNSt8_Rb_treeIPN5clang13NamespaceDeclESt4pairIKS2_S2_ESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<clang::NamespaceDecl*, std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>, std::_Select1st<std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>>, std::less<clang::NamespaceDecl*>, std::allocator<std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::NamespaceDecl* const, clang::NamespaceDecl*>>*)"},
    {"_ZN4llvm15SmallVectorImplIN5clang17OverloadCandidateEED2Ev", "llvm::SmallVectorImpl<clang::OverloadCandidate>::~SmallVectorImpl()"},
    {"_ZNK5clang4Decl7getAttrINS_12SentinelAttrEEEPT_v", "clang::SentinelAttr* clang::Decl::getAttr<clang::SentinelAttr>() const"},
    {"_ZN5clang4Sema22ConvertDeclToDeclGroupEPNS_4DeclE", "clang::Sema::ConvertDeclToDeclGroup(clang::Decl*)"},
    {"_ZN5clang4Sema11getTypeNameERNS_14IdentifierInfoENS_14SourceLocationEPNS_5ScopeEPNS_12CXXScopeSpecEbbNS_9OpaquePtrINS_8QualTypeEEE", "clang::Sema::getTypeName(clang::IdentifierInfo&, clang::SourceLocation, clang::Scope*, clang::CXXScopeSpec*, bool, bool, clang::OpaquePtr<clang::QualType>)"},
    {"_ZN5clang4Sema9isTagNameERNS_14IdentifierInfoEPNS_5ScopeE", "clang::Sema::isTagName(clang::IdentifierInfo&, clang::Scope*)"},
    {"_ZN5clang4Sema23DiagnoseUnknownTypeNameERKNS_14IdentifierInfoENS_14SourceLocationEPNS_5ScopeEPNS_12CXXScopeSpecERNS_9OpaquePtrINS_8QualTypeEEE", "clang::Sema::DiagnoseUnknownTypeName(clang::IdentifierInfo const&, clang::SourceLocation, clang::Scope*, clang::CXXScopeSpec*, clang::OpaquePtr<clang::QualType>&)"},
    {"_ZN5clang4Sema15getContainingDCEPNS_11DeclContextE", "clang::Sema::getContainingDC(clang::DeclContext*)"},
    {"_ZN5clang4Sema15PushDeclContextEPNS_5ScopeEPNS_11DeclContextE", "clang::Sema::PushDeclContext(clang::Scope*, clang::DeclContext*)"},
    {"_ZN5clang4Sema14PopDeclContextEv", "clang::Sema::PopDeclContext()"},
    {"_ZN5clang4Sema22EnterDeclaratorContextEPNS_5ScopeEPNS_11DeclContextE", "clang::Sema::EnterDeclaratorContext(clang::Scope*, clang::DeclContext*)"},
    {"_ZN5clang4Sema21ExitDeclaratorContextEPNS_5ScopeE", "clang::Sema::ExitDeclaratorContext(clang::Scope*)"},
    {"_ZN5clang4Sema17PushOnScopeChainsEPNS_9NamedDeclEPNS_5ScopeEb", "clang::Sema::PushOnScopeChains(clang::NamedDecl*, clang::Scope*, bool)"},
    {"_ZN5clang4Sema13isDeclInScopeERPNS_9NamedDeclEPNS_11DeclContextEPNS_5ScopeE", "clang::Sema::isDeclInScope(clang::NamedDecl*&, clang::DeclContext*, clang::Scope*)"},
    {"_ZN5clang4Sema22getScopeForDeclContextEPNS_5ScopeEPNS_11DeclContextE", "clang::Sema::getScopeForDeclContext(clang::Scope*, clang::DeclContext*)"},
    {"_ZNK5clang4Sema32ShouldWarnIfUnusedFileScopedDeclEPKNS_14DeclaratorDeclE", "clang::Sema::ShouldWarnIfUnusedFileScopedDecl(clang::DeclaratorDecl const*) const"},
    {"_ZN5clang4Sema24MarkUnusedFileScopedDeclEPKNS_14DeclaratorDeclE", "clang::Sema::MarkUnusedFileScopedDecl(clang::DeclaratorDecl const*)"},
    {"_ZN5clang4Sema18DiagnoseUnusedDeclEPKNS_9NamedDeclE", "clang::Sema::DiagnoseUnusedDecl(clang::NamedDecl const*)"},
    {"_ZN5clang4Sema13ActOnPopScopeENS_14SourceLocationEPNS_5ScopeE", "clang::Sema::ActOnPopScope(clang::SourceLocation, clang::Scope*)"},
    {"_ZN5clang4Sema20getObjCInterfaceDeclERPNS_14IdentifierInfoENS_14SourceLocationEb", "clang::Sema::getObjCInterfaceDecl(clang::IdentifierInfo*&, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema20getNonFieldDeclScopeEPNS_5ScopeE", "clang::Sema::getNonFieldDeclScope(clang::Scope*)"},
    {"_ZN5clang4Sema19LazilyCreateBuiltinEPNS_14IdentifierInfoEjPNS_5ScopeEbNS_14SourceLocationE", "clang::Sema::LazilyCreateBuiltin(clang::IdentifierInfo*, unsigned int, clang::Scope*, bool, clang::SourceLocation)"},
    {"_ZN5clang4Sema26AddKnownFunctionAttributesEPNS_12FunctionDeclE", "clang::Sema::AddKnownFunctionAttributes(clang::FunctionDecl*)"},
    {"_ZN5clang4Sema16MergeTypeDefDeclEPNS_11TypedefDeclERNS_12LookupResultE", "clang::Sema::MergeTypeDefDecl(clang::TypedefDecl*, clang::LookupResult&)"},
    {"_ZN5clang4Sema16getSpecialMemberEPKNS_13CXXMethodDeclE", "clang::Sema::getSpecialMember(clang::CXXMethodDecl const*)"},
    {"_ZN5clang4Sema17MergeFunctionDeclEPNS_12FunctionDeclEPNS_4DeclE", "clang::Sema::MergeFunctionDecl(clang::FunctionDecl*, clang::Decl*)"},
    {"_ZN5clang4Sema28MergeCompatibleFunctionDeclsEPNS_12FunctionDeclES2_", "clang::Sema::MergeCompatibleFunctionDecls(clang::FunctionDecl*, clang::FunctionDecl*)"},
    {"_Z19MergeDeclAttributesPN5clang4DeclES1_RNS_10ASTContextE", "MergeDeclAttributes(clang::Decl*, clang::Decl*, clang::ASTContext&)"},
    {"_ZN5clang4Sema12MergeVarDeclEPNS_7VarDeclERNS_12LookupResultE", "clang::Sema::MergeVarDecl(clang::VarDecl*, clang::LookupResult&)"},
    {"_ZN5clang4Sema26ParsedFreeStandingDeclSpecEPNS_5ScopeENS_15AccessSpecifierERNS_8DeclSpecE", "clang::Sema::ParsedFreeStandingDeclSpec(clang::Scope*, clang::AccessSpecifier, clang::DeclSpec&)"},
    {"_ZN5clang4Sema27BuildAnonymousStructOrUnionEPNS_5ScopeERNS_8DeclSpecENS_15AccessSpecifierEPNS_10RecordDeclE", "clang::Sema::BuildAnonymousStructOrUnion(clang::Scope*, clang::DeclSpec&, clang::AccessSpecifier, clang::RecordDecl*)"},
    {"_ZN5clang4Sema30BuildMicrosoftCAnonymousStructEPNS_5ScopeERNS_8DeclSpecEPNS_10RecordDeclE", "clang::Sema::BuildMicrosoftCAnonymousStruct(clang::Scope*, clang::DeclSpec&, clang::RecordDecl*)"},
    {"_ZN5clang4Sema12ActOnVlaStmtERKNS_8DeclSpecE", "clang::Sema::ActOnVlaStmt(clang::DeclSpec const&)"},
    {"_ZN5clang4Sema20CheckNontrivialFieldEPNS_9FieldDeclE", "clang::Sema::CheckNontrivialField(clang::FieldDecl*)"},
    {"_Z35InjectAnonymousStructOrUnionMembersRN5clang4SemaEPNS_5ScopeEPNS_11DeclContextEPNS_10RecordDeclENS_15AccessSpecifierERN4llvm11SmallVectorIPNS_9NamedDeclELj2EEEb", "InjectAnonymousStructOrUnionMembers(clang::Sema&, clang::Scope*, clang::DeclContext*, clang::RecordDecl*, clang::AccessSpecifier, llvm::SmallVector<clang::NamedDecl*, 2u>&, bool)"},
    {"_ZN5clang4Sema20GetNameForDeclaratorERNS_10DeclaratorE", "clang::Sema::GetNameForDeclarator(clang::Declarator&)"},
    {"_ZN5clang4Sema24GetNameFromUnqualifiedIdERKNS_13UnqualifiedIdE", "clang::Sema::GetNameFromUnqualifiedId(clang::UnqualifiedId const&)"},
    {"_ZN5clang4Sema15ActOnDeclaratorEPNS_5ScopeERNS_10DeclaratorE", "clang::Sema::ActOnDeclarator(clang::Scope*, clang::Declarator&)"},
    {"_ZN5clang4Sema16HandleDeclaratorEPNS_5ScopeERNS_10DeclaratorENS_11ASTMultiPtrIPNS_21TemplateParameterListEEEb", "clang::Sema::HandleDeclarator(clang::Scope*, clang::Declarator&, clang::ASTMultiPtr<clang::TemplateParameterList*>, bool)"},
    {"_ZN5clang4Sema22ActOnTypedefDeclaratorEPNS_5ScopeERNS_10DeclaratorEPNS_11DeclContextENS_8QualTypeEPNS_14TypeSourceInfoERNS_12LookupResultERb", "clang::Sema::ActOnTypedefDeclarator(clang::Scope*, clang::Declarator&, clang::DeclContext*, clang::QualType, clang::TypeSourceInfo*, clang::LookupResult&, bool&)"},
    {"_ZN5clang4Sema23ActOnFunctionDeclaratorEPNS_5ScopeERNS_10DeclaratorEPNS_11DeclContextENS_8QualTypeEPNS_14TypeSourceInfoERNS_12LookupResultENS_11ASTMultiPtrIPNS_21TemplateParameterListEEEbRb", "clang::Sema::ActOnFunctionDeclarator(clang::Scope*, clang::Declarator&, clang::DeclContext*, clang::QualType, clang::TypeSourceInfo*, clang::LookupResult&, clang::ASTMultiPtr<clang::TemplateParameterList*>, bool, bool&)"},
    {"_ZN5clang4Sema23ActOnVariableDeclaratorEPNS_5ScopeERNS_10DeclaratorEPNS_11DeclContextENS_8QualTypeEPNS_14TypeSourceInfoERNS_12LookupResultENS_11ASTMultiPtrIPNS_21TemplateParameterListEEERb", "clang::Sema::ActOnVariableDeclarator(clang::Scope*, clang::Declarator&, clang::DeclContext*, clang::QualType, clang::TypeSourceInfo*, clang::LookupResult&, clang::ASTMultiPtr<clang::TemplateParameterList*>, bool&)"},
    {"_ZN5clang4Sema32RegisterLocallyScopedExternCDeclEPNS_9NamedDeclERKNS_12LookupResultEPNS_5ScopeE", "clang::Sema::RegisterLocallyScopedExternCDecl(clang::NamedDecl*, clang::LookupResult const&, clang::Scope*)"},
    {"_ZN5clang4Sema26DiagnoseFunctionSpecifiersERNS_10DeclaratorE", "clang::Sema::DiagnoseFunctionSpecifiers(clang::Declarator&)"},
    {"_ZN5clang4Sema16ParseTypedefDeclEPNS_5ScopeERNS_10DeclaratorENS_8QualTypeEPNS_14TypeSourceInfoE", "clang::Sema::ParseTypedefDecl(clang::Scope*, clang::Declarator&, clang::QualType, clang::TypeSourceInfo*)"},
    {"_Z35TryToFixInvalidVariablyModifiedTypeN5clang8QualTypeERNS_10ASTContextERbRN4llvm6APSIntE", "TryToFixInvalidVariablyModifiedType(clang::QualType, clang::ASTContext&, bool&, llvm::APSInt&)"},
    {"_Z20FilterLookupForScopeRN5clang4SemaERNS_12LookupResultEPNS_11DeclContextEPNS_5ScopeEb", "FilterLookupForScope(clang::Sema&, clang::LookupResult&, clang::DeclContext*, clang::Scope*, bool)"},
    {"_ZN5clang4Sema11CheckShadowEPNS_5ScopeEPNS_7VarDeclERKNS_12LookupResultE", "clang::Sema::CheckShadow(clang::Scope*, clang::VarDecl*, clang::LookupResult const&)"},
    {"_ZN5clang4Sema24CheckVariableDeclarationEPNS_7VarDeclERNS_12LookupResultERb", "clang::Sema::CheckVariableDeclaration(clang::VarDecl*, clang::LookupResult&, bool&)"},
    {"_ZN5clang4Sema11CheckShadowEPNS_5ScopeEPNS_7VarDeclE", "clang::Sema::CheckShadow(clang::Scope*, clang::VarDecl*)"},
    {"_ZN5clang4Sema20AddOverriddenMethodsEPNS_13CXXRecordDeclEPNS_13CXXMethodDeclE", "clang::Sema::AddOverriddenMethods(clang::CXXRecordDecl*, clang::CXXMethodDecl*)"},
    {"_Z20FindOverriddenMethodPKN5clang16CXXBaseSpecifierERNS_11CXXBasePathEPv", "FindOverriddenMethod(clang::CXXBaseSpecifier const*, clang::CXXBasePath&, void*)"},
    {"_ZN5clang4Sema26BuildParmVarDeclForTypedefEPNS_11DeclContextENS_14SourceLocationENS_8QualTypeE", "clang::Sema::BuildParmVarDeclForTypedef(clang::DeclContext*, clang::SourceLocation, clang::QualType)"},
    {"_ZN5clang4Sema24CheckFunctionDeclarationEPNS_5ScopeEPNS_12FunctionDeclERNS_12LookupResultEbRb", "clang::Sema::CheckFunctionDeclaration(clang::Scope*, clang::FunctionDecl*, clang::LookupResult&, bool, bool&)"},
    {"_Z28DiagnoseInvalidRedeclarationRN5clang4SemaEPNS_12FunctionDeclE", "DiagnoseInvalidRedeclaration(clang::Sema&, clang::FunctionDecl*)"},
    {"_ZN5clang4Sema9CheckMainEPNS_12FunctionDeclE", "clang::Sema::CheckMain(clang::FunctionDecl*)"},
    {"_ZN5clang4Sema27CheckForConstantInitializerEPNS_4ExprENS_8QualTypeE", "clang::Sema::CheckForConstantInitializer(clang::Expr*, clang::QualType)"},
    {"_ZN5clang4Sema20AddInitializerToDeclEPNS_4DeclEPNS_4ExprE", "clang::Sema::AddInitializerToDecl(clang::Decl*, clang::Expr*)"},
    {"_ZN5clang4Sema20AddInitializerToDeclEPNS_4DeclEPNS_4ExprEb", "clang::Sema::AddInitializerToDecl(clang::Decl*, clang::Expr*, bool)"},
    {"_ZN5clang4Sema32CheckCompleteVariableDeclarationEPNS_7VarDeclE", "clang::Sema::CheckCompleteVariableDeclaration(clang::VarDecl*)"},
    {"_ZN5clang4Sema21ActOnInitializerErrorEPNS_4DeclE", "clang::Sema::ActOnInitializerError(clang::Decl*)"},
    {"_ZN5clang4Sema22ActOnUninitializedDeclEPNS_4DeclEb", "clang::Sema::ActOnUninitializedDecl(clang::Decl*, bool)"},
    {"_ZN5clang4Sema23FinalizeDeclaratorGroupEPNS_5ScopeERKNS_8DeclSpecEPPNS_4DeclEj", "clang::Sema::FinalizeDeclaratorGroup(clang::Scope*, clang::DeclSpec const&, clang::Decl**, unsigned int)"},
    {"_ZN5clang4Sema20ActOnParamDeclaratorEPNS_5ScopeERNS_10DeclaratorE", "clang::Sema::ActOnParamDeclarator(clang::Scope*, clang::Declarator&)"},
    {"_ZN5clang4Sema14CheckParameterEPNS_11DeclContextEPNS_14TypeSourceInfoENS_8QualTypeEPNS_14IdentifierInfoENS_14SourceLocationENS_12StorageClassES9_", "clang::Sema::CheckParameter(clang::DeclContext*, clang::TypeSourceInfo*, clang::QualType, clang::IdentifierInfo*, clang::SourceLocation, clang::StorageClass, clang::StorageClass)"},
    {"_ZN5clang4Sema24DiagnoseUnusedParametersEPKPNS_11ParmVarDeclES4_", "clang::Sema::DiagnoseUnusedParameters(clang::ParmVarDecl* const*, clang::ParmVarDecl* const*)"},
    {"_ZN5clang4Sema38DiagnoseSizeOfParametersAndReturnValueEPKPNS_11ParmVarDeclES4_NS_8QualTypeEPNS_9NamedDeclE", "clang::Sema::DiagnoseSizeOfParametersAndReturnValue(clang::ParmVarDecl* const*, clang::ParmVarDecl* const*, clang::QualType, clang::NamedDecl*)"},
    {"_ZN5clang4Sema31ActOnFinishKNRParamDeclarationsEPNS_5ScopeERNS_10DeclaratorENS_14SourceLocationE", "clang::Sema::ActOnFinishKNRParamDeclarations(clang::Scope*, clang::Declarator&, clang::SourceLocation)"},
    {"_ZN5clang4Sema23ActOnStartOfFunctionDefEPNS_5ScopeERNS_10DeclaratorE", "clang::Sema::ActOnStartOfFunctionDef(clang::Scope*, clang::Declarator&)"},
    {"_ZN5clang4Sema23ActOnStartOfFunctionDefEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnStartOfFunctionDef(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema23ActOnFinishFunctionBodyEPNS_4DeclEPNS_4StmtE", "clang::Sema::ActOnFinishFunctionBody(clang::Decl*, clang::Stmt*)"},
    {"_ZN5clang4Sema23ActOnFinishFunctionBodyEPNS_4DeclEPNS_4StmtEb", "clang::Sema::ActOnFinishFunctionBody(clang::Decl*, clang::Stmt*, bool)"},
    {"_ZN5clang4Sema24ImplicitlyDefineFunctionENS_14SourceLocationERNS_14IdentifierInfoEPNS_5ScopeE", "clang::Sema::ImplicitlyDefineFunction(clang::SourceLocation, clang::IdentifierInfo&, clang::Scope*)"},
    {"_ZN5clang4Sema28isAcceptableTagRedeclarationEPKNS_7TagDeclENS_11TagTypeKindENS_14SourceLocationERKNS_14IdentifierInfoE", "clang::Sema::isAcceptableTagRedeclaration(clang::TagDecl const*, clang::TagTypeKind, clang::SourceLocation, clang::IdentifierInfo const&)"},
    {"_ZN5clang4Sema8ActOnTagEPNS_5ScopeEjNS0_10TagUseKindENS_14SourceLocationERNS_12CXXScopeSpecEPNS_14IdentifierInfoES4_PNS_13AttributeListENS_15AccessSpecifierENS_11ASTMultiPtrIPNS_21TemplateParameterListEEERbSG_bbNS_12ActionResultINS_9OpaquePtrINS_8QualTypeEEELb0EEE", "clang::Sema::ActOnTag(clang::Scope*, unsigned int, clang::Sema::TagUseKind, clang::SourceLocation, clang::CXXScopeSpec&, clang::IdentifierInfo*, clang::SourceLocation, clang::AttributeList*, clang::AccessSpecifier, clang::ASTMultiPtr<clang::TemplateParameterList*>, bool&, bool&, bool, bool, clang::ActionResult<clang::OpaquePtr<clang::QualType>, false>)"},
    {"_ZN5clang4Sema23ActOnTagStartDefinitionEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnTagStartDefinition(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema31ActOnStartCXXMemberDeclarationsEPNS_5ScopeEPNS_4DeclERNS_19ClassVirtSpecifiersENS_14SourceLocationE", "clang::Sema::ActOnStartCXXMemberDeclarations(clang::Scope*, clang::Decl*, clang::ClassVirtSpecifiers&, clang::SourceLocation)"},
    {"_ZN5clang4Sema24ActOnTagFinishDefinitionEPNS_5ScopeEPNS_4DeclENS_14SourceLocationE", "clang::Sema::ActOnTagFinishDefinition(clang::Scope*, clang::Decl*, clang::SourceLocation)"},
    {"_ZN5clang4Sema23ActOnTagDefinitionErrorEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnTagDefinitionError(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema14VerifyBitFieldENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPKNS_4ExprEPb", "clang::Sema::VerifyBitField(clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::Expr const*, bool*)"},
    {"_ZN5clang4Sema10ActOnFieldEPNS_5ScopeEPNS_4DeclENS_14SourceLocationERNS_10DeclaratorEPNS_4ExprE", "clang::Sema::ActOnField(clang::Scope*, clang::Decl*, clang::SourceLocation, clang::Declarator&, clang::Expr*)"},
    {"_ZN5clang4Sema11HandleFieldEPNS_5ScopeEPNS_10RecordDeclENS_14SourceLocationERNS_10DeclaratorEPNS_4ExprENS_15AccessSpecifierE", "clang::Sema::HandleField(clang::Scope*, clang::RecordDecl*, clang::SourceLocation, clang::Declarator&, clang::Expr*, clang::AccessSpecifier)"},
    {"_ZN5clang4Sema14CheckFieldDeclENS_15DeclarationNameENS_8QualTypeEPNS_14TypeSourceInfoEPNS_10RecordDeclENS_14SourceLocationEbPNS_4ExprES7_NS_15AccessSpecifierEPNS_9NamedDeclEPNS_10DeclaratorE", "clang::Sema::CheckFieldDecl(clang::DeclarationName, clang::QualType, clang::TypeSourceInfo*, clang::RecordDecl*, clang::SourceLocation, bool, clang::Expr*, clang::SourceLocation, clang::AccessSpecifier, clang::NamedDecl*, clang::Declarator*)"},
    {"_ZN5clang4Sema18DiagnoseNontrivialEPKNS_10RecordTypeENS0_16CXXSpecialMemberE", "clang::Sema::DiagnoseNontrivial(clang::RecordType const*, clang::Sema::CXXSpecialMember)"},
    {"_ZN5clang4Sema9ActOnIvarEPNS_5ScopeENS_14SourceLocationEPNS_4DeclERNS_10DeclaratorEPNS_4ExprENS_3tok15ObjCKeywordKindE", "clang::Sema::ActOnIvar(clang::Scope*, clang::SourceLocation, clang::Decl*, clang::Declarator&, clang::Expr*, clang::tok::ObjCKeywordKind)"},
    {"_ZN5clang4Sema17ActOnLastBitfieldENS_14SourceLocationEPNS_4DeclERN4llvm15SmallVectorImplIS3_EE", "clang::Sema::ActOnLastBitfield(clang::SourceLocation, clang::Decl*, llvm::SmallVectorImpl<clang::Decl*>&)"},
    {"_ZN5clang4Sema11ActOnFieldsEPNS_5ScopeENS_14SourceLocationEPNS_4DeclEPS5_jS3_S3_PNS_13AttributeListE", "clang::Sema::ActOnFields(clang::Scope*, clang::SourceLocation, clang::Decl*, clang::Decl**, unsigned int, clang::SourceLocation, clang::SourceLocation, clang::AttributeList*)"},
    {"_ZN5clang4Sema17CheckEnumConstantEPNS_8EnumDeclEPNS_16EnumConstantDeclENS_14SourceLocationEPNS_14IdentifierInfoEPNS_4ExprE", "clang::Sema::CheckEnumConstant(clang::EnumDecl*, clang::EnumConstantDecl*, clang::SourceLocation, clang::IdentifierInfo*, clang::Expr*)"},
    {"_Z27isRepresentableIntegerValueRN5clang10ASTContextERN4llvm6APSIntENS_8QualTypeE", "isRepresentableIntegerValue(clang::ASTContext&, llvm::APSInt&, clang::QualType)"},
    {"_ZN5clang4Sema17ActOnEnumConstantEPNS_5ScopeEPNS_4DeclES4_NS_14SourceLocationEPNS_14IdentifierInfoEPNS_13AttributeListES5_PNS_4ExprE", "clang::Sema::ActOnEnumConstant(clang::Scope*, clang::Decl*, clang::Decl*, clang::SourceLocation, clang::IdentifierInfo*, clang::AttributeList*, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema13ActOnEnumBodyENS_14SourceLocationES1_S1_PNS_4DeclEPS3_jPNS_5ScopeEPNS_13AttributeListE", "clang::Sema::ActOnEnumBody(clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::Decl*, clang::Decl**, unsigned int, clang::Scope*, clang::AttributeList*)"},
    {"_ZN5clang4Sema21ActOnFileScopeAsmDeclENS_14SourceLocationEPNS_4ExprE", "clang::Sema::ActOnFileScopeAsmDecl(clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema17ActOnPragmaWeakIDEPNS_14IdentifierInfoENS_14SourceLocationES3_", "clang::Sema::ActOnPragmaWeakID(clang::IdentifierInfo*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema20ActOnPragmaWeakAliasEPNS_14IdentifierInfoES2_NS_14SourceLocationES3_S3_", "clang::Sema::ActOnPragmaWeakAlias(clang::IdentifierInfo*, clang::IdentifierInfo*, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang12RedeclarableINS_11TypedefDeclEE22setPreviousDeclarationEPS1_", "clang::Redeclarable<clang::TypedefDecl>::setPreviousDeclaration(clang::TypedefDecl*)"},
    {"_ZN5clang12RedeclarableINS_7VarDeclEE22setPreviousDeclarationEPS1_", "clang::Redeclarable<clang::VarDecl>::setPreviousDeclaration(clang::VarDecl*)"},
    {"_ZNK5clang4Decl7getAttrINS_13DLLImportAttrEEEPT_v", "clang::DLLImportAttr* clang::Decl::getAttr<clang::DLLImportAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_13DLLExportAttrEEEPT_v", "clang::DLLExportAttr* clang::Decl::getAttr<clang::DLLExportAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_10FormatAttrEEEPT_v", "clang::FormatAttr* clang::Decl::getAttr<clang::FormatAttr>() const"},
    {"_ZNK5clang13CXXRecordDecl25hasTrivialCopyConstructorEv", "clang::CXXRecordDecl::hasTrivialCopyConstructor() const"},
    {"_ZNK5clang13CXXRecordDecl21hasTrivialConstructorEv", "clang::CXXRecordDecl::hasTrivialConstructor() const"},
    {"_ZNK5clang13CXXRecordDecl24hasTrivialCopyAssignmentEv", "clang::CXXRecordDecl::hasTrivialCopyAssignment() const"},
    {"_ZNK5clang13CXXRecordDecl20hasTrivialDestructorEv", "clang::CXXRecordDecl::hasTrivialDestructor() const"},
    {"_ZNK5clang4Decl7getAttrINS_10PackedAttrEEEPT_v", "clang::PackedAttr* clang::Decl::getAttr<clang::PackedAttr>() const"},
    {"_ZNK4llvm6APSInt10extOrTruncEj", "llvm::APSInt::extOrTrunc(unsigned int) const"},
    {"_ZN4llvm15SmallVectorImplIPN5clang9FieldDeclEE6resizeEj", "llvm::SmallVectorImpl<clang::FieldDecl*>::resize(unsigned int)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang15DeclaratorChunkELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::DeclaratorChunk, false>::grow(unsigned long)"},
    {"_ZN5clang12CXXBasePathsD2Ev", "clang::CXXBasePaths::~CXXBasePaths()"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_S2_IbjEESt10_Select1stIS5_ENS0_16QualTypeOrderingESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, std::pair<bool, unsigned int>>, std::_Select1st<std::pair<clang::QualType const, std::pair<bool, unsigned int>>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, std::pair<bool, unsigned int>>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::QualType const, std::pair<bool, unsigned int>>>*)"},
    {"_ZN5clang12LookupResult22resolveKindAfterFilterEv", "clang::LookupResult::resolveKindAfterFilter()"},
    {"_ZN5clang10Declarator5clearEv", "clang::Declarator::clear()"},
    {"_ZN4llvm15SmallVectorImplIPN5clang9NamedDeclEE6resizeEj", "llvm::SmallVectorImpl<clang::NamedDecl*>::resize(unsigned int)"},
    {"_ZN5clang4Sema17CheckNoReturnAttrERKNS_13AttributeListE", "clang::Sema::CheckNoReturnAttr(clang::AttributeList const&)"},
    {"_ZN5clang4Sema14AddAlignedAttrENS_14SourceLocationEPNS_4DeclEPNS_4ExprE", "clang::Sema::AddAlignedAttr(clang::SourceLocation, clang::Decl*, clang::Expr*)"},
    {"_ZN5clang4Sema14AddAlignedAttrENS_14SourceLocationEPNS_4DeclEPNS_14TypeSourceInfoE", "clang::Sema::AddAlignedAttr(clang::SourceLocation, clang::Decl*, clang::TypeSourceInfo*)"},
    {"_ZN5clang4Sema20CheckCallingConvAttrERKNS_13AttributeListERNS_11CallingConvE", "clang::Sema::CheckCallingConvAttr(clang::AttributeList const&, clang::CallingConv&)"},
    {"_ZN5clang4Sema16CheckRegparmAttrERKNS_13AttributeListERj", "clang::Sema::CheckRegparmAttr(clang::AttributeList const&, unsigned int&)"},
    {"_ZN5clang4Sema24ProcessDeclAttributeListEPNS_5ScopeEPNS_4DeclEPKNS_13AttributeListEbb", "clang::Sema::ProcessDeclAttributeList(clang::Scope*, clang::Decl*, clang::AttributeList const*, bool, bool)"},
    {"_ZN5clang4Sema19DeclClonePragmaWeakEPNS_9NamedDeclEPNS_14IdentifierInfoE", "clang::Sema::DeclClonePragmaWeak(clang::NamedDecl*, clang::IdentifierInfo*)"},
    {"_ZN5clang4Sema19DeclApplyPragmaWeakEPNS_5ScopeEPNS_9NamedDeclERNS0_8WeakInfoE", "clang::Sema::DeclApplyPragmaWeak(clang::Scope*, clang::NamedDecl*, clang::Sema::WeakInfo&)"},
    {"_ZN5clang4Sema21ProcessDeclAttributesEPNS_5ScopeEPNS_4DeclERKNS_10DeclaratorEbb", "clang::Sema::ProcessDeclAttributes(clang::Scope*, clang::Decl*, clang::Declarator const&, bool, bool)"},
    {"_ZN5clang4Sema22PushParsingDeclarationEv", "clang::Sema::PushParsingDeclaration()"},
    {"_ZN5clang4Sema21PopParsingDeclarationEmPNS_4DeclE", "clang::Sema::PopParsingDeclaration(unsigned long, clang::Decl*)"},
    {"_ZN5clang4Sema29HandleDelayedDeprecationCheckERNS_4sema17DelayedDiagnosticEPNS_4DeclE", "clang::Sema::HandleDelayedDeprecationCheck(clang::sema::DelayedDiagnostic&, clang::Decl*)"},
    {"_ZN5clang4Sema22EmitDeprecationWarningEPNS_9NamedDeclEN4llvm9StringRefENS_14SourceLocationEb", "clang::Sema::EmitDeprecationWarning(clang::NamedDecl*, llvm::StringRef, clang::SourceLocation, bool)"},
    {"_Z26ProcessInheritableDeclAttrPN5clang5ScopeEPNS_4DeclERKNS_13AttributeListERNS_4SemaE", "ProcessInheritableDeclAttr(clang::Scope*, clang::Decl*, clang::AttributeList const&, clang::Sema&)"},
    {"_Z15getFunctionTypePKN5clang4DeclEb", "getFunctionType(clang::Decl const*, bool)"},
    {"_ZN4llvm25array_pod_sort_comparatorIjEEiPKvS2_", "int llvm::array_pod_sort_comparator<unsigned int>(void const*, void const*)"},
    {"_Z14isNSStringTypeN5clang8QualTypeERNS_10ASTContextE", "isNSStringType(clang::QualType, clang::ASTContext&)"},
    {"_Z14isCFStringTypeN5clang8QualTypeERNS_10ASTContextE", "isCFStringType(clang::QualType, clang::ASTContext&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang4sema17DelayedDiagnosticELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::sema::DelayedDiagnostic, false>::grow(unsigned long)"},
    {"_ZNK5clang4Decl7getAttrINS_13VecReturnAttrEEEPT_v", "clang::VecReturnAttr* clang::Decl::getAttr<clang::VecReturnAttr>() const"},
    {"_ZN5clang4Sema23SetParamDefaultArgumentEPNS_11ParmVarDeclEPNS_4ExprENS_14SourceLocationE", "clang::Sema::SetParamDefaultArgument(clang::ParmVarDecl*, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema25ActOnParamDefaultArgumentEPNS_4DeclENS_14SourceLocationEPNS_4ExprE", "clang::Sema::ActOnParamDefaultArgument(clang::Decl*, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_127CheckDefaultArgumentVisitorEbE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::CheckDefaultArgumentVisitor, bool>::Visit(clang::Stmt*)"},
    {"_ZN5clang4Sema33ActOnParamUnparsedDefaultArgumentEPNS_4DeclENS_14SourceLocationES3_", "clang::Sema::ActOnParamUnparsedDefaultArgument(clang::Decl*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema30ActOnParamDefaultArgumentErrorEPNS_4DeclE", "clang::Sema::ActOnParamDefaultArgumentError(clang::Decl*)"},
    {"_ZN5clang4Sema29CheckExtraCXXDefaultArgumentsERNS_10DeclaratorE", "clang::Sema::CheckExtraCXXDefaultArguments(clang::Declarator&)"},
    {"_ZN5clang4Sema20MergeCXXFunctionDeclEPNS_12FunctionDeclES2_", "clang::Sema::MergeCXXFunctionDecl(clang::FunctionDecl*, clang::FunctionDecl*)"},
    {"_ZN5clang4Sema24CheckCXXDefaultArgumentsEPNS_12FunctionDeclE", "clang::Sema::CheckCXXDefaultArguments(clang::FunctionDecl*)"},
    {"_ZN5clang4Sema18isCurrentClassNameERKNS_14IdentifierInfoEPNS_5ScopeEPKNS_12CXXScopeSpecE", "clang::Sema::isCurrentClassName(clang::IdentifierInfo const&, clang::Scope*, clang::CXXScopeSpec const*)"},
    {"_ZN5clang4Sema18CheckBaseSpecifierEPNS_13CXXRecordDeclENS_11SourceRangeEbNS_15AccessSpecifierEPNS_14TypeSourceInfoENS_14SourceLocationE", "clang::Sema::CheckBaseSpecifier(clang::CXXRecordDecl*, clang::SourceRange, bool, clang::AccessSpecifier, clang::TypeSourceInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema18ActOnBaseSpecifierEPNS_4DeclENS_11SourceRangeEbNS_15AccessSpecifierENS_9OpaquePtrINS_8QualTypeEEENS_14SourceLocationES8_", "clang::Sema::ActOnBaseSpecifier(clang::Decl*, clang::SourceRange, bool, clang::AccessSpecifier, clang::OpaquePtr<clang::QualType>, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema20AttachBaseSpecifiersEPNS_13CXXRecordDeclEPPNS_16CXXBaseSpecifierEj", "clang::Sema::AttachBaseSpecifiers(clang::CXXRecordDecl*, clang::CXXBaseSpecifier**, unsigned int)"},
    {"_ZN5clang4Sema19ActOnBaseSpecifiersEPNS_4DeclEPPNS_16CXXBaseSpecifierEj", "clang::Sema::ActOnBaseSpecifiers(clang::Decl*, clang::CXXBaseSpecifier**, unsigned int)"},
    {"_ZN5clang4Sema13IsDerivedFromENS_8QualTypeES1_", "clang::Sema::IsDerivedFrom(clang::QualType, clang::QualType)"},
    {"_Z15GetClassForTypeN5clang8QualTypeE", "GetClassForType(clang::QualType)"},
    {"_ZN5clang4Sema13IsDerivedFromENS_8QualTypeES1_RNS_12CXXBasePathsE", "clang::Sema::IsDerivedFrom(clang::QualType, clang::QualType, clang::CXXBasePaths&)"},
    {"_ZN5clang4Sema18BuildBasePathArrayERKNS_12CXXBasePathsERN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEE", "clang::Sema::BuildBasePathArray(clang::CXXBasePaths const&, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u>&)"},
    {"_ZN5clang4Sema27BasePathInvolvesVirtualBaseERKN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEE", "clang::Sema::BasePathInvolvesVirtualBase(llvm::SmallVector<clang::CXXBaseSpecifier*, 4u> const&)"},
    {"_ZN5clang4Sema28CheckDerivedToBaseConversionENS_8QualTypeES1_jjNS_14SourceLocationENS_11SourceRangeENS_15DeclarationNameEPN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEE", "clang::Sema::CheckDerivedToBaseConversion(clang::QualType, clang::QualType, unsigned int, unsigned int, clang::SourceLocation, clang::SourceRange, clang::DeclarationName, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u>*)"},
    {"_ZN5clang4Sema30getAmbiguousPathsDisplayStringERNS_12CXXBasePathsE", "clang::Sema::getAmbiguousPathsDisplayString(clang::CXXBasePaths&)"},
    {"_ZN5clang4Sema28CheckDerivedToBaseConversionENS_8QualTypeES1_NS_14SourceLocationENS_11SourceRangeEPN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEEb", "clang::Sema::CheckDerivedToBaseConversion(clang::QualType, clang::QualType, clang::SourceLocation, clang::SourceRange, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u>*, bool)"},
    {"_ZN5clang4Sema20ActOnAccessSpecifierENS_15AccessSpecifierENS_14SourceLocationES2_", "clang::Sema::ActOnAccessSpecifier(clang::AccessSpecifier, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema20CheckOverrideControlEPKNS_4DeclE", "clang::Sema::CheckOverrideControl(clang::Decl const*)"},
    {"_ZN5clang4Sema38CheckIfOverriddenFunctionIsMarkedFinalEPKNS_13CXXMethodDeclES3_", "clang::Sema::CheckIfOverriddenFunctionIsMarkedFinal(clang::CXXMethodDecl const*, clang::CXXMethodDecl const*)"},
    {"_ZN5clang4Sema24ActOnCXXMemberDeclaratorEPNS_5ScopeENS_15AccessSpecifierERNS_10DeclaratorENS_11ASTMultiPtrIPNS_21TemplateParameterListEEEPNS_4ExprERKNS_14VirtSpecifiersESB_bb", "clang::Sema::ActOnCXXMemberDeclarator(clang::Scope*, clang::AccessSpecifier, clang::Declarator&, clang::ASTMultiPtr<clang::TemplateParameterList*>, clang::Expr*, clang::VirtSpecifiers const&, clang::Expr*, bool, bool)"},
    {"_ZN5clang4Sema14SetDeclDeletedEPNS_4DeclENS_14SourceLocationE", "clang::Sema::SetDeclDeleted(clang::Decl*, clang::SourceLocation)"},
    {"_ZN5clang4Sema19ActOnMemInitializerEPNS_4DeclEPNS_5ScopeERNS_12CXXScopeSpecEPNS_14IdentifierInfoENS_9OpaquePtrINS_8QualTypeEEENS_14SourceLocationESC_PPNS_4ExprEjSC_SC_", "clang::Sema::ActOnMemInitializer(clang::Decl*, clang::Scope*, clang::CXXScopeSpec&, clang::IdentifierInfo*, clang::OpaquePtr<clang::QualType>, clang::SourceLocation, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema22BuildMemberInitializerEPNS_9ValueDeclEPPNS_4ExprEjNS_14SourceLocationES6_S6_", "clang::Sema::BuildMemberInitializer(clang::ValueDecl*, clang::Expr**, unsigned int, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation)"},
    {"_Z19FindBaseInitializerRN5clang4SemaEPNS_13CXXRecordDeclENS_8QualTypeERPKNS_16CXXBaseSpecifierES8_", "FindBaseInitializer(clang::Sema&, clang::CXXRecordDecl*, clang::QualType, clang::CXXBaseSpecifier const*&, clang::CXXBaseSpecifier const*&)"},
    {"_ZN5clang4Sema20BuildBaseInitializerENS_8QualTypeEPNS_14TypeSourceInfoEPPNS_4ExprEjNS_14SourceLocationES7_PNS_13CXXRecordDeclES7_", "clang::Sema::BuildBaseInitializer(clang::QualType, clang::TypeSourceInfo*, clang::Expr**, unsigned int, clang::SourceLocation, clang::SourceLocation, clang::CXXRecordDecl*, clang::SourceLocation)"},
    {"_Z35InitExprContainsUninitializedFieldsPKN5clang4StmtEPKNS_9ValueDeclEPNS_14SourceLocationE", "InitExprContainsUninitializedFields(clang::Stmt const*, clang::ValueDecl const*, clang::SourceLocation*)"},
    {"_ZN5clang4Sema26BuildDelegatingInitializerEPNS_14TypeSourceInfoEPPNS_4ExprEjNS_14SourceLocationES6_PNS_13CXXRecordDeclES6_", "clang::Sema::BuildDelegatingInitializer(clang::TypeSourceInfo*, clang::Expr**, unsigned int, clang::SourceLocation, clang::SourceLocation, clang::CXXRecordDecl*, clang::SourceLocation)"},
    {"_ZN5clang4Sema19SetCtorInitializersEPNS_18CXXConstructorDeclEPPNS_18CXXCtorInitializerEjb", "clang::Sema::SetCtorInitializers(clang::CXXConstructorDecl*, clang::CXXCtorInitializer**, unsigned int, bool)"},
    {"_Z28BuildImplicitBaseInitializerRN5clang4SemaEPNS_18CXXConstructorDeclE23ImplicitInitializerKindPNS_16CXXBaseSpecifierEbRPNS_18CXXCtorInitializerE", "BuildImplicitBaseInitializer(clang::Sema&, clang::CXXConstructorDecl*, ImplicitInitializerKind, clang::CXXBaseSpecifier*, bool, clang::CXXCtorInitializer*&)"},
    {"_Z23CollectFieldInitializerRN12_GLOBAL__N_116BaseAndFieldInfoEPN5clang9FieldDeclES4_", "CollectFieldInitializer((anonymous namespace)::BaseAndFieldInfo&, clang::FieldDecl*, clang::FieldDecl*)"},
    {"_ZN5clang4Sema38MarkBaseAndMemberDestructorsReferencedENS_14SourceLocationEPNS_13CXXRecordDeclE", "clang::Sema::MarkBaseAndMemberDestructorsReferenced(clang::SourceLocation, clang::CXXRecordDecl*)"},
    {"_ZN5clang4Sema20ActOnMemInitializersEPNS_4DeclENS_14SourceLocationEPPNS_18CXXCtorInitializerEjb", "clang::Sema::ActOnMemInitializers(clang::Decl*, clang::SourceLocation, clang::CXXCtorInitializer**, unsigned int, bool)"},
    {"_ZN12_GLOBAL__N_118CheckRedundantInitERN5clang4SemaEPNS0_18CXXCtorInitializerERS4_", "(anonymous namespace)::CheckRedundantInit(clang::Sema&, clang::CXXCtorInitializer*, clang::CXXCtorInitializer*&)"},
    {"_ZN5clang4Sema28ActOnDefaultCtorInitializersEPNS_4DeclE", "clang::Sema::ActOnDefaultCtorInitializers(clang::Decl*)"},
    {"_ZN5clang4Sema22RequireNonAbstractTypeENS_14SourceLocationENS_8QualTypeEjNS0_17AbstractDiagSelIDE", "clang::Sema::RequireNonAbstractType(clang::SourceLocation, clang::QualType, unsigned int, clang::Sema::AbstractDiagSelID)"},
    {"_ZN5clang4Sema22RequireNonAbstractTypeENS_14SourceLocationENS_8QualTypeERKNS_17PartialDiagnosticE", "clang::Sema::RequireNonAbstractType(clang::SourceLocation, clang::QualType, clang::PartialDiagnostic const&)"},
    {"_ZN5clang4Sema20DiagnoseAbstractTypeEPKNS_13CXXRecordDeclE", "clang::Sema::DiagnoseAbstractType(clang::CXXRecordDecl const*)"},
    {"_ZN5clang4Sema22CheckCompletedCXXClassEPNS_13CXXRecordDeclE", "clang::Sema::CheckCompletedCXXClass(clang::CXXRecordDecl*)"},
    {"_Z23CheckAbstractClassUsageRN12_GLOBAL__N_117AbstractUsageInfoEPN5clang13CXXRecordDeclE", "CheckAbstractClassUsage((anonymous namespace)::AbstractUsageInfo&, clang::CXXRecordDecl*)"},
    {"_ZN5clang4Sema28DiagnoseHiddenVirtualMethodsEPNS_13CXXRecordDeclEPNS_13CXXMethodDeclE", "clang::Sema::DiagnoseHiddenVirtualMethods(clang::CXXRecordDecl*, clang::CXXMethodDecl*)"},
    {"_ZN5clang4Sema28DeclareInheritedConstructorsEPNS_13CXXRecordDeclE", "clang::Sema::DeclareInheritedConstructors(clang::CXXRecordDecl*)"},
    {"_Z23FindHiddenVirtualMethodPKN5clang16CXXBaseSpecifierERNS_11CXXBasePathEPv", "FindHiddenVirtualMethod(clang::CXXBaseSpecifier const*, clang::CXXBasePath&, void*)"},
    {"_ZN5clang4Sema33ActOnFinishCXXMemberSpecificationEPNS_5ScopeENS_14SourceLocationEPNS_4DeclES3_S3_PNS_13AttributeListE", "clang::Sema::ActOnFinishCXXMemberSpecification(clang::Scope*, clang::SourceLocation, clang::Decl*, clang::SourceLocation, clang::SourceLocation, clang::AttributeList*)"},
    {"_ZN5clang4Sema35AddImplicitlyDeclaredMembersToClassEPNS_13CXXRecordDeclE", "clang::Sema::AddImplicitlyDeclaredMembersToClass(clang::CXXRecordDecl*)"},
    {"_ZN5clang4Sema29DeclareImplicitCopyAssignmentEPNS_13CXXRecordDeclE", "clang::Sema::DeclareImplicitCopyAssignment(clang::CXXRecordDecl*)"},
    {"_ZN5clang4Sema25DeclareImplicitDestructorEPNS_13CXXRecordDeclE", "clang::Sema::DeclareImplicitDestructor(clang::CXXRecordDecl*)"},
    {"_ZN5clang4Sema25ActOnReenterTemplateScopeEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnReenterTemplateScope(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema35ActOnStartDelayedMemberDeclarationsEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnStartDelayedMemberDeclarations(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema36ActOnFinishDelayedMemberDeclarationsEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnFinishDelayedMemberDeclarations(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema37ActOnStartDelayedCXXMethodDeclarationEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnStartDelayedCXXMethodDeclaration(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema30ActOnDelayedCXXMethodParameterEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnDelayedCXXMethodParameter(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema38ActOnFinishDelayedCXXMethodDeclarationEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnFinishDelayedCXXMethodDeclaration(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema16CheckConstructorEPNS_18CXXConstructorDeclE", "clang::Sema::CheckConstructor(clang::CXXConstructorDecl*)"},
    {"_ZN5clang4Sema26CheckConstructorDeclaratorERNS_10DeclaratorENS_8QualTypeERNS_12StorageClassE", "clang::Sema::CheckConstructorDeclarator(clang::Declarator&, clang::QualType, clang::StorageClass&)"},
    {"_ZN5clang4Sema15CheckDestructorEPNS_17CXXDestructorDeclE", "clang::Sema::CheckDestructor(clang::CXXDestructorDecl*)"},
    {"_ZN5clang4Sema25CheckDestructorDeclaratorERNS_10DeclaratorENS_8QualTypeERNS_12StorageClassE", "clang::Sema::CheckDestructorDeclarator(clang::Declarator&, clang::QualType, clang::StorageClass&)"},
    {"_ZN5clang4Sema25CheckConversionDeclaratorERNS_10DeclaratorERNS_8QualTypeERNS_12StorageClassE", "clang::Sema::CheckConversionDeclarator(clang::Declarator&, clang::QualType&, clang::StorageClass&)"},
    {"_ZN5clang4Sema25ActOnConversionDeclaratorEPNS_17CXXConversionDeclE", "clang::Sema::ActOnConversionDeclarator(clang::CXXConversionDecl*)"},
    {"_ZN5clang4Sema22ActOnStartNamespaceDefEPNS_5ScopeENS_14SourceLocationES3_PNS_14IdentifierInfoES3_PNS_13AttributeListE", "clang::Sema::ActOnStartNamespaceDef(clang::Scope*, clang::SourceLocation, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::AttributeList*)"},
    {"_ZNK5clang4Sema15getStdNamespaceEv", "clang::Sema::getStdNamespace() const"},
    {"_ZN5clang4Sema23ActOnFinishNamespaceDefEPNS_4DeclENS_14SourceLocationE", "clang::Sema::ActOnFinishNamespaceDef(clang::Decl*, clang::SourceLocation)"},
    {"_ZNK5clang4Sema14getStdBadAllocEv", "clang::Sema::getStdBadAlloc() const"},
    {"_ZN5clang4Sema23getOrCreateStdNamespaceEv", "clang::Sema::getOrCreateStdNamespace()"},
    {"_ZN5clang4Sema19ActOnUsingDirectiveEPNS_5ScopeENS_14SourceLocationES3_RNS_12CXXScopeSpecES3_PNS_14IdentifierInfoEPNS_13AttributeListE", "clang::Sema::ActOnUsingDirective(clang::Scope*, clang::SourceLocation, clang::SourceLocation, clang::CXXScopeSpec&, clang::SourceLocation, clang::IdentifierInfo*, clang::AttributeList*)"},
    {"_ZN5clang4Sema18PushUsingDirectiveEPNS_5ScopeEPNS_18UsingDirectiveDeclE", "clang::Sema::PushUsingDirective(clang::Scope*, clang::UsingDirectiveDecl*)"},
    {"_ZN5clang4Sema21ActOnUsingDeclarationEPNS_5ScopeENS_15AccessSpecifierEbNS_14SourceLocationERNS_12CXXScopeSpecERNS_13UnqualifiedIdEPNS_13AttributeListEbS4_", "clang::Sema::ActOnUsingDeclaration(clang::Scope*, clang::AccessSpecifier, bool, clang::SourceLocation, clang::CXXScopeSpec&, clang::UnqualifiedId&, clang::AttributeList*, bool, clang::SourceLocation)"},
    {"_ZN5clang4Sema21BuildUsingDeclarationEPNS_5ScopeENS_15AccessSpecifierENS_14SourceLocationERNS_12CXXScopeSpecERKNS_19DeclarationNameInfoEPNS_13AttributeListEbbS4_", "clang::Sema::BuildUsingDeclaration(clang::Scope*, clang::AccessSpecifier, clang::SourceLocation, clang::CXXScopeSpec&, clang::DeclarationNameInfo const&, clang::AttributeList*, bool, bool, clang::SourceLocation)"},
    {"_ZN5clang4Sema20CheckUsingShadowDeclEPNS_9UsingDeclEPNS_9NamedDeclERKNS_12LookupResultE", "clang::Sema::CheckUsingShadowDecl(clang::UsingDecl*, clang::NamedDecl*, clang::LookupResult const&)"},
    {"_ZN5clang4Sema20BuildUsingShadowDeclEPNS_5ScopeEPNS_9UsingDeclEPNS_9NamedDeclE", "clang::Sema::BuildUsingShadowDecl(clang::Scope*, clang::UsingDecl*, clang::NamedDecl*)"},
    {"_ZN5clang4Sema19HideUsingShadowDeclEPNS_5ScopeEPNS_15UsingShadowDeclE", "clang::Sema::HideUsingShadowDecl(clang::Scope*, clang::UsingShadowDecl*)"},
    {"_ZN5clang4Sema27CheckUsingDeclRedeclarationENS_14SourceLocationEbRKNS_12CXXScopeSpecES1_RKNS_12LookupResultE", "clang::Sema::CheckUsingDeclRedeclaration(clang::SourceLocation, bool, clang::CXXScopeSpec const&, clang::SourceLocation, clang::LookupResult const&)"},
    {"_ZN5clang4Sema23CheckUsingDeclQualifierENS_14SourceLocationERKNS_12CXXScopeSpecES1_", "clang::Sema::CheckUsingDeclQualifier(clang::SourceLocation, clang::CXXScopeSpec const&, clang::SourceLocation)"},
    {"_ZN5clang4Sema34CheckInheritedConstructorUsingDeclEPNS_9UsingDeclE", "clang::Sema::CheckInheritedConstructorUsingDecl(clang::UsingDecl*)"},
    {"_ZN5clang4Sema22ActOnNamespaceAliasDefEPNS_5ScopeENS_14SourceLocationES3_PNS_14IdentifierInfoERNS_12CXXScopeSpecES3_S5_", "clang::Sema::ActOnNamespaceAliasDef(clang::Scope*, clang::SourceLocation, clang::SourceLocation, clang::IdentifierInfo*, clang::CXXScopeSpec&, clang::SourceLocation, clang::IdentifierInfo*)"},
    {"_ZN5clang4Sema33DeclareImplicitDefaultConstructorEPNS_13CXXRecordDeclE", "clang::Sema::DeclareImplicitDefaultConstructor(clang::CXXRecordDecl*)"},
    {"_ZN12_GLOBAL__N_130ImplicitExceptionSpecification10CalledDeclEPN5clang13CXXMethodDeclE", "(anonymous namespace)::ImplicitExceptionSpecification::CalledDecl(clang::CXXMethodDecl*)"},
    {"_Z27getDefaultConstructorUnsafeRN5clang4SemaEPNS_13CXXRecordDeclE", "getDefaultConstructorUnsafe(clang::Sema&, clang::CXXRecordDecl*)"},
    {"_ZN5clang4Sema32DefineImplicitDefaultConstructorENS_14SourceLocationEPNS_18CXXConstructorDeclE", "clang::Sema::DefineImplicitDefaultConstructor(clang::SourceLocation, clang::CXXConstructorDecl*)"},
    {"_ZN5clang4Sema14MarkVTableUsedENS_14SourceLocationEPNS_13CXXRecordDeclEb", "clang::Sema::MarkVTableUsed(clang::SourceLocation, clang::CXXRecordDecl*, bool)"},
    {"_ZN5clang4Sema24DefineImplicitDestructorENS_14SourceLocationEPNS_17CXXDestructorDeclE", "clang::Sema::DefineImplicitDestructor(clang::SourceLocation, clang::CXXDestructorDecl*)"},
    {"_Z22hasConstCopyAssignmentRN5clang4SemaEPKNS_13CXXRecordDeclE", "hasConstCopyAssignment(clang::Sema&, clang::CXXRecordDecl const*)"},
    {"_ZN5clang4Sema28DefineImplicitCopyAssignmentENS_14SourceLocationEPNS_13CXXMethodDeclE", "clang::Sema::DefineImplicitCopyAssignment(clang::SourceLocation, clang::CXXMethodDecl*)"},
    {"_Z21BuildSingleCopyAssignRN5clang4SemaENS_14SourceLocationENS_8QualTypeEPNS_4ExprES5_bj", "BuildSingleCopyAssign(clang::Sema&, clang::SourceLocation, clang::QualType, clang::Expr*, clang::Expr*, bool, unsigned int)"},
    {"_ZN5clang4Sema30DeclareImplicitCopyConstructorEPNS_13CXXRecordDeclE", "clang::Sema::DeclareImplicitCopyConstructor(clang::CXXRecordDecl*)"},
    {"_ZN5clang4Sema29DefineImplicitCopyConstructorENS_14SourceLocationEPNS_18CXXConstructorDeclEj", "clang::Sema::DefineImplicitCopyConstructor(clang::SourceLocation, clang::CXXConstructorDecl*, unsigned int)"},
    {"_ZN5clang4Sema21BuildCXXConstructExprENS_14SourceLocationENS_8QualTypeEPNS_18CXXConstructorDeclENS_11ASTMultiPtrIPNS_4ExprEEEbjNS_11SourceRangeE", "clang::Sema::BuildCXXConstructExpr(clang::SourceLocation, clang::QualType, clang::CXXConstructorDecl*, clang::ASTMultiPtr<clang::Expr*>, bool, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21BuildCXXConstructExprENS_14SourceLocationENS_8QualTypeEPNS_18CXXConstructorDeclEbNS_11ASTMultiPtrIPNS_4ExprEEEbjNS_11SourceRangeE", "clang::Sema::BuildCXXConstructExpr(clang::SourceLocation, clang::QualType, clang::CXXConstructorDecl*, bool, clang::ASTMultiPtr<clang::Expr*>, bool, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema28InitializeVarWithConstructorEPNS_7VarDeclEPNS_18CXXConstructorDeclENS_11ASTMultiPtrIPNS_4ExprEEE", "clang::Sema::InitializeVarWithConstructor(clang::VarDecl*, clang::CXXConstructorDecl*, clang::ASTMultiPtr<clang::Expr*>)"},
    {"_ZN5clang4Sema25FinalizeVarWithDestructorEPNS_7VarDeclEPKNS_10RecordTypeE", "clang::Sema::FinalizeVarWithDestructor(clang::VarDecl*, clang::RecordType const*)"},
    {"_ZN5clang4Sema29AddCXXDirectInitializerToDeclEPNS_4DeclENS_14SourceLocationENS_11ASTMultiPtrIPNS_4ExprEEES3_", "clang::Sema::AddCXXDirectInitializerToDecl(clang::Decl*, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation)"},
    {"_ZN5clang4Sema23CompleteConstructorCallEPNS_18CXXConstructorDeclENS_11ASTMultiPtrIPNS_4ExprEEENS_14SourceLocationERNS_15ASTOwningVectorIS5_Lj8EEE", "clang::Sema::CompleteConstructorCall(clang::CXXConstructorDecl*, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation, clang::ASTOwningVector<clang::Expr*, 8u>&)"},
    {"_ZN5clang4Sema34CheckOverloadedOperatorDeclarationEPNS_12FunctionDeclE", "clang::Sema::CheckOverloadedOperatorDeclaration(clang::FunctionDecl*)"},
    {"_ZN5clang4Sema31CheckLiteralOperatorDeclarationEPNS_12FunctionDeclE", "clang::Sema::CheckLiteralOperatorDeclaration(clang::FunctionDecl*)"},
    {"_ZN5clang4Sema30ActOnStartLinkageSpecificationEPNS_5ScopeENS_14SourceLocationES3_N4llvm9StringRefES3_", "clang::Sema::ActOnStartLinkageSpecification(clang::Scope*, clang::SourceLocation, clang::SourceLocation, llvm::StringRef, clang::SourceLocation)"},
    {"_ZN5clang4Sema31ActOnFinishLinkageSpecificationEPNS_5ScopeEPNS_4DeclENS_14SourceLocationE", "clang::Sema::ActOnFinishLinkageSpecification(clang::Scope*, clang::Decl*, clang::SourceLocation)"},
    {"_ZN5clang4Sema25BuildExceptionDeclarationEPNS_5ScopeEPNS_14TypeSourceInfoEPNS_14IdentifierInfoENS_14SourceLocationE", "clang::Sema::BuildExceptionDeclaration(clang::Scope*, clang::TypeSourceInfo*, clang::IdentifierInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema24ActOnExceptionDeclaratorEPNS_5ScopeERNS_10DeclaratorE", "clang::Sema::ActOnExceptionDeclarator(clang::Scope*, clang::Declarator&)"},
    {"_ZN5clang4Sema28ActOnStaticAssertDeclarationENS_14SourceLocationEPNS_4ExprES3_", "clang::Sema::ActOnStaticAssertDeclaration(clang::SourceLocation, clang::Expr*, clang::Expr*)"},
    {"_ZN5clang4Sema19CheckFriendTypeDeclENS_14SourceLocationEPNS_14TypeSourceInfoE", "clang::Sema::CheckFriendTypeDecl(clang::SourceLocation, clang::TypeSourceInfo*)"},
    {"_ZN5clang4Sema23ActOnTemplatedFriendTagEPNS_5ScopeENS_14SourceLocationEjS3_RNS_12CXXScopeSpecEPNS_14IdentifierInfoES3_PNS_13AttributeListENS_11ASTMultiPtrIPNS_21TemplateParameterListEEE", "clang::Sema::ActOnTemplatedFriendTag(clang::Scope*, clang::SourceLocation, unsigned int, clang::SourceLocation, clang::CXXScopeSpec&, clang::IdentifierInfo*, clang::SourceLocation, clang::AttributeList*, clang::ASTMultiPtr<clang::TemplateParameterList*>)"},
    {"_ZN5clang4Sema19ActOnFriendTypeDeclEPNS_5ScopeERKNS_8DeclSpecENS_11ASTMultiPtrIPNS_21TemplateParameterListEEE", "clang::Sema::ActOnFriendTypeDecl(clang::Scope*, clang::DeclSpec const&, clang::ASTMultiPtr<clang::TemplateParameterList*>)"},
    {"_ZN5clang4Sema23ActOnFriendFunctionDeclEPNS_5ScopeERNS_10DeclaratorEbNS_11ASTMultiPtrIPNS_21TemplateParameterListEEE", "clang::Sema::ActOnFriendFunctionDecl(clang::Scope*, clang::Declarator&, bool, clang::ASTMultiPtr<clang::TemplateParameterList*>)"},
    {"_ZN5clang4Sema43DiagnoseReturnInConstructorExceptionHandlerEPNS_10CXXTryStmtE", "clang::Sema::DiagnoseReturnInConstructorExceptionHandler(clang::CXXTryStmt*)"},
    {"_Z21SearchForReturnInStmtRN5clang4SemaEPNS_4StmtE", "SearchForReturnInStmt(clang::Sema&, clang::Stmt*)"},
    {"_ZN5clang4Sema33CheckOverridingFunctionReturnTypeEPKNS_13CXXMethodDeclES3_", "clang::Sema::CheckOverridingFunctionReturnType(clang::CXXMethodDecl const*, clang::CXXMethodDecl const*)"},
    {"_ZN5clang4Sema15CheckPureMethodEPNS_13CXXMethodDeclENS_11SourceRangeE", "clang::Sema::CheckPureMethod(clang::CXXMethodDecl*, clang::SourceRange)"},
    {"_ZN5clang4Sema28ActOnCXXEnterDeclInitializerEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnCXXEnterDeclInitializer(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema27ActOnCXXExitDeclInitializerEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnCXXExitDeclInitializer(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema28ActOnCXXConditionDeclarationEPNS_5ScopeERNS_10DeclaratorE", "clang::Sema::ActOnCXXConditionDeclaration(clang::Scope*, clang::Declarator&)"},
    {"_ZN5clang4Sema28MarkVirtualMembersReferencedENS_14SourceLocationEPKNS_13CXXRecordDeclE", "clang::Sema::MarkVirtualMembersReferenced(clang::SourceLocation, clang::CXXRecordDecl const*)"},
    {"_ZN5clang4Sema17DefineUsedVTablesEv", "clang::Sema::DefineUsedVTables()"},
    {"_ZN5clang4Sema19SetIvarInitializersEPNS_22ObjCImplementationDeclE", "clang::Sema::SetIvarInitializers(clang::ObjCImplementationDecl*)"},
    {"_ZN12_GLOBAL__N_127CheckDefaultArgumentVisitor9VisitExprEPN5clang4ExprE", "(anonymous namespace)::CheckDefaultArgumentVisitor::VisitExpr(clang::Expr*)"},
    {"_Z38CheckOperatorNewDeleteDeclarationScopeRN5clang4SemaEPKNS_12FunctionDeclE", "CheckOperatorNewDeleteDeclarationScope(clang::Sema&, clang::FunctionDecl const*)"},
    {"_Z27CheckOperatorNewDeleteTypesRN5clang4SemaEPKNS_12FunctionDeclENS_7CanQualINS_4TypeEEES7_jj", "CheckOperatorNewDeleteTypes(clang::Sema&, clang::FunctionDecl const*, clang::CanQual<clang::Type>, clang::CanQual<clang::Type>, unsigned int, unsigned int)"},
    {"_ZZN5clang4Sema23CheckUsingDeclQualifierENS_14SourceLocationERKNS_12CXXScopeSpecES1_EN8UserData14doesNotContainEPKNS_13CXXRecordDeclEPv", "clang::Sema::CheckUsingDeclQualifier(clang::SourceLocation, clang::CXXScopeSpec const&, clang::SourceLocation)::UserData::doesNotContain(clang::CXXRecordDecl const*, void*)"},
    {"_ZZN5clang4Sema23CheckUsingDeclQualifierENS_14SourceLocationERKNS_12CXXScopeSpecES1_EN8UserData7collectEPKNS_13CXXRecordDeclEPv", "clang::Sema::CheckUsingDeclQualifier(clang::SourceLocation, clang::CXXScopeSpec const&, clang::SourceLocation)::UserData::collect(clang::CXXRecordDecl const*, void*)"},
    {"_ZN12_GLOBAL__N_118CheckAbstractUsage5VisitEN5clang7TypeLocENS1_4Sema17AbstractDiagSelIDE", "(anonymous namespace)::CheckAbstractUsage::Visit(clang::TypeLoc, clang::Sema::AbstractDiagSelID)"},
    {"_ZN12_GLOBAL__N_118CheckAbstractUsage5CheckEN5clang7TypeLocENS1_4Sema17AbstractDiagSelIDE", "(anonymous namespace)::CheckAbstractUsage::Check(clang::TypeLoc, clang::Sema::AbstractDiagSelID)"},
    {"_ZN5clang14AccessSpecDecl6CreateERNS_10ASTContextENS_15AccessSpecifierEPNS_11DeclContextENS_14SourceLocationES6_", "clang::AccessSpecDecl::Create(clang::ASTContext&, clang::AccessSpecifier, clang::DeclContext*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeESt4pairINS1_7CanQualIS2_EEPNS1_18CXXConstructorDeclEENS_12DenseMapInfoIS4_EENSB_ISA_EEE6insertERKS5_IS4_SA_E", "llvm::DenseMap<clang::Type const*, std::pair<clang::CanQual<clang::Type>, clang::CXXConstructorDecl*>, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<std::pair<clang::CanQual<clang::Type>, clang::CXXConstructorDecl*>>>::insert(std::pair<clang::Type const*, std::pair<clang::CanQual<clang::Type>, clang::CXXConstructorDecl*>> const&)"},
    {"_ZN4llvm8DenseMapIPN5clang13CXXRecordDeclEbNS_12DenseMapInfoIS3_EENS4_IbEEE6insertERKSt4pairIS3_bE", "llvm::DenseMap<clang::CXXRecordDecl*, bool, llvm::DenseMapInfo<clang::CXXRecordDecl*>, llvm::DenseMapInfo<bool>>::insert(std::pair<clang::CXXRecordDecl*, bool> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeESt4pairINS1_7CanQualIS2_EEPNS1_18CXXConstructorDeclEENS_12DenseMapInfoIS4_EENSB_ISA_EEE16InsertIntoBucketERKS4_RKSA_PS5_IS4_SA_E", "llvm::DenseMap<clang::Type const*, std::pair<clang::CanQual<clang::Type>, clang::CXXConstructorDecl*>, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<std::pair<clang::CanQual<clang::Type>, clang::CXXConstructorDecl*>>>::InsertIntoBucket(clang::Type const* const&, std::pair<clang::CanQual<clang::Type>, clang::CXXConstructorDecl*> const&, std::pair<clang::Type const*, std::pair<clang::CanQual<clang::Type>, clang::CXXConstructorDecl*>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeESt4pairINS1_7CanQualIS2_EEPNS1_18CXXConstructorDeclEENS_12DenseMapInfoIS4_EENSB_ISA_EEE4growEj", "llvm::DenseMap<clang::Type const*, std::pair<clang::CanQual<clang::Type>, clang::CXXConstructorDecl*>, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<std::pair<clang::CanQual<clang::Type>, clang::CXXConstructorDecl*>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPvPN5clang18CXXCtorInitializerENS_12DenseMapInfoIS1_EENS5_IS4_EEE16InsertIntoBucketERKS1_RKS4_PSt4pairIS1_S4_E", "llvm::DenseMap<void*, clang::CXXCtorInitializer*, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<clang::CXXCtorInitializer*>>::InsertIntoBucket(void* const&, clang::CXXCtorInitializer* const&, std::pair<void*, clang::CXXCtorInitializer*>*)"},
    {"_ZN4llvm8DenseMapIPvPN5clang18CXXCtorInitializerENS_12DenseMapInfoIS1_EENS5_IS4_EEE4growEj", "llvm::DenseMap<void*, clang::CXXCtorInitializer*, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<clang::CXXCtorInitializer*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKvPN5clang18CXXCtorInitializerENS_12DenseMapInfoIS2_EENS6_IS5_EEE16InsertIntoBucketERKS2_RKS5_PSt4pairIS2_S5_E", "llvm::DenseMap<void const*, clang::CXXCtorInitializer*, llvm::DenseMapInfo<void const*>, llvm::DenseMapInfo<clang::CXXCtorInitializer*>>::InsertIntoBucket(void const* const&, clang::CXXCtorInitializer* const&, std::pair<void const*, clang::CXXCtorInitializer*>*)"},
    {"_ZN4llvm8DenseMapIPKvPN5clang18CXXCtorInitializerENS_12DenseMapInfoIS2_EENS6_IS5_EEE4growEj", "llvm::DenseMap<void const*, clang::CXXCtorInitializer*, llvm::DenseMapInfo<void const*>, llvm::DenseMapInfo<clang::CXXCtorInitializer*>>::grow(unsigned int)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_PNS0_16CXXBaseSpecifierEESt10_Select1stIS6_ENS0_16QualTypeOrderingESaIS6_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS6_ERKS6_", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, clang::CXXBaseSpecifier*>, std::_Select1st<std::pair<clang::QualType const, clang::CXXBaseSpecifier*>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, clang::CXXBaseSpecifier*>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::QualType const, clang::CXXBaseSpecifier*>>, std::pair<clang::QualType const, clang::CXXBaseSpecifier*> const&)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_PNS0_16CXXBaseSpecifierEESt10_Select1stIS6_ENS0_16QualTypeOrderingESaIS6_EE16_M_insert_uniqueERKS6_", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, clang::CXXBaseSpecifier*>, std::_Select1st<std::pair<clang::QualType const, clang::CXXBaseSpecifier*>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, clang::CXXBaseSpecifier*>>>::_M_insert_unique(std::pair<clang::QualType const, clang::CXXBaseSpecifier*> const&)"},
    {"_ZN4llvm8DenseMapIPN5clang11ParmVarDeclENS1_14SourceLocationENS_12DenseMapInfoIS3_EENS5_IS4_EEE16InsertIntoBucketERKS3_RKS4_PSt4pairIS3_S4_E", "llvm::DenseMap<clang::ParmVarDecl*, clang::SourceLocation, llvm::DenseMapInfo<clang::ParmVarDecl*>, llvm::DenseMapInfo<clang::SourceLocation>>::InsertIntoBucket(clang::ParmVarDecl* const&, clang::SourceLocation const&, std::pair<clang::ParmVarDecl*, clang::SourceLocation>*)"},
    {"_ZN4llvm8DenseMapIPN5clang11ParmVarDeclENS1_14SourceLocationENS_12DenseMapInfoIS3_EENS5_IS4_EEE4growEj", "llvm::DenseMap<clang::ParmVarDecl*, clang::SourceLocation, llvm::DenseMapInfo<clang::ParmVarDecl*>, llvm::DenseMapInfo<clang::SourceLocation>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEcNS_12DenseMapInfoIS4_EENS5_IcEEE6insertERKSt4pairIS4_cE", "llvm::DenseMap<clang::CXXRecordDecl const*, char, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<char>>::insert(std::pair<clang::CXXRecordDecl const*, char> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEcNS_12DenseMapInfoIS4_EENS5_IcEEE16InsertIntoBucketERKS4_RKcPSt4pairIS4_cE", "llvm::DenseMap<clang::CXXRecordDecl const*, char, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<char>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, char const&, std::pair<clang::CXXRecordDecl const*, char>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEcNS_12DenseMapInfoIS4_EENS5_IcEEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, char, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZN5clang15UsingShadowDeclC2EPNS_11DeclContextENS_14SourceLocationEPNS_9UsingDeclEPNS_9NamedDeclE", "clang::UsingShadowDecl::UsingShadowDecl(clang::DeclContext*, clang::SourceLocation, clang::UsingDecl*, clang::NamedDecl*)"},
    {"_ZN5clang15UsingShadowDeclD1Ev", "clang::UsingShadowDecl::~UsingShadowDecl()"},
    {"_ZN5clang15UsingShadowDeclD0Ev", "clang::UsingShadowDecl::~UsingShadowDecl()"},
    {"_ZN4llvm8DenseMapIPN5clang10RecordDeclESt4pairIPNS1_9NamedDeclEPNS1_18CXXCtorInitializerEENS_12DenseMapInfoIS3_EENSA_IS9_EEE16InsertIntoBucketERKS3_RKS9_PS4_IS3_S9_E", "llvm::DenseMap<clang::RecordDecl*, std::pair<clang::NamedDecl*, clang::CXXCtorInitializer*>, llvm::DenseMapInfo<clang::RecordDecl*>, llvm::DenseMapInfo<std::pair<clang::NamedDecl*, clang::CXXCtorInitializer*>>>::InsertIntoBucket(clang::RecordDecl* const&, std::pair<clang::NamedDecl*, clang::CXXCtorInitializer*> const&, std::pair<clang::RecordDecl*, std::pair<clang::NamedDecl*, clang::CXXCtorInitializer*>>*)"},
    {"_ZN4llvm8DenseMapIPN5clang10RecordDeclESt4pairIPNS1_9NamedDeclEPNS1_18CXXCtorInitializerEENS_12DenseMapInfoIS3_EENSA_IS9_EEE4growEj", "llvm::DenseMap<clang::RecordDecl*, std::pair<clang::NamedDecl*, clang::CXXCtorInitializer*>, llvm::DenseMapInfo<clang::RecordDecl*>, llvm::DenseMapInfo<std::pair<clang::NamedDecl*, clang::CXXCtorInitializer*>>>::grow(unsigned int)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang17InitializedEntityELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::InitializedEntity, false>::grow(unsigned long)"},
    {"_ZN5clang14AccessSpecDeclD1Ev", "clang::AccessSpecDecl::~AccessSpecDecl()"},
    {"_ZN5clang14AccessSpecDeclD0Ev", "clang::AccessSpecDecl::~AccessSpecDecl()"},
    {"_ZNK5clang14AccessSpecDecl14getSourceRangeEv", "clang::AccessSpecDecl::getSourceRange() const"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_PNS0_16CXXBaseSpecifierEESt10_Select1stIS6_ENS0_16QualTypeOrderingESaIS6_EE8_M_eraseEPSt13_Rb_tree_nodeIS6_E", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, clang::CXXBaseSpecifier*>, std::_Select1st<std::pair<clang::QualType const, clang::CXXBaseSpecifier*>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, clang::CXXBaseSpecifier*>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::QualType const, clang::CXXBaseSpecifier*>>*)"},
    {"_ZN5clang4Sema25ActOnStartOfObjCMethodDefEPNS_5ScopeEPNS_4DeclE", "clang::Sema::ActOnStartOfObjCMethodDef(clang::Scope*, clang::Decl*)"},
    {"_ZN5clang4Sema24ActOnStartClassInterfaceENS_14SourceLocationEPNS_14IdentifierInfoES1_S3_S1_PKPNS_4DeclEjPKS1_S1_PNS_13AttributeListE", "clang::Sema::ActOnStartClassInterface(clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::Decl* const*, unsigned int, clang::SourceLocation const*, clang::SourceLocation, clang::AttributeList*)"},
    {"_ZN5clang4Sema18CheckObjCDeclScopeEPNS_4DeclE", "clang::Sema::CheckObjCDeclScope(clang::Decl*)"},
    {"_ZN5clang4Sema22ActOnCompatiblityAliasENS_14SourceLocationEPNS_14IdentifierInfoES1_S3_S1_", "clang::Sema::ActOnCompatiblityAlias(clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema52CheckForwardProtocolDeclarationForCircularDependencyEPNS_14IdentifierInfoERNS_14SourceLocationES3_RKNS_8ObjCListINS_16ObjCProtocolDeclEEE", "clang::Sema::CheckForwardProtocolDeclarationForCircularDependency(clang::IdentifierInfo*, clang::SourceLocation&, clang::SourceLocation, clang::ObjCList<clang::ObjCProtocolDecl> const&)"},
    {"_ZN5clang4Sema27ActOnStartProtocolInterfaceENS_14SourceLocationEPNS_14IdentifierInfoES1_PKPNS_4DeclEjPKS1_S1_PNS_13AttributeListE", "clang::Sema::ActOnStartProtocolInterface(clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::Decl* const*, unsigned int, clang::SourceLocation const*, clang::SourceLocation, clang::AttributeList*)"},
    {"_ZN5clang4Sema23FindProtocolDeclarationEbPKSt4pairIPNS_14IdentifierInfoENS_14SourceLocationEEjRN4llvm15SmallVectorImplIPNS_4DeclEEE", "clang::Sema::FindProtocolDeclaration(bool, std::pair<clang::IdentifierInfo*, clang::SourceLocation> const*, unsigned int, llvm::SmallVectorImpl<clang::Decl*>&)"},
    {"_ZN5clang4Sema32DiagnoseClassExtensionDupMethodsEPNS_16ObjCCategoryDeclEPNS_17ObjCInterfaceDeclE", "clang::Sema::DiagnoseClassExtensionDupMethods(clang::ObjCCategoryDecl*, clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang4Sema26MatchTwoMethodDeclarationsEPKNS_14ObjCMethodDeclES3_bb", "clang::Sema::MatchTwoMethodDeclarations(clang::ObjCMethodDecl const*, clang::ObjCMethodDecl const*, bool, bool)"},
    {"_ZN5clang4Sema31ActOnForwardProtocolDeclarationENS_14SourceLocationEPKSt4pairIPNS_14IdentifierInfoES1_EjPNS_13AttributeListE", "clang::Sema::ActOnForwardProtocolDeclaration(clang::SourceLocation, std::pair<clang::IdentifierInfo*, clang::SourceLocation> const*, unsigned int, clang::AttributeList*)"},
    {"_ZN5clang4Sema27ActOnStartCategoryInterfaceENS_14SourceLocationEPNS_14IdentifierInfoES1_S3_S1_PKPNS_4DeclEjPKS1_S1_", "clang::Sema::ActOnStartCategoryInterface(clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::Decl* const*, unsigned int, clang::SourceLocation const*, clang::SourceLocation)"},
    {"_ZN5clang4Sema32ActOnStartCategoryImplementationENS_14SourceLocationEPNS_14IdentifierInfoES1_S3_S1_", "clang::Sema::ActOnStartCategoryImplementation(clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema29ActOnStartClassImplementationENS_14SourceLocationEPNS_14IdentifierInfoES1_S3_S1_", "clang::Sema::ActOnStartClassImplementation(clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema24CheckImplementationIvarsEPNS_22ObjCImplementationDeclEPPNS_12ObjCIvarDeclEjNS_14SourceLocationE", "clang::Sema::CheckImplementationIvars(clang::ObjCImplementationDecl*, clang::ObjCIvarDecl**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang4Sema19WarnUndefinedMethodENS_14SourceLocationEPNS_14ObjCMethodDeclERbj", "clang::Sema::WarnUndefinedMethod(clang::SourceLocation, clang::ObjCMethodDecl*, bool&, unsigned int)"},
    {"_ZN5clang4Sema27WarnConflictingTypedMethodsEPNS_14ObjCMethodDeclES2_", "clang::Sema::WarnConflictingTypedMethods(clang::ObjCMethodDecl*, clang::ObjCMethodDecl*)"},
    {"_ZN5clang4Sema23CheckProtocolMethodDefsENS_14SourceLocationEPNS_16ObjCProtocolDeclERbRKN4llvm8DenseSetINS_8SelectorENS5_12DenseMapInfoIS7_EEEESC_PNS_17ObjCContainerDeclE", "clang::Sema::CheckProtocolMethodDefs(clang::SourceLocation, clang::ObjCProtocolDecl*, bool&, llvm::DenseSet<clang::Selector, llvm::DenseMapInfo<clang::Selector>> const&, llvm::DenseSet<clang::Selector, llvm::DenseMapInfo<clang::Selector>> const&, clang::ObjCContainerDecl*)"},
    {"_ZN5clang4Sema26MatchAllMethodDeclarationsERKN4llvm8DenseSetINS_8SelectorENS1_12DenseMapInfoIS3_EEEES8_RS6_S9_PNS_12ObjCImplDeclEPNS_17ObjCContainerDeclERbb", "clang::Sema::MatchAllMethodDeclarations(llvm::DenseSet<clang::Selector, llvm::DenseMapInfo<clang::Selector>> const&, llvm::DenseSet<clang::Selector, llvm::DenseMapInfo<clang::Selector>> const&, llvm::DenseSet<clang::Selector, llvm::DenseMapInfo<clang::Selector>>&, llvm::DenseSet<clang::Selector, llvm::DenseMapInfo<clang::Selector>>&, clang::ObjCImplDecl*, clang::ObjCContainerDecl*, bool&, bool)"},
    {"_ZN5clang4Sema25ImplMethodsVsClassMethodsEPNS_5ScopeEPNS_12ObjCImplDeclEPNS_17ObjCContainerDeclEb", "clang::Sema::ImplMethodsVsClassMethods(clang::Scope*, clang::ObjCImplDecl*, clang::ObjCContainerDecl*, bool)"},
    {"_ZN5clang4Sema28ActOnForwardClassDeclarationENS_14SourceLocationEPPNS_14IdentifierInfoEPS1_j", "clang::Sema::ActOnForwardClassDeclaration(clang::SourceLocation, clang::IdentifierInfo**, clang::SourceLocation*, unsigned int)"},
    {"_ZN5clang4Sema14ReadMethodPoolENS_8SelectorE", "clang::Sema::ReadMethodPool(clang::Selector)"},
    {"_ZN5clang4Sema21AddMethodToGlobalPoolEPNS_14ObjCMethodDeclEbb", "clang::Sema::AddMethodToGlobalPool(clang::ObjCMethodDecl*, bool, bool)"},
    {"_ZN5clang4Sema24LookupMethodInGlobalPoolENS_8SelectorENS_11SourceRangeEbbb", "clang::Sema::LookupMethodInGlobalPool(clang::Selector, clang::SourceRange, bool, bool, bool)"},
    {"_ZN5clang4Sema35LookupImplementedMethodInGlobalPoolENS_8SelectorE", "clang::Sema::LookupImplementedMethodInGlobalPool(clang::Selector)"},
    {"_ZN5clang4Sema33CompareMethodParamsInBaseAndSuperEPNS_4DeclEPNS_14ObjCMethodDeclEb", "clang::Sema::CompareMethodParamsInBaseAndSuper(clang::Decl*, clang::ObjCMethodDecl*, bool)"},
    {"_ZN5clang4Sema22DiagnoseDuplicateIvarsEPNS_17ObjCInterfaceDeclES2_", "clang::Sema::DiagnoseDuplicateIvars(clang::ObjCInterfaceDecl*, clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang4Sema10ActOnAtEndEPNS_5ScopeENS_11SourceRangeEPNS_4DeclEPS5_jS6_jPNS_9OpaquePtrINS_12DeclGroupRefEEEj", "clang::Sema::ActOnAtEnd(clang::Scope*, clang::SourceRange, clang::Decl*, clang::Decl**, unsigned int, clang::Decl**, unsigned int, clang::OpaquePtr<clang::DeclGroupRef>*, unsigned int)"},
    {"_ZN5clang4Sema22ActOnMethodDeclarationEPNS_5ScopeENS_14SourceLocationES3_NS_3tok9TokenKindEPNS_4DeclERNS_12ObjCDeclSpecENS_9OpaquePtrINS_8QualTypeEEENS_8SelectorEPNS0_11ObjCArgInfoEPNS_15DeclaratorChunk9ParamInfoEjPNS_13AttributeListENS4_15ObjCKeywordKindEb", "clang::Sema::ActOnMethodDeclaration(clang::Scope*, clang::SourceLocation, clang::SourceLocation, clang::tok::TokenKind, clang::Decl*, clang::ObjCDeclSpec&, clang::OpaquePtr<clang::QualType>, clang::Selector, clang::Sema::ObjCArgInfo*, clang::DeclaratorChunk::ParamInfo*, unsigned int, clang::AttributeList*, clang::tok::ObjCKeywordKind, bool)"},
    {"_ZN5clang4Sema9ActOnDefsEPNS_5ScopeEPNS_4DeclENS_14SourceLocationEPNS_14IdentifierInfoERN4llvm15SmallVectorImplIS4_EE", "clang::Sema::ActOnDefs(clang::Scope*, clang::Decl*, clang::SourceLocation, clang::IdentifierInfo*, llvm::SmallVectorImpl<clang::Decl*>&)"},
    {"_ZN5clang4Sema22BuildObjCExceptionDeclEPNS_14TypeSourceInfoENS_8QualTypeEPNS_14IdentifierInfoENS_14SourceLocationEb", "clang::Sema::BuildObjCExceptionDecl(clang::TypeSourceInfo*, clang::QualType, clang::IdentifierInfo*, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema22ActOnObjCExceptionDeclEPNS_5ScopeERNS_10DeclaratorE", "clang::Sema::ActOnObjCExceptionDecl(clang::Scope*, clang::Declarator&)"},
    {"_ZN5clang4Sema33CollectIvarsToConstructOrDestructEPNS_17ObjCInterfaceDeclERN4llvm15SmallVectorImplIPNS_12ObjCIvarDeclEEE", "clang::Sema::CollectIvarsToConstructOrDestruct(clang::ObjCInterfaceDecl*, llvm::SmallVectorImpl<clang::ObjCIvarDecl*>&)"},
    {"_ZN5clang22ObjCImplementationDecl19setIvarInitializersERNS_10ASTContextEPPNS_18CXXCtorInitializerEj", "clang::ObjCImplementationDecl::setIvarInitializers(clang::ASTContext&, clang::CXXCtorInitializer**, unsigned int)"},
    {"_ZN5clang4Sema35DiagnoseUseOfUnimplementedSelectorsEv", "clang::Sema::DiagnoseUseOfUnimplementedSelectors()"},
    {"_Z23isObjCTypeSubstitutableRN5clang10ASTContextEPKNS_21ObjCObjectPointerTypeES4_b", "isObjCTypeSubstitutable(clang::ASTContext&, clang::ObjCObjectPointerType const*, clang::ObjCObjectPointerType const*, bool)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorESt4pairINS1_14ObjCMethodListES4_ENS_12DenseMapInfoIS2_EENS6_IS5_EEE6insertERKS3_IS2_S5_E", "llvm::DenseMap<clang::Selector, std::pair<clang::ObjCMethodList, clang::ObjCMethodList>, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<std::pair<clang::ObjCMethodList, clang::ObjCMethodList>>>::insert(std::pair<clang::Selector, std::pair<clang::ObjCMethodList, clang::ObjCMethodList>> const&)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorESt4pairINS1_14ObjCMethodListES4_ENS_12DenseMapInfoIS2_EENS6_IS5_EEE16InsertIntoBucketERKS2_RKS5_PS3_IS2_S5_E", "llvm::DenseMap<clang::Selector, std::pair<clang::ObjCMethodList, clang::ObjCMethodList>, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<std::pair<clang::ObjCMethodList, clang::ObjCMethodList>>>::InsertIntoBucket(clang::Selector const&, std::pair<clang::ObjCMethodList, clang::ObjCMethodList> const&, std::pair<clang::Selector, std::pair<clang::ObjCMethodList, clang::ObjCMethodList>>*)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorESt4pairINS1_14ObjCMethodListES4_ENS_12DenseMapInfoIS2_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::Selector, std::pair<clang::ObjCMethodList, clang::ObjCMethodList>, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<std::pair<clang::ObjCMethodList, clang::ObjCMethodList>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEcNS_12DenseMapInfoIS2_EENS3_IcEEE6insertERKSt4pairIS2_cE", "llvm::DenseMap<clang::Selector, char, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<char>>::insert(std::pair<clang::Selector, char> const&)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEcNS_12DenseMapInfoIS2_EENS3_IcEEE16InsertIntoBucketERKS2_RKcPSt4pairIS2_cE", "llvm::DenseMap<clang::Selector, char, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<char>>::InsertIntoBucket(clang::Selector const&, char const&, std::pair<clang::Selector, char>*)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEcNS_12DenseMapInfoIS2_EENS3_IcEEE4growEj", "llvm::DenseMap<clang::Selector, char, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEPKNS1_14ObjCMethodDeclENS_12DenseMapInfoIS2_EENS6_IS5_EEE16InsertIntoBucketERKS2_RKS5_PSt4pairIS2_S5_E", "llvm::DenseMap<clang::Selector, clang::ObjCMethodDecl const*, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<clang::ObjCMethodDecl const*>>::InsertIntoBucket(clang::Selector const&, clang::ObjCMethodDecl const* const&, std::pair<clang::Selector, clang::ObjCMethodDecl const*>*)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEPKNS1_14ObjCMethodDeclENS_12DenseMapInfoIS2_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::Selector, clang::ObjCMethodDecl const*, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<clang::ObjCMethodDecl const*>>::grow(unsigned int)"},
    {"_ZN5clang4Sema27CheckSpecifiedExceptionTypeENS_8QualTypeERKNS_11SourceRangeE", "clang::Sema::CheckSpecifiedExceptionType(clang::QualType, clang::SourceRange const&)"},
    {"_ZN5clang4Sema25CheckDistantExceptionSpecENS_8QualTypeE", "clang::Sema::CheckDistantExceptionSpec(clang::QualType)"},
    {"_ZN5clang4Sema28CheckEquivalentExceptionSpecEPNS_12FunctionDeclES2_", "clang::Sema::CheckEquivalentExceptionSpec(clang::FunctionDecl*, clang::FunctionDecl*)"},
    {"_ZN5clang4Sema28CheckEquivalentExceptionSpecERKNS_17PartialDiagnosticES3_PKNS_17FunctionProtoTypeENS_14SourceLocationES6_S7_PbS8_", "clang::Sema::CheckEquivalentExceptionSpec(clang::PartialDiagnostic const&, clang::PartialDiagnostic const&, clang::FunctionProtoType const*, clang::SourceLocation, clang::FunctionProtoType const*, clang::SourceLocation, bool*, bool*)"},
    {"_ZN5clang4Sema28CheckEquivalentExceptionSpecEPKNS_17FunctionProtoTypeENS_14SourceLocationES3_S4_", "clang::Sema::CheckEquivalentExceptionSpec(clang::FunctionProtoType const*, clang::SourceLocation, clang::FunctionProtoType const*, clang::SourceLocation)"},
    {"_ZN5clang4Sema24CheckExceptionSpecSubsetERKNS_17PartialDiagnosticES3_PKNS_17FunctionProtoTypeENS_14SourceLocationES6_S7_", "clang::Sema::CheckExceptionSpecSubset(clang::PartialDiagnostic const&, clang::PartialDiagnostic const&, clang::FunctionProtoType const*, clang::SourceLocation, clang::FunctionProtoType const*, clang::SourceLocation)"},
    {"_ZN5clang4Sema23CheckParamExceptionSpecERKNS_17PartialDiagnosticEPKNS_17FunctionProtoTypeENS_14SourceLocationES6_S7_", "clang::Sema::CheckParamExceptionSpec(clang::PartialDiagnostic const&, clang::FunctionProtoType const*, clang::SourceLocation, clang::FunctionProtoType const*, clang::SourceLocation)"},
    {"_ZN5clang4Sema31CheckExceptionSpecCompatibilityEPNS_4ExprENS_8QualTypeE", "clang::Sema::CheckExceptionSpecCompatibility(clang::Expr*, clang::QualType)"},
    {"_ZN5clang21GetUnderlyingFunctionENS_8QualTypeE", "clang::GetUnderlyingFunction(clang::QualType)"},
    {"_ZN5clang4Sema36CheckOverridingFunctionExceptionSpecEPKNS_13CXXMethodDeclES3_", "clang::Sema::CheckOverridingFunctionExceptionSpec(clang::CXXMethodDecl const*, clang::CXXMethodDecl const*)"},
    {"_ZN5clang4Sema17DiagnoseUseOfDeclEPNS_9NamedDeclENS_14SourceLocationEb", "clang::Sema::DiagnoseUseOfDecl(clang::NamedDecl*, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema21DiagnoseSentinelCallsEPNS_9NamedDeclENS_14SourceLocationEPPNS_4ExprEj", "clang::Sema::DiagnoseSentinelCalls(clang::NamedDecl*, clang::SourceLocation, clang::Expr**, unsigned int)"},
    {"_ZNK5clang4Sema12getExprRangeEPNS_4ExprE", "clang::Sema::getExprRange(clang::Expr*) const"},
    {"_ZN5clang4Sema30DefaultFunctionArrayConversionERPNS_4ExprE", "clang::Sema::DefaultFunctionArrayConversion(clang::Expr*&)"},
    {"_ZN5clang4Sema23DefaultLvalueConversionERPNS_4ExprE", "clang::Sema::DefaultLvalueConversion(clang::Expr*&)"},
    {"_ZN5clang4Sema24ConvertPropertyForRValueERPNS_4ExprE", "clang::Sema::ConvertPropertyForRValue(clang::Expr*&)"},
    {"_ZN5clang4Sema36DefaultFunctionArrayLvalueConversionERPNS_4ExprE", "clang::Sema::DefaultFunctionArrayLvalueConversion(clang::Expr*&)"},
    {"_ZN5clang4Sema21UsualUnaryConversionsERPNS_4ExprE", "clang::Sema::UsualUnaryConversions(clang::Expr*&)"},
    {"_ZN5clang4Sema24DefaultArgumentPromotionERPNS_4ExprE", "clang::Sema::DefaultArgumentPromotion(clang::Expr*&)"},
    {"_ZN5clang4Sema32DefaultVariadicArgumentPromotionERPNS_4ExprENS0_16VariadicCallTypeEPNS_12FunctionDeclE", "clang::Sema::DefaultVariadicArgumentPromotion(clang::Expr*&, clang::Sema::VariadicCallType, clang::FunctionDecl*)"},
    {"_ZN5clang4Sema19DiagRuntimeBehaviorENS_14SourceLocationERKNS_17PartialDiagnosticE", "clang::Sema::DiagRuntimeBehavior(clang::SourceLocation, clang::PartialDiagnostic const&)"},
    {"_ZN5clang4Sema26UsualArithmeticConversionsERPNS_4ExprES3_b", "clang::Sema::UsualArithmeticConversions(clang::Expr*&, clang::Expr*&, bool)"},
    {"_ZN5clang4Sema18ActOnStringLiteralEPKNS_5TokenEj", "clang::Sema::ActOnStringLiteral(clang::Token const*, unsigned int)"},
    {"_ZN5clang4Sema16BuildDeclRefExprEPNS_9ValueDeclENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationEPKNS_12CXXScopeSpecE", "clang::Sema::BuildDeclRefExpr(clang::ValueDecl*, clang::QualType, clang::ExprValueKind, clang::SourceLocation, clang::CXXScopeSpec const*)"},
    {"_ZN5clang4Sema16BuildDeclRefExprEPNS_9ValueDeclENS_8QualTypeENS_13ExprValueKindERKNS_19DeclarationNameInfoEPKNS_12CXXScopeSpecE", "clang::Sema::BuildDeclRefExpr(clang::ValueDecl*, clang::QualType, clang::ExprValueKind, clang::DeclarationNameInfo const&, clang::CXXScopeSpec const*)"},
    {"_ZN5clang4Sema25MarkDeclarationReferencedENS_14SourceLocationEPNS_4DeclE", "clang::Sema::MarkDeclarationReferenced(clang::SourceLocation, clang::Decl*)"},
    {"_ZN5clang4Sema40BuildAnonymousStructUnionMemberReferenceERKNS_12CXXScopeSpecENS_14SourceLocationEPNS_17IndirectFieldDeclEPNS_4ExprES4_", "clang::Sema::BuildAnonymousStructUnionMemberReference(clang::CXXScopeSpec const&, clang::SourceLocation, clang::IndirectFieldDecl*, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema24BuildDeclarationNameExprERKNS_12CXXScopeSpecERKNS_19DeclarationNameInfoEPNS_9NamedDeclE", "clang::Sema::BuildDeclarationNameExpr(clang::CXXScopeSpec const&, clang::DeclarationNameInfo const&, clang::NamedDecl*)"},
    {"_Z23BuildFieldReferenceExprRN5clang4SemaEPNS_4ExprEbRKNS_12CXXScopeSpecEPNS_9FieldDeclENS_14DeclAccessPairERKNS_19DeclarationNameInfoE", "BuildFieldReferenceExpr(clang::Sema&, clang::Expr*, bool, clang::CXXScopeSpec const&, clang::FieldDecl*, clang::DeclAccessPair, clang::DeclarationNameInfo const&)"},
    {"_ZN5clang4Sema19DiagnoseEmptyLookupEPNS_5ScopeERNS_12CXXScopeSpecERNS_12LookupResultENS0_18CorrectTypoContextE", "clang::Sema::DiagnoseEmptyLookup(clang::Scope*, clang::CXXScopeSpec&, clang::LookupResult&, clang::Sema::CorrectTypoContext)"},
    {"_ZN5clang4Sema28canSynthesizeProvisionalIvarEPNS_14IdentifierInfoE", "clang::Sema::canSynthesizeProvisionalIvar(clang::IdentifierInfo*)"},
    {"_ZN5clang4Sema28canSynthesizeProvisionalIvarEPNS_16ObjCPropertyDeclE", "clang::Sema::canSynthesizeProvisionalIvar(clang::ObjCPropertyDecl*)"},
    {"_ZN5clang4Sema17ActOnIdExpressionEPNS_5ScopeERNS_12CXXScopeSpecERNS_13UnqualifiedIdEbb", "clang::Sema::ActOnIdExpression(clang::Scope*, clang::CXXScopeSpec&, clang::UnqualifiedId&, bool, bool)"},
    {"_Z22DecomposeUnqualifiedIdRN5clang4SemaERKNS_13UnqualifiedIdERNS_24TemplateArgumentListInfoERNS_19DeclarationNameInfoERPKS5_", "DecomposeUnqualifiedId(clang::Sema&, clang::UnqualifiedId const&, clang::TemplateArgumentListInfo&, clang::DeclarationNameInfo&, clang::TemplateArgumentListInfo const*&)"},
    {"_ZN5clang4Sema18LookupInObjCMethodERNS_12LookupResultEPNS_5ScopeEPNS_14IdentifierInfoEb", "clang::Sema::LookupInObjCMethod(clang::LookupResult&, clang::Scope*, clang::IdentifierInfo*, bool)"},
    {"_ZN5clang4Sema26UseArgumentDependentLookupERKNS_12CXXScopeSpecERKNS_12LookupResultEb", "clang::Sema::UseArgumentDependentLookup(clang::CXXScopeSpec const&, clang::LookupResult const&, bool)"},
    {"_ZN5clang4Sema31BuildPossibleImplicitMemberExprERKNS_12CXXScopeSpecERNS_12LookupResultEPKNS_24TemplateArgumentListInfoE", "clang::Sema::BuildPossibleImplicitMemberExpr(clang::CXXScopeSpec const&, clang::LookupResult&, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang4Sema24BuildDeclarationNameExprERKNS_12CXXScopeSpecERNS_12LookupResultEb", "clang::Sema::BuildDeclarationNameExpr(clang::CXXScopeSpec const&, clang::LookupResult&, bool)"},
    {"_ZN5clang4Sema23BuildImplicitMemberExprERKNS_12CXXScopeSpecERNS_12LookupResultEPKNS_24TemplateArgumentListInfoEb", "clang::Sema::BuildImplicitMemberExpr(clang::CXXScopeSpec const&, clang::LookupResult&, clang::TemplateArgumentListInfo const*, bool)"},
    {"_Z25DiagnoseInstanceReferenceRN5clang4SemaERKNS_12CXXScopeSpecEPNS_9NamedDeclERKNS_19DeclarationNameInfoE", "DiagnoseInstanceReference(clang::Sema&, clang::CXXScopeSpec const&, clang::NamedDecl*, clang::DeclarationNameInfo const&)"},
    {"_ZN5clang4Sema33BuildQualifiedDeclarationNameExprERNS_12CXXScopeSpecERKNS_19DeclarationNameInfoE", "clang::Sema::BuildQualifiedDeclarationNameExpr(clang::CXXScopeSpec&, clang::DeclarationNameInfo const&)"},
    {"_ZN5clang4Sema29PerformObjectMemberConversionERPNS_4ExprEPNS_19NestedNameSpecifierEPNS_9NamedDeclES7_", "clang::Sema::PerformObjectMemberConversion(clang::Expr*&, clang::NestedNameSpecifier*, clang::NamedDecl*, clang::NamedDecl*)"},
    {"_ZN5clang4Sema24BuildMemberReferenceExprEPNS_4ExprENS_8QualTypeENS_14SourceLocationEbRKNS_12CXXScopeSpecEPNS_9NamedDeclERNS_12LookupResultEPKNS_24TemplateArgumentListInfoEb", "clang::Sema::BuildMemberReferenceExpr(clang::Expr*, clang::QualType, clang::SourceLocation, bool, clang::CXXScopeSpec const&, clang::NamedDecl*, clang::LookupResult&, clang::TemplateArgumentListInfo const*, bool)"},
    {"_Z15CheckDeclInExprRN5clang4SemaENS_14SourceLocationEPNS_9NamedDeclE", "CheckDeclInExpr(clang::Sema&, clang::SourceLocation, clang::NamedDecl*)"},
    {"_Z21BuildBlockDeclRefExprRN5clang4SemaEPNS_9ValueDeclERKNS_19DeclarationNameInfoEb", "BuildBlockDeclRefExpr(clang::Sema&, clang::ValueDecl*, clang::DeclarationNameInfo const&, bool)"},
    {"_ZN5clang4Sema19ActOnPredefinedExprENS_14SourceLocationENS_3tok9TokenKindE", "clang::Sema::ActOnPredefinedExpr(clang::SourceLocation, clang::tok::TokenKind)"},
    {"_ZN5clang4Sema22ActOnCharacterConstantERKNS_5TokenE", "clang::Sema::ActOnCharacterConstant(clang::Token const&)"},
    {"_ZN5clang4Sema20ActOnNumericConstantERKNS_5TokenE", "clang::Sema::ActOnNumericConstant(clang::Token const&)"},
    {"_ZN5clang4Sema14ActOnParenExprENS_14SourceLocationES1_PNS_4ExprE", "clang::Sema::ActOnParenExpr(clang::SourceLocation, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema25CheckSizeOfAlignOfOperandENS_8QualTypeENS_14SourceLocationENS_11SourceRangeEb", "clang::Sema::CheckSizeOfAlignOfOperand(clang::QualType, clang::SourceLocation, clang::SourceRange, bool)"},
    {"_ZN5clang4Sema23CreateSizeOfAlignOfExprEPNS_14TypeSourceInfoENS_14SourceLocationEbNS_11SourceRangeE", "clang::Sema::CreateSizeOfAlignOfExpr(clang::TypeSourceInfo*, clang::SourceLocation, bool, clang::SourceRange)"},
    {"_ZN5clang4Sema23CreateSizeOfAlignOfExprEPNS_4ExprENS_14SourceLocationEbNS_11SourceRangeE", "clang::Sema::CreateSizeOfAlignOfExpr(clang::Expr*, clang::SourceLocation, bool, clang::SourceRange)"},
    {"_ZN5clang4Sema20CheckPlaceholderExprEPNS_4ExprENS_14SourceLocationE", "clang::Sema::CheckPlaceholderExpr(clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema22ActOnSizeOfAlignOfExprENS_14SourceLocationEbbPvRKNS_11SourceRangeE", "clang::Sema::ActOnSizeOfAlignOfExpr(clang::SourceLocation, bool, bool, void*, clang::SourceRange const&)"},
    {"_ZN5clang4Sema19ActOnPostfixUnaryOpEPNS_5ScopeENS_14SourceLocationENS_3tok9TokenKindEPNS_4ExprE", "clang::Sema::ActOnPostfixUnaryOp(clang::Scope*, clang::SourceLocation, clang::tok::TokenKind, clang::Expr*)"},
    {"_ZN5clang4Sema12BuildUnaryOpEPNS_5ScopeENS_14SourceLocationENS_17UnaryOperatorKindEPNS_4ExprE", "clang::Sema::BuildUnaryOp(clang::Scope*, clang::SourceLocation, clang::UnaryOperatorKind, clang::Expr*)"},
    {"_ZN5clang4Sema23ActOnArraySubscriptExprEPNS_5ScopeEPNS_4ExprENS_14SourceLocationES4_S5_", "clang::Sema::ActOnArraySubscriptExpr(clang::Scope*, clang::Expr*, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema36MaybeConvertParenListExprToParenExprEPNS_5ScopeEPNS_4ExprE", "clang::Sema::MaybeConvertParenListExprToParenExpr(clang::Scope*, clang::Expr*)"},
    {"_ZN5clang4Sema31CreateBuiltinArraySubscriptExprEPNS_4ExprENS_14SourceLocationES2_S3_", "clang::Sema::CreateBuiltinArraySubscriptExpr(clang::Expr*, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema24ActOnDependentMemberExprEPNS_4ExprENS_8QualTypeEbNS_14SourceLocationERKNS_12CXXScopeSpecEPNS_9NamedDeclERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoE", "clang::Sema::ActOnDependentMemberExpr(clang::Expr*, clang::QualType, bool, clang::SourceLocation, clang::CXXScopeSpec const&, clang::NamedDecl*, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang4Sema29CheckQualifiedMemberReferenceEPNS_4ExprENS_8QualTypeERKNS_12CXXScopeSpecERKNS_12LookupResultE", "clang::Sema::CheckQualifiedMemberReference(clang::Expr*, clang::QualType, clang::CXXScopeSpec const&, clang::LookupResult const&)"},
    {"_Z24IsProvablyNotDerivedFromRN5clang4SemaEPNS_13CXXRecordDeclERKN4llvm11SmallPtrSetIS3_Lj4EEE", "IsProvablyNotDerivedFrom(clang::Sema&, clang::CXXRecordDecl*, llvm::SmallPtrSet<clang::CXXRecordDecl*, 4u> const&)"},
    {"_ZN5clang4Sema24BuildMemberReferenceExprEPNS_4ExprENS_8QualTypeENS_14SourceLocationEbRNS_12CXXScopeSpecEPNS_9NamedDeclERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoE", "clang::Sema::BuildMemberReferenceExpr(clang::Expr*, clang::QualType, clang::SourceLocation, bool, clang::CXXScopeSpec&, clang::NamedDecl*, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*)"},
    {"_Z24LookupMemberExprInRecordRN5clang4SemaERNS_12LookupResultENS_11SourceRangeEPKNS_10RecordTypeENS_14SourceLocationERNS_12CXXScopeSpecEb", "LookupMemberExprInRecord(clang::Sema&, clang::LookupResult&, clang::SourceRange, clang::RecordType const*, clang::SourceLocation, clang::CXXScopeSpec&, bool)"},
    {"_ZN5clang4Sema16LookupMemberExprERNS_12LookupResultERPNS_4ExprERbNS_14SourceLocationERNS_12CXXScopeSpecEPNS_4DeclEb", "clang::Sema::LookupMemberExpr(clang::LookupResult&, clang::Expr*&, bool&, clang::SourceLocation, clang::CXXScopeSpec&, clang::Decl*, bool)"},
    {"_Z34ShouldTryAgainWithRedefinitionTypeRN5clang4SemaERPNS_4ExprE", "ShouldTryAgainWithRedefinitionType(clang::Sema&, clang::Expr*&)"},
    {"_Z24FindGetterSetterNameDeclPKN5clang21ObjCObjectPointerTypeEPNS_14IdentifierInfoERKNS_8SelectorERNS_10ASTContextE", "FindGetterSetterNameDecl(clang::ObjCObjectPointerType const*, clang::IdentifierInfo*, clang::Selector const&, clang::ASTContext&)"},
    {"_ZN5clang4Sema13ActOnCallExprEPNS_5ScopeEPNS_4ExprENS_14SourceLocationENS_11ASTMultiPtrIS4_EES5_S4_", "clang::Sema::ActOnCallExpr(clang::Scope*, clang::Expr*, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema21ActOnMemberAccessExprEPNS_5ScopeEPNS_4ExprENS_14SourceLocationENS_3tok9TokenKindERNS_12CXXScopeSpecERNS_13UnqualifiedIdEPNS_4DeclEb", "clang::Sema::ActOnMemberAccessExpr(clang::Scope*, clang::Expr*, clang::SourceLocation, clang::tok::TokenKind, clang::CXXScopeSpec&, clang::UnqualifiedId&, clang::Decl*, bool)"},
    {"_ZN5clang4Sema22BuildCXXDefaultArgExprENS_14SourceLocationEPNS_12FunctionDeclEPNS_11ParmVarDeclE", "clang::Sema::BuildCXXDefaultArgExpr(clang::SourceLocation, clang::FunctionDecl*, clang::ParmVarDecl*)"},
    {"_ZN5clang4Sema32MarkDeclarationsReferencedInExprEPNS_4ExprE", "clang::Sema::MarkDeclarationsReferencedInExpr(clang::Expr*)"},
    {"_ZN5clang4Sema23ConvertArgumentsForCallEPNS_8CallExprEPNS_4ExprEPNS_12FunctionDeclEPKNS_17FunctionProtoTypeEPS4_jNS_14SourceLocationE", "clang::Sema::ConvertArgumentsForCall(clang::CallExpr*, clang::Expr*, clang::FunctionDecl*, clang::FunctionProtoType const*, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang4Sema22GatherArgumentsForCallENS_14SourceLocationEPNS_12FunctionDeclEPKNS_17FunctionProtoTypeEjPPNS_4ExprEjRN4llvm11SmallVectorIS8_Lj8EEENS0_16VariadicCallTypeE", "clang::Sema::GatherArgumentsForCall(clang::SourceLocation, clang::FunctionDecl*, clang::FunctionProtoType const*, unsigned int, clang::Expr**, unsigned int, llvm::SmallVector<clang::Expr*, 8u>&, clang::Sema::VariadicCallType)"},
    {"_ZN5clang4Sema19CheckCallReturnTypeENS_8QualTypeENS_14SourceLocationEPNS_8CallExprEPNS_12FunctionDeclE", "clang::Sema::CheckCallReturnType(clang::QualType, clang::SourceLocation, clang::CallExpr*, clang::FunctionDecl*)"},
    {"_ZN5clang4Sema21BuildResolvedCallExprEPNS_4ExprEPNS_9NamedDeclENS_14SourceLocationEPS2_jS5_S2_", "clang::Sema::BuildResolvedCallExpr(clang::Expr*, clang::NamedDecl*, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema23ActOnCUDAExecConfigExprEPNS_5ScopeENS_14SourceLocationENS_11ASTMultiPtrIPNS_4ExprEEES3_", "clang::Sema::ActOnCUDAExecConfigExpr(clang::Scope*, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation)"},
    {"_ZN5clang4Sema20ActOnCompoundLiteralENS_14SourceLocationENS_9OpaquePtrINS_8QualTypeEEES1_PNS_4ExprE", "clang::Sema::ActOnCompoundLiteral(clang::SourceLocation, clang::OpaquePtr<clang::QualType>, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema24BuildCompoundLiteralExprENS_14SourceLocationEPNS_14TypeSourceInfoES1_PNS_4ExprE", "clang::Sema::BuildCompoundLiteralExpr(clang::SourceLocation, clang::TypeSourceInfo*, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema13ActOnInitListENS_14SourceLocationENS_11ASTMultiPtrIPNS_4ExprEEES1_", "clang::Sema::ActOnInitList(clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation)"},
    {"_ZN5clang4Sema14CheckCastTypesENS_11SourceRangeENS_8QualTypeERPNS_4ExprERNS_8CastKindERNS_13ExprValueKindERN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEEb", "clang::Sema::CheckCastTypes(clang::SourceRange, clang::QualType, clang::Expr*&, clang::CastKind&, clang::ExprValueKind&, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u>&, bool)"},
    {"_ZN5clang4Sema18CheckExtVectorCastENS_11SourceRangeENS_8QualTypeERPNS_4ExprERNS_8CastKindE", "clang::Sema::CheckExtVectorCast(clang::SourceRange, clang::QualType, clang::Expr*&, clang::CastKind&)"},
    {"_ZN5clang4Sema15CheckVectorCastENS_11SourceRangeENS_8QualTypeES2_RNS_8CastKindE", "clang::Sema::CheckVectorCast(clang::SourceRange, clang::QualType, clang::QualType, clang::CastKind&)"},
    {"_Z17PrepareScalarCastRN5clang4SemaERPNS_4ExprENS_8QualTypeE", "PrepareScalarCast(clang::Sema&, clang::Expr*&, clang::QualType)"},
    {"_ZN5clang4Sema13ActOnCastExprEPNS_5ScopeENS_14SourceLocationENS_9OpaquePtrINS_8QualTypeEEES3_PNS_4ExprE", "clang::Sema::ActOnCastExpr(clang::Scope*, clang::SourceLocation, clang::OpaquePtr<clang::QualType>, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema24ActOnCastOfParenListExprEPNS_5ScopeENS_14SourceLocationES3_PNS_4ExprEPNS_14TypeSourceInfoE", "clang::Sema::ActOnCastOfParenListExpr(clang::Scope*, clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::TypeSourceInfo*)"},
    {"_ZN5clang4Sema19BuildCStyleCastExprENS_14SourceLocationEPNS_14TypeSourceInfoES1_PNS_4ExprE", "clang::Sema::BuildCStyleCastExpr(clang::SourceLocation, clang::TypeSourceInfo*, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema10ActOnBinOpEPNS_5ScopeENS_14SourceLocationENS_3tok9TokenKindEPNS_4ExprES7_", "clang::Sema::ActOnBinOp(clang::Scope*, clang::SourceLocation, clang::tok::TokenKind, clang::Expr*, clang::Expr*)"},
    {"_ZN5clang4Sema25ActOnParenOrParenListExprENS_14SourceLocationES1_NS_11ASTMultiPtrIPNS_4ExprEEENS_9OpaquePtrINS_8QualTypeEEE", "clang::Sema::ActOnParenOrParenListExpr(clang::SourceLocation, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::OpaquePtr<clang::QualType>)"},
    {"_ZN5clang4Sema24CheckConditionalOperandsERPNS_4ExprES3_S3_S3_RNS_13ExprValueKindERNS_14ExprObjectKindENS_14SourceLocationE", "clang::Sema::CheckConditionalOperands(clang::Expr*&, clang::Expr*&, clang::Expr*&, clang::Expr*&, clang::ExprValueKind&, clang::ExprObjectKind&, clang::SourceLocation)"},
    {"_ZN5clang4Sema19CheckVectorOperandsENS_14SourceLocationERPNS_4ExprES4_", "clang::Sema::CheckVectorOperands(clang::SourceLocation, clang::Expr*&, clang::Expr*&)"},
    {"_ZN5clang4Sema28FindCompositeObjCPointerTypeERPNS_4ExprES3_NS_14SourceLocationE", "clang::Sema::FindCompositeObjCPointerType(clang::Expr*&, clang::Expr*&, clang::SourceLocation)"},
    {"_ZN5clang4Sema18ActOnConditionalOpENS_14SourceLocationES1_PNS_4ExprES3_S3_", "clang::Sema::ActOnConditionalOp(clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::Expr*, clang::Expr*)"},
    {"_ZN5clang4Sema26CheckAssignmentConstraintsENS_14SourceLocationENS_8QualTypeES2_", "clang::Sema::CheckAssignmentConstraints(clang::SourceLocation, clang::QualType, clang::QualType)"},
    {"_ZN5clang4Sema26CheckAssignmentConstraintsENS_8QualTypeERPNS_4ExprERNS_8CastKindE", "clang::Sema::CheckAssignmentConstraints(clang::QualType, clang::Expr*&, clang::CastKind&)"},
    {"_ZN5clang4Sema40CheckTransparentUnionArgumentConstraintsENS_8QualTypeERPNS_4ExprE", "clang::Sema::CheckTransparentUnionArgumentConstraints(clang::QualType, clang::Expr*&)"},
    {"_ZN5clang4Sema32CheckSingleAssignmentConstraintsENS_8QualTypeERPNS_4ExprE", "clang::Sema::CheckSingleAssignmentConstraints(clang::QualType, clang::Expr*&)"},
    {"_ZN5clang4Sema15InvalidOperandsENS_14SourceLocationERPNS_4ExprES4_", "clang::Sema::InvalidOperands(clang::SourceLocation, clang::Expr*&, clang::Expr*&)"},
    {"_ZN5clang4Sema27CheckMultiplyDivideOperandsERPNS_4ExprES3_NS_14SourceLocationEbb", "clang::Sema::CheckMultiplyDivideOperands(clang::Expr*&, clang::Expr*&, clang::SourceLocation, bool, bool)"},
    {"_ZN5clang4Sema22CheckRemainderOperandsERPNS_4ExprES3_NS_14SourceLocationEb", "clang::Sema::CheckRemainderOperands(clang::Expr*&, clang::Expr*&, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema21CheckAdditionOperandsERPNS_4ExprES3_NS_14SourceLocationEPNS_8QualTypeE", "clang::Sema::CheckAdditionOperands(clang::Expr*&, clang::Expr*&, clang::SourceLocation, clang::QualType*)"},
    {"_ZN5clang4Sema24CheckSubtractionOperandsERPNS_4ExprES3_NS_14SourceLocationEPNS_8QualTypeE", "clang::Sema::CheckSubtractionOperands(clang::Expr*&, clang::Expr*&, clang::SourceLocation, clang::QualType*)"},
    {"_ZN5clang4Sema18CheckShiftOperandsERPNS_4ExprES3_NS_14SourceLocationEb", "clang::Sema::CheckShiftOperands(clang::Expr*&, clang::Expr*&, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema20CheckCompareOperandsERPNS_4ExprES3_NS_14SourceLocationEjb", "clang::Sema::CheckCompareOperands(clang::Expr*&, clang::Expr*&, clang::SourceLocation, unsigned int, bool)"},
    {"_ZN5clang4Sema26CheckVectorCompareOperandsERPNS_4ExprES3_NS_14SourceLocationEb", "clang::Sema::CheckVectorCompareOperands(clang::Expr*&, clang::Expr*&, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema23CheckAssignmentOperandsEPNS_4ExprERS2_NS_14SourceLocationENS_8QualTypeE", "clang::Sema::CheckAssignmentOperands(clang::Expr*, clang::Expr*&, clang::SourceLocation, clang::QualType)"},
    {"_Z24CheckForModifiableLvaluePN5clang4ExprENS_14SourceLocationERNS_4SemaE", "CheckForModifiableLvalue(clang::Expr*, clang::SourceLocation, clang::Sema&)"},
    {"_ZN5clang4Sema24ConvertPropertyForLValueERPNS_4ExprES3_RNS_8QualTypeE", "clang::Sema::ConvertPropertyForLValue(clang::Expr*&, clang::Expr*&, clang::QualType&)"},
    {"_ZN5clang4Sema24DiagnoseAssignmentResultENS0_17AssignConvertTypeENS_14SourceLocationENS_8QualTypeES3_PNS_4ExprENS0_16AssignmentActionEPb", "clang::Sema::DiagnoseAssignmentResult(clang::Sema::AssignConvertType, clang::SourceLocation, clang::QualType, clang::QualType, clang::Expr*, clang::Sema::AssignmentAction, bool*)"},
    {"_ZN5clang4Sema18CreateBuiltinBinOpENS_14SourceLocationENS_18BinaryOperatorKindEPNS_4ExprES4_", "clang::Sema::CreateBuiltinBinOp(clang::SourceLocation, clang::BinaryOperatorKind, clang::Expr*, clang::Expr*)"},
    {"_ZN5clang4Sema10BuildBinOpEPNS_5ScopeENS_14SourceLocationENS_18BinaryOperatorKindEPNS_4ExprES6_", "clang::Sema::BuildBinOp(clang::Scope*, clang::SourceLocation, clang::BinaryOperatorKind, clang::Expr*, clang::Expr*)"},
    {"_ZN5clang4Sema20CreateBuiltinUnaryOpENS_14SourceLocationENS_17UnaryOperatorKindEPNS_4ExprE", "clang::Sema::CreateBuiltinUnaryOp(clang::SourceLocation, clang::UnaryOperatorKind, clang::Expr*)"},
    {"_Z30CheckIncrementDecrementOperandRN5clang4SemaEPNS_4ExprERNS_13ExprValueKindENS_14SourceLocationEbb", "CheckIncrementDecrementOperand(clang::Sema&, clang::Expr*, clang::ExprValueKind&, clang::SourceLocation, bool, bool)"},
    {"_Z23CheckIndirectionOperandRN5clang4SemaEPNS_4ExprERNS_13ExprValueKindENS_14SourceLocationE", "CheckIndirectionOperand(clang::Sema&, clang::Expr*, clang::ExprValueKind&, clang::SourceLocation)"},
    {"_Z20CheckRealImagOperandRN5clang4SemaERPNS_4ExprENS_14SourceLocationEb", "CheckRealImagOperand(clang::Sema&, clang::Expr*&, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema12ActOnUnaryOpEPNS_5ScopeENS_14SourceLocationENS_3tok9TokenKindEPNS_4ExprE", "clang::Sema::ActOnUnaryOp(clang::Scope*, clang::SourceLocation, clang::tok::TokenKind, clang::Expr*)"},
    {"_ZN5clang4Sema14ActOnAddrLabelENS_14SourceLocationES1_PNS_14IdentifierInfoE", "clang::Sema::ActOnAddrLabel(clang::SourceLocation, clang::SourceLocation, clang::IdentifierInfo*)"},
    {"_ZN5clang4Sema13ActOnStmtExprENS_14SourceLocationEPNS_4StmtES1_", "clang::Sema::ActOnStmtExpr(clang::SourceLocation, clang::Stmt*, clang::SourceLocation)"},
    {"_ZN5clang4Sema20BuildBuiltinOffsetOfENS_14SourceLocationEPNS_14TypeSourceInfoEPNS0_17OffsetOfComponentEjS1_", "clang::Sema::BuildBuiltinOffsetOf(clang::SourceLocation, clang::TypeSourceInfo*, clang::Sema::OffsetOfComponent*, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang4Sema20ActOnBuiltinOffsetOfEPNS_5ScopeENS_14SourceLocationES3_NS_9OpaquePtrINS_8QualTypeEEEPNS0_17OffsetOfComponentEjS3_", "clang::Sema::ActOnBuiltinOffsetOf(clang::Scope*, clang::SourceLocation, clang::SourceLocation, clang::OpaquePtr<clang::QualType>, clang::Sema::OffsetOfComponent*, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang4Sema15ActOnChooseExprENS_14SourceLocationEPNS_4ExprES3_S3_S1_", "clang::Sema::ActOnChooseExpr(clang::SourceLocation, clang::Expr*, clang::Expr*, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema15ActOnBlockStartENS_14SourceLocationEPNS_5ScopeE", "clang::Sema::ActOnBlockStart(clang::SourceLocation, clang::Scope*)"},
    {"_ZN5clang4Sema19ActOnBlockArgumentsERNS_10DeclaratorEPNS_5ScopeE", "clang::Sema::ActOnBlockArguments(clang::Declarator&, clang::Scope*)"},
    {"_ZN5clang4Sema15ActOnBlockErrorENS_14SourceLocationEPNS_5ScopeE", "clang::Sema::ActOnBlockError(clang::SourceLocation, clang::Scope*)"},
    {"_ZN5clang4Sema18ActOnBlockStmtExprENS_14SourceLocationEPNS_4StmtEPNS_5ScopeE", "clang::Sema::ActOnBlockStmtExpr(clang::SourceLocation, clang::Stmt*, clang::Scope*)"},
    {"_ZN5clang4Sema10ActOnVAArgENS_14SourceLocationEPNS_4ExprENS_9OpaquePtrINS_8QualTypeEEES1_", "clang::Sema::ActOnVAArg(clang::SourceLocation, clang::Expr*, clang::OpaquePtr<clang::QualType>, clang::SourceLocation)"},
    {"_ZN5clang4Sema14BuildVAArgExprENS_14SourceLocationEPNS_4ExprEPNS_14TypeSourceInfoES1_", "clang::Sema::BuildVAArgExpr(clang::SourceLocation, clang::Expr*, clang::TypeSourceInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema16ActOnGNUNullExprENS_14SourceLocationE", "clang::Sema::ActOnGNUNullExpr(clang::SourceLocation)"},
    {"_ZN5clang4Sema31VerifyIntegerConstantExpressionEPKNS_4ExprEPN4llvm6APSIntE", "clang::Sema::VerifyIntegerConstantExpression(clang::Expr const*, llvm::APSInt*)"},
    {"_ZN5clang4Sema31PushExpressionEvaluationContextENS0_27ExpressionEvaluationContextE", "clang::Sema::PushExpressionEvaluationContext(clang::Sema::ExpressionEvaluationContext)"},
    {"_ZN5clang4Sema30PopExpressionEvaluationContextEv", "clang::Sema::PopExpressionEvaluationContext()"},
    {"_ZN5clang4Sema32MarkDeclarationsReferencedInTypeENS_14SourceLocationENS_8QualTypeE", "clang::Sema::MarkDeclarationsReferencedInType(clang::SourceLocation, clang::QualType)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119MarkReferencedDeclsEE12TraverseTypeENS_8QualTypeE", "clang::RecursiveASTVisitor<(anonymous namespace)::MarkReferencedDecls>::TraverseType(clang::QualType)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_119EvaluatedExprMarkerEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::EvaluatedExprMarker, void>::Visit(clang::Stmt*)"},
    {"_ZN5clang4Sema29DiagnoseAssignmentAsConditionEPNS_4ExprE", "clang::Sema::DiagnoseAssignmentAsCondition(clang::Expr*)"},
    {"_ZN5clang4Sema31DiagnoseEqualityWithExtraParensEPNS_9ParenExprE", "clang::Sema::DiagnoseEqualityWithExtraParens(clang::ParenExpr*)"},
    {"_ZN5clang4Sema21CheckBooleanConditionERPNS_4ExprENS_14SourceLocationE", "clang::Sema::CheckBooleanCondition(clang::Expr*&, clang::SourceLocation)"},
    {"_ZN5clang4Sema21ActOnBooleanConditionEPNS_5ScopeENS_14SourceLocationEPNS_4ExprE", "clang::Sema::ActOnBooleanCondition(clang::Scope*, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang20EvaluatedExprVisitorIN12_GLOBAL__N_119EvaluatedExprMarkerEE9VisitStmtEPNS_4StmtE", "clang::EvaluatedExprVisitor<(anonymous namespace)::EvaluatedExprMarker>::VisitStmt(clang::Stmt*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119MarkReferencedDeclsEE27TraverseNestedNameSpecifierEPNS_19NestedNameSpecifierE", "clang::RecursiveASTVisitor<(anonymous namespace)::MarkReferencedDecls>::TraverseNestedNameSpecifier(clang::NestedNameSpecifier*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119MarkReferencedDeclsEE24TraverseTemplateArgumentERKNS_16TemplateArgumentE", "clang::RecursiveASTVisitor<(anonymous namespace)::MarkReferencedDecls>::TraverseTemplateArgument(clang::TemplateArgument const&)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119MarkReferencedDeclsEE12TraverseStmtEPNS_4StmtE", "clang::RecursiveASTVisitor<(anonymous namespace)::MarkReferencedDecls>::TraverseStmt(clang::Stmt*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119MarkReferencedDeclsEE15TraverseTypeLocENS_7TypeLocE", "clang::RecursiveASTVisitor<(anonymous namespace)::MarkReferencedDecls>::TraverseTypeLoc(clang::TypeLoc)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119MarkReferencedDeclsEE27TraverseTemplateArgumentLocERKNS_19TemplateArgumentLocE", "clang::RecursiveASTVisitor<(anonymous namespace)::MarkReferencedDecls>::TraverseTemplateArgumentLoc(clang::TemplateArgumentLoc const&)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119MarkReferencedDeclsEE12TraverseDeclEPNS_4DeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::MarkReferencedDecls>::TraverseDecl(clang::Decl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119MarkReferencedDeclsEE24TraverseDeclaratorHelperEPNS_14DeclaratorDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::MarkReferencedDecls>::TraverseDeclaratorHelper(clang::DeclaratorDecl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119MarkReferencedDeclsEE22TraverseFunctionHelperEPNS_12FunctionDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::MarkReferencedDecls>::TraverseFunctionHelper(clang::FunctionDecl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_119MarkReferencedDeclsEE23TraverseCXXRecordHelperEPNS_13CXXRecordDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::MarkReferencedDecls>::TraverseCXXRecordHelper(clang::CXXRecordDecl*)"},
    {"_Z38EmitDiagnosticForLogicalAndInLogicalOrRN5clang4SemaENS_14SourceLocationEPNS_4ExprE", "EmitDiagnosticForLogicalAndInLogicalOr(clang::Sema&, clang::SourceLocation, clang::Expr*)"},
    {"_Z18SuggestParenthesesRN5clang4SemaENS_14SourceLocationERKNS_17PartialDiagnosticES5_NS_11SourceRangeES5_S6_", "SuggestParentheses(clang::Sema&, clang::SourceLocation, clang::PartialDiagnostic const&, clang::PartialDiagnostic const&, clang::SourceRange, clang::PartialDiagnostic const&, clang::SourceRange)"},
    {"_Z40FindGetterSetterNameDeclFromProtocolListPKN5clang16ObjCProtocolDeclEPNS_14IdentifierInfoERKNS_8SelectorERNS_10ASTContextE", "FindGetterSetterNameDeclFromProtocolList(clang::ObjCProtocolDecl const*, clang::IdentifierInfo*, clang::Selector const&, clang::ASTContext&)"},
    {"_Z16propagateCaptureRN5clang4SemaEjRKNS_9BlockDecl7CaptureE", "propagateCapture(clang::Sema&, unsigned int, clang::BlockDecl::Capture const&)"},
    {"_ZN5clang13SelectorTable19constructSetterNameERNS_15IdentifierTableERS0_PKNS_14IdentifierInfoE", "clang::SelectorTable::constructSetterName(clang::IdentifierTable&, clang::SelectorTable&, clang::IdentifierInfo const*)"},
    {"_ZN5clang4Sema20CheckBitwiseOperandsERPNS_4ExprES3_NS_14SourceLocationEb", "clang::Sema::CheckBitwiseOperands(clang::Expr*&, clang::Expr*&, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema20CheckLogicalOperandsERPNS_4ExprES3_NS_14SourceLocationEj", "clang::Sema::CheckLogicalOperands(clang::Expr*&, clang::Expr*&, clang::SourceLocation, unsigned int)"},
    {"_ZNK5clang4Decl7getAttrINS_12NoReturnAttrEEEPT_v", "clang::NoReturnAttr* clang::Decl::getAttr<clang::NoReturnAttr>() const"},
    {"_ZN5clang4Sema33ExpressionEvaluationContextRecord7DestroyEv", "clang::Sema::ExpressionEvaluationContextRecord::Destroy()"},
    {"_ZN5clang4Sema33ExpressionEvaluationContextRecord13addDiagnosticENS_14SourceLocationERKNS_17PartialDiagnosticE", "clang::Sema::ExpressionEvaluationContextRecord::addDiagnostic(clang::SourceLocation, clang::PartialDiagnostic const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang12OffsetOfExpr12OffsetOfNodeELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::OffsetOfExpr::OffsetOfNode, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEPNS1_9LabelStmtENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::IdentifierInfo*, clang::LabelStmt*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::LabelStmt*>>::InsertIntoBucket(clang::IdentifierInfo* const&, clang::LabelStmt* const&, std::pair<clang::IdentifierInfo*, clang::LabelStmt*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEPNS1_9LabelStmtENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::IdentifierInfo*, clang::LabelStmt*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::LabelStmt*>>::grow(unsigned int)"},
    {"_ZN5clang10ChooseExprC2ENS_14SourceLocationEPNS_4ExprES3_S3_NS_8QualTypeENS_13ExprValueKindENS_14ExprObjectKindES1_bb", "clang::ChooseExpr::ChooseExpr(clang::SourceLocation, clang::Expr*, clang::Expr*, clang::Expr*, clang::QualType, clang::ExprValueKind, clang::ExprObjectKind, clang::SourceLocation, bool, bool)"},
    {"_ZN5clang17CXXDefaultArgExprC2ENS_4Stmt9StmtClassENS_14SourceLocationEPNS_11ParmVarDeclE", "clang::CXXDefaultArgExpr::CXXDefaultArgExpr(clang::Stmt::StmtClass, clang::SourceLocation, clang::ParmVarDecl*)"},
    {"_ZN5clang18ArraySubscriptExprC2EPNS_4ExprES2_NS_8QualTypeENS_13ExprValueKindENS_14ExprObjectKindENS_14SourceLocationE", "clang::ArraySubscriptExpr::ArraySubscriptExpr(clang::Expr*, clang::Expr*, clang::QualType, clang::ExprValueKind, clang::ExprObjectKind, clang::SourceLocation)"},
    {"_ZN4llvm8DenseMapIPN5clang7VarDeclEjNS_12DenseMapInfoIS3_EENS4_IjEEE16InsertIntoBucketERKS3_RKjPSt4pairIS3_jE", "llvm::DenseMap<clang::VarDecl*, unsigned int, llvm::DenseMapInfo<clang::VarDecl*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::VarDecl* const&, unsigned int const&, std::pair<clang::VarDecl*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPN5clang7VarDeclEjNS_12DenseMapInfoIS3_EENS4_IjEEE4growEj", "llvm::DenseMap<clang::VarDecl*, unsigned int, llvm::DenseMapInfo<clang::VarDecl*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN5clang4Sema17getDestructorNameENS_14SourceLocationERNS_14IdentifierInfoES1_PNS_5ScopeERNS_12CXXScopeSpecENS_9OpaquePtrINS_8QualTypeEEEb", "clang::Sema::getDestructorName(clang::SourceLocation, clang::IdentifierInfo&, clang::SourceLocation, clang::Scope*, clang::CXXScopeSpec&, clang::OpaquePtr<clang::QualType>, bool)"},
    {"_ZN5clang4Sema14BuildCXXTypeIdENS_8QualTypeENS_14SourceLocationEPNS_14TypeSourceInfoES2_", "clang::Sema::BuildCXXTypeId(clang::QualType, clang::SourceLocation, clang::TypeSourceInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema14BuildCXXTypeIdENS_8QualTypeENS_14SourceLocationEPNS_4ExprES2_", "clang::Sema::BuildCXXTypeId(clang::QualType, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema14ActOnCXXTypeidENS_14SourceLocationES1_bPvS1_", "clang::Sema::ActOnCXXTypeid(clang::SourceLocation, clang::SourceLocation, bool, void*, clang::SourceLocation)"},
    {"_ZN5clang4Sema14BuildCXXUuidofENS_8QualTypeENS_14SourceLocationEPNS_14TypeSourceInfoES2_", "clang::Sema::BuildCXXUuidof(clang::QualType, clang::SourceLocation, clang::TypeSourceInfo*, clang::SourceLocation)"},
    {"_Z17GetUuidAttrOfTypeN5clang8QualTypeE", "GetUuidAttrOfType(clang::QualType)"},
    {"_ZN5clang4Sema14BuildCXXUuidofENS_8QualTypeENS_14SourceLocationEPNS_4ExprES2_", "clang::Sema::BuildCXXUuidof(clang::QualType, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema14ActOnCXXUuidofENS_14SourceLocationES1_bPvS1_", "clang::Sema::ActOnCXXUuidof(clang::SourceLocation, clang::SourceLocation, bool, void*, clang::SourceLocation)"},
    {"_ZN5clang4Sema19ActOnCXXBoolLiteralENS_14SourceLocationENS_3tok9TokenKindE", "clang::Sema::ActOnCXXBoolLiteral(clang::SourceLocation, clang::tok::TokenKind)"},
    {"_ZN5clang4Sema22ActOnCXXNullPtrLiteralENS_14SourceLocationE", "clang::Sema::ActOnCXXNullPtrLiteral(clang::SourceLocation)"},
    {"_ZN5clang4Sema13ActOnCXXThrowENS_14SourceLocationEPNS_4ExprE", "clang::Sema::ActOnCXXThrow(clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema20CheckCXXThrowOperandENS_14SourceLocationERPNS_4ExprE", "clang::Sema::CheckCXXThrowOperand(clang::SourceLocation, clang::Expr*&)"},
    {"_ZN5clang4Sema17tryCaptureCXXThisEv", "clang::Sema::tryCaptureCXXThis()"},
    {"_ZN5clang4Sema12ActOnCXXThisENS_14SourceLocationE", "clang::Sema::ActOnCXXThis(clang::SourceLocation)"},
    {"_ZN5clang4Sema25ActOnCXXTypeConstructExprENS_9OpaquePtrINS_8QualTypeEEENS_14SourceLocationENS_11ASTMultiPtrIPNS_4ExprEEES4_", "clang::Sema::ActOnCXXTypeConstructExpr(clang::OpaquePtr<clang::QualType>, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation)"},
    {"_ZN5clang4Sema25BuildCXXTypeConstructExprEPNS_14TypeSourceInfoENS_14SourceLocationENS_11ASTMultiPtrIPNS_4ExprEEES3_", "clang::Sema::BuildCXXTypeConstructExpr(clang::TypeSourceInfo*, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation)"},
    {"_ZN5clang4Sema11ActOnCXXNewENS_14SourceLocationEbS1_NS_11ASTMultiPtrIPNS_4ExprEEES1_NS_11SourceRangeERNS_10DeclaratorES1_S5_S1_", "clang::Sema::ActOnCXXNew(clang::SourceLocation, bool, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation, clang::SourceRange, clang::Declarator&, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation)"},
    {"_ZN5clang4Sema11BuildCXXNewENS_14SourceLocationEbS1_NS_11ASTMultiPtrIPNS_4ExprEEES1_NS_11SourceRangeENS_8QualTypeEPNS_14TypeSourceInfoES4_S1_S5_S1_", "clang::Sema::BuildCXXNew(clang::SourceLocation, bool, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation, clang::SourceRange, clang::QualType, clang::TypeSourceInfo*, clang::Expr*, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation)"},
    {"_ZN5clang4Sema18CheckAllocatedTypeENS_8QualTypeENS_14SourceLocationENS_11SourceRangeE", "clang::Sema::CheckAllocatedType(clang::QualType, clang::SourceLocation, clang::SourceRange)"},
    {"_ZN5clang4Sema23FindAllocationFunctionsENS_14SourceLocationENS_11SourceRangeEbNS_8QualTypeEbPPNS_4ExprEjRPNS_12FunctionDeclES9_", "clang::Sema::FindAllocationFunctions(clang::SourceLocation, clang::SourceRange, bool, clang::QualType, bool, clang::Expr**, unsigned int, clang::FunctionDecl*&, clang::FunctionDecl*&)"},
    {"_Z28doesUsualArrayDeleteWantSizeRN5clang4SemaENS_14SourceLocationENS_8QualTypeE", "doesUsualArrayDeleteWantSize(clang::Sema&, clang::SourceLocation, clang::QualType)"},
    {"_ZN5clang4Sema22FindAllocationOverloadENS_14SourceLocationENS_11SourceRangeENS_15DeclarationNameEPPNS_4ExprEjPNS_11DeclContextEbRPNS_12FunctionDeclE", "clang::Sema::FindAllocationOverload(clang::SourceLocation, clang::SourceRange, clang::DeclarationName, clang::Expr**, unsigned int, clang::DeclContext*, bool, clang::FunctionDecl*&)"},
    {"_ZN5clang4Sema22DeclareGlobalNewDeleteEv", "clang::Sema::DeclareGlobalNewDelete()"},
    {"_ZN5clang4Sema31DeclareGlobalAllocationFunctionENS_15DeclarationNameENS_8QualTypeES2_b", "clang::Sema::DeclareGlobalAllocationFunction(clang::DeclarationName, clang::QualType, clang::QualType, bool)"},
    {"_ZN5clang4Sema24FindDeallocationFunctionENS_14SourceLocationEPNS_13CXXRecordDeclENS_15DeclarationNameERPNS_12FunctionDeclE", "clang::Sema::FindDeallocationFunction(clang::SourceLocation, clang::CXXRecordDecl*, clang::DeclarationName, clang::FunctionDecl*&)"},
    {"_ZN5clang4Sema14ActOnCXXDeleteENS_14SourceLocationEbbPNS_4ExprE", "clang::Sema::ActOnCXXDelete(clang::SourceLocation, bool, bool, clang::Expr*)"},
    {"_ZN5clang4Sema22CheckConditionVariableEPNS_7VarDeclENS_14SourceLocationEb", "clang::Sema::CheckConditionVariable(clang::VarDecl*, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema24CheckCXXBooleanConditionERPNS_4ExprE", "clang::Sema::CheckCXXBooleanCondition(clang::Expr*&)"},
    {"_ZN5clang4Sema42IsStringLiteralToNonConstPointerConversionEPNS_4ExprENS_8QualTypeE", "clang::Sema::IsStringLiteralToNonConstPointerConversion(clang::Expr*, clang::QualType)"},
    {"_ZN5clang4Sema25PerformImplicitConversionERPNS_4ExprENS_8QualTypeERKNS_26ImplicitConversionSequenceENS0_16AssignmentActionEb", "clang::Sema::PerformImplicitConversion(clang::Expr*&, clang::QualType, clang::ImplicitConversionSequence const&, clang::Sema::AssignmentAction, bool)"},
    {"_ZN5clang4Sema25PerformImplicitConversionERPNS_4ExprENS_8QualTypeERKNS_26StandardConversionSequenceENS0_16AssignmentActionEb", "clang::Sema::PerformImplicitConversion(clang::Expr*&, clang::QualType, clang::StandardConversionSequence const&, clang::Sema::AssignmentAction, bool)"},
    {"_ZN5clang4Sema19ActOnUnaryTypeTraitENS_14UnaryTypeTraitENS_14SourceLocationENS_9OpaquePtrINS_8QualTypeEEES2_", "clang::Sema::ActOnUnaryTypeTrait(clang::UnaryTypeTrait, clang::SourceLocation, clang::OpaquePtr<clang::QualType>, clang::SourceLocation)"},
    {"_ZN5clang4Sema19BuildUnaryTypeTraitENS_14UnaryTypeTraitENS_14SourceLocationEPNS_14TypeSourceInfoES2_", "clang::Sema::BuildUnaryTypeTrait(clang::UnaryTypeTrait, clang::SourceLocation, clang::TypeSourceInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema20ActOnBinaryTypeTraitENS_15BinaryTypeTraitENS_14SourceLocationENS_9OpaquePtrINS_8QualTypeEEES5_S2_", "clang::Sema::ActOnBinaryTypeTrait(clang::BinaryTypeTrait, clang::SourceLocation, clang::OpaquePtr<clang::QualType>, clang::OpaquePtr<clang::QualType>, clang::SourceLocation)"},
    {"_ZN5clang4Sema20BuildBinaryTypeTraitENS_15BinaryTypeTraitENS_14SourceLocationEPNS_14TypeSourceInfoES4_S2_", "clang::Sema::BuildBinaryTypeTrait(clang::BinaryTypeTrait, clang::SourceLocation, clang::TypeSourceInfo*, clang::TypeSourceInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema28CheckPointerToMemberOperandsERPNS_4ExprES3_RNS_13ExprValueKindENS_14SourceLocationEb", "clang::Sema::CheckPointerToMemberOperands(clang::Expr*&, clang::Expr*&, clang::ExprValueKind&, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema27CXXCheckConditionalOperandsERPNS_4ExprES3_S3_S3_RNS_13ExprValueKindERNS_14ExprObjectKindENS_14SourceLocationE", "clang::Sema::CXXCheckConditionalOperands(clang::Expr*&, clang::Expr*&, clang::Expr*&, clang::Expr*&, clang::ExprValueKind&, clang::ExprObjectKind&, clang::SourceLocation)"},
    {"_Z19TryClassUnificationRN5clang4SemaEPNS_4ExprES3_NS_14SourceLocationERbRNS_8QualTypeE", "TryClassUnification(clang::Sema&, clang::Expr*, clang::Expr*, clang::SourceLocation, bool&, clang::QualType&)"},
    {"_Z21ConvertForConditionalRN5clang4SemaERPNS_4ExprENS_8QualTypeE", "ConvertForConditional(clang::Sema&, clang::Expr*&, clang::QualType)"},
    {"_ZN5clang4Sema24FindCompositePointerTypeENS_14SourceLocationERPNS_4ExprES4_Pb", "clang::Sema::FindCompositePointerType(clang::SourceLocation, clang::Expr*&, clang::Expr*&, bool*)"},
    {"_ZN5clang4Sema20MaybeBindToTemporaryEPNS_4ExprE", "clang::Sema::MaybeBindToTemporary(clang::Expr*)"},
    {"_ZN5clang4Sema27MaybeCreateExprWithCleanupsEPNS_4ExprE", "clang::Sema::MaybeCreateExprWithCleanups(clang::Expr*)"},
    {"_ZN5clang4Sema27MaybeCreateExprWithCleanupsENS_12ActionResultIPNS_4ExprELb1EEE", "clang::Sema::MaybeCreateExprWithCleanups(clang::ActionResult<clang::Expr*, true>)"},
    {"_ZN5clang4Sema27MaybeCreateStmtWithCleanupsEPNS_4StmtE", "clang::Sema::MaybeCreateStmtWithCleanups(clang::Stmt*)"},
    {"_ZN5clang4Sema28ActOnStartCXXMemberReferenceEPNS_5ScopeEPNS_4ExprENS_14SourceLocationENS_3tok9TokenKindERNS_9OpaquePtrINS_8QualTypeEEERb", "clang::Sema::ActOnStartCXXMemberReference(clang::Scope*, clang::Expr*, clang::SourceLocation, clang::tok::TokenKind, clang::OpaquePtr<clang::QualType>&, bool&)"},
    {"_ZN5clang4Sema21DiagnoseDtorReferenceENS_14SourceLocationEPNS_4ExprE", "clang::Sema::DiagnoseDtorReference(clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema25BuildPseudoDestructorExprEPNS_4ExprENS_14SourceLocationENS_3tok9TokenKindERKNS_12CXXScopeSpecEPNS_14TypeSourceInfoES3_S3_NS_27PseudoDestructorTypeStorageEb", "clang::Sema::BuildPseudoDestructorExpr(clang::Expr*, clang::SourceLocation, clang::tok::TokenKind, clang::CXXScopeSpec const&, clang::TypeSourceInfo*, clang::SourceLocation, clang::SourceLocation, clang::PseudoDestructorTypeStorage, bool)"},
    {"_ZN5clang4Sema25ActOnPseudoDestructorExprEPNS_5ScopeEPNS_4ExprENS_14SourceLocationENS_3tok9TokenKindERNS_12CXXScopeSpecERNS_13UnqualifiedIdES5_S5_SB_b", "clang::Sema::ActOnPseudoDestructorExpr(clang::Scope*, clang::Expr*, clang::SourceLocation, clang::tok::TokenKind, clang::CXXScopeSpec&, clang::UnqualifiedId&, clang::SourceLocation, clang::SourceLocation, clang::UnqualifiedId&, bool)"},
    {"_ZN5clang4Sema22BuildCXXMemberCallExprEPNS_4ExprEPNS_9NamedDeclEPNS_13CXXMethodDeclE", "clang::Sema::BuildCXXMemberCallExpr(clang::Expr*, clang::NamedDecl*, clang::CXXMethodDecl*)"},
    {"_ZN5clang4Sema20BuildCXXNoexceptExprENS_14SourceLocationEPNS_4ExprES1_", "clang::Sema::BuildCXXNoexceptExpr(clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema17ActOnNoexceptExprENS_14SourceLocationES1_PNS_4ExprES1_", "clang::Sema::ActOnNoexceptExpr(clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema23IgnoredValueConversionsERPNS_4ExprE", "clang::Sema::IgnoredValueConversions(clang::Expr*&)"},
    {"_ZN5clang4Sema19ActOnFinishFullExprEPNS_4ExprE", "clang::Sema::ActOnFinishFullExpr(clang::Expr*)"},
    {"_ZN5clang4Sema19ActOnFinishFullStmtEPNS_4StmtE", "clang::Sema::ActOnFinishFullStmt(clang::Stmt*)"},
    {"_ZN5clang10Declarator19DropFirstTypeObjectEv", "clang::Declarator::DropFirstTypeObject()"},
    {"_ZN4llvm11SmallVectorIPN5clang4ExprELj8EEC2EjRKS3_", "llvm::SmallVector<clang::Expr*, 8u>::SmallVector(unsigned int, clang::Expr* const&)"},
    {"_ZN5clang19BinaryTypeTraitExprC2ENS_14SourceLocationENS_15BinaryTypeTraitEPNS_14TypeSourceInfoES4_bS1_NS_8QualTypeE", "clang::BinaryTypeTraitExpr::BinaryTypeTraitExpr(clang::SourceLocation, clang::BinaryTypeTrait, clang::TypeSourceInfo*, clang::TypeSourceInfo*, bool, clang::SourceLocation, clang::QualType)"},
    {"_ZNK5clang4Decl7getAttrINS_8UuidAttrEEEPT_v", "clang::UuidAttr* clang::Decl::getAttr<clang::UuidAttr>() const"},
    {"_ZN5clang4Sema22ParseObjCStringLiteralEPNS_14SourceLocationEPPNS_4ExprEj", "clang::Sema::ParseObjCStringLiteral(clang::SourceLocation*, clang::Expr**, unsigned int)"},
    {"_ZN5clang4Sema25BuildObjCEncodeExpressionENS_14SourceLocationEPNS_14TypeSourceInfoES1_", "clang::Sema::BuildObjCEncodeExpression(clang::SourceLocation, clang::TypeSourceInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema25ParseObjCEncodeExpressionENS_14SourceLocationES1_S1_NS_9OpaquePtrINS_8QualTypeEEES1_", "clang::Sema::ParseObjCEncodeExpression(clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::OpaquePtr<clang::QualType>, clang::SourceLocation)"},
    {"_ZN5clang4Sema27ParseObjCSelectorExpressionENS_8SelectorENS_14SourceLocationES2_S2_S2_", "clang::Sema::ParseObjCSelectorExpression(clang::Selector, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema27ParseObjCProtocolExpressionEPNS_14IdentifierInfoENS_14SourceLocationES3_S3_S3_", "clang::Sema::ParseObjCProtocolExpression(clang::IdentifierInfo*, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema18tryCaptureObjCSelfEv", "clang::Sema::tryCaptureObjCSelf()"},
    {"_ZN5clang4Sema25CheckMessageArgumentTypesEPPNS_4ExprEjNS_8SelectorEPNS_14ObjCMethodDeclEbNS_14SourceLocationES7_RNS_8QualTypeERNS_13ExprValueKindE", "clang::Sema::CheckMessageArgumentTypes(clang::Expr**, unsigned int, clang::Selector, clang::ObjCMethodDecl*, bool, clang::SourceLocation, clang::SourceLocation, clang::QualType&, clang::ExprValueKind&)"},
    {"_ZN5clang4Sema10isSelfExprEPNS_4ExprE", "clang::Sema::isSelfExpr(clang::Expr*)"},
    {"_ZN5clang4Sema24LookupPrivateClassMethodENS_8SelectorEPNS_17ObjCInterfaceDeclE", "clang::Sema::LookupPrivateClassMethod(clang::Selector, clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang4Sema27LookupPrivateInstanceMethodENS_8SelectorEPNS_17ObjCInterfaceDeclE", "clang::Sema::LookupPrivateInstanceMethod(clang::Selector, clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang4Sema25HandleExprPropertyRefExprEPKNS_21ObjCObjectPointerTypeEPNS_4ExprENS_15DeclarationNameENS_14SourceLocationES7_NS_8QualTypeEb", "clang::Sema::HandleExprPropertyRefExpr(clang::ObjCObjectPointerType const*, clang::Expr*, clang::DeclarationName, clang::SourceLocation, clang::SourceLocation, clang::QualType, bool)"},
    {"_ZN5clang4Sema25ActOnClassPropertyRefExprERNS_14IdentifierInfoES2_NS_14SourceLocationES3_", "clang::Sema::ActOnClassPropertyRefExpr(clang::IdentifierInfo&, clang::IdentifierInfo&, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema18getObjCMessageKindEPNS_5ScopeEPNS_14IdentifierInfoENS_14SourceLocationEbbRNS_9OpaquePtrINS_8QualTypeEEE", "clang::Sema::getObjCMessageKind(clang::Scope*, clang::IdentifierInfo*, clang::SourceLocation, bool, bool, clang::OpaquePtr<clang::QualType>&)"},
    {"_ZN5clang4Sema17ActOnSuperMessageEPNS_5ScopeENS_14SourceLocationENS_8SelectorES3_S3_S3_NS_11ASTMultiPtrIPNS_4ExprEEE", "clang::Sema::ActOnSuperMessage(clang::Scope*, clang::SourceLocation, clang::Selector, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>)"},
    {"_ZN5clang4Sema20BuildInstanceMessageEPNS_4ExprENS_8QualTypeENS_14SourceLocationENS_8SelectorEPNS_14ObjCMethodDeclES4_S4_S4_NS_11ASTMultiPtrIS2_EE", "clang::Sema::BuildInstanceMessage(clang::Expr*, clang::QualType, clang::SourceLocation, clang::Selector, clang::ObjCMethodDecl*, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>)"},
    {"_ZN5clang4Sema17BuildClassMessageEPNS_14TypeSourceInfoENS_8QualTypeENS_14SourceLocationENS_8SelectorEPNS_14ObjCMethodDeclES4_S4_S4_NS_11ASTMultiPtrIPNS_4ExprEEE", "clang::Sema::BuildClassMessage(clang::TypeSourceInfo*, clang::QualType, clang::SourceLocation, clang::Selector, clang::ObjCMethodDecl*, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>)"},
    {"_ZN5clang4Sema17ActOnClassMessageEPNS_5ScopeENS_9OpaquePtrINS_8QualTypeEEENS_8SelectorENS_14SourceLocationES7_S7_NS_11ASTMultiPtrIPNS_4ExprEEE", "clang::Sema::ActOnClassMessage(clang::Scope*, clang::OpaquePtr<clang::QualType>, clang::Selector, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>)"},
    {"_ZN5clang4Sema20ActOnInstanceMessageEPNS_5ScopeEPNS_4ExprENS_8SelectorENS_14SourceLocationES6_S6_NS_11ASTMultiPtrIS4_EE", "clang::Sema::ActOnInstanceMessage(clang::Scope*, clang::Expr*, clang::Selector, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::ASTMultiPtr<clang::Expr*>)"},
    {"_ZN5clang4Sema26ActOnDesignatedInitializerERNS_11DesignationENS_14SourceLocationEbNS_12ActionResultIPNS_4ExprELb1EEE", "clang::Sema::ActOnDesignatedInitializer(clang::Designation&, clang::SourceLocation, bool, clang::ActionResult<clang::Expr*, true>)"},
    {"_Z24CheckArrayDesignatorExprRN5clang4SemaEPNS_4ExprERN4llvm6APSIntE", "CheckArrayDesignatorExpr(clang::Sema&, clang::Expr*, llvm::APSInt&)"},
    {"_ZN5clang4Sema13CheckInitListERKNS_17InitializedEntityERPNS_12InitListExprERNS_8QualTypeE", "clang::Sema::CheckInitList(clang::InitializedEntity const&, clang::InitListExpr*&, clang::QualType&)"},
    {"_ZN12_GLOBAL__N_115InitListCheckerC1ERN5clang4SemaERKNS1_17InitializedEntityEPNS1_12InitListExprERNS1_8QualTypeE", "(anonymous namespace)::InitListChecker::InitListChecker(clang::Sema&, clang::InitializedEntity const&, clang::InitListExpr*, clang::QualType&)"},
    {"_ZN5clang17InitializedEntityC1ERNS_10ASTContextEjRKS0_", "clang::InitializedEntity::InitializedEntity(clang::ASTContext&, unsigned int, clang::InitializedEntity const&)"},
    {"_ZN5clang17InitializedEntityC2ERNS_10ASTContextEjRKS0_", "clang::InitializedEntity::InitializedEntity(clang::ASTContext&, unsigned int, clang::InitializedEntity const&)"},
    {"_ZN5clang17InitializedEntity14InitializeBaseERNS_10ASTContextEPNS_16CXXBaseSpecifierEb", "clang::InitializedEntity::InitializeBase(clang::ASTContext&, clang::CXXBaseSpecifier*, bool)"},
    {"_ZNK5clang17InitializedEntity7getNameEv", "clang::InitializedEntity::getName() const"},
    {"_ZNK5clang17InitializedEntity7getDeclEv", "clang::InitializedEntity::getDecl() const"},
    {"_ZNK5clang17InitializedEntity10allowsNRVOEv", "clang::InitializedEntity::allowsNRVO() const"},
    {"_ZN5clang22InitializationSequence4Step7DestroyEv", "clang::InitializationSequence::Step::Destroy()"},
    {"_ZNK5clang22InitializationSequence24isDirectReferenceBindingEv", "clang::InitializationSequence::isDirectReferenceBinding() const"},
    {"_ZNK5clang22InitializationSequence11isAmbiguousEv", "clang::InitializationSequence::isAmbiguous() const"},
    {"_ZNK5clang22InitializationSequence27isConstructorInitializationEv", "clang::InitializationSequence::isConstructorInitialization() const"},
    {"_ZN5clang22InitializationSequence32AddAddressOverloadResolutionStepEPNS_12FunctionDeclENS_14DeclAccessPairE", "clang::InitializationSequence::AddAddressOverloadResolutionStep(clang::FunctionDecl*, clang::DeclAccessPair)"},
    {"_ZN5clang22InitializationSequence24AddDerivedToBaseCastStepENS_8QualTypeENS_13ExprValueKindE", "clang::InitializationSequence::AddDerivedToBaseCastStep(clang::QualType, clang::ExprValueKind)"},
    {"_ZN5clang22InitializationSequence23AddReferenceBindingStepENS_8QualTypeEb", "clang::InitializationSequence::AddReferenceBindingStep(clang::QualType, bool)"},
    {"_ZN5clang22InitializationSequence28AddExtraneousCopyToTemporaryENS_8QualTypeE", "clang::InitializationSequence::AddExtraneousCopyToTemporary(clang::QualType)"},
    {"_ZN5clang22InitializationSequence21AddUserConversionStepEPNS_12FunctionDeclENS_14DeclAccessPairENS_8QualTypeE", "clang::InitializationSequence::AddUserConversionStep(clang::FunctionDecl*, clang::DeclAccessPair, clang::QualType)"},
    {"_ZN5clang22InitializationSequence30AddQualificationConversionStepENS_8QualTypeENS_13ExprValueKindE", "clang::InitializationSequence::AddQualificationConversionStep(clang::QualType, clang::ExprValueKind)"},
    {"_ZN5clang22InitializationSequence25AddConversionSequenceStepERKNS_26ImplicitConversionSequenceENS_8QualTypeE", "clang::InitializationSequence::AddConversionSequenceStep(clang::ImplicitConversionSequence const&, clang::QualType)"},
    {"_ZN5clang22InitializationSequence25AddListInitializationStepENS_8QualTypeE", "clang::InitializationSequence::AddListInitializationStep(clang::QualType)"},
    {"_ZN5clang22InitializationSequence32AddConstructorInitializationStepEPNS_18CXXConstructorDeclENS_15AccessSpecifierENS_8QualTypeE", "clang::InitializationSequence::AddConstructorInitializationStep(clang::CXXConstructorDecl*, clang::AccessSpecifier, clang::QualType)"},
    {"_ZN5clang22InitializationSequence25AddZeroInitializationStepENS_8QualTypeE", "clang::InitializationSequence::AddZeroInitializationStep(clang::QualType)"},
    {"_ZN5clang22InitializationSequence18AddCAssignmentStepENS_8QualTypeE", "clang::InitializationSequence::AddCAssignmentStep(clang::QualType)"},
    {"_ZN5clang22InitializationSequence17AddStringInitStepENS_8QualTypeE", "clang::InitializationSequence::AddStringInitStep(clang::QualType)"},
    {"_ZN5clang22InitializationSequence27AddObjCObjectConversionStepENS_8QualTypeE", "clang::InitializationSequence::AddObjCObjectConversionStep(clang::QualType)"},
    {"_ZN5clang22InitializationSequence18SetOverloadFailureENS0_11FailureKindENS_17OverloadingResultE", "clang::InitializationSequence::SetOverloadFailure(clang::InitializationSequence::FailureKind, clang::OverloadingResult)"},
    {"_ZN5clang22InitializationSequenceC1ERNS_4SemaERKNS_17InitializedEntityERKNS_18InitializationKindEPPNS_4ExprEj", "clang::InitializationSequence::InitializationSequence(clang::Sema&, clang::InitializedEntity const&, clang::InitializationKind const&, clang::Expr**, unsigned int)"},
    {"_ZN5clang22InitializationSequenceC2ERNS_4SemaERKNS_17InitializedEntityERKNS_18InitializationKindEPPNS_4ExprEj", "clang::InitializationSequence::InitializationSequence(clang::Sema&, clang::InitializedEntity const&, clang::InitializationKind const&, clang::Expr**, unsigned int)"},
    {"_Z12IsStringInitPN5clang4ExprENS_8QualTypeERNS_10ASTContextE", "IsStringInit(clang::Expr*, clang::QualType, clang::ASTContext&)"},
    {"_Z28TryConstructorInitializationRN5clang4SemaERKNS_17InitializedEntityERKNS_18InitializationKindEPPNS_4ExprEjNS_8QualTypeERNS_22InitializationSequenceE", "TryConstructorInitialization(clang::Sema&, clang::InitializedEntity const&, clang::InitializationKind const&, clang::Expr**, unsigned int, clang::QualType, clang::InitializationSequence&)"},
    {"_Z24TryUserDefinedConversionRN5clang4SemaERKNS_17InitializedEntityERKNS_18InitializationKindEPNS_4ExprERNS_22InitializationSequenceE", "TryUserDefinedConversion(clang::Sema&, clang::InitializedEntity const&, clang::InitializationKind const&, clang::Expr*, clang::InitializationSequence&)"},
    {"_ZN5clang22InitializationSequenceD1Ev", "clang::InitializationSequence::~InitializationSequence()"},
    {"_ZN5clang22InitializationSequenceD2Ev", "clang::InitializationSequence::~InitializationSequence()"},
    {"_ZN5clang22InitializationSequence21PrintInitLocationNoteERNS_4SemaERKNS_17InitializedEntityE", "clang::InitializationSequence::PrintInitLocationNote(clang::Sema&, clang::InitializedEntity const&)"},
    {"_ZN5clang22InitializationSequence7PerformERNS_4SemaERKNS_17InitializedEntityERKNS_18InitializationKindENS_11ASTMultiPtrIPNS_4ExprEEEPNS_8QualTypeE", "clang::InitializationSequence::Perform(clang::Sema&, clang::InitializedEntity const&, clang::InitializationKind const&, clang::ASTMultiPtr<clang::Expr*>, clang::QualType*)"},
    {"_ZN5clang22InitializationSequence8DiagnoseERNS_4SemaERKNS_17InitializedEntityERKNS_18InitializationKindEPPNS_4ExprEj", "clang::InitializationSequence::Diagnose(clang::Sema&, clang::InitializedEntity const&, clang::InitializationKind const&, clang::Expr**, unsigned int)"},
    {"_Z10CopyObjectRN5clang4SemaENS_8QualTypeERKNS_17InitializedEntityENS_12ActionResultIPNS_4ExprELb1EEEb", "CopyObject(clang::Sema&, clang::QualType, clang::InitializedEntity const&, clang::ActionResult<clang::Expr*, true>, bool)"},
    {"_Z15CheckStringInitPN5clang4ExprERNS_8QualTypeERNS_4SemaE", "CheckStringInit(clang::Expr*, clang::QualType&, clang::Sema&)"},
    {"_ZNK5clang22InitializationSequence4dumpERN4llvm11raw_ostreamE", "clang::InitializationSequence::dump(llvm::raw_ostream&) const"},
    {"_ZNK5clang22InitializationSequence4dumpEv", "clang::InitializationSequence::dump() const"},
    {"_ZN5clang4Sema25PerformCopyInitializationERKNS_17InitializedEntityENS_14SourceLocationENS_12ActionResultIPNS_4ExprELb1EEE", "clang::Sema::PerformCopyInitialization(clang::InitializedEntity const&, clang::SourceLocation, clang::ActionResult<clang::Expr*, true>)"},
    {"_Z32TryRefInitWithConversionFunctionRN5clang4SemaERKNS_17InitializedEntityERKNS_18InitializationKindEPNS_4ExprEbRNS_22InitializationSequenceE", "TryRefInitWithConversionFunction(clang::Sema&, clang::InitializedEntity const&, clang::InitializationKind const&, clang::Expr*, bool, clang::InitializationSequence&)"},
    {"_ZN12_GLOBAL__N_115InitListChecker26getStructuredSubobjectInitEPN5clang12InitListExprEjNS1_8QualTypeES3_jNS1_11SourceRangeE", "(anonymous namespace)::InitListChecker::getStructuredSubobjectInit(clang::InitListExpr*, unsigned int, clang::QualType, clang::InitListExpr*, unsigned int, clang::SourceRange)"},
    {"_ZN12_GLOBAL__N_115InitListChecker21CheckExplicitInitListERKN5clang17InitializedEntityEPNS1_12InitListExprERNS1_8QualTypeERjS6_S9_b", "(anonymous namespace)::InitListChecker::CheckExplicitInitList(clang::InitializedEntity const&, clang::InitListExpr*, clang::QualType&, unsigned int&, clang::InitListExpr*, unsigned int&, bool)"},
    {"_ZN12_GLOBAL__N_115InitListChecker26FillInValueInitializationsERKN5clang17InitializedEntityEPNS1_12InitListExprERb", "(anonymous namespace)::InitListChecker::FillInValueInitializations(clang::InitializedEntity const&, clang::InitListExpr*, bool&)"},
    {"_ZN12_GLOBAL__N_115InitListChecker23FillInValueInitForFieldEjPN5clang9FieldDeclERKNS1_17InitializedEntityEPNS1_12InitListExprERb", "(anonymous namespace)::InitListChecker::FillInValueInitForField(unsigned int, clang::FieldDecl*, clang::InitializedEntity const&, clang::InitListExpr*, bool&)"},
    {"_ZN12_GLOBAL__N_115InitListChecker21CheckListElementTypesERKN5clang17InitializedEntityEPNS1_12InitListExprERNS1_8QualTypeEbRjS6_S9_b", "(anonymous namespace)::InitListChecker::CheckListElementTypes(clang::InitializedEntity const&, clang::InitListExpr*, clang::QualType&, bool, unsigned int&, clang::InitListExpr*, unsigned int&, bool)"},
    {"_ZN12_GLOBAL__N_115InitListChecker15CheckScalarTypeERKN5clang17InitializedEntityEPNS1_12InitListExprENS1_8QualTypeERjS6_S8_", "(anonymous namespace)::InitListChecker::CheckScalarType(clang::InitializedEntity const&, clang::InitListExpr*, clang::QualType, unsigned int&, clang::InitListExpr*, unsigned int&)"},
    {"_ZN12_GLOBAL__N_115InitListChecker21CheckStructUnionTypesERKN5clang17InitializedEntityEPNS1_12InitListExprENS1_8QualTypeENS1_11DeclContext22specific_decl_iteratorINS1_9FieldDeclEEEbRjS6_SC_b", "(anonymous namespace)::InitListChecker::CheckStructUnionTypes(clang::InitializedEntity const&, clang::InitListExpr*, clang::QualType, clang::DeclContext::specific_decl_iterator<clang::FieldDecl>, bool, unsigned int&, clang::InitListExpr*, unsigned int&, bool)"},
    {"_ZN12_GLOBAL__N_115InitListChecker14CheckArrayTypeERKN5clang17InitializedEntityEPNS1_12InitListExprERNS1_8QualTypeEN4llvm6APSIntEbRjS6_SB_", "(anonymous namespace)::InitListChecker::CheckArrayType(clang::InitializedEntity const&, clang::InitListExpr*, clang::QualType&, llvm::APSInt, bool, unsigned int&, clang::InitListExpr*, unsigned int&)"},
    {"_ZN12_GLOBAL__N_115InitListChecker18CheckReferenceTypeERKN5clang17InitializedEntityEPNS1_12InitListExprENS1_8QualTypeERjS6_S8_", "(anonymous namespace)::InitListChecker::CheckReferenceType(clang::InitializedEntity const&, clang::InitListExpr*, clang::QualType, unsigned int&, clang::InitListExpr*, unsigned int&)"},
    {"_ZN12_GLOBAL__N_115InitListChecker27UpdateStructuredListElementEPN5clang12InitListExprERjPNS1_4ExprE", "(anonymous namespace)::InitListChecker::UpdateStructuredListElement(clang::InitListExpr*, unsigned int&, clang::Expr*)"},
    {"_ZN12_GLOBAL__N_115InitListChecker26CheckDesignatedInitializerERKN5clang17InitializedEntityEPNS1_12InitListExprEPNS1_18DesignatedInitExprEjRNS1_8QualTypeEPNS1_11DeclContext22specific_decl_iteratorINS1_9FieldDeclEEEPN4llvm6APSIntERjS6_SJ_bb", "(anonymous namespace)::InitListChecker::CheckDesignatedInitializer(clang::InitializedEntity const&, clang::InitListExpr*, clang::DesignatedInitExpr*, unsigned int, clang::QualType&, clang::DeclContext::specific_decl_iterator<clang::FieldDecl>*, llvm::APSInt*, unsigned int&, clang::InitListExpr*, unsigned int&, bool, bool)"},
    {"_ZN12_GLOBAL__N_115InitListChecker19CheckSubElementTypeERKN5clang17InitializedEntityEPNS1_12InitListExprENS1_8QualTypeERjS6_S8_", "(anonymous namespace)::InitListChecker::CheckSubElementType(clang::InitializedEntity const&, clang::InitListExpr*, clang::QualType, unsigned int&, clang::InitListExpr*, unsigned int&)"},
    {"_ZN12_GLOBAL__N_115InitListChecker21CheckImplicitInitListERKN5clang17InitializedEntityEPNS1_12InitListExprENS1_8QualTypeERjS6_S8_b", "(anonymous namespace)::InitListChecker::CheckImplicitInitList(clang::InitializedEntity const&, clang::InitListExpr*, clang::QualType, unsigned int&, clang::InitListExpr*, unsigned int&, bool)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang22InitializationSequence4StepELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::InitializationSequence::Step, false>::grow(unsigned long)"},
    {"_ZNSt8_Rb_treeIPN5clang12InitListExprESt4pairIKS2_S2_ESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<clang::InitListExpr*, std::pair<clang::InitListExpr* const, clang::InitListExpr*>, std::_Select1st<std::pair<clang::InitListExpr* const, clang::InitListExpr*>>, std::less<clang::InitListExpr*>, std::allocator<std::pair<clang::InitListExpr* const, clang::InitListExpr*>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::InitListExpr* const, clang::InitListExpr*>>*)"},
    {"_ZNSt8_Rb_treeIPN5clang12InitListExprESt4pairIKS2_S2_ESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS5_ERKS5_", "std::_Rb_tree<clang::InitListExpr*, std::pair<clang::InitListExpr* const, clang::InitListExpr*>, std::_Select1st<std::pair<clang::InitListExpr* const, clang::InitListExpr*>>, std::less<clang::InitListExpr*>, std::allocator<std::pair<clang::InitListExpr* const, clang::InitListExpr*>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::InitListExpr* const, clang::InitListExpr*>>, std::pair<clang::InitListExpr* const, clang::InitListExpr*> const&)"},
    {"_ZNSt8_Rb_treeIPN5clang12InitListExprESt4pairIKS2_S2_ESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE16_M_insert_uniqueERKS5_", "std::_Rb_tree<clang::InitListExpr*, std::pair<clang::InitListExpr* const, clang::InitListExpr*>, std::_Select1st<std::pair<clang::InitListExpr* const, clang::InitListExpr*>>, std::less<clang::InitListExpr*>, std::allocator<std::pair<clang::InitListExpr* const, clang::InitListExpr*>>>::_M_insert_unique(std::pair<clang::InitListExpr* const, clang::InitListExpr*> const&)"},
    {"_ZN5clang12LookupResult9configureEv", "clang::LookupResult::configure()"},
    {"_ZNK5clang12LookupResult6sanityEv", "clang::LookupResult::sanity() const"},
    {"_ZN5clang12LookupResult11deletePathsEPNS_12CXXBasePathsE", "clang::LookupResult::deletePaths(clang::CXXBasePaths*)"},
    {"_ZN5clang12LookupResult11resolveKindEv", "clang::LookupResult::resolveKind()"},
    {"_ZN5clang12LookupResult21addDeclsFromBasePathsERKNS_12CXXBasePathsE", "clang::LookupResult::addDeclsFromBasePaths(clang::CXXBasePaths const&)"},
    {"_ZN5clang12LookupResult26setAmbiguousBaseSubobjectsERNS_12CXXBasePathsE", "clang::LookupResult::setAmbiguousBaseSubobjects(clang::CXXBasePaths&)"},
    {"_ZN5clang12LookupResult30setAmbiguousBaseSubobjectTypesERNS_12CXXBasePathsE", "clang::LookupResult::setAmbiguousBaseSubobjectTypes(clang::CXXBasePaths&)"},
    {"_ZN5clang12LookupResult5printERN4llvm11raw_ostreamE", "clang::LookupResult::print(llvm::raw_ostream&)"},
    {"_ZN5clang4Sema33ForceDeclarationOfImplicitMembersEPNS_13CXXRecordDeclE", "clang::Sema::ForceDeclarationOfImplicitMembers(clang::CXXRecordDecl*)"},
    {"_Z31CanDeclareSpecialMemberFunctionRN5clang10ASTContextEPKNS_13CXXRecordDeclE", "CanDeclareSpecialMemberFunction(clang::ASTContext&, clang::CXXRecordDecl const*)"},
    {"_ZN5clang4Sema13CppLookupNameERNS_12LookupResultEPNS_5ScopeE", "clang::Sema::CppLookupName(clang::LookupResult&, clang::Scope*)"},
    {"_Z38DeclareImplicitMemberFunctionsWithNameRN5clang4SemaENS_15DeclarationNameEPKNS_11DeclContextE", "DeclareImplicitMemberFunctionsWithName(clang::Sema&, clang::DeclarationName, clang::DeclContext const*)"},
    {"_Z16findOuterContextPN5clang5ScopeE", "findOuterContext(clang::Scope*)"},
    {"_ZN5clang4Sema19LookupQualifiedNameERNS_12LookupResultEPNS_11DeclContextEb", "clang::Sema::LookupQualifiedName(clang::LookupResult&, clang::DeclContext*, bool)"},
    {"_ZN12_GLOBAL__N_123UnqualUsingDirectiveSet15visitScopeChainEPN5clang5ScopeES3_", "(anonymous namespace)::UnqualUsingDirectiveSet::visitScopeChain(clang::Scope*, clang::Scope*)"},
    {"_ZN12_GLOBAL__N_123UnqualUsingDirectiveSet4doneEv", "(anonymous namespace)::UnqualUsingDirectiveSet::done()"},
    {"_ZN5clang4Sema10LookupNameERNS_12LookupResultEPNS_5ScopeEb", "clang::Sema::LookupName(clang::LookupResult&, clang::Scope*, bool)"},
    {"_Z13LookupBuiltinRN5clang4SemaERNS_12LookupResultE", "LookupBuiltin(clang::Sema&, clang::LookupResult&)"},
    {"_Z12LookupDirectRN5clang4SemaERNS_12LookupResultEPKNS_11DeclContextE", "LookupDirect(clang::Sema&, clang::LookupResult&, clang::DeclContext const*)"},
    {"_Z15LookupAnyMemberPKN5clang16CXXBaseSpecifierERNS_11CXXBasePathEPv", "LookupAnyMember(clang::CXXBaseSpecifier const*, clang::CXXBasePath&, void*)"},
    {"_ZN5clang4Sema16LookupParsedNameERNS_12LookupResultEPNS_5ScopeEPNS_12CXXScopeSpecEbb", "clang::Sema::LookupParsedName(clang::LookupResult&, clang::Scope*, clang::CXXScopeSpec*, bool, bool)"},
    {"_ZN5clang4Sema23DiagnoseAmbiguousLookupERNS_12LookupResultE", "clang::Sema::DiagnoseAmbiguousLookup(clang::LookupResult&)"},
    {"_ZN5clang4Sema34FindAssociatedClassesAndNamespacesEPPNS_4ExprEjRN4llvm11SmallPtrSetIPNS_11DeclContextELj16EEERNS5_IPNS_13CXXRecordDeclELj16EEE", "clang::Sema::FindAssociatedClassesAndNamespaces(clang::Expr**, unsigned int, llvm::SmallPtrSet<clang::DeclContext*, 16u>&, llvm::SmallPtrSet<clang::CXXRecordDecl*, 16u>&)"},
    {"_Z33addAssociatedClassesAndNamespacesRN12_GLOBAL__N_116AssociatedLookupEN5clang8QualTypeE", "addAssociatedClassesAndNamespaces((anonymous namespace)::AssociatedLookup&, clang::QualType)"},
    {"_ZN5clang4Sema16LookupSingleNameEPNS_5ScopeENS_15DeclarationNameENS_14SourceLocationENS0_14LookupNameKindENS0_17RedeclarationKindE", "clang::Sema::LookupSingleName(clang::Scope*, clang::DeclarationName, clang::SourceLocation, clang::Sema::LookupNameKind, clang::Sema::RedeclarationKind)"},
    {"_ZN5clang4Sema14LookupProtocolEPNS_14IdentifierInfoENS_14SourceLocationE", "clang::Sema::LookupProtocol(clang::IdentifierInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema28LookupOverloadedOperatorNameENS_22OverloadedOperatorKindEPNS_5ScopeENS_8QualTypeES4_RNS_17UnresolvedSetImplE", "clang::Sema::LookupOverloadedOperatorName(clang::OverloadedOperatorKind, clang::Scope*, clang::QualType, clang::QualType, clang::UnresolvedSetImpl&)"},
    {"_Z38IsAcceptableNonMemberOperatorCandidatePN5clang12FunctionDeclENS_8QualTypeES2_RNS_10ASTContextE", "IsAcceptableNonMemberOperatorCandidate(clang::FunctionDecl*, clang::QualType, clang::QualType, clang::ASTContext&)"},
    {"_ZN5clang4Sema18LookupConstructorsEPNS_13CXXRecordDeclE", "clang::Sema::LookupConstructors(clang::CXXRecordDecl*)"},
    {"_ZN5clang4Sema16LookupDestructorEPNS_13CXXRecordDeclE", "clang::Sema::LookupDestructor(clang::CXXRecordDecl*)"},
    {"_ZN5clang9ADLResult6insertEPNS_9NamedDeclE", "clang::ADLResult::insert(clang::NamedDecl*)"},
    {"_ZN5clang4Sema23ArgumentDependentLookupENS_15DeclarationNameEbPPNS_4ExprEjRNS_9ADLResultE", "clang::Sema::ArgumentDependentLookup(clang::DeclarationName, bool, clang::Expr**, unsigned int, clang::ADLResult&)"},
    {"_ZN5clang19VisibleDeclConsumerD0Ev", "clang::VisibleDeclConsumer::~VisibleDeclConsumer()"},
    {"_ZN5clang19VisibleDeclConsumerD1Ev", "clang::VisibleDeclConsumer::~VisibleDeclConsumer()"},
    {"_ZN5clang19VisibleDeclConsumerD2Ev", "clang::VisibleDeclConsumer::~VisibleDeclConsumer()"},
    {"_ZN5clang4Sema18LookupVisibleDeclsEPNS_5ScopeENS0_14LookupNameKindERNS_19VisibleDeclConsumerEb", "clang::Sema::LookupVisibleDecls(clang::Scope*, clang::Sema::LookupNameKind, clang::VisibleDeclConsumer&, bool)"},
    {"_ZN12_GLOBAL__N_117ShadowContextRAIIC1ERNS_18VisibleDeclsRecordE", "(anonymous namespace)::ShadowContextRAII::ShadowContextRAII((anonymous namespace)::VisibleDeclsRecord&)"},
    {"_Z18LookupVisibleDeclsPN5clang5ScopeERNS_12LookupResultERN12_GLOBAL__N_123UnqualUsingDirectiveSetERNS_19VisibleDeclConsumerERNS4_18VisibleDeclsRecordE", "LookupVisibleDecls(clang::Scope*, clang::LookupResult&, (anonymous namespace)::UnqualUsingDirectiveSet&, clang::VisibleDeclConsumer&, (anonymous namespace)::VisibleDeclsRecord&)"},
    {"_ZN12_GLOBAL__N_117ShadowContextRAIID1Ev", "(anonymous namespace)::ShadowContextRAII::~ShadowContextRAII()"},
    {"_ZN5clang4Sema18LookupVisibleDeclsEPNS_11DeclContextENS0_14LookupNameKindERNS_19VisibleDeclConsumerEb", "clang::Sema::LookupVisibleDecls(clang::DeclContext*, clang::Sema::LookupNameKind, clang::VisibleDeclConsumer&, bool)"},
    {"_Z18LookupVisibleDeclsPN5clang11DeclContextERNS_12LookupResultEbbRNS_19VisibleDeclConsumerERN12_GLOBAL__N_118VisibleDeclsRecordE", "LookupVisibleDecls(clang::DeclContext*, clang::LookupResult&, bool, bool, clang::VisibleDeclConsumer&, (anonymous namespace)::VisibleDeclsRecord&)"},
    {"_ZN5clang4Sema11CorrectTypoERNS_12LookupResultEPNS_5ScopeEPNS_12CXXScopeSpecEPNS_11DeclContextEbNS0_18CorrectTypoContextEPKNS_21ObjCObjectPointerTypeE", "clang::Sema::CorrectTypo(clang::LookupResult&, clang::Scope*, clang::CXXScopeSpec*, clang::DeclContext*, bool, clang::Sema::CorrectTypoContext, clang::ObjCObjectPointerType const*)"},
    {"_ZN12_GLOBAL__N_122TypoCorrectionConsumer9FoundNameEN4llvm9StringRefE", "(anonymous namespace)::TypoCorrectionConsumer::FoundName(llvm::StringRef)"},
    {"_Z25LookupPotentialTypoResultRN5clang4SemaERNS_12LookupResultEPNS_14IdentifierInfoEPNS_5ScopeEPNS_12CXXScopeSpecEPNS_11DeclContextEbNS0_18CorrectTypoContextE", "LookupPotentialTypoResult(clang::Sema&, clang::LookupResult&, clang::IdentifierInfo*, clang::Scope*, clang::CXXScopeSpec*, clang::DeclContext*, bool, clang::Sema::CorrectTypoContext)"},
    {"_ZN12_GLOBAL__N_122TypoCorrectionConsumerD1Ev", "(anonymous namespace)::TypoCorrectionConsumer::~TypoCorrectionConsumer()"},
    {"_ZN12_GLOBAL__N_122TypoCorrectionConsumerD0Ev", "(anonymous namespace)::TypoCorrectionConsumer::~TypoCorrectionConsumer()"},
    {"_ZN12_GLOBAL__N_122TypoCorrectionConsumer9FoundDeclEPN5clang9NamedDeclES3_b", "(anonymous namespace)::TypoCorrectionConsumer::FoundDecl(clang::NamedDecl*, clang::NamedDecl*, bool)"},
    {"_ZN12_GLOBAL__N_118VisibleDeclsRecord11checkHiddenEPN5clang9NamedDeclE", "(anonymous namespace)::VisibleDeclsRecord::checkHidden(clang::NamedDecl*)"},
    {"_ZN12_GLOBAL__N_118VisibleDeclsRecord3addEPN5clang9NamedDeclE", "(anonymous namespace)::VisibleDeclsRecord::add(clang::NamedDecl*)"},
    {"_ZNK12_GLOBAL__N_123UnqualUsingDirectiveSet16getNamespacesForEPN5clang11DeclContextE", "(anonymous namespace)::UnqualUsingDirectiveSet::getNamespacesFor(clang::DeclContext*) const"},
    {"_Z25CollectEnclosingNamespaceRN4llvm11SmallPtrSetIPN5clang11DeclContextELj16EEES3_", "CollectEnclosingNamespace(llvm::SmallPtrSet<clang::DeclContext*, 16u>&, clang::DeclContext*)"},
    {"_Z33addAssociatedClassesAndNamespacesRN12_GLOBAL__N_116AssociatedLookupERKN5clang16TemplateArgumentE", "addAssociatedClassesAndNamespaces((anonymous namespace)::AssociatedLookup&, clang::TemplateArgument const&)"},
    {"_ZSt16__introsort_loopIPN12_GLOBAL__N_116UnqualUsingEntryElNS1_10ComparatorEEvT_S4_T0_T1_", "void std::__introsort_loop<(anonymous namespace)::UnqualUsingEntry*, long, (anonymous namespace)::UnqualUsingEntry::Comparator>((anonymous namespace)::UnqualUsingEntry*, (anonymous namespace)::UnqualUsingEntry*, long, (anonymous namespace)::UnqualUsingEntry::Comparator)"},
    {"_ZSt16__insertion_sortIPN12_GLOBAL__N_116UnqualUsingEntryENS1_10ComparatorEEvT_S4_T0_", "void std::__insertion_sort<(anonymous namespace)::UnqualUsingEntry*, (anonymous namespace)::UnqualUsingEntry::Comparator>((anonymous namespace)::UnqualUsingEntry*, (anonymous namespace)::UnqualUsingEntry*, (anonymous namespace)::UnqualUsingEntry::Comparator)"},
    {"_ZN12_GLOBAL__N_123UnqualUsingDirectiveSet17addUsingDirectiveEPN5clang18UsingDirectiveDeclEPNS1_11DeclContextE", "(anonymous namespace)::UnqualUsingDirectiveSet::addUsingDirective(clang::UsingDirectiveDecl*, clang::DeclContext*)"},
    {"_ZN12_GLOBAL__N_123UnqualUsingDirectiveSet18addUsingDirectivesEPN5clang11DeclContextES3_", "(anonymous namespace)::UnqualUsingDirectiveSet::addUsingDirectives(clang::DeclContext*, clang::DeclContext*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoESt4pairINS_9StringRefEbENS_12DenseMapInfoIS3_EENS7_IS6_EEE16InsertIntoBucketERKS3_RKS6_PS4_IS3_S6_E", "llvm::DenseMap<clang::IdentifierInfo*, std::pair<llvm::StringRef, bool>, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<std::pair<llvm::StringRef, bool>>>::InsertIntoBucket(clang::IdentifierInfo* const&, std::pair<llvm::StringRef, bool> const&, std::pair<clang::IdentifierInfo*, std::pair<llvm::StringRef, bool>>*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoESt4pairINS_9StringRefEbENS_12DenseMapInfoIS3_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::IdentifierInfo*, std::pair<llvm::StringRef, bool>, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<std::pair<llvm::StringRef, bool>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang9NamedDeclES3_NS_12DenseMapInfoIS3_EES5_E16InsertIntoBucketERKS3_S8_PSt4pairIS3_S3_E", "llvm::DenseMap<clang::NamedDecl*, clang::NamedDecl*, llvm::DenseMapInfo<clang::NamedDecl*>, llvm::DenseMapInfo<clang::NamedDecl*>>::InsertIntoBucket(clang::NamedDecl* const&, clang::NamedDecl* const&, std::pair<clang::NamedDecl*, clang::NamedDecl*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang9NamedDeclES3_NS_12DenseMapInfoIS3_EES5_E4growEj", "llvm::DenseMap<clang::NamedDecl*, clang::NamedDecl*, llvm::DenseMapInfo<clang::NamedDecl*>, llvm::DenseMapInfo<clang::NamedDecl*>>::grow(unsigned int)"},
    {"_ZNSt8_Rb_treeIPN5clang4DeclES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE16_M_insert_uniqueERKS2_", "std::_Rb_tree<clang::Decl*, clang::Decl*, std::_Identity<clang::Decl*>, std::less<clang::Decl*>, std::allocator<clang::Decl*>>::_M_insert_unique(clang::Decl* const&)"},
    {"_ZN4llvm9StringMapIbNS_16BumpPtrAllocatorEE16GetOrCreateValueIbEERNS_14StringMapEntryIbEENS_9StringRefET_", "llvm::StringMapEntry<bool>& llvm::StringMap<bool, llvm::BumpPtrAllocator>::GetOrCreateValue<bool>(llvm::StringRef, bool)"},
    {"_ZNSt8_Rb_treeIPN5clang4DeclES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE8_M_eraseEPSt13_Rb_tree_nodeIS2_E", "std::_Rb_tree<clang::Decl*, clang::Decl*, std::_Identity<clang::Decl*>, std::less<clang::Decl*>, std::allocator<clang::Decl*>>::_M_erase(std::_Rb_tree_node<clang::Decl*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang11DeclContextEcNS_12DenseMapInfoIS3_EENS4_IcEEE6insertERKSt4pairIS3_cE", "llvm::DenseMap<clang::DeclContext*, char, llvm::DenseMapInfo<clang::DeclContext*>, llvm::DenseMapInfo<char>>::insert(std::pair<clang::DeclContext*, char> const&)"},
    {"_ZN4llvm8DenseMapIPN5clang11DeclContextEcNS_12DenseMapInfoIS3_EENS4_IcEEE16InsertIntoBucketERKS3_RKcPSt4pairIS3_cE", "llvm::DenseMap<clang::DeclContext*, char, llvm::DenseMapInfo<clang::DeclContext*>, llvm::DenseMapInfo<char>>::InsertIntoBucket(clang::DeclContext* const&, char const&, std::pair<clang::DeclContext*, char>*)"},
    {"_ZN4llvm8DenseMapIPN5clang11DeclContextEcNS_12DenseMapInfoIS3_EENS4_IcEEE4growEj", "llvm::DenseMap<clang::DeclContext*, char, llvm::DenseMapInfo<clang::DeclContext*>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZN5clang4Sema13ActOnPropertyEPNS_5ScopeENS_14SourceLocationERNS_15FieldDeclaratorERNS_12ObjCDeclSpecENS_8SelectorES8_PNS_4DeclEPbNS_3tok15ObjCKeywordKindEPNS_11DeclContextE", "clang::Sema::ActOnProperty(clang::Scope*, clang::SourceLocation, clang::FieldDeclarator&, clang::ObjCDeclSpec&, clang::Selector, clang::Selector, clang::Decl*, bool*, clang::tok::ObjCKeywordKind, clang::DeclContext*)"},
    {"_ZN5clang4Sema30HandlePropertyInClassExtensionEPNS_5ScopeEPNS_16ObjCCategoryDeclENS_14SourceLocationERNS_15FieldDeclaratorENS_8SelectorES8_bbjPbPNS_14TypeSourceInfoENS_3tok15ObjCKeywordKindE", "clang::Sema::HandlePropertyInClassExtension(clang::Scope*, clang::ObjCCategoryDecl*, clang::SourceLocation, clang::FieldDeclarator&, clang::Selector, clang::Selector, bool, bool, unsigned int, bool*, clang::TypeSourceInfo*, clang::tok::ObjCKeywordKind)"},
    {"_ZN5clang4Sema27CheckObjCPropertyAttributesEPNS_4DeclENS_14SourceLocationERj", "clang::Sema::CheckObjCPropertyAttributes(clang::Decl*, clang::SourceLocation, unsigned int&)"},
    {"_ZN5clang4Sema18CreatePropertyDeclEPNS_5ScopeEPNS_17ObjCContainerDeclENS_14SourceLocationERNS_15FieldDeclaratorENS_8SelectorES8_bbjPNS_14TypeSourceInfoENS_3tok15ObjCKeywordKindEPNS_11DeclContextE", "clang::Sema::CreatePropertyDecl(clang::Scope*, clang::ObjCContainerDecl*, clang::SourceLocation, clang::FieldDeclarator&, clang::Selector, clang::Selector, bool, bool, unsigned int, clang::TypeSourceInfo*, clang::tok::ObjCKeywordKind, clang::DeclContext*)"},
    {"_ZN5clang4Sema19ProcessPropertyDeclEPNS_16ObjCPropertyDeclEPNS_17ObjCContainerDeclES2_S4_", "clang::Sema::ProcessPropertyDecl(clang::ObjCPropertyDecl*, clang::ObjCContainerDecl*, clang::ObjCPropertyDecl*, clang::ObjCContainerDecl*)"},
    {"_ZN5clang4Sema21ActOnPropertyImplDeclEPNS_5ScopeENS_14SourceLocationES3_bPNS_4DeclEPNS_14IdentifierInfoES7_S3_", "clang::Sema::ActOnPropertyImplDecl(clang::Scope*, clang::SourceLocation, clang::SourceLocation, bool, clang::Decl*, clang::IdentifierInfo*, clang::IdentifierInfo*, clang::SourceLocation)"},
    {"_ZN5clang4Sema24DiagnosePropertyMismatchEPNS_16ObjCPropertyDeclES2_PKNS_14IdentifierInfoE", "clang::Sema::DiagnosePropertyMismatch(clang::ObjCPropertyDecl*, clang::ObjCPropertyDecl*, clang::IdentifierInfo const*)"},
    {"_ZN5clang4Sema32DiagnosePropertyAccessorMismatchEPNS_16ObjCPropertyDeclEPNS_14ObjCMethodDeclENS_14SourceLocationE", "clang::Sema::DiagnosePropertyAccessorMismatch(clang::ObjCPropertyDecl*, clang::ObjCMethodDecl*, clang::SourceLocation)"},
    {"_ZN5clang4Sema31ComparePropertiesInBaseAndSuperEPNS_17ObjCInterfaceDeclE", "clang::Sema::ComparePropertiesInBaseAndSuper(clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang4Sema33MatchOneProtocolPropertiesInClassEPNS_4DeclEPNS_16ObjCProtocolDeclE", "clang::Sema::MatchOneProtocolPropertiesInClass(clang::Decl*, clang::ObjCProtocolDecl*)"},
    {"_ZN5clang4Sema17ComparePropertiesEPNS_4DeclES2_", "clang::Sema::CompareProperties(clang::Decl*, clang::Decl*)"},
    {"_ZN5clang4Sema18isPropertyReadonlyEPNS_16ObjCPropertyDeclEPNS_17ObjCInterfaceDeclE", "clang::Sema::isPropertyReadonly(clang::ObjCPropertyDecl*, clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang4Sema26CollectImmediatePropertiesEPNS_17ObjCContainerDeclERN4llvm8DenseMapIPNS_14IdentifierInfoEPNS_16ObjCPropertyDeclENS3_12DenseMapInfoIS6_EENS9_IS8_EEEESD_", "clang::Sema::CollectImmediateProperties(clang::ObjCContainerDecl*, llvm::DenseMap<clang::IdentifierInfo*, clang::ObjCPropertyDecl*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::ObjCPropertyDecl*>>&, llvm::DenseMap<clang::IdentifierInfo*, clang::ObjCPropertyDecl*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::ObjCPropertyDecl*>>&)"},
    {"_ZN5clang4Sema18LookupPropertyDeclEPKNS_17ObjCContainerDeclEPNS_14IdentifierInfoE", "clang::Sema::LookupPropertyDecl(clang::ObjCContainerDecl const*, clang::IdentifierInfo*)"},
    {"_ZN5clang4Sema27DefaultSynthesizePropertiesEPNS_5ScopeEPNS_12ObjCImplDeclEPNS_17ObjCInterfaceDeclE", "clang::Sema::DefaultSynthesizeProperties(clang::Scope*, clang::ObjCImplDecl*, clang::ObjCInterfaceDecl*)"},
    {"_Z35CollectClassPropertyImplementationsPN5clang17ObjCContainerDeclERN4llvm8DenseMapIPNS_14IdentifierInfoEPNS_16ObjCPropertyDeclENS2_12DenseMapInfoIS5_EENS8_IS7_EEEE", "CollectClassPropertyImplementations(clang::ObjCContainerDecl*, llvm::DenseMap<clang::IdentifierInfo*, clang::ObjCPropertyDecl*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::ObjCPropertyDecl*>>&)"},
    {"_ZN5clang4Sema31DiagnoseUnimplementedPropertiesEPNS_5ScopeEPNS_12ObjCImplDeclEPNS_17ObjCContainerDeclERKN4llvm8DenseSetINS_8SelectorENS7_12DenseMapInfoIS9_EEEE", "clang::Sema::DiagnoseUnimplementedProperties(clang::Scope*, clang::ObjCImplDecl*, clang::ObjCContainerDecl*, llvm::DenseSet<clang::Selector, llvm::DenseMapInfo<clang::Selector>> const&)"},
    {"_ZN5clang4Sema31AtomicPropertySetterGetterRulesEPNS_12ObjCImplDeclEPNS_17ObjCContainerDeclE", "clang::Sema::AtomicPropertySetterGetterRules(clang::ObjCImplDecl*, clang::ObjCContainerDecl*)"},
    {"_Z16AddPropertyAttrsRN5clang4SemaEPNS_14ObjCMethodDeclEPNS_16ObjCPropertyDeclE", "AddPropertyAttrs(clang::Sema&, clang::ObjCMethodDecl*, clang::ObjCPropertyDecl*)"},
    {"_ZN4llvm8DenseMapIPN5clang16ObjCPropertyDeclEcNS_12DenseMapInfoIS3_EENS4_IcEEE6insertERKSt4pairIS3_cE", "llvm::DenseMap<clang::ObjCPropertyDecl*, char, llvm::DenseMapInfo<clang::ObjCPropertyDecl*>, llvm::DenseMapInfo<char>>::insert(std::pair<clang::ObjCPropertyDecl*, char> const&)"},
    {"_ZN4llvm8DenseMapIPN5clang16ObjCPropertyDeclEcNS_12DenseMapInfoIS3_EENS4_IcEEE16InsertIntoBucketERKS3_RKcPSt4pairIS3_cE", "llvm::DenseMap<clang::ObjCPropertyDecl*, char, llvm::DenseMapInfo<clang::ObjCPropertyDecl*>, llvm::DenseMapInfo<char>>::InsertIntoBucket(clang::ObjCPropertyDecl* const&, char const&, std::pair<clang::ObjCPropertyDecl*, char>*)"},
    {"_ZN4llvm8DenseMapIPN5clang16ObjCPropertyDeclEcNS_12DenseMapInfoIS3_EENS4_IcEEE4growEj", "llvm::DenseMap<clang::ObjCPropertyDecl*, char, llvm::DenseMapInfo<clang::ObjCPropertyDecl*>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEPNS1_16ObjCPropertyDeclENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::IdentifierInfo*, clang::ObjCPropertyDecl*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::ObjCPropertyDecl*>>::InsertIntoBucket(clang::IdentifierInfo* const&, clang::ObjCPropertyDecl* const&, std::pair<clang::IdentifierInfo*, clang::ObjCPropertyDecl*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEPNS1_16ObjCPropertyDeclENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::IdentifierInfo*, clang::ObjCPropertyDecl*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::ObjCPropertyDecl*>>::grow(unsigned int)"},
    {"_ZN5clang21GetConversionCategoryENS_22ImplicitConversionKindE", "clang::GetConversionCategory(clang::ImplicitConversionKind)"},
    {"_ZN5clang17GetConversionRankENS_22ImplicitConversionKindE", "clang::GetConversionRank(clang::ImplicitConversionKind)"},
    {"_ZN5clang25GetImplicitConversionNameENS_22ImplicitConversionKindE", "clang::GetImplicitConversionName(clang::ImplicitConversionKind)"},
    {"_ZN5clang26StandardConversionSequence23setAsIdentityConversionEv", "clang::StandardConversionSequence::setAsIdentityConversion()"},
    {"_ZNK5clang26StandardConversionSequence7getRankEv", "clang::StandardConversionSequence::getRank() const"},
    {"_ZNK5clang26StandardConversionSequence25isPointerConversionToBoolEv", "clang::StandardConversionSequence::isPointerConversionToBool() const"},
    {"_ZNK5clang26StandardConversionSequence32isPointerConversionToVoidPointerERNS_10ASTContextE", "clang::StandardConversionSequence::isPointerConversionToVoidPointer(clang::ASTContext&) const"},
    {"_ZNK5clang26StandardConversionSequence10DebugPrintEv", "clang::StandardConversionSequence::DebugPrint() const"},
    {"_ZNK5clang29UserDefinedConversionSequence10DebugPrintEv", "clang::UserDefinedConversionSequence::DebugPrint() const"},
    {"_ZNK5clang26ImplicitConversionSequence10DebugPrintEv", "clang::ImplicitConversionSequence::DebugPrint() const"},
    {"_ZN5clang27AmbiguousConversionSequence9constructEv", "clang::AmbiguousConversionSequence::construct()"},
    {"_ZN5clang27AmbiguousConversionSequence8destructEv", "clang::AmbiguousConversionSequence::destruct()"},
    {"_ZN5clang27AmbiguousConversionSequence8copyFromERKS0_", "clang::AmbiguousConversionSequence::copyFrom(clang::AmbiguousConversionSequence const&)"},
    {"_ZN5clang17OverloadCandidate20DeductionFailureInfo7DestroyEv", "clang::OverloadCandidate::DeductionFailureInfo::Destroy()"},
    {"_ZN5clang17OverloadCandidate20DeductionFailureInfo20getTemplateParameterEv", "clang::OverloadCandidate::DeductionFailureInfo::getTemplateParameter()"},
    {"_ZN5clang17OverloadCandidate20DeductionFailureInfo23getTemplateArgumentListEv", "clang::OverloadCandidate::DeductionFailureInfo::getTemplateArgumentList()"},
    {"_ZN5clang17OverloadCandidate20DeductionFailureInfo11getFirstArgEv", "clang::OverloadCandidate::DeductionFailureInfo::getFirstArg()"},
    {"_ZN5clang17OverloadCandidate20DeductionFailureInfo12getSecondArgEv", "clang::OverloadCandidate::DeductionFailureInfo::getSecondArg()"},
    {"_ZN5clang20OverloadCandidateSet5clearEv", "clang::OverloadCandidateSet::clear()"},
    {"_ZN5clang4Sema13CheckOverloadEPNS_5ScopeEPNS_12FunctionDeclERKNS_12LookupResultERPNS_9NamedDeclEb", "clang::Sema::CheckOverload(clang::Scope*, clang::FunctionDecl*, clang::LookupResult const&, clang::NamedDecl*&, bool)"},
    {"_ZN5clang4Sema10IsOverloadEPNS_12FunctionDeclES2_b", "clang::Sema::IsOverload(clang::FunctionDecl*, clang::FunctionDecl*, bool)"},
    {"_ZN5clang4Sema24FunctionArgTypesAreEqualEPKNS_17FunctionProtoTypeES3_", "clang::Sema::FunctionArgTypesAreEqual(clang::FunctionProtoType const*, clang::FunctionProtoType const*)"},
    {"_ZN5clang4Sema21TryImplicitConversionERNS_22InitializationSequenceERKNS_17InitializedEntityEPNS_4ExprEbbbb", "clang::Sema::TryImplicitConversion(clang::InitializationSequence&, clang::InitializedEntity const&, clang::Expr*, bool, bool, bool, bool)"},
    {"_ZN5clang21TryImplicitConversionERNS_4SemaEPNS_4ExprENS_8QualTypeEbbbb", "clang::TryImplicitConversion(clang::Sema&, clang::Expr*, clang::QualType, bool, bool, bool, bool)"},
    {"_ZN5clang4Sema25PerformImplicitConversionERPNS_4ExprENS_8QualTypeENS0_16AssignmentActionEb", "clang::Sema::PerformImplicitConversion(clang::Expr*&, clang::QualType, clang::Sema::AssignmentAction, bool)"},
    {"_ZN5clang4Sema25PerformImplicitConversionERPNS_4ExprENS_8QualTypeENS0_16AssignmentActionEbRNS_26ImplicitConversionSequenceE", "clang::Sema::PerformImplicitConversion(clang::Expr*&, clang::QualType, clang::Sema::AssignmentAction, bool, clang::ImplicitConversionSequence&)"},
    {"_ZN5clang4Sema19IsIntegralPromotionEPNS_4ExprENS_8QualTypeES3_", "clang::Sema::IsIntegralPromotion(clang::Expr*, clang::QualType, clang::QualType)"},
    {"_ZN5clang4Sema24IsFloatingPointPromotionENS_8QualTypeES1_", "clang::Sema::IsFloatingPointPromotion(clang::QualType, clang::QualType)"},
    {"_ZN5clang4Sema18IsComplexPromotionENS_8QualTypeES1_", "clang::Sema::IsComplexPromotion(clang::QualType, clang::QualType)"},
    {"_ZN5clang4Sema19IsPointerConversionEPNS_4ExprENS_8QualTypeES3_bRS3_Rb", "clang::Sema::IsPointerConversion(clang::Expr*, clang::QualType, clang::QualType, bool, clang::QualType&, bool&)"},
    {"_ZN5clang4Sema23isObjCPointerConversionENS_8QualTypeES1_RS1_Rb", "clang::Sema::isObjCPointerConversion(clang::QualType, clang::QualType, clang::QualType&, bool&)"},
    {"_ZN5clang34BuildSimilarlyQualifiedPointerTypeEPKNS_4TypeENS_8QualTypeES3_RNS_10ASTContextE", "clang::BuildSimilarlyQualifiedPointerType(clang::Type const*, clang::QualType, clang::QualType, clang::ASTContext&)"},
    {"_ZN5clang4Sema22CheckPointerConversionEPNS_4ExprENS_8QualTypeERNS_8CastKindERN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEEb", "clang::Sema::CheckPointerConversion(clang::Expr*, clang::QualType, clang::CastKind&, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u>&, bool)"},
    {"_ZN5clang4Sema25IsMemberPointerConversionEPNS_4ExprENS_8QualTypeES3_bRS3_", "clang::Sema::IsMemberPointerConversion(clang::Expr*, clang::QualType, clang::QualType, bool, clang::QualType&)"},
    {"_ZN5clang4Sema28CheckMemberPointerConversionEPNS_4ExprENS_8QualTypeERNS_8CastKindERN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEEb", "clang::Sema::CheckMemberPointerConversion(clang::Expr*, clang::QualType, clang::CastKind&, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u>&, bool)"},
    {"_ZN5clang4Sema25IsQualificationConversionENS_8QualTypeES1_b", "clang::Sema::IsQualificationConversion(clang::QualType, clang::QualType, bool)"},
    {"_ZN5clang4Sema37DiagnoseMultipleUserDefinedConversionEPNS_4ExprENS_8QualTypeE", "clang::Sema::DiagnoseMultipleUserDefinedConversion(clang::Expr*, clang::QualType)"},
    {"_ZN5clang23IsUserDefinedConversionERNS_4SemaEPNS_4ExprENS_8QualTypeERNS_29UserDefinedConversionSequenceERNS_20OverloadCandidateSetEb", "clang::IsUserDefinedConversion(clang::Sema&, clang::Expr*, clang::QualType, clang::UserDefinedConversionSequence&, clang::OverloadCandidateSet&, bool)"},
    {"_ZN5clang20OverloadCandidateSet14NoteCandidatesERNS_4SemaENS_28OverloadCandidateDisplayKindEPPNS_4ExprEjPKcNS_14SourceLocationE", "clang::OverloadCandidateSet::NoteCandidates(clang::Sema&, clang::OverloadCandidateDisplayKind, clang::Expr**, unsigned int, char const*, clang::SourceLocation)"},
    {"_ZN5clang4Sema28CompareReferenceRelationshipENS_14SourceLocationENS_8QualTypeES2_RbS3_", "clang::Sema::CompareReferenceRelationship(clang::SourceLocation, clang::QualType, clang::QualType, bool&, bool&)"},
    {"_ZN5clang4Sema35PerformObjectArgumentInitializationERPNS_4ExprEPNS_19NestedNameSpecifierEPNS_9NamedDeclEPNS_13CXXMethodDeclE", "clang::Sema::PerformObjectArgumentInitialization(clang::Expr*&, clang::NestedNameSpecifier*, clang::NamedDecl*, clang::CXXMethodDecl*)"},
    {"_ZN5clang31TryObjectArgumentInitializationERNS_4SemaENS_8QualTypeENS_4Expr14ClassificationEPNS_13CXXMethodDeclEPNS_13CXXRecordDeclE", "clang::TryObjectArgumentInitialization(clang::Sema&, clang::QualType, clang::Expr::Classification, clang::CXXMethodDecl*, clang::CXXRecordDecl*)"},
    {"_ZN5clang4Sema32PerformContextuallyConvertToBoolERPNS_4ExprE", "clang::Sema::PerformContextuallyConvertToBool(clang::Expr*&)"},
    {"_ZN5clang4Sema34PerformContextuallyConvertToObjCIdERPNS_4ExprE", "clang::Sema::PerformContextuallyConvertToObjCId(clang::Expr*&)"},
    {"_ZN5clang4Sema34ConvertToIntegralOrEnumerationTypeENS_14SourceLocationEPNS_4ExprERKNS_17PartialDiagnosticES6_S6_S6_S6_S6_S6_", "clang::Sema::ConvertToIntegralOrEnumerationType(clang::SourceLocation, clang::Expr*, clang::PartialDiagnostic const&, clang::PartialDiagnostic const&, clang::PartialDiagnostic const&, clang::PartialDiagnostic const&, clang::PartialDiagnostic const&, clang::PartialDiagnostic const&, clang::PartialDiagnostic const&)"},
    {"_ZN5clang4Sema20AddOverloadCandidateEPNS_12FunctionDeclENS_14DeclAccessPairEPPNS_4ExprEjRNS_20OverloadCandidateSetEbb", "clang::Sema::AddOverloadCandidate(clang::FunctionDecl*, clang::DeclAccessPair, clang::Expr**, unsigned int, clang::OverloadCandidateSet&, bool, bool)"},
    {"_ZN5clang4Sema18AddMethodCandidateEPNS_13CXXMethodDeclENS_14DeclAccessPairEPNS_13CXXRecordDeclENS_8QualTypeENS_4Expr14ClassificationEPPS7_jRNS_20OverloadCandidateSetEb", "clang::Sema::AddMethodCandidate(clang::CXXMethodDecl*, clang::DeclAccessPair, clang::CXXRecordDecl*, clang::QualType, clang::Expr::Classification, clang::Expr**, unsigned int, clang::OverloadCandidateSet&, bool)"},
    {"_ZN5clang21TryCopyInitializationERNS_4SemaEPNS_4ExprENS_8QualTypeEbb", "clang::TryCopyInitialization(clang::Sema&, clang::Expr*, clang::QualType, bool, bool)"},
    {"_ZN5clang4Sema21AddFunctionCandidatesERKNS_17UnresolvedSetImplEPPNS_4ExprEjRNS_20OverloadCandidateSetEb", "clang::Sema::AddFunctionCandidates(clang::UnresolvedSetImpl const&, clang::Expr**, unsigned int, clang::OverloadCandidateSet&, bool)"},
    {"_ZN5clang4Sema26AddMethodTemplateCandidateEPNS_20FunctionTemplateDeclENS_14DeclAccessPairEPNS_13CXXRecordDeclEPKNS_24TemplateArgumentListInfoENS_8QualTypeENS_4Expr14ClassificationEPPSA_jRNS_20OverloadCandidateSetEb", "clang::Sema::AddMethodTemplateCandidate(clang::FunctionTemplateDecl*, clang::DeclAccessPair, clang::CXXRecordDecl*, clang::TemplateArgumentListInfo const*, clang::QualType, clang::Expr::Classification, clang::Expr**, unsigned int, clang::OverloadCandidateSet&, bool)"},
    {"_ZN5clang4Sema28AddTemplateOverloadCandidateEPNS_20FunctionTemplateDeclENS_14DeclAccessPairEPKNS_24TemplateArgumentListInfoEPPNS_4ExprEjRNS_20OverloadCandidateSetEb", "clang::Sema::AddTemplateOverloadCandidate(clang::FunctionTemplateDecl*, clang::DeclAccessPair, clang::TemplateArgumentListInfo const*, clang::Expr**, unsigned int, clang::OverloadCandidateSet&, bool)"},
    {"_ZN5clang4Sema18AddMethodCandidateENS_14DeclAccessPairENS_8QualTypeENS_4Expr14ClassificationEPPS3_jRNS_20OverloadCandidateSetEb", "clang::Sema::AddMethodCandidate(clang::DeclAccessPair, clang::QualType, clang::Expr::Classification, clang::Expr**, unsigned int, clang::OverloadCandidateSet&, bool)"},
    {"_ZN5clang4Sema22AddConversionCandidateEPNS_17CXXConversionDeclENS_14DeclAccessPairEPNS_13CXXRecordDeclEPNS_4ExprENS_8QualTypeERNS_20OverloadCandidateSetE", "clang::Sema::AddConversionCandidate(clang::CXXConversionDecl*, clang::DeclAccessPair, clang::CXXRecordDecl*, clang::Expr*, clang::QualType, clang::OverloadCandidateSet&)"},
    {"_ZN5clang4Sema30AddTemplateConversionCandidateEPNS_20FunctionTemplateDeclENS_14DeclAccessPairEPNS_13CXXRecordDeclEPNS_4ExprENS_8QualTypeERNS_20OverloadCandidateSetE", "clang::Sema::AddTemplateConversionCandidate(clang::FunctionTemplateDecl*, clang::DeclAccessPair, clang::CXXRecordDecl*, clang::Expr*, clang::QualType, clang::OverloadCandidateSet&)"},
    {"_ZN5clang4Sema21AddSurrogateCandidateEPNS_17CXXConversionDeclENS_14DeclAccessPairEPNS_13CXXRecordDeclEPKNS_17FunctionProtoTypeEPNS_4ExprEPSA_jRNS_20OverloadCandidateSetE", "clang::Sema::AddSurrogateCandidate(clang::CXXConversionDecl*, clang::DeclAccessPair, clang::CXXRecordDecl*, clang::FunctionProtoType const*, clang::Expr*, clang::Expr**, unsigned int, clang::OverloadCandidateSet&)"},
    {"_ZN5clang4Sema27AddMemberOperatorCandidatesENS_22OverloadedOperatorKindENS_14SourceLocationEPPNS_4ExprEjRNS_20OverloadCandidateSetENS_11SourceRangeE", "clang::Sema::AddMemberOperatorCandidates(clang::OverloadedOperatorKind, clang::SourceLocation, clang::Expr**, unsigned int, clang::OverloadCandidateSet&, clang::SourceRange)"},
    {"_ZN5clang4Sema19AddBuiltinCandidateENS_8QualTypeEPS1_PPNS_4ExprEjRNS_20OverloadCandidateSetEbj", "clang::Sema::AddBuiltinCandidate(clang::QualType, clang::QualType*, clang::Expr**, unsigned int, clang::OverloadCandidateSet&, bool, unsigned int)"},
    {"_ZN5clang23BuiltinCandidateTypeSet39AddPointerWithMoreQualifiedTypeVariantsENS_8QualTypeERKNS_10QualifiersE", "clang::BuiltinCandidateTypeSet::AddPointerWithMoreQualifiedTypeVariants(clang::QualType, clang::Qualifiers const&)"},
    {"_ZN5clang23BuiltinCandidateTypeSet45AddMemberPointerWithMoreQualifiedTypeVariantsENS_8QualTypeE", "clang::BuiltinCandidateTypeSet::AddMemberPointerWithMoreQualifiedTypeVariants(clang::QualType)"},
    {"_ZN5clang23BuiltinCandidateTypeSet21AddTypesConvertedFromENS_8QualTypeENS_14SourceLocationEbbRKNS_10QualifiersE", "clang::BuiltinCandidateTypeSet::AddTypesConvertedFrom(clang::QualType, clang::SourceLocation, bool, bool, clang::Qualifiers const&)"},
    {"_ZN5clang4Sema28AddBuiltinOperatorCandidatesENS_22OverloadedOperatorKindENS_14SourceLocationEPPNS_4ExprEjRNS_20OverloadCandidateSetE", "clang::Sema::AddBuiltinOperatorCandidates(clang::OverloadedOperatorKind, clang::SourceLocation, clang::Expr**, unsigned int, clang::OverloadCandidateSet&)"},
    {"_ZN5clang12_GLOBAL__N_130BuiltinOperatorOverloadBuilder35addGenericBinaryArithmeticOverloadsEb", "clang::(anonymous namespace)::BuiltinOperatorOverloadBuilder::addGenericBinaryArithmeticOverloads(bool)"},
    {"_ZN5clang12_GLOBAL__N_130BuiltinOperatorOverloadBuilder35addBinaryBitwiseArithmeticOverloadsENS_22OverloadedOperatorKindE", "clang::(anonymous namespace)::BuiltinOperatorOverloadBuilder::addBinaryBitwiseArithmeticOverloads(clang::OverloadedOperatorKind)"},
    {"_ZN5clang4Sema36AddArgumentDependentLookupCandidatesENS_15DeclarationNameEbPPNS_4ExprEjPKNS_24TemplateArgumentListInfoERNS_20OverloadCandidateSetEb", "clang::Sema::AddArgumentDependentLookupCandidates(clang::DeclarationName, bool, clang::Expr**, unsigned int, clang::TemplateArgumentListInfo const*, clang::OverloadCandidateSet&, bool)"},
    {"_ZN5clang25isBetterOverloadCandidateERNS_4SemaERKNS_17OverloadCandidateES4_NS_14SourceLocationEb", "clang::isBetterOverloadCandidate(clang::Sema&, clang::OverloadCandidate const&, clang::OverloadCandidate const&, clang::SourceLocation, bool)"},
    {"_ZN5clang34CompareImplicitConversionSequencesERNS_4SemaERKNS_26ImplicitConversionSequenceES4_", "clang::CompareImplicitConversionSequences(clang::Sema&, clang::ImplicitConversionSequence const&, clang::ImplicitConversionSequence const&)"},
    {"_ZN5clang34CompareStandardConversionSequencesERNS_4SemaERKNS_26StandardConversionSequenceES4_", "clang::CompareStandardConversionSequences(clang::Sema&, clang::StandardConversionSequence const&, clang::StandardConversionSequence const&)"},
    {"_ZN5clang20OverloadCandidateSet18BestViableFunctionERNS_4SemaENS_14SourceLocationERPNS_17OverloadCandidateEb", "clang::OverloadCandidateSet::BestViableFunction(clang::Sema&, clang::SourceLocation, clang::OverloadCandidate*&, bool)"},
    {"_ZN5clang4Sema21NoteOverloadCandidateEPNS_12FunctionDeclE", "clang::Sema::NoteOverloadCandidate(clang::FunctionDecl*)"},
    {"_ZN5clang12_GLOBAL__N_125ClassifyOverloadCandidateERNS_4SemaEPNS_12FunctionDeclERSs", "clang::(anonymous namespace)::ClassifyOverloadCandidate(clang::Sema&, clang::FunctionDecl*, std::string&)"},
    {"_ZNK5clang26ImplicitConversionSequence27DiagnoseAmbiguousConversionERNS_4SemaENS_14SourceLocationERKNS_17PartialDiagnosticE", "clang::ImplicitConversionSequence::DiagnoseAmbiguousConversion(clang::Sema&, clang::SourceLocation, clang::PartialDiagnostic const&) const"},
    {"_ZN5clang4Sema34ResolveAddressOfOverloadedFunctionEPNS_4ExprENS_8QualTypeEbRNS_14DeclAccessPairE", "clang::Sema::ResolveAddressOfOverloadedFunction(clang::Expr*, clang::QualType, bool, clang::DeclAccessPair&)"},
    {"_ZN5clang20IsNoReturnConversionERNS_10ASTContextENS_8QualTypeES2_RS2_", "clang::IsNoReturnConversion(clang::ASTContext&, clang::QualType, clang::QualType, clang::QualType&)"},
    {"_ZN5clang4Sema43ResolveSingleFunctionTemplateSpecializationEPNS_4ExprE", "clang::Sema::ResolveSingleFunctionTemplateSpecialization(clang::Expr*)"},
    {"_ZN5clang4Sema27AddOverloadedCallCandidatesEPNS_20UnresolvedLookupExprEPPNS_4ExprEjRNS_20OverloadCandidateSetEb", "clang::Sema::AddOverloadedCallCandidates(clang::UnresolvedLookupExpr*, clang::Expr**, unsigned int, clang::OverloadCandidateSet&, bool)"},
    {"_ZN5clang4Sema23BuildOverloadedCallExprEPNS_5ScopeEPNS_4ExprEPNS_20UnresolvedLookupExprENS_14SourceLocationEPS4_jS7_S4_", "clang::Sema::BuildOverloadedCallExpr(clang::Scope*, clang::Expr*, clang::UnresolvedLookupExpr*, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema30FixOverloadedFunctionReferenceEPNS_4ExprENS_14DeclAccessPairEPNS_12FunctionDeclE", "clang::Sema::FixOverloadedFunctionReference(clang::Expr*, clang::DeclAccessPair, clang::FunctionDecl*)"},
    {"_ZN5clang4Sema23CreateOverloadedUnaryOpENS_14SourceLocationEjRKNS_17UnresolvedSetImplEPNS_4ExprE", "clang::Sema::CreateOverloadedUnaryOp(clang::SourceLocation, unsigned int, clang::UnresolvedSetImpl const&, clang::Expr*)"},
    {"_ZN5clang4Sema21CreateOverloadedBinOpENS_14SourceLocationEjRKNS_17UnresolvedSetImplEPNS_4ExprES6_", "clang::Sema::CreateOverloadedBinOp(clang::SourceLocation, unsigned int, clang::UnresolvedSetImpl const&, clang::Expr*, clang::Expr*)"},
    {"_ZN5clang4Sema34CreateOverloadedArraySubscriptExprENS_14SourceLocationES1_PNS_4ExprES3_", "clang::Sema::CreateOverloadedArraySubscriptExpr(clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::Expr*)"},
    {"_ZN5clang4Sema25BuildCallToMemberFunctionEPNS_5ScopeEPNS_4ExprENS_14SourceLocationEPS4_jS5_", "clang::Sema::BuildCallToMemberFunction(clang::Scope*, clang::Expr*, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang4Sema28BuildCallToObjectOfClassTypeEPNS_5ScopeEPNS_4ExprENS_14SourceLocationEPS4_jS5_", "clang::Sema::BuildCallToObjectOfClassType(clang::Scope*, clang::Expr*, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang4Sema24BuildOverloadedArrowExprEPNS_5ScopeEPNS_4ExprENS_14SourceLocationE", "clang::Sema::BuildOverloadedArrowExpr(clang::Scope*, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema30FixOverloadedFunctionReferenceENS_12ActionResultIPNS_4ExprELb1EEENS_14DeclAccessPairEPNS_12FunctionDeclE", "clang::Sema::FixOverloadedFunctionReference(clang::ActionResult<clang::Expr*, true>, clang::DeclAccessPair, clang::FunctionDecl*)"},
    {"_ZSt16__introsort_loopIPPN5clang17OverloadCandidateElNS0_12_GLOBAL__N_135CompareOverloadCandidatesForDisplayEEvT_S6_T0_T1_", "void std::__introsort_loop<clang::OverloadCandidate**, long, clang::(anonymous namespace)::CompareOverloadCandidatesForDisplay>(clang::OverloadCandidate**, clang::OverloadCandidate**, long, clang::(anonymous namespace)::CompareOverloadCandidatesForDisplay)"},
    {"_ZN5clang12_GLOBAL__N_135CompareOverloadCandidatesForDisplayclEPKNS_17OverloadCandidateES4_", "clang::(anonymous namespace)::CompareOverloadCandidatesForDisplay::operator()(clang::OverloadCandidate const*, clang::OverloadCandidate const*)"},
    {"_ZSt13__adjust_heapIPPN5clang17OverloadCandidateElS2_NS0_12_GLOBAL__N_135CompareOverloadCandidatesForDisplayEEvT_T0_S7_T1_T2_", "void std::__adjust_heap<clang::OverloadCandidate**, long, clang::OverloadCandidate*, clang::(anonymous namespace)::CompareOverloadCandidatesForDisplay>(clang::OverloadCandidate**, long, long, clang::OverloadCandidate*, clang::(anonymous namespace)::CompareOverloadCandidatesForDisplay)"},
    {"_ZN5clang12_GLOBAL__N_121DiagnoseArityMismatchERNS_4SemaEPNS_17OverloadCandidateEj", "clang::(anonymous namespace)::DiagnoseArityMismatch(clang::Sema&, clang::OverloadCandidate*, unsigned int)"},
    {"_ZN5clang38AddBuiltinAssignmentOperatorCandidatesERNS_4SemaENS_8QualTypeEPPNS_4ExprEjRNS_20OverloadCandidateSetE", "clang::AddBuiltinAssignmentOperatorCandidates(clang::Sema&, clang::QualType, clang::Expr**, unsigned int, clang::OverloadCandidateSet&)"},
    {"_ZN5clang12_GLOBAL__N_130BuiltinOperatorOverloadBuilder29getUsualArithmeticConversionsEjj", "clang::(anonymous namespace)::BuiltinOperatorOverloadBuilder::getUsualArithmeticConversions(unsigned int, unsigned int)"},
    {"_ZN5clang12_GLOBAL__N_130BuiltinOperatorOverloadBuilder35addPlusPlusMinusMinusStyleOverloadsENS_8QualTypeEb", "clang::(anonymous namespace)::BuiltinOperatorOverloadBuilder::addPlusPlusMinusMinusStyleOverloads(clang::QualType, bool)"},
    {"_ZN5clang24FindConversionForRefInitERNS_4SemaERNS_26ImplicitConversionSequenceENS_8QualTypeENS_14SourceLocationEPNS_4ExprES4_bb", "clang::FindConversionForRefInit(clang::Sema&, clang::ImplicitConversionSequence&, clang::QualType, clang::SourceLocation, clang::Expr*, clang::QualType, bool, bool)"},
    {"_ZN4llvm15SmallVectorImplIN5clang17OverloadCandidateEE9push_backERKS2_", "llvm::SmallVectorImpl<clang::OverloadCandidate>::push_back(clang::OverloadCandidate const&)"},
    {"_ZN4llvm15SmallVectorImplIN5clang26ImplicitConversionSequenceEE6resizeEj", "llvm::SmallVectorImpl<clang::ImplicitConversionSequence>::resize(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIN5clang23BuiltinCandidateTypeSetEE9push_backERKS2_", "llvm::SmallVectorImpl<clang::BuiltinCandidateTypeSet>::push_back(clang::BuiltinCandidateTypeSet const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang23BuiltinCandidateTypeSetELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::BuiltinCandidateTypeSet, false>::grow(unsigned long)"},
    {"_ZSt24__uninitialized_copy_auxIPN5clang23BuiltinCandidateTypeSetES2_ET0_T_S4_S3_St12__false_type", "clang::BuiltinCandidateTypeSet* std::__uninitialized_copy_aux<clang::BuiltinCandidateTypeSet*, clang::BuiltinCandidateTypeSet*>(clang::BuiltinCandidateTypeSet*, clang::BuiltinCandidateTypeSet*, clang::BuiltinCandidateTypeSet*, std::__false_type)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang26ImplicitConversionSequenceELb0EE18uninitialized_copyIPS2_S5_EEvT_S6_T0_", "void llvm::SmallVectorTemplateBase<clang::ImplicitConversionSequence, false>::uninitialized_copy<clang::ImplicitConversionSequence*, clang::ImplicitConversionSequence*>(clang::ImplicitConversionSequence*, clang::ImplicitConversionSequence*, clang::ImplicitConversionSequence*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang17OverloadCandidateELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::OverloadCandidate, false>::grow(unsigned long)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang17OverloadCandidateELb0EE13destroy_rangeEPS2_S4_", "llvm::SmallVectorTemplateBase<clang::OverloadCandidate, false>::destroy_range(clang::OverloadCandidate*, clang::OverloadCandidate*)"},
    {"_ZSt24__uninitialized_copy_auxIPN5clang17OverloadCandidateES2_ET0_T_S4_S3_St12__false_type", "clang::OverloadCandidate* std::__uninitialized_copy_aux<clang::OverloadCandidate*, clang::OverloadCandidate*>(clang::OverloadCandidate*, clang::OverloadCandidate*, clang::OverloadCandidate*, std::__false_type)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang26ImplicitConversionSequenceELb0EE18uninitialized_copyIPKS2_PS2_EEvT_S8_T0_", "void llvm::SmallVectorTemplateBase<clang::ImplicitConversionSequence, false>::uninitialized_copy<clang::ImplicitConversionSequence const*, clang::ImplicitConversionSequence*>(clang::ImplicitConversionSequence const*, clang::ImplicitConversionSequence const*, clang::ImplicitConversionSequence*)"},
    {"_ZNSt6__copyILb0ESt26random_access_iterator_tagE4copyIPKN5clang26ImplicitConversionSequenceEPS4_EET0_T_S9_S8_", "clang::ImplicitConversionSequence* std::__copy<false, std::random_access_iterator_tag>::copy<clang::ImplicitConversionSequence const*, clang::ImplicitConversionSequence*>(clang::ImplicitConversionSequence const*, clang::ImplicitConversionSequence const*, clang::ImplicitConversionSequence*)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang12FunctionDeclEEaSERKS4_", "llvm::SmallVectorImpl<clang::FunctionDecl*>::operator=(llvm::SmallVectorImpl<clang::FunctionDecl*> const&)"},
    {"_ZN4llvm15SmallVectorImplIN5clang23BuiltinCandidateTypeSetEED2Ev", "llvm::SmallVectorImpl<clang::BuiltinCandidateTypeSet>::~SmallVectorImpl()"},
    {"_ZNK4llvm8DenseMapISt4pairIN5clang7CanQualINS2_4TypeEEES5_EcNS_12DenseMapInfoIS6_EENS7_IcEEE15LookupBucketForERKS6_RPS1_IS6_cE", "llvm::DenseMap<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>, char, llvm::DenseMapInfo<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>>, llvm::DenseMapInfo<char>>::LookupBucketFor(std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>> const&, std::pair<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>, char>*&) const"},
    {"_ZN4llvm8DenseMapISt4pairIN5clang7CanQualINS2_4TypeEEES5_EcNS_12DenseMapInfoIS6_EENS7_IcEEE6insertERKS1_IS6_cE", "llvm::DenseMap<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>, char, llvm::DenseMapInfo<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>>, llvm::DenseMapInfo<char>>::insert(std::pair<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>, char> const&)"},
    {"_ZN4llvm8DenseMapISt4pairIN5clang7CanQualINS2_4TypeEEES5_EcNS_12DenseMapInfoIS6_EENS7_IcEEE16InsertIntoBucketERKS6_RKcPS1_IS6_cE", "llvm::DenseMap<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>, char, llvm::DenseMapInfo<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>>, llvm::DenseMapInfo<char>>::InsertIntoBucket(std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>> const&, char const&, std::pair<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>, char>*)"},
    {"_ZN4llvm8DenseMapISt4pairIN5clang7CanQualINS2_4TypeEEES5_EcNS_12DenseMapInfoIS6_EENS7_IcEEE4growEj", "llvm::DenseMap<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>, char, llvm::DenseMapInfo<std::pair<clang::CanQual<clang::Type>, clang::CanQual<clang::Type>>>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZN5clang20OverloadCandidateSetD2Ev", "clang::OverloadCandidateSet::~OverloadCandidateSet()"},
    {"_ZN5clang4Sema13ActOnExprStmtENS0_11FullExprArgE", "clang::Sema::ActOnExprStmt(clang::Sema::FullExprArg)"},
    {"_ZN5clang4Sema13ActOnNullStmtENS_14SourceLocationEb", "clang::Sema::ActOnNullStmt(clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema13ActOnDeclStmtENS_9OpaquePtrINS_12DeclGroupRefEEENS_14SourceLocationES4_", "clang::Sema::ActOnDeclStmt(clang::OpaquePtr<clang::DeclGroupRef>, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema20ActOnForEachDeclStmtENS_9OpaquePtrINS_12DeclGroupRefEEE", "clang::Sema::ActOnForEachDeclStmt(clang::OpaquePtr<clang::DeclGroupRef>)"},
    {"_ZN5clang4Sema24DiagnoseUnusedExprResultEPKNS_4StmtE", "clang::Sema::DiagnoseUnusedExprResult(clang::Stmt const*)"},
    {"_ZN5clang4Sema17ActOnCompoundStmtENS_14SourceLocationES1_NS_11ASTMultiPtrIPNS_4StmtEEEb", "clang::Sema::ActOnCompoundStmt(clang::SourceLocation, clang::SourceLocation, clang::ASTMultiPtr<clang::Stmt*>, bool)"},
    {"_ZN5clang4Sema13ActOnCaseStmtENS_14SourceLocationEPNS_4ExprES1_S3_S1_", "clang::Sema::ActOnCaseStmt(clang::SourceLocation, clang::Expr*, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema17ActOnCaseStmtBodyEPNS_4StmtES2_", "clang::Sema::ActOnCaseStmtBody(clang::Stmt*, clang::Stmt*)"},
    {"_ZN5clang4Sema16ActOnDefaultStmtENS_14SourceLocationES1_PNS_4StmtEPNS_5ScopeE", "clang::Sema::ActOnDefaultStmt(clang::SourceLocation, clang::SourceLocation, clang::Stmt*, clang::Scope*)"},
    {"_ZN5clang4Sema14ActOnLabelStmtENS_14SourceLocationEPNS_14IdentifierInfoES1_PNS_4StmtEPKNS_13AttributeListE", "clang::Sema::ActOnLabelStmt(clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::Stmt*, clang::AttributeList const*)"},
    {"_ZN5clang4Sema14ActOnLabelStmtENS_14SourceLocationEPNS_14IdentifierInfoES1_PNS_4StmtEb", "clang::Sema::ActOnLabelStmt(clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::Stmt*, bool)"},
    {"_ZN5clang4Sema11ActOnIfStmtENS_14SourceLocationENS0_11FullExprArgEPNS_4DeclEPNS_4StmtES1_S6_", "clang::Sema::ActOnIfStmt(clang::SourceLocation, clang::Sema::FullExprArg, clang::Decl*, clang::Stmt*, clang::SourceLocation, clang::Stmt*)"},
    {"_ZN5clang4Sema34ConvertIntegerToTypeWarnOnOverflowERN4llvm6APSIntEjbNS_14SourceLocationEj", "clang::Sema::ConvertIntegerToTypeWarnOnOverflow(llvm::APSInt&, unsigned int, bool, clang::SourceLocation, unsigned int)"},
    {"_ZN5clang4Sema22ActOnStartOfSwitchStmtENS_14SourceLocationEPNS_4ExprEPNS_4DeclE", "clang::Sema::ActOnStartOfSwitchStmt(clang::SourceLocation, clang::Expr*, clang::Decl*)"},
    {"_ZN5clang4Sema21ActOnFinishSwitchStmtENS_14SourceLocationEPNS_4StmtES3_", "clang::Sema::ActOnFinishSwitchStmt(clang::SourceLocation, clang::Stmt*, clang::Stmt*)"},
    {"_Z11CmpCaseValsRKSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEES7_", "CmpCaseVals(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&)"},
    {"_Z12AdjustAPSIntRN4llvm6APSIntEjb", "AdjustAPSInt(llvm::APSInt&, unsigned int, bool)"},
    {"_Z11CmpEnumValsRKSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEES7_", "CmpEnumVals(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)"},
    {"_Z10EqEnumValsRKSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEES7_", "EqEnumVals(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)"},
    {"_ZN5clang4Sema14ActOnWhileStmtENS_14SourceLocationENS0_11FullExprArgEPNS_4DeclEPNS_4StmtE", "clang::Sema::ActOnWhileStmt(clang::SourceLocation, clang::Sema::FullExprArg, clang::Decl*, clang::Stmt*)"},
    {"_ZN5clang4Sema11ActOnDoStmtENS_14SourceLocationEPNS_4StmtES1_S1_PNS_4ExprES1_", "clang::Sema::ActOnDoStmt(clang::SourceLocation, clang::Stmt*, clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema12ActOnForStmtENS_14SourceLocationES1_PNS_4StmtENS0_11FullExprArgEPNS_4DeclES4_S1_S3_", "clang::Sema::ActOnForStmt(clang::SourceLocation, clang::SourceLocation, clang::Stmt*, clang::Sema::FullExprArg, clang::Decl*, clang::Sema::FullExprArg, clang::SourceLocation, clang::Stmt*)"},
    {"_ZN5clang4Sema22ActOnForEachLValueExprEPNS_4ExprE", "clang::Sema::ActOnForEachLValueExpr(clang::Expr*)"},
    {"_ZN5clang4Sema26ActOnObjCForCollectionStmtENS_14SourceLocationES1_PNS_4StmtEPNS_4ExprES1_S3_", "clang::Sema::ActOnObjCForCollectionStmt(clang::SourceLocation, clang::SourceLocation, clang::Stmt*, clang::Expr*, clang::SourceLocation, clang::Stmt*)"},
    {"_ZN5clang4Sema13ActOnGotoStmtENS_14SourceLocationES1_PNS_14IdentifierInfoE", "clang::Sema::ActOnGotoStmt(clang::SourceLocation, clang::SourceLocation, clang::IdentifierInfo*)"},
    {"_ZN5clang4Sema21ActOnIndirectGotoStmtENS_14SourceLocationES1_PNS_4ExprE", "clang::Sema::ActOnIndirectGotoStmt(clang::SourceLocation, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema17ActOnContinueStmtENS_14SourceLocationEPNS_5ScopeE", "clang::Sema::ActOnContinueStmt(clang::SourceLocation, clang::Scope*)"},
    {"_ZN5clang4Sema14ActOnBreakStmtENS_14SourceLocationEPNS_5ScopeE", "clang::Sema::ActOnBreakStmt(clang::SourceLocation, clang::Scope*)"},
    {"_ZN5clang4Sema23getCopyElisionCandidateENS_8QualTypeEPNS_4ExprEb", "clang::Sema::getCopyElisionCandidate(clang::QualType, clang::Expr*, bool)"},
    {"_ZN5clang4Sema31PerformMoveOrCopyInitializationERKNS_17InitializedEntityEPKNS_7VarDeclENS_8QualTypeEPNS_4ExprE", "clang::Sema::PerformMoveOrCopyInitialization(clang::InitializedEntity const&, clang::VarDecl const*, clang::QualType, clang::Expr*)"},
    {"_ZN5clang4Sema20ActOnBlockReturnStmtENS_14SourceLocationEPNS_4ExprE", "clang::Sema::ActOnBlockReturnStmt(clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema15ActOnReturnStmtENS_14SourceLocationEPNS_4ExprE", "clang::Sema::ActOnReturnStmt(clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema12ActOnAsmStmtENS_14SourceLocationEbbjjPPNS_14IdentifierInfoENS_11ASTMultiPtrIPNS_4ExprEEES8_S7_S8_S1_b", "clang::Sema::ActOnAsmStmt(clang::SourceLocation, bool, bool, unsigned int, unsigned int, clang::IdentifierInfo**, clang::ASTMultiPtr<clang::Expr*>, clang::ASTMultiPtr<clang::Expr*>, clang::Expr*, clang::ASTMultiPtr<clang::Expr*>, clang::SourceLocation, bool)"},
    {"_Z14CheckAsmLValuePKN5clang4ExprERNS_4SemaE", "CheckAsmLValue(clang::Expr const*, clang::Sema&)"},
    {"_ZN5clang4Sema20ActOnObjCAtCatchStmtENS_14SourceLocationES1_PNS_4DeclEPNS_4StmtE", "clang::Sema::ActOnObjCAtCatchStmt(clang::SourceLocation, clang::SourceLocation, clang::Decl*, clang::Stmt*)"},
    {"_ZN5clang4Sema22ActOnObjCAtFinallyStmtENS_14SourceLocationEPNS_4StmtE", "clang::Sema::ActOnObjCAtFinallyStmt(clang::SourceLocation, clang::Stmt*)"},
    {"_ZN5clang4Sema18ActOnObjCAtTryStmtENS_14SourceLocationEPNS_4StmtENS_11ASTMultiPtrIS3_EES3_", "clang::Sema::ActOnObjCAtTryStmt(clang::SourceLocation, clang::Stmt*, clang::ASTMultiPtr<clang::Stmt*>, clang::Stmt*)"},
    {"_ZN5clang4Sema20BuildObjCAtThrowStmtENS_14SourceLocationEPNS_4ExprE", "clang::Sema::BuildObjCAtThrowStmt(clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema20ActOnObjCAtThrowStmtENS_14SourceLocationEPNS_4ExprEPNS_5ScopeE", "clang::Sema::ActOnObjCAtThrowStmt(clang::SourceLocation, clang::Expr*, clang::Scope*)"},
    {"_ZN5clang4Sema27ActOnObjCAtSynchronizedStmtENS_14SourceLocationEPNS_4ExprEPNS_4StmtE", "clang::Sema::ActOnObjCAtSynchronizedStmt(clang::SourceLocation, clang::Expr*, clang::Stmt*)"},
    {"_ZN5clang4Sema18ActOnCXXCatchBlockENS_14SourceLocationEPNS_4DeclEPNS_4StmtE", "clang::Sema::ActOnCXXCatchBlock(clang::SourceLocation, clang::Decl*, clang::Stmt*)"},
    {"_ZN5clang4Sema16ActOnCXXTryBlockENS_14SourceLocationEPNS_4StmtENS_11ASTMultiPtrIS3_EE", "clang::Sema::ActOnCXXTryBlock(clang::SourceLocation, clang::Stmt*, clang::ASTMultiPtr<clang::Stmt*>)"},
    {"_ZN4llvm25array_pod_sort_comparatorIN12_GLOBAL__N_115TypeWithHandlerEEEiPKvS4_", "int llvm::array_pod_sort_comparator<(anonymous namespace)::TypeWithHandler>(void const*, void const*)"},
    {"_ZSt6uniqueIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEEPFbRKS6_S9_EET_SC_SC_T0_", "std::pair<llvm::APSInt, clang::EnumConstantDecl*>* std::unique<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&))"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang10TargetInfo14ConstraintInfoELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::TargetInfo::ConstraintInfo, false>::grow(unsigned long)"},
    {"_ZSt21__inplace_stable_sortIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEEPFbRKS6_S9_EEvT_SC_T0_", "void std::__inplace_stable_sort<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&))"},
    {"_ZSt22__stable_sort_adaptiveIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEES7_lPFbRKS6_S9_EEvT_SC_T0_T1_T2_", "void std::__stable_sort_adaptive<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, long, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, long, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&))"},
    {"_ZSt24__merge_sort_with_bufferIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEES7_PFbRKS6_S9_EEvT_SC_T0_T1_", "void std::__merge_sort_with_buffer<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&))"},
    {"_ZSt16__merge_adaptiveIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEElS7_PFbRKS6_S9_EEvT_SC_SC_T0_SD_T1_SD_T2_", "void std::__merge_adaptive<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, long, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, long, long, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, long, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&))"},
    {"_ZSt5mergeIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEES7_S7_PFbRKS6_S9_EET1_T_SD_T0_SE_SC_T2_", "std::pair<llvm::APSInt, clang::EnumConstantDecl*>* std::merge<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&))"},
    {"_ZSt16__merge_backwardIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEES7_S7_PFbRKS6_S9_EET1_T_SD_T0_SE_SC_T2_", "std::pair<llvm::APSInt, clang::EnumConstantDecl*>* std::__merge_backward<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&))"},
    {"_ZSt17__rotate_adaptiveIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEES7_lET_S8_S8_S8_T1_S9_T0_S9_", "std::pair<llvm::APSInt, clang::EnumConstantDecl*>* std::__rotate_adaptive<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, long>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, long, long, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, long)"},
    {"_ZSt8__rotateIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEEEvT_S8_S8_St26random_access_iterator_tag", "void std::__rotate<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::random_access_iterator_tag)"},
    {"_ZSt4swapISt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEEEvRT_S8_", "void std::swap<std::pair<llvm::APSInt, clang::EnumConstantDecl*>>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>&, std::pair<llvm::APSInt, clang::EnumConstantDecl*>&)"},
    {"_ZNSt15__copy_backwardILb0ESt26random_access_iterator_tagE8__copy_bIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEESA_EET0_T_SC_SB_", "std::pair<llvm::APSInt, clang::EnumConstantDecl*>* std::__copy_backward<false, std::random_access_iterator_tag>::__copy_b<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*)"},
    {"_ZNSt6__copyILb0ESt26random_access_iterator_tagE4copyIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEESA_EET0_T_SC_SB_", "std::pair<llvm::APSInt, clang::EnumConstantDecl*>* std::__copy<false, std::random_access_iterator_tag>::copy<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*)"},
    {"_ZSt16__insertion_sortIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEEPFbRKS6_S9_EEvT_SC_T0_", "void std::__insertion_sort<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&))"},
    {"_ZSt25__unguarded_linear_insertIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEES6_PFbRKS6_S9_EEvT_T0_T1_", "void std::__unguarded_linear_insert<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&))"},
    {"_ZSt22__merge_without_bufferIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEElPFbRKS6_S9_EEvT_SC_SC_T0_SD_T1_", "void std::__merge_without_buffer<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, long, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&)>(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, long, long, bool (*)(std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&, std::pair<llvm::APSInt, clang::EnumConstantDecl*> const&))"},
    {"_ZNSt17_Temporary_bufferIPSt4pairIN4llvm6APSIntEPN5clang16EnumConstantDeclEES6_EC2ES7_S7_", "std::_Temporary_buffer<std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>>::_Temporary_buffer(std::pair<llvm::APSInt, clang::EnumConstantDecl*>*, std::pair<llvm::APSInt, clang::EnumConstantDecl*>*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairINS_6APSIntEPN5clang16EnumConstantDeclEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<llvm::APSInt, clang::EnumConstantDecl*>, false>::grow(unsigned long)"},
    {"_ZNSt6vectorIN4llvm6APSIntESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<llvm::APSInt, std::allocator<llvm::APSInt>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::APSInt*, std::vector<llvm::APSInt, std::allocator<llvm::APSInt>>>, llvm::APSInt const&)"},
    {"_ZNSt15__copy_backwardILb0ESt26random_access_iterator_tagE8__copy_bIPN4llvm6APSIntES5_EET0_T_S7_S6_", "llvm::APSInt* std::__copy_backward<false, std::random_access_iterator_tag>::__copy_b<llvm::APSInt*, llvm::APSInt*>(llvm::APSInt*, llvm::APSInt*, llvm::APSInt*)"},
    {"_ZNSt6__copyILb0ESt26random_access_iterator_tagE4copyIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESA_EET0_T_SC_SB_", "std::pair<llvm::APSInt, clang::CaseStmt*>* std::__copy<false, std::random_access_iterator_tag>::copy<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*)"},
    {"_ZSt21__inplace_stable_sortIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEEEvT_SE_", "void std::__inplace_stable_sort<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>)"},
    {"_ZSt22__stable_sort_adaptiveIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEES9_lEvT_SE_T0_T1_", "void std::__stable_sort_adaptive<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>*, long>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>*, long)"},
    {"_ZSt24__merge_sort_with_bufferIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEES9_EvT_SE_T0_", "void std::__merge_sort_with_buffer<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>*>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>*)"},
    {"_ZSt16__merge_adaptiveIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEElS9_EvT_SE_SE_T0_SF_T1_SF_", "void std::__merge_adaptive<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, long, std::pair<llvm::APSInt, clang::CaseStmt*>*>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, long, long, std::pair<llvm::APSInt, clang::CaseStmt*>*, long)"},
    {"_ZSt5mergeIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEEN9__gnu_cxx17__normal_iteratorIS7_St6vectorIS6_SaIS6_EEEESD_ET1_T_SF_T0_SG_SE_", "__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>> std::merge<std::pair<llvm::APSInt, clang::CaseStmt*>*, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>)"},
    {"_ZSt16__merge_backwardIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEES9_SD_ET1_T_SF_T0_SG_SE_", "__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>> std::__merge_backward<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>*, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>)"},
    {"_ZSt11lower_boundIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEES8_ET_SE_SE_RKT0_", "__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>> std::lower_bound<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*> const&)"},
    {"_ZSt11upper_boundIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEES8_ET_SE_SE_RKT0_", "__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>> std::upper_bound<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*> const&)"},
    {"_ZSt17__rotate_adaptiveIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEES9_lET_SE_SE_SE_T1_SF_T0_SF_", "__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>> std::__rotate_adaptive<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>*, long>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, long, long, std::pair<llvm::APSInt, clang::CaseStmt*>*, long)"},
    {"_ZSt8__rotateIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEEEvT_SE_SE_St26random_access_iterator_tag", "void std::__rotate<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::random_access_iterator_tag)"},
    {"_ZSt4swapISt4pairIN4llvm6APSIntEPN5clang8CaseStmtEEEvRT_S8_", "void std::swap<std::pair<llvm::APSInt, clang::CaseStmt*>>(std::pair<llvm::APSInt, clang::CaseStmt*>&, std::pair<llvm::APSInt, clang::CaseStmt*>&)"},
    {"_ZNSt15__copy_backwardILb0ESt26random_access_iterator_tagE8__copy_bIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESA_EET0_T_SC_SB_", "std::pair<llvm::APSInt, clang::CaseStmt*>* std::__copy_backward<false, std::random_access_iterator_tag>::__copy_b<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*)"},
    {"_ZSt5mergeIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEES7_N9__gnu_cxx17__normal_iteratorIS7_St6vectorIS6_SaIS6_EEEEET1_T_SF_T0_SG_SE_", "__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>> std::merge<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>)"},
    {"_ZSt5mergeIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEESD_S9_ET1_T_SF_T0_SG_SE_", "std::pair<llvm::APSInt, clang::CaseStmt*>* std::merge<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>*>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>*)"},
    {"_ZSt16__insertion_sortIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEEEvT_SE_", "void std::__insertion_sort<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>)"},
    {"_ZSt25__unguarded_linear_insertIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEES8_EvT_T0_", "void std::__unguarded_linear_insert<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>)"},
    {"_ZSt22__merge_without_bufferIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEElEvT_SE_SE_T0_SF_", "void std::__merge_without_buffer<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, long>(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, long, long)"},
    {"_ZNSt17_Temporary_bufferIN9__gnu_cxx17__normal_iteratorIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESt6vectorIS8_SaIS8_EEEES8_EC2ESD_SD_", "std::_Temporary_buffer<__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*>>::_Temporary_buffer(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>)"},
    {"_ZSt21__inplace_stable_sortIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEEPFbRKS6_S9_EEvT_SC_T0_", "void std::__inplace_stable_sort<std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&)>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&))"},
    {"_ZSt22__stable_sort_adaptiveIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEES7_lPFbRKS6_S9_EEvT_SC_T0_T1_T2_", "void std::__stable_sort_adaptive<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, long, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&)>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, long, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&))"},
    {"_ZSt24__merge_sort_with_bufferIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEES7_PFbRKS6_S9_EEvT_SC_T0_T1_", "void std::__merge_sort_with_buffer<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&)>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&))"},
    {"_ZSt16__merge_adaptiveIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEElS7_PFbRKS6_S9_EEvT_SC_SC_T0_SD_T1_SD_T2_", "void std::__merge_adaptive<std::pair<llvm::APSInt, clang::CaseStmt*>*, long, std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&)>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, long, long, std::pair<llvm::APSInt, clang::CaseStmt*>*, long, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&))"},
    {"_ZSt5mergeIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEES7_S7_PFbRKS6_S9_EET1_T_SD_T0_SE_SC_T2_", "std::pair<llvm::APSInt, clang::CaseStmt*>* std::merge<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&)>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&))"},
    {"_ZSt16__merge_backwardIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEES7_S7_PFbRKS6_S9_EET1_T_SD_T0_SE_SC_T2_", "std::pair<llvm::APSInt, clang::CaseStmt*>* std::__merge_backward<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&)>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&))"},
    {"_ZSt17__rotate_adaptiveIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEES7_lET_S8_S8_S8_T1_S9_T0_S9_", "std::pair<llvm::APSInt, clang::CaseStmt*>* std::__rotate_adaptive<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, long>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, long, long, std::pair<llvm::APSInt, clang::CaseStmt*>*, long)"},
    {"_ZSt8__rotateIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEEEvT_S8_S8_St26random_access_iterator_tag", "void std::__rotate<std::pair<llvm::APSInt, clang::CaseStmt*>*>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::random_access_iterator_tag)"},
    {"_ZSt16__insertion_sortIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEEPFbRKS6_S9_EEvT_SC_T0_", "void std::__insertion_sort<std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&)>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&))"},
    {"_ZSt25__unguarded_linear_insertIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEES6_PFbRKS6_S9_EEvT_T0_T1_", "void std::__unguarded_linear_insert<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&)>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&))"},
    {"_ZSt22__merge_without_bufferIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEElPFbRKS6_S9_EEvT_SC_SC_T0_SD_T1_", "void std::__merge_without_buffer<std::pair<llvm::APSInt, clang::CaseStmt*>*, long, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&)>(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*, long, long, bool (*)(std::pair<llvm::APSInt, clang::CaseStmt*> const&, std::pair<llvm::APSInt, clang::CaseStmt*> const&))"},
    {"_ZNSt17_Temporary_bufferIPSt4pairIN4llvm6APSIntEPN5clang8CaseStmtEES6_EC2ES7_S7_", "std::_Temporary_buffer<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>>::_Temporary_buffer(std::pair<llvm::APSInt, clang::CaseStmt*>*, std::pair<llvm::APSInt, clang::CaseStmt*>*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairINS_6APSIntEPN5clang8CaseStmtEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<llvm::APSInt, clang::CaseStmt*>, false>::grow(unsigned long)"},
    {"_ZNSt6vectorISt4pairIN4llvm6APSIntEPN5clang8CaseStmtEESaIS6_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS6_S8_EERKS6_", "std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::APSInt, clang::CaseStmt*>*, std::vector<std::pair<llvm::APSInt, clang::CaseStmt*>, std::allocator<std::pair<llvm::APSInt, clang::CaseStmt*>>>>, std::pair<llvm::APSInt, clang::CaseStmt*> const&)"},
    {"_ZN4llvm15SmallVectorImplIN5clang10TargetInfo14ConstraintInfoEED2Ev", "llvm::SmallVectorImpl<clang::TargetInfo::ConstraintInfo>::~SmallVectorImpl()"},
    {"_ZN5clang22getTemplateParamsRangeEPKPKNS_21TemplateParameterListEj", "clang::getTemplateParamsRange(clang::TemplateParameterList const* const*, unsigned int)"},
    {"_ZN5clang4Sema14isTemplateNameEPNS_5ScopeERNS_12CXXScopeSpecEbRNS_13UnqualifiedIdENS_9OpaquePtrINS_8QualTypeEEEbRNS7_INS_12TemplateNameEEERb", "clang::Sema::isTemplateName(clang::Scope*, clang::CXXScopeSpec&, bool, clang::UnqualifiedId&, clang::OpaquePtr<clang::QualType>, bool, clang::OpaquePtr<clang::TemplateName>&, bool&)"},
    {"_ZN5clang4Sema18LookupTemplateNameERNS_12LookupResultEPNS_5ScopeERNS_12CXXScopeSpecENS_8QualTypeEbRb", "clang::Sema::LookupTemplateName(clang::LookupResult&, clang::Scope*, clang::CXXScopeSpec&, clang::QualType, bool, bool&)"},
    {"_ZN5clang4Sema27DiagnoseUnknownTemplateNameERKNS_14IdentifierInfoENS_14SourceLocationEPNS_5ScopeEPKNS_12CXXScopeSpecERNS_9OpaquePtrINS_12TemplateNameEEERNS_16TemplateNameKindE", "clang::Sema::DiagnoseUnknownTemplateName(clang::IdentifierInfo const&, clang::SourceLocation, clang::Scope*, clang::CXXScopeSpec const*, clang::OpaquePtr<clang::TemplateName>&, clang::TemplateNameKind&)"},
    {"_Z29FilterAcceptableTemplateNamesRN5clang10ASTContextERNS_12LookupResultE", "FilterAcceptableTemplateNames(clang::ASTContext&, clang::LookupResult&)"},
    {"_ZN5clang4Sema26ActOnDependentIdExpressionERKNS_12CXXScopeSpecERKNS_19DeclarationNameInfoEbPKNS_24TemplateArgumentListInfoE", "clang::Sema::ActOnDependentIdExpression(clang::CXXScopeSpec const&, clang::DeclarationNameInfo const&, bool, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang4Sema25BuildDependentDeclRefExprERKNS_12CXXScopeSpecERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoE", "clang::Sema::BuildDependentDeclRefExpr(clang::CXXScopeSpec const&, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang4Sema31DiagnoseTemplateParameterShadowENS_14SourceLocationEPNS_4DeclE", "clang::Sema::DiagnoseTemplateParameterShadow(clang::SourceLocation, clang::Decl*)"},
    {"_ZN5clang4Sema20AdjustDeclIfTemplateERPNS_4DeclE", "clang::Sema::AdjustDeclIfTemplate(clang::Decl*&)"},
    {"_ZNK5clang22ParsedTemplateArgument24getTemplatePackExpansionENS_14SourceLocationE", "clang::ParsedTemplateArgument::getTemplatePackExpansion(clang::SourceLocation) const"},
    {"_ZN5clang4Sema26translateTemplateArgumentsERKNS_18ASTTemplateArgsPtrERNS_24TemplateArgumentListInfoE", "clang::Sema::translateTemplateArguments(clang::ASTTemplateArgsPtr const&, clang::TemplateArgumentListInfo&)"},
    {"_Z25translateTemplateArgumentRN5clang4SemaERKNS_22ParsedTemplateArgumentE", "translateTemplateArgument(clang::Sema&, clang::ParsedTemplateArgument const&)"},
    {"_ZN5clang4Sema18ActOnTypeParameterEPNS_5ScopeEbbNS_14SourceLocationES3_PNS_14IdentifierInfoES3_jjS3_NS_9OpaquePtrINS_8QualTypeEEE", "clang::Sema::ActOnTypeParameter(clang::Scope*, bool, bool, clang::SourceLocation, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, unsigned int, unsigned int, clang::SourceLocation, clang::OpaquePtr<clang::QualType>)"},
    {"_ZN5clang4Sema21CheckTemplateArgumentEPNS_20TemplateTypeParmDeclEPNS_14TypeSourceInfoE", "clang::Sema::CheckTemplateArgument(clang::TemplateTypeParmDecl*, clang::TypeSourceInfo*)"},
    {"_ZN5clang4Sema33CheckNonTypeTemplateParameterTypeENS_8QualTypeENS_14SourceLocationE", "clang::Sema::CheckNonTypeTemplateParameterType(clang::QualType, clang::SourceLocation)"},
    {"_ZN5clang4Sema29ActOnNonTypeTemplateParameterEPNS_5ScopeERNS_10DeclaratorEjjNS_14SourceLocationEPNS_4ExprE", "clang::Sema::ActOnNonTypeTemplateParameter(clang::Scope*, clang::Declarator&, unsigned int, unsigned int, clang::SourceLocation, clang::Expr*)"},
    {"_ZN5clang4Sema21CheckTemplateArgumentEPNS_23NonTypeTemplateParmDeclENS_8QualTypeERPNS_4ExprERNS_16TemplateArgumentENS0_25CheckTemplateArgumentKindE", "clang::Sema::CheckTemplateArgument(clang::NonTypeTemplateParmDecl*, clang::QualType, clang::Expr*&, clang::TemplateArgument&, clang::Sema::CheckTemplateArgumentKind)"},
    {"_ZN5clang4Sema30ActOnTemplateTemplateParameterEPNS_5ScopeENS_14SourceLocationEPNS_21TemplateParameterListES3_PNS_14IdentifierInfoES3_jjS3_NS_22ParsedTemplateArgumentE", "clang::Sema::ActOnTemplateTemplateParameter(clang::Scope*, clang::SourceLocation, clang::TemplateParameterList*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, unsigned int, unsigned int, clang::SourceLocation, clang::ParsedTemplateArgument)"},
    {"_ZN5clang4Sema26ActOnTemplateParameterListEjNS_14SourceLocationES1_S1_PPNS_4DeclEjS1_", "clang::Sema::ActOnTemplateParameterList(unsigned int, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::Decl**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang4Sema18CheckClassTemplateEPNS_5ScopeEjNS0_10TagUseKindENS_14SourceLocationERNS_12CXXScopeSpecEPNS_14IdentifierInfoES4_PNS_13AttributeListEPNS_21TemplateParameterListENS_15AccessSpecifierE", "clang::Sema::CheckClassTemplate(clang::Scope*, unsigned int, clang::Sema::TagUseKind, clang::SourceLocation, clang::CXXScopeSpec&, clang::IdentifierInfo*, clang::SourceLocation, clang::AttributeList*, clang::TemplateParameterList*, clang::AccessSpecifier)"},
    {"_ZN5clang4Sema22CheckTemplateDeclScopeEPNS_5ScopeEPNS_21TemplateParameterListE", "clang::Sema::CheckTemplateDeclScope(clang::Scope*, clang::TemplateParameterList*)"},
    {"_ZN5clang4Sema30TemplateParameterListsAreEqualEPNS_21TemplateParameterListES2_bNS0_30TemplateParameterListEqualKindENS_14SourceLocationE", "clang::Sema::TemplateParameterListsAreEqual(clang::TemplateParameterList*, clang::TemplateParameterList*, bool, clang::Sema::TemplateParameterListEqualKind, clang::SourceLocation)"},
    {"_ZN5clang4Sema26CheckTemplateParameterListEPNS_21TemplateParameterListES2_NS0_24TemplateParamListContextE", "clang::Sema::CheckTemplateParameterList(clang::TemplateParameterList*, clang::TemplateParameterList*, clang::Sema::TemplateParamListContext)"},
    {"_Z32DiagnoseUnexpandedParameterPacksRN5clang4SemaEPNS_24TemplateTemplateParmDeclE", "DiagnoseUnexpandedParameterPacks(clang::Sema&, clang::TemplateTemplateParmDecl*)"},
    {"_Z31DiagnoseDefaultTemplateArgumentRN5clang4SemaENS0_24TemplateParamListContextENS_14SourceLocationENS_11SourceRangeE", "DiagnoseDefaultTemplateArgument(clang::Sema&, clang::Sema::TemplateParamListContext, clang::SourceLocation, clang::SourceRange)"},
    {"_ZN5clang4Sema39MatchTemplateParametersToScopeSpecifierENS_14SourceLocationERKNS_12CXXScopeSpecEPPNS_21TemplateParameterListEjbRbS8_", "clang::Sema::MatchTemplateParametersToScopeSpecifier(clang::SourceLocation, clang::CXXScopeSpec const&, clang::TemplateParameterList**, unsigned int, bool, bool&, bool&)"},
    {"_ZN5clang4Sema19CheckTemplateIdTypeENS_12TemplateNameENS_14SourceLocationERKNS_24TemplateArgumentListInfoE", "clang::Sema::CheckTemplateIdType(clang::TemplateName, clang::SourceLocation, clang::TemplateArgumentListInfo const&)"},
    {"_ZN5clang4Sema25CheckTemplateArgumentListEPNS_12TemplateDeclENS_14SourceLocationERKNS_24TemplateArgumentListInfoEbRN4llvm15SmallVectorImplINS_16TemplateArgumentEEE", "clang::Sema::CheckTemplateArgumentList(clang::TemplateDecl*, clang::SourceLocation, clang::TemplateArgumentListInfo const&, bool, llvm::SmallVectorImpl<clang::TemplateArgument>&)"},
    {"_ZN5clang4Sema19ActOnTemplateIdTypeENS_9OpaquePtrINS_12TemplateNameEEENS_14SourceLocationES4_NS_18ASTTemplateArgsPtrES4_", "clang::Sema::ActOnTemplateIdType(clang::OpaquePtr<clang::TemplateName>, clang::SourceLocation, clang::SourceLocation, clang::ASTTemplateArgsPtr, clang::SourceLocation)"},
    {"_ZN5clang4Sema22ActOnTagTemplateIdTypeERNS_12CXXScopeSpecENS_12ActionResultINS_9OpaquePtrINS_8QualTypeEEELb0EEENS0_10TagUseKindENS_17TypeSpecifierTypeENS_14SourceLocationE", "clang::Sema::ActOnTagTemplateIdType(clang::CXXScopeSpec&, clang::ActionResult<clang::OpaquePtr<clang::QualType>, false>, clang::Sema::TagUseKind, clang::TypeSpecifierType, clang::SourceLocation)"},
    {"_ZN5clang4Sema19BuildTemplateIdExprERKNS_12CXXScopeSpecERNS_12LookupResultEbRKNS_24TemplateArgumentListInfoE", "clang::Sema::BuildTemplateIdExpr(clang::CXXScopeSpec const&, clang::LookupResult&, bool, clang::TemplateArgumentListInfo const&)"},
    {"_ZN5clang4Sema28BuildQualifiedTemplateIdExprERNS_12CXXScopeSpecERKNS_19DeclarationNameInfoERKNS_24TemplateArgumentListInfoE", "clang::Sema::BuildQualifiedTemplateIdExpr(clang::CXXScopeSpec&, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const&)"},
    {"_ZN5clang4Sema26ActOnDependentTemplateNameEPNS_5ScopeENS_14SourceLocationERNS_12CXXScopeSpecERNS_13UnqualifiedIdENS_9OpaquePtrINS_8QualTypeEEEbRNS8_INS_12TemplateNameEEE", "clang::Sema::ActOnDependentTemplateName(clang::Scope*, clang::SourceLocation, clang::CXXScopeSpec&, clang::UnqualifiedId&, clang::OpaquePtr<clang::QualType>, bool, clang::OpaquePtr<clang::TemplateName>&)"},
    {"_ZN5clang4Sema25CheckTemplateTypeArgumentEPNS_20TemplateTypeParmDeclERKNS_19TemplateArgumentLocERN4llvm15SmallVectorImplINS_16TemplateArgumentEEE", "clang::Sema::CheckTemplateTypeArgument(clang::TemplateTypeParmDecl*, clang::TemplateArgumentLoc const&, llvm::SmallVectorImpl<clang::TemplateArgument>&)"},
    {"_ZN5clang4Sema39SubstDefaultTemplateArgumentIfAvailableEPNS_12TemplateDeclENS_14SourceLocationES3_PNS_4DeclERN4llvm15SmallVectorImplINS_16TemplateArgumentEEE", "clang::Sema::SubstDefaultTemplateArgumentIfAvailable(clang::TemplateDecl*, clang::SourceLocation, clang::SourceLocation, clang::Decl*, llvm::SmallVectorImpl<clang::TemplateArgument>&)"},
    {"_Z28SubstDefaultTemplateArgumentRN5clang4SemaEPNS_12TemplateDeclENS_14SourceLocationES4_PNS_20TemplateTypeParmDeclERN4llvm15SmallVectorImplINS_16TemplateArgumentEEE", "SubstDefaultTemplateArgument(clang::Sema&, clang::TemplateDecl*, clang::SourceLocation, clang::SourceLocation, clang::TemplateTypeParmDecl*, llvm::SmallVectorImpl<clang::TemplateArgument>&)"},
    {"_Z28SubstDefaultTemplateArgumentRN5clang4SemaEPNS_12TemplateDeclENS_14SourceLocationES4_PNS_23NonTypeTemplateParmDeclERN4llvm15SmallVectorImplINS_16TemplateArgumentEEE", "SubstDefaultTemplateArgument(clang::Sema&, clang::TemplateDecl*, clang::SourceLocation, clang::SourceLocation, clang::NonTypeTemplateParmDecl*, llvm::SmallVectorImpl<clang::TemplateArgument>&)"},
    {"_Z28SubstDefaultTemplateArgumentRN5clang4SemaEPNS_12TemplateDeclENS_14SourceLocationES4_PNS_24TemplateTemplateParmDeclERN4llvm15SmallVectorImplINS_16TemplateArgumentEEE", "SubstDefaultTemplateArgument(clang::Sema&, clang::TemplateDecl*, clang::SourceLocation, clang::SourceLocation, clang::TemplateTemplateParmDecl*, llvm::SmallVectorImpl<clang::TemplateArgument>&)"},
    {"_ZN5clang4Sema21CheckTemplateArgumentEPNS_9NamedDeclERKNS_19TemplateArgumentLocES2_NS_14SourceLocationES6_jRN4llvm15SmallVectorImplINS_16TemplateArgumentEEENS0_25CheckTemplateArgumentKindE", "clang::Sema::CheckTemplateArgument(clang::NamedDecl*, clang::TemplateArgumentLoc const&, clang::NamedDecl*, clang::SourceLocation, clang::SourceLocation, unsigned int, llvm::SmallVectorImpl<clang::TemplateArgument>&, clang::Sema::CheckTemplateArgumentKind)"},
    {"_ZN5clang4Sema21CheckTemplateArgumentEPNS_24TemplateTemplateParmDeclERKNS_19TemplateArgumentLocE", "clang::Sema::CheckTemplateArgument(clang::TemplateTemplateParmDecl*, clang::TemplateArgumentLoc const&)"},
    {"_ZN5clang4Sema36CheckTemplateArgumentPointerToMemberEPNS_4ExprERNS_16TemplateArgumentE", "clang::Sema::CheckTemplateArgumentPointerToMember(clang::Expr*, clang::TemplateArgument&)"},
    {"_Z46CheckTemplateArgumentAddressOfObjectOrFunctionRN5clang4SemaEPNS_23NonTypeTemplateParmDeclENS_8QualTypeEPNS_4ExprERNS_16TemplateArgumentE", "CheckTemplateArgumentAddressOfObjectOrFunction(clang::Sema&, clang::NonTypeTemplateParmDecl*, clang::QualType, clang::Expr*, clang::TemplateArgument&)"},
    {"_ZN5clang4Sema39BuildExpressionFromDeclTemplateArgumentERKNS_16TemplateArgumentENS_8QualTypeENS_14SourceLocationE", "clang::Sema::BuildExpressionFromDeclTemplateArgument(clang::TemplateArgument const&, clang::QualType, clang::SourceLocation)"},
    {"_ZN5clang4Sema43BuildExpressionFromIntegralTemplateArgumentERKNS_16TemplateArgumentENS_14SourceLocationE", "clang::Sema::BuildExpressionFromIntegralTemplateArgument(clang::TemplateArgument const&, clang::SourceLocation)"},
    {"_Z42DiagnoseTemplateParameterListArityMismatchRN5clang4SemaEPNS_21TemplateParameterListES3_NS0_30TemplateParameterListEqualKindENS_14SourceLocationE", "DiagnoseTemplateParameterListArityMismatch(clang::Sema&, clang::TemplateParameterList*, clang::TemplateParameterList*, clang::Sema::TemplateParameterListEqualKind, clang::SourceLocation)"},
    {"_Z26MatchTemplateParameterKindRN5clang4SemaEPNS_9NamedDeclES3_bNS0_30TemplateParameterListEqualKindENS_14SourceLocationE", "MatchTemplateParameterKind(clang::Sema&, clang::NamedDecl*, clang::NamedDecl*, bool, clang::Sema::TemplateParameterListEqualKind, clang::SourceLocation)"},
    {"_ZN5clang4Sema32ActOnClassTemplateSpecializationEPNS_5ScopeEjNS0_10TagUseKindENS_14SourceLocationERNS_12CXXScopeSpecENS_9OpaquePtrINS_12TemplateNameEEES4_S4_NS_18ASTTemplateArgsPtrES4_PNS_13AttributeListENS_11ASTMultiPtrIPNS_21TemplateParameterListEEE", "clang::Sema::ActOnClassTemplateSpecialization(clang::Scope*, unsigned int, clang::Sema::TagUseKind, clang::SourceLocation, clang::CXXScopeSpec&, clang::OpaquePtr<clang::TemplateName>, clang::SourceLocation, clang::SourceLocation, clang::ASTTemplateArgsPtr, clang::SourceLocation, clang::AttributeList*, clang::ASTMultiPtr<clang::TemplateParameterList*>)"},
    {"_Z32CheckTemplateSpecializationScopeRN5clang4SemaEPNS_9NamedDeclES3_NS_14SourceLocationEb", "CheckTemplateSpecializationScope(clang::Sema&, clang::NamedDecl*, clang::NamedDecl*, clang::SourceLocation, bool)"},
    {"_Z15getPreviousDeclPN5clang9NamedDeclE", "getPreviousDecl(clang::NamedDecl*)"},
    {"_ZN5clang4Sema23ActOnTemplateDeclaratorEPNS_5ScopeENS_11ASTMultiPtrIPNS_21TemplateParameterListEEERNS_10DeclaratorE", "clang::Sema::ActOnTemplateDeclarator(clang::Scope*, clang::ASTMultiPtr<clang::TemplateParameterList*>, clang::Declarator&)"},
    {"_ZN5clang4Sema31ActOnStartOfFunctionTemplateDefEPNS_5ScopeENS_11ASTMultiPtrIPNS_21TemplateParameterListEEERNS_10DeclaratorE", "clang::Sema::ActOnStartOfFunctionTemplateDef(clang::Scope*, clang::ASTMultiPtr<clang::TemplateParameterList*>, clang::Declarator&)"},
    {"_ZN5clang4Sema38CheckSpecializationInstantiationRedeclENS_14SourceLocationENS_26TemplateSpecializationKindEPNS_9NamedDeclES2_S1_Rb", "clang::Sema::CheckSpecializationInstantiationRedecl(clang::SourceLocation, clang::TemplateSpecializationKind, clang::NamedDecl*, clang::TemplateSpecializationKind, clang::SourceLocation, bool&)"},
    {"_ZN5clang4Sema44CheckDependentFunctionTemplateSpecializationEPNS_12FunctionDeclERKNS_24TemplateArgumentListInfoERNS_12LookupResultE", "clang::Sema::CheckDependentFunctionTemplateSpecialization(clang::FunctionDecl*, clang::TemplateArgumentListInfo const&, clang::LookupResult&)"},
    {"_ZN5clang4Sema35CheckFunctionTemplateSpecializationEPNS_12FunctionDeclEPKNS_24TemplateArgumentListInfoERNS_12LookupResultE", "clang::Sema::CheckFunctionTemplateSpecialization(clang::FunctionDecl*, clang::TemplateArgumentListInfo const*, clang::LookupResult&)"},
    {"_ZN5clang4Sema25CheckMemberSpecializationEPNS_9NamedDeclERNS_12LookupResultE", "clang::Sema::CheckMemberSpecialization(clang::NamedDecl*, clang::LookupResult&)"},
    {"_ZN5clang4Sema26ActOnExplicitInstantiationEPNS_5ScopeENS_14SourceLocationES3_jS3_RKNS_12CXXScopeSpecENS_9OpaquePtrINS_12TemplateNameEEES3_S3_NS_18ASTTemplateArgsPtrES3_PNS_13AttributeListE", "clang::Sema::ActOnExplicitInstantiation(clang::Scope*, clang::SourceLocation, clang::SourceLocation, unsigned int, clang::SourceLocation, clang::CXXScopeSpec const&, clang::OpaquePtr<clang::TemplateName>, clang::SourceLocation, clang::SourceLocation, clang::ASTTemplateArgsPtr, clang::SourceLocation, clang::AttributeList*)"},
    {"_Z31CheckExplicitInstantiationScopeRN5clang4SemaEPNS_9NamedDeclENS_14SourceLocationEb", "CheckExplicitInstantiationScope(clang::Sema&, clang::NamedDecl*, clang::SourceLocation, bool)"},
    {"_ZN5clang4Sema26ActOnExplicitInstantiationEPNS_5ScopeENS_14SourceLocationES3_jS3_RNS_12CXXScopeSpecEPNS_14IdentifierInfoES3_PNS_13AttributeListE", "clang::Sema::ActOnExplicitInstantiation(clang::Scope*, clang::SourceLocation, clang::SourceLocation, unsigned int, clang::SourceLocation, clang::CXXScopeSpec&, clang::IdentifierInfo*, clang::SourceLocation, clang::AttributeList*)"},
    {"_ZN5clang4Sema26ActOnExplicitInstantiationEPNS_5ScopeENS_14SourceLocationES3_RNS_10DeclaratorE", "clang::Sema::ActOnExplicitInstantiation(clang::Scope*, clang::SourceLocation, clang::SourceLocation, clang::Declarator&)"},
    {"_ZN5clang4Sema17ActOnDependentTagEPNS_5ScopeEjNS0_10TagUseKindERKNS_12CXXScopeSpecEPNS_14IdentifierInfoENS_14SourceLocationES9_", "clang::Sema::ActOnDependentTag(clang::Scope*, unsigned int, clang::Sema::TagUseKind, clang::CXXScopeSpec const&, clang::IdentifierInfo*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang4Sema17ActOnTypenameTypeEPNS_5ScopeENS_14SourceLocationERKNS_12CXXScopeSpecERKNS_14IdentifierInfoES3_", "clang::Sema::ActOnTypenameType(clang::Scope*, clang::SourceLocation, clang::CXXScopeSpec const&, clang::IdentifierInfo const&, clang::SourceLocation)"},
    {"_ZN5clang4Sema17CheckTypenameTypeENS_21ElaboratedTypeKeywordEPNS_19NestedNameSpecifierERKNS_14IdentifierInfoENS_14SourceLocationENS_11SourceRangeES7_", "clang::Sema::CheckTypenameType(clang::ElaboratedTypeKeyword, clang::NestedNameSpecifier*, clang::IdentifierInfo const&, clang::SourceLocation, clang::SourceRange, clang::SourceLocation)"},
    {"_ZN5clang4Sema17ActOnTypenameTypeEPNS_5ScopeENS_14SourceLocationERKNS_12CXXScopeSpecES3_NS_9OpaquePtrINS_8QualTypeEEE", "clang::Sema::ActOnTypenameType(clang::Scope*, clang::SourceLocation, clang::CXXScopeSpec const&, clang::SourceLocation, clang::OpaquePtr<clang::QualType>)"},
    {"_ZN5clang4Sema33RebuildTypeInCurrentInstantiationEPNS_14TypeSourceInfoENS_14SourceLocationENS_15DeclarationNameE", "clang::Sema::RebuildTypeInCurrentInstantiation(clang::TypeSourceInfo*, clang::SourceLocation, clang::DeclarationName)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE13TransformTypeEPNS_14TypeSourceInfoE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformType(clang::TypeSourceInfo*)"},
    {"_ZN5clang4Sema33RebuildExprInCurrentInstantiationEPNS_4ExprE", "clang::Sema::RebuildExprInCurrentInstantiation(clang::Expr*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE13TransformExprEPNS_4ExprE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformExpr(clang::Expr*)"},
    {"_ZN5clang4Sema48RebuildNestedNameSpecifierInCurrentInstantiationERNS_12CXXScopeSpecE", "clang::Sema::RebuildNestedNameSpecifierInCurrentInstantiation(clang::CXXScopeSpec&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE28TransformNestedNameSpecifierEPNS_19NestedNameSpecifierENS_11SourceRangeENS_8QualTypeEPNS_9NamedDeclE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformNestedNameSpecifier(clang::NestedNameSpecifier*, clang::SourceRange, clang::QualType, clang::NamedDecl*)"},
    {"_ZN5clang4Sema31getTemplateArgumentBindingsTextEPKNS_21TemplateParameterListERKNS_20TemplateArgumentListE", "clang::Sema::getTemplateArgumentBindingsText(clang::TemplateParameterList const*, clang::TemplateArgumentList const&)"},
    {"_ZN5clang4Sema31getTemplateArgumentBindingsTextEPKNS_21TemplateParameterListEPKNS_16TemplateArgumentEj", "clang::Sema::getTemplateArgumentBindingsText(clang::TemplateParameterList const*, clang::TemplateArgument const*, unsigned int)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE26TransformTypeInObjectScopeEPNS_14TypeSourceInfoENS_8QualTypeEPNS_9NamedDeclEPNS_19NestedNameSpecifierE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformTypeInObjectScope(clang::TypeSourceInfo*, clang::QualType, clang::NamedDecl*, clang::NestedNameSpecifier*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE21TransformTemplateNameENS_12TemplateNameENS_8QualTypeEPNS_9NamedDeclE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformTemplateName(clang::TemplateName, clang::QualType, clang::NamedDecl*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE35TransformTemplateSpecializationTypeERNS_14TypeLocBuilderENS_29TemplateSpecializationTypeLocENS_12TemplateNameE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformTemplateSpecializationType(clang::TypeLocBuilder&, clang::TemplateSpecializationTypeLoc, clang::TemplateName)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE44TransformDependentTemplateSpecializationTypeERNS_14TypeLocBuilderENS_38DependentTemplateSpecializationTypeLocEPNS_19NestedNameSpecifierE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformDependentTemplateSpecializationType(clang::TypeLocBuilder&, clang::DependentTemplateSpecializationTypeLoc, clang::NestedNameSpecifier*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE13TransformTypeERNS_14TypeLocBuilderENS_7TypeLocE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformType(clang::TypeLocBuilder&, clang::TypeLoc)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE27TransformFunctionTypeParamsENS_14SourceLocationEPPNS_11ParmVarDeclEjPKNS_8QualTypeERN4llvm15SmallVectorImplIS8_EEPNSC_IS6_EE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformFunctionTypeParams(clang::SourceLocation, clang::ParmVarDecl**, unsigned int, clang::QualType const*, llvm::SmallVectorImpl<clang::QualType>&, llvm::SmallVectorImpl<clang::ParmVarDecl*>*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE26TransformFunctionTypeParamEPNS_11ParmVarDeclEN4llvm8OptionalIjEE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformFunctionTypeParam(clang::ParmVarDecl*, llvm::Optional<unsigned int>)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE16RebuildArrayTypeENS_8QualTypeENS_9ArrayType17ArraySizeModifierEPKN4llvm5APIntEPNS_4ExprEjNS_11SourceRangeE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::RebuildArrayType(clang::QualType, clang::ArrayType::ArraySizeModifier, llvm::APInt const*, clang::Expr*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE22TransformReferenceTypeERNS_14TypeLocBuilderENS_16ReferenceTypeLocE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformReferenceType(clang::TypeLocBuilder&, clang::ReferenceTypeLoc)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE26TransformTemplateArgumentsINS_33TemplateArgumentLocInventIteratorIS2_PKNS_16TemplateArgumentEEEEEbT_SA_RNS_24TemplateArgumentListInfoE", "bool clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformTemplateArguments<clang::TemplateArgumentLocInventIterator<(anonymous namespace)::CurrentInstantiationRebuilder, clang::TemplateArgument const*>>(clang::TemplateArgumentLocInventIterator<(anonymous namespace)::CurrentInstantiationRebuilder, clang::TemplateArgument const*>, clang::TemplateArgumentLocInventIterator<(anonymous namespace)::CurrentInstantiationRebuilder, clang::TemplateArgument const*>, clang::TemplateArgumentListInfo&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE25TransformTemplateArgumentERKNS_19TemplateArgumentLocERS4_", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformTemplateArgument(clang::TemplateArgumentLoc const&, clang::TemplateArgumentLoc&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE20RebuildPackExpansionENS_19TemplateArgumentLocENS_14SourceLocationEN4llvm8OptionalIjEE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::RebuildPackExpansion(clang::TemplateArgumentLoc, clang::SourceLocation, llvm::Optional<unsigned int>)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE25InventTemplateArgumentLocERKNS_16TemplateArgumentERNS_19TemplateArgumentLocE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::InventTemplateArgumentLoc(clang::TemplateArgument const&, clang::TemplateArgumentLoc&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE23TransformBinaryOperatorEPNS_14BinaryOperatorE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformBinaryOperator(clang::BinaryOperator*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE17TransformCallExprEPNS_8CallExprE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformCallExpr(clang::CallExpr*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE21TransformCompoundStmtEPNS_12CompoundStmtEb", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformCompoundStmt(clang::CompoundStmt*, bool)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE13TransformStmtEPNS_4StmtE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformStmt(clang::Stmt*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE21TransformCXXCatchStmtEPNS_12CXXCatchStmtE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformCXXCatchStmt(clang::CXXCatchStmt*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE14TransformExprsEPPNS_4ExprEjbRN4llvm15SmallVectorImplIS5_EEPb", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformExprs(clang::Expr**, unsigned int, bool, llvm::SmallVectorImpl<clang::Expr*>&, bool*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE26TransformTemplateArgumentsIPKNS_19TemplateArgumentLocEEEbT_S8_RNS_24TemplateArgumentListInfoE", "bool clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformTemplateArguments<clang::TemplateArgumentLoc const*>(clang::TemplateArgumentLoc const*, clang::TemplateArgumentLoc const*, clang::TemplateArgumentListInfo&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE28TransformDeclarationNameInfoERKNS_19DeclarationNameInfoE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformDeclarationNameInfo(clang::DeclarationNameInfo const&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_129CurrentInstantiationRebuilderEE25TransformCXXNamedCastExprEPNS_16CXXNamedCastExprE", "clang::TreeTransform<(anonymous namespace)::CurrentInstantiationRebuilder>::TransformCXXNamedCastExpr(clang::CXXNamedCastExpr*)"},
    {"_Z50CheckNonTypeClassTemplatePartialSpecializationArgsRN5clang4SemaEPNS_23NonTypeTemplateParmDeclEPKNS_16TemplateArgumentEj", "CheckNonTypeClassTemplatePartialSpecializationArgs(clang::Sema&, clang::NonTypeTemplateParmDecl*, clang::TemplateArgument const*, unsigned int)"},
    {"_ZN5clang11TypeVisitorIN12_GLOBAL__N_127UnnamedLocalNoLinkageFinderEbE5VisitEPKNS_4TypeE", "clang::TypeVisitor<(anonymous namespace)::UnnamedLocalNoLinkageFinder, bool>::Visit(clang::Type const*)"},
    {"_ZN12_GLOBAL__N_127UnnamedLocalNoLinkageFinder24VisitNestedNameSpecifierEPN5clang19NestedNameSpecifierE", "(anonymous namespace)::UnnamedLocalNoLinkageFinder::VisitNestedNameSpecifier(clang::NestedNameSpecifier*)"},
    {"_ZN12_GLOBAL__N_127UnnamedLocalNoLinkageFinder12VisitTagDeclEPKN5clang7TagDeclE", "(anonymous namespace)::UnnamedLocalNoLinkageFinder::VisitTagDecl(clang::TagDecl const*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_117DependencyCheckerEE12TraverseTypeENS_8QualTypeE", "clang::RecursiveASTVisitor<(anonymous namespace)::DependencyChecker>::TraverseType(clang::QualType)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_117DependencyCheckerEE27TraverseNestedNameSpecifierEPNS_19NestedNameSpecifierE", "clang::RecursiveASTVisitor<(anonymous namespace)::DependencyChecker>::TraverseNestedNameSpecifier(clang::NestedNameSpecifier*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_117DependencyCheckerEE24TraverseTemplateArgumentERKNS_16TemplateArgumentE", "clang::RecursiveASTVisitor<(anonymous namespace)::DependencyChecker>::TraverseTemplateArgument(clang::TemplateArgument const&)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_117DependencyCheckerEE12TraverseStmtEPNS_4StmtE", "clang::RecursiveASTVisitor<(anonymous namespace)::DependencyChecker>::TraverseStmt(clang::Stmt*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_117DependencyCheckerEE15TraverseTypeLocENS_7TypeLocE", "clang::RecursiveASTVisitor<(anonymous namespace)::DependencyChecker>::TraverseTypeLoc(clang::TypeLoc)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_117DependencyCheckerEE27TraverseTemplateArgumentLocERKNS_19TemplateArgumentLocE", "clang::RecursiveASTVisitor<(anonymous namespace)::DependencyChecker>::TraverseTemplateArgumentLoc(clang::TemplateArgumentLoc const&)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_117DependencyCheckerEE12TraverseDeclEPNS_4DeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::DependencyChecker>::TraverseDecl(clang::Decl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_117DependencyCheckerEE24TraverseDeclaratorHelperEPNS_14DeclaratorDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::DependencyChecker>::TraverseDeclaratorHelper(clang::DeclaratorDecl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_117DependencyCheckerEE22TraverseFunctionHelperEPNS_12FunctionDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::DependencyChecker>::TraverseFunctionHelper(clang::FunctionDecl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_117DependencyCheckerEE23TraverseCXXRecordHelperEPNS_13CXXRecordDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::DependencyChecker>::TraverseCXXRecordHelper(clang::CXXRecordDecl*)"},
    {"_ZN4llvm15SmallVectorImplIN5clang19TemplateArgumentLocEEaSERKS3_", "llvm::SmallVectorImpl<clang::TemplateArgumentLoc>::operator=(llvm::SmallVectorImpl<clang::TemplateArgumentLoc> const&)"},
    {"_ZSt24__uninitialized_copy_auxIPKN5clang19TemplateArgumentLocEPS1_ET0_T_S6_S5_St12__false_type", "clang::TemplateArgumentLoc* std::__uninitialized_copy_aux<clang::TemplateArgumentLoc const*, clang::TemplateArgumentLoc*>(clang::TemplateArgumentLoc const*, clang::TemplateArgumentLoc const*, clang::TemplateArgumentLoc*, std::__false_type)"},
    {"_ZN5clang4Sema23DeduceTemplateArgumentsEPNS_38ClassTemplatePartialSpecializationDeclERKNS_20TemplateArgumentListERNS_4sema21TemplateDeductionInfoE", "clang::Sema::DeduceTemplateArguments(clang::ClassTemplatePartialSpecializationDecl*, clang::TemplateArgumentList const&, clang::sema::TemplateDeductionInfo&)"},
    {"_Z31FinishTemplateArgumentDeductionRN5clang4SemaEPNS_38ClassTemplatePartialSpecializationDeclERKNS_20TemplateArgumentListERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEERNS_4sema21TemplateDeductionInfoE", "FinishTemplateArgumentDeduction(clang::Sema&, clang::ClassTemplatePartialSpecializationDecl*, clang::TemplateArgumentList const&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&, clang::sema::TemplateDeductionInfo&)"},
    {"_ZN5clang4Sema35SubstituteExplicitTemplateArgumentsEPNS_20FunctionTemplateDeclERKNS_24TemplateArgumentListInfoERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEERNS7_INS_8QualTypeEEEPSB_RNS_4sema21TemplateDeductionInfoE", "clang::Sema::SubstituteExplicitTemplateArguments(clang::FunctionTemplateDecl*, clang::TemplateArgumentListInfo const&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&, llvm::SmallVectorImpl<clang::QualType>&, clang::QualType*, clang::sema::TemplateDeductionInfo&)"},
    {"_ZN5clang4Sema31FinishTemplateArgumentDeductionEPNS_20FunctionTemplateDeclERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEEjRPNS_12FunctionDeclERNS_4sema21TemplateDeductionInfoE", "clang::Sema::FinishTemplateArgumentDeduction(clang::FunctionTemplateDecl*, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&, unsigned int, clang::FunctionDecl*&, clang::sema::TemplateDeductionInfo&)"},
    {"_Z30ConvertDeducedTemplateArgumentRN5clang4SemaEPNS_9NamedDeclENS_23DeducedTemplateArgumentES3_NS_8QualTypeEjRNS_4sema21TemplateDeductionInfoEbRN4llvm15SmallVectorImplINS_16TemplateArgumentEEE", "ConvertDeducedTemplateArgument(clang::Sema&, clang::NamedDecl*, clang::DeducedTemplateArgument, clang::NamedDecl*, clang::QualType, unsigned int, clang::sema::TemplateDeductionInfo&, bool, llvm::SmallVectorImpl<clang::TemplateArgument>&)"},
    {"_ZN5clang4Sema23DeduceTemplateArgumentsEPNS_20FunctionTemplateDeclEPKNS_24TemplateArgumentListInfoEPPNS_4ExprEjRPNS_12FunctionDeclERNS_4sema21TemplateDeductionInfoE", "clang::Sema::DeduceTemplateArguments(clang::FunctionTemplateDecl*, clang::TemplateArgumentListInfo const*, clang::Expr**, unsigned int, clang::FunctionDecl*&, clang::sema::TemplateDeductionInfo&)"},
    {"_Z41AdjustFunctionParmAndArgTypesForDeductionRN5clang4SemaEPNS_21TemplateParameterListERNS_8QualTypeES5_PNS_4ExprERj", "AdjustFunctionParmAndArgTypesForDeduction(clang::Sema&, clang::TemplateParameterList*, clang::QualType&, clang::QualType&, clang::Expr*, unsigned int&)"},
    {"_Z23DeduceTemplateArgumentsRN5clang4SemaEPNS_21TemplateParameterListENS_8QualTypeES4_RNS_4sema21TemplateDeductionInfoERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEEjbPNS9_I33RefParamPartialOrderingComparisonEE", "DeduceTemplateArguments(clang::Sema&, clang::TemplateParameterList*, clang::QualType, clang::QualType, clang::sema::TemplateDeductionInfo&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&, unsigned int, bool, llvm::SmallVectorImpl<RefParamPartialOrderingComparison>*)"},
    {"_Z28PrepareArgumentPackDeductionRN5clang4SemaERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEERKNS3_IjEES6_RNS3_INS2_11SmallVectorIS4_Lj4EEEEE", "PrepareArgumentPackDeduction(clang::Sema&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&, llvm::SmallVectorImpl<unsigned int> const&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&, llvm::SmallVectorImpl<llvm::SmallVector<clang::DeducedTemplateArgument, 4u>>&)"},
    {"_Z27FinishArgumentPackDeductionRN5clang4SemaEPNS_21TemplateParameterListEbRN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEERKNS5_IjEES8_RNS5_INS4_11SmallVectorIS6_Lj4EEEEERNS_4sema21TemplateDeductionInfoE", "FinishArgumentPackDeduction(clang::Sema&, clang::TemplateParameterList*, bool, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&, llvm::SmallVectorImpl<unsigned int> const&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&, llvm::SmallVectorImpl<llvm::SmallVector<clang::DeducedTemplateArgument, 4u>>&, clang::sema::TemplateDeductionInfo&)"},
    {"_ZN5clang4Sema23DeduceTemplateArgumentsEPNS_20FunctionTemplateDeclEPKNS_24TemplateArgumentListInfoENS_8QualTypeERPNS_12FunctionDeclERNS_4sema21TemplateDeductionInfoE", "clang::Sema::DeduceTemplateArguments(clang::FunctionTemplateDecl*, clang::TemplateArgumentListInfo const*, clang::QualType, clang::FunctionDecl*&, clang::sema::TemplateDeductionInfo&)"},
    {"_ZN5clang4Sema23DeduceTemplateArgumentsEPNS_20FunctionTemplateDeclENS_8QualTypeERPNS_17CXXConversionDeclERNS_4sema21TemplateDeductionInfoE", "clang::Sema::DeduceTemplateArguments(clang::FunctionTemplateDecl*, clang::QualType, clang::CXXConversionDecl*&, clang::sema::TemplateDeductionInfo&)"},
    {"_ZN5clang4Sema23DeduceTemplateArgumentsEPNS_20FunctionTemplateDeclEPKNS_24TemplateArgumentListInfoERPNS_12FunctionDeclERNS_4sema21TemplateDeductionInfoE", "clang::Sema::DeduceTemplateArguments(clang::FunctionTemplateDecl*, clang::TemplateArgumentListInfo const*, clang::FunctionDecl*&, clang::sema::TemplateDeductionInfo&)"},
    {"_ZN5clang4Sema26getMoreSpecializedTemplateEPNS_20FunctionTemplateDeclES2_NS_14SourceLocationENS_30TemplatePartialOrderingContextEj", "clang::Sema::getMoreSpecializedTemplate(clang::FunctionTemplateDecl*, clang::FunctionTemplateDecl*, clang::SourceLocation, clang::TemplatePartialOrderingContext, unsigned int)"},
    {"_Z24isAtLeastAsSpecializedAsRN5clang4SemaENS_14SourceLocationEPNS_20FunctionTemplateDeclES4_NS_30TemplatePartialOrderingContextEjPN4llvm15SmallVectorImplI33RefParamPartialOrderingComparisonEE", "isAtLeastAsSpecializedAs(clang::Sema&, clang::SourceLocation, clang::FunctionTemplateDecl*, clang::FunctionTemplateDecl*, clang::TemplatePartialOrderingContext, unsigned int, llvm::SmallVectorImpl<RefParamPartialOrderingComparison>*)"},
    {"_ZN5clang4Sema18getMostSpecializedENS_21UnresolvedSetIteratorES1_NS_30TemplatePartialOrderingContextEjNS_14SourceLocationERKNS_17PartialDiagnosticES6_S6_", "clang::Sema::getMostSpecialized(clang::UnresolvedSetIterator, clang::UnresolvedSetIterator, clang::TemplatePartialOrderingContext, unsigned int, clang::SourceLocation, clang::PartialDiagnostic const&, clang::PartialDiagnostic const&, clang::PartialDiagnostic const&)"},
    {"_ZN5clang4Sema39getMoreSpecializedPartialSpecializationEPNS_38ClassTemplatePartialSpecializationDeclES2_NS_14SourceLocationE", "clang::Sema::getMoreSpecializedPartialSpecialization(clang::ClassTemplatePartialSpecializationDecl*, clang::ClassTemplatePartialSpecializationDecl*, clang::SourceLocation)"},
    {"_ZN5clang4Sema26MarkUsedTemplateParametersERKNS_20TemplateArgumentListEbjRN4llvm15SmallVectorImplIbEE", "clang::Sema::MarkUsedTemplateParameters(clang::TemplateArgumentList const&, bool, unsigned int, llvm::SmallVectorImpl<bool>&)"},
    {"_Z26MarkUsedTemplateParametersRN5clang4SemaERKNS_16TemplateArgumentEbjRN4llvm15SmallVectorImplIbEE", "MarkUsedTemplateParameters(clang::Sema&, clang::TemplateArgument const&, bool, unsigned int, llvm::SmallVectorImpl<bool>&)"},
    {"_ZN5clang4Sema29MarkDeducedTemplateParametersEPNS_20FunctionTemplateDeclERN4llvm15SmallVectorImplIbEE", "clang::Sema::MarkDeducedTemplateParameters(clang::FunctionTemplateDecl*, llvm::SmallVectorImpl<bool>&)"},
    {"_Z26MarkUsedTemplateParametersRN5clang4SemaENS_8QualTypeEbjRN4llvm15SmallVectorImplIbEE", "MarkUsedTemplateParameters(clang::Sema&, clang::QualType, bool, unsigned int, llvm::SmallVectorImpl<bool>&)"},
    {"_Z26MarkUsedTemplateParametersRN5clang4SemaENS_12TemplateNameEbjRN4llvm15SmallVectorImplIbEE", "MarkUsedTemplateParameters(clang::Sema&, clang::TemplateName, bool, unsigned int, llvm::SmallVectorImpl<bool>&)"},
    {"_Z26MarkUsedTemplateParametersRN5clang4SemaEPNS_19NestedNameSpecifierEbjRN4llvm15SmallVectorImplIbEE", "MarkUsedTemplateParameters(clang::Sema&, clang::NestedNameSpecifier*, bool, unsigned int, llvm::SmallVectorImpl<bool>&)"},
    {"_Z35MaybeAddImplicitObjectParameterTypeRN5clang10ASTContextEPNS_13CXXMethodDeclERN4llvm15SmallVectorImplINS_8QualTypeEEE", "MaybeAddImplicitObjectParameterType(clang::ASTContext&, clang::CXXMethodDecl*, llvm::SmallVectorImpl<clang::QualType>&)"},
    {"_Z23DeduceTemplateArgumentsRN5clang4SemaEPNS_21TemplateParameterListEPKNS_8QualTypeEjS6_jRNS_4sema21TemplateDeductionInfoERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEEjbPNSB_I33RefParamPartialOrderingComparisonEE", "DeduceTemplateArguments(clang::Sema&, clang::TemplateParameterList*, clang::QualType const*, unsigned int, clang::QualType const*, unsigned int, clang::sema::TemplateDeductionInfo&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&, unsigned int, bool, llvm::SmallVectorImpl<RefParamPartialOrderingComparison>*)"},
    {"_Z29checkDeducedTemplateArgumentsRN5clang10ASTContextERKNS_23DeducedTemplateArgumentES4_", "checkDeducedTemplateArguments(clang::ASTContext&, clang::DeducedTemplateArgument const&, clang::DeducedTemplateArgument const&)"},
    {"_Z20hasSameExtendedValueN4llvm6APSIntES0_", "hasSameExtendedValue(llvm::APSInt, llvm::APSInt)"},
    {"_Z29DeduceNonTypeTemplateArgumentRN5clang4SemaEPNS_23NonTypeTemplateParmDeclEN4llvm6APSIntENS_8QualTypeEbRNS_4sema21TemplateDeductionInfoERNS4_15SmallVectorImplINS_23DeducedTemplateArgumentEEE", "DeduceNonTypeTemplateArgument(clang::Sema&, clang::NonTypeTemplateParmDecl*, llvm::APSInt, clang::QualType, bool, clang::sema::TemplateDeductionInfo&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&)"},
    {"_Z29DeduceNonTypeTemplateArgumentRN5clang4SemaEPNS_23NonTypeTemplateParmDeclEPNS_4ExprERNS_4sema21TemplateDeductionInfoERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEE", "DeduceNonTypeTemplateArgument(clang::Sema&, clang::NonTypeTemplateParmDecl*, clang::Expr*, clang::sema::TemplateDeductionInfo&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&)"},
    {"_Z23DeduceTemplateArgumentsRN5clang4SemaEPNS_21TemplateParameterListEPKNS_26TemplateSpecializationTypeENS_8QualTypeERNS_4sema21TemplateDeductionInfoERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEE", "DeduceTemplateArguments(clang::Sema&, clang::TemplateParameterList*, clang::TemplateSpecializationType const*, clang::QualType, clang::sema::TemplateDeductionInfo&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&)"},
    {"_Z23DeduceTemplateArgumentsRN5clang4SemaEPNS_21TemplateParameterListENS_12TemplateNameES4_RNS_4sema21TemplateDeductionInfoERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEE", "DeduceTemplateArguments(clang::Sema&, clang::TemplateParameterList*, clang::TemplateName, clang::TemplateName, clang::sema::TemplateDeductionInfo&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&)"},
    {"_Z23DeduceTemplateArgumentsRN5clang4SemaEPNS_21TemplateParameterListEPKNS_16TemplateArgumentEjS6_jRNS_4sema21TemplateDeductionInfoERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEEb", "DeduceTemplateArguments(clang::Sema&, clang::TemplateParameterList*, clang::TemplateArgument const*, unsigned int, clang::TemplateArgument const*, unsigned int, clang::sema::TemplateDeductionInfo&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&, bool)"},
    {"_Z23DeduceTemplateArgumentsRN5clang4SemaEPNS_21TemplateParameterListERKNS_16TemplateArgumentES4_RNS_4sema21TemplateDeductionInfoERN4llvm15SmallVectorImplINS_23DeducedTemplateArgumentEEE", "DeduceTemplateArguments(clang::Sema&, clang::TemplateParameterList*, clang::TemplateArgument const&, clang::TemplateArgument, clang::sema::TemplateDeductionInfo&, llvm::SmallVectorImpl<clang::DeducedTemplateArgument>&)"},
    {"_Z17GetTypeOfFunctionRN5clang10ASTContextERKNS_12OverloadExpr10FindResultEPNS_12FunctionDeclE", "GetTypeOfFunction(clang::ASTContext&, clang::OverloadExpr::FindResult const&, clang::FunctionDecl*)"},
    {"_Z17isSameTemplateArgRN5clang10ASTContextERKNS_16TemplateArgumentES4_", "isSameTemplateArg(clang::ASTContext&, clang::TemplateArgument const&, clang::TemplateArgument const&)"},
    {"_ZN4llvm15SmallVectorImplIN5clang23DeducedTemplateArgumentEE6resizeEj", "llvm::SmallVectorImpl<clang::DeducedTemplateArgument>::resize(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIN5clang23DeducedTemplateArgumentEE9push_backERKS2_", "llvm::SmallVectorImpl<clang::DeducedTemplateArgument>::push_back(clang::DeducedTemplateArgument const&)"},
    {"_ZN4llvm15SmallVectorImplISt4pairIN5clang14SourceLocationENS2_17PartialDiagnosticEEE6appendIPKS5_EEvT_SA_", "void llvm::SmallVectorImpl<std::pair<clang::SourceLocation, clang::PartialDiagnostic>>::append<std::pair<clang::SourceLocation, clang::PartialDiagnostic> const*>(std::pair<clang::SourceLocation, clang::PartialDiagnostic> const*, std::pair<clang::SourceLocation, clang::PartialDiagnostic> const*)"},
    {"_ZN4llvm8DenseMapIPN5clang4DeclENS_11SmallVectorISt4pairINS1_14SourceLocationENS1_17PartialDiagnosticEELj1EEENS_12DenseMapInfoIS3_EENSA_IS9_EEE16FindAndConstructERKS3_", "llvm::DenseMap<clang::Decl*, llvm::SmallVector<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, 1u>, llvm::DenseMapInfo<clang::Decl*>, llvm::DenseMapInfo<llvm::SmallVector<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, 1u>>>::FindAndConstruct(clang::Decl* const&)"},
    {"_ZN4llvm8DenseMapIPN5clang4DeclENS_11SmallVectorISt4pairINS1_14SourceLocationENS1_17PartialDiagnosticEELj1EEENS_12DenseMapInfoIS3_EENSA_IS9_EEE16InsertIntoBucketERKS3_RKS9_PS5_IS3_S9_E", "llvm::DenseMap<clang::Decl*, llvm::SmallVector<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, 1u>, llvm::DenseMapInfo<clang::Decl*>, llvm::DenseMapInfo<llvm::SmallVector<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, 1u>>>::InsertIntoBucket(clang::Decl* const&, llvm::SmallVector<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, 1u> const&, std::pair<clang::Decl*, llvm::SmallVector<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, 1u>>*)"},
    {"_ZN4llvm8DenseMapIPN5clang4DeclENS_11SmallVectorISt4pairINS1_14SourceLocationENS1_17PartialDiagnosticEELj1EEENS_12DenseMapInfoIS3_EENSA_IS9_EEE4growEj", "llvm::DenseMap<clang::Decl*, llvm::SmallVector<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, 1u>, llvm::DenseMapInfo<clang::Decl*>, llvm::DenseMapInfo<llvm::SmallVector<std::pair<clang::SourceLocation, clang::PartialDiagnostic>, 1u>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplISt4pairIN5clang14SourceLocationENS2_17PartialDiagnosticEEEaSERKS6_", "llvm::SmallVectorImpl<std::pair<clang::SourceLocation, clang::PartialDiagnostic>>::operator=(llvm::SmallVectorImpl<std::pair<clang::SourceLocation, clang::PartialDiagnostic>> const&)"},
    {"_ZNSt6__copyILb0ESt26random_access_iterator_tagE4copyIPKSt4pairIN5clang14SourceLocationENS4_17PartialDiagnosticEEPS7_EET0_T_SC_SB_", "std::pair<clang::SourceLocation, clang::PartialDiagnostic>* std::__copy<false, std::random_access_iterator_tag>::copy<std::pair<clang::SourceLocation, clang::PartialDiagnostic> const*, std::pair<clang::SourceLocation, clang::PartialDiagnostic>*>(std::pair<clang::SourceLocation, clang::PartialDiagnostic> const*, std::pair<clang::SourceLocation, clang::PartialDiagnostic> const*, std::pair<clang::SourceLocation, clang::PartialDiagnostic>*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang23DeducedTemplateArgumentELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::DeducedTemplateArgument, false>::grow(unsigned long)"},
    {"_ZSt24__uninitialized_copy_auxIPN5clang23DeducedTemplateArgumentES2_ET0_T_S4_S3_St12__false_type", "clang::DeducedTemplateArgument* std::__uninitialized_copy_aux<clang::DeducedTemplateArgument*, clang::DeducedTemplateArgument*>(clang::DeducedTemplateArgument*, clang::DeducedTemplateArgument*, clang::DeducedTemplateArgument*, std::__false_type)"},
    {"_ZN4llvm15SmallVectorImplIN5clang23DeducedTemplateArgumentEE15construct_rangeEPS2_S4_RKS2_", "llvm::SmallVectorImpl<clang::DeducedTemplateArgument>::construct_range(clang::DeducedTemplateArgument*, clang::DeducedTemplateArgument*, clang::DeducedTemplateArgument const&)"},
    {"_ZN4llvm11SmallVectorINS0_IN5clang23DeducedTemplateArgumentELj4EEELj2EEC2EjRKS3_", "llvm::SmallVector<llvm::SmallVector<clang::DeducedTemplateArgument, 4u>, 2u>::SmallVector(unsigned int, llvm::SmallVector<clang::DeducedTemplateArgument, 4u> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_11SmallVectorIN5clang23DeducedTemplateArgumentELj4EEELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::SmallVector<clang::DeducedTemplateArgument, 4u>, false>::grow(unsigned long)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_11SmallVectorIN5clang23DeducedTemplateArgumentELj4EEELb0EE13destroy_rangeEPS4_S6_", "llvm::SmallVectorTemplateBase<llvm::SmallVector<clang::DeducedTemplateArgument, 4u>, false>::destroy_range(llvm::SmallVector<clang::DeducedTemplateArgument, 4u>*, llvm::SmallVector<clang::DeducedTemplateArgument, 4u>*)"},
    {"_ZN4llvm15SmallVectorImplIN5clang23DeducedTemplateArgumentEEaSERKS3_", "llvm::SmallVectorImpl<clang::DeducedTemplateArgument>::operator=(llvm::SmallVectorImpl<clang::DeducedTemplateArgument> const&)"},
    {"_ZSt24__uninitialized_copy_auxIPKN5clang23DeducedTemplateArgumentEPS1_ET0_T_S6_S5_St12__false_type", "clang::DeducedTemplateArgument* std::__uninitialized_copy_aux<clang::DeducedTemplateArgument const*, clang::DeducedTemplateArgument*>(clang::DeducedTemplateArgument const*, clang::DeducedTemplateArgument const*, clang::DeducedTemplateArgument*, std::__false_type)"},
    {"_ZN4llvm15SmallVectorImplIN5clang8QualTypeEE6insertIPKS2_EEPS2_S7_T_S8_", "clang::QualType* llvm::SmallVectorImpl<clang::QualType>::insert<clang::QualType const*>(clang::QualType*, clang::QualType const*, clang::QualType const*)"},
    {"_ZN4llvm15SmallVectorImplIN5clang8QualTypeEE6resizeEj", "llvm::SmallVectorImpl<clang::QualType>::resize(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIN5clang23DeducedTemplateArgumentEE6appendIPKNS1_16TemplateArgumentEEEvT_S8_", "void llvm::SmallVectorImpl<clang::DeducedTemplateArgument>::append<clang::TemplateArgument const*>(clang::TemplateArgument const*, clang::TemplateArgument const*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseI33RefParamPartialOrderingComparisonLb0EE4growEm", "llvm::SmallVectorTemplateBase<RefParamPartialOrderingComparison, false>::grow(unsigned long)"},
    {"_ZN5clang23DeducedTemplateArgumentC2ERKNS_16TemplateArgumentEb", "clang::DeducedTemplateArgument::DeducedTemplateArgument(clang::TemplateArgument const&, bool)"},
    {"_ZN5clang4Sema28getTemplateInstantiationArgsEPNS_9NamedDeclEPKNS_20TemplateArgumentListEbPKNS_12FunctionDeclE", "clang::Sema::getTemplateInstantiationArgs(clang::NamedDecl*, clang::TemplateArgumentList const*, bool, clang::FunctionDecl const*)"},
    {"_ZNK5clang4Sema27ActiveTemplateInstantiation21isInstantiationRecordEv", "clang::Sema::ActiveTemplateInstantiation::isInstantiationRecord() const"},
    {"_ZN5clang4Sema21InstantiatingTemplateC1ERS0_NS_14SourceLocationEPNS_4DeclENS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::Decl*, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC2ERS0_NS_14SourceLocationEPNS_4DeclENS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::Decl*, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplate23CheckInstantiationDepthENS_14SourceLocationENS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::CheckInstantiationDepth(clang::SourceLocation, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC1ERS0_NS_14SourceLocationEPNS_12TemplateDeclEPKNS_16TemplateArgumentEjNS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::TemplateDecl*, clang::TemplateArgument const*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC2ERS0_NS_14SourceLocationEPNS_12TemplateDeclEPKNS_16TemplateArgumentEjNS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::TemplateDecl*, clang::TemplateArgument const*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC1ERS0_NS_14SourceLocationEPNS_20FunctionTemplateDeclEPKNS_16TemplateArgumentEjNS0_27ActiveTemplateInstantiation17InstantiationKindERNS_4sema21TemplateDeductionInfoENS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::FunctionTemplateDecl*, clang::TemplateArgument const*, unsigned int, clang::Sema::ActiveTemplateInstantiation::InstantiationKind, clang::sema::TemplateDeductionInfo&, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC2ERS0_NS_14SourceLocationEPNS_20FunctionTemplateDeclEPKNS_16TemplateArgumentEjNS0_27ActiveTemplateInstantiation17InstantiationKindERNS_4sema21TemplateDeductionInfoENS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::FunctionTemplateDecl*, clang::TemplateArgument const*, unsigned int, clang::Sema::ActiveTemplateInstantiation::InstantiationKind, clang::sema::TemplateDeductionInfo&, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC1ERS0_NS_14SourceLocationEPNS_38ClassTemplatePartialSpecializationDeclEPKNS_16TemplateArgumentEjRNS_4sema21TemplateDeductionInfoENS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::ClassTemplatePartialSpecializationDecl*, clang::TemplateArgument const*, unsigned int, clang::sema::TemplateDeductionInfo&, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC2ERS0_NS_14SourceLocationEPNS_38ClassTemplatePartialSpecializationDeclEPKNS_16TemplateArgumentEjRNS_4sema21TemplateDeductionInfoENS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::ClassTemplatePartialSpecializationDecl*, clang::TemplateArgument const*, unsigned int, clang::sema::TemplateDeductionInfo&, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC1ERS0_NS_14SourceLocationEPNS_11ParmVarDeclEPKNS_16TemplateArgumentEjNS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::ParmVarDecl*, clang::TemplateArgument const*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC2ERS0_NS_14SourceLocationEPNS_11ParmVarDeclEPKNS_16TemplateArgumentEjNS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::ParmVarDecl*, clang::TemplateArgument const*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC1ERS0_NS_14SourceLocationEPNS_9NamedDeclEPNS_23NonTypeTemplateParmDeclEPKNS_16TemplateArgumentEjNS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::NamedDecl*, clang::NonTypeTemplateParmDecl*, clang::TemplateArgument const*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC2ERS0_NS_14SourceLocationEPNS_9NamedDeclEPNS_23NonTypeTemplateParmDeclEPKNS_16TemplateArgumentEjNS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::NamedDecl*, clang::NonTypeTemplateParmDecl*, clang::TemplateArgument const*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC1ERS0_NS_14SourceLocationEPNS_9NamedDeclEPNS_24TemplateTemplateParmDeclEPKNS_16TemplateArgumentEjNS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::NamedDecl*, clang::TemplateTemplateParmDecl*, clang::TemplateArgument const*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC2ERS0_NS_14SourceLocationEPNS_9NamedDeclEPNS_24TemplateTemplateParmDeclEPKNS_16TemplateArgumentEjNS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::NamedDecl*, clang::TemplateTemplateParmDecl*, clang::TemplateArgument const*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC1ERS0_NS_14SourceLocationEPNS_12TemplateDeclEPNS_9NamedDeclEPKNS_16TemplateArgumentEjNS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::TemplateDecl*, clang::NamedDecl*, clang::TemplateArgument const*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplateC2ERS0_NS_14SourceLocationEPNS_12TemplateDeclEPNS_9NamedDeclEPKNS_16TemplateArgumentEjNS_11SourceRangeE", "clang::Sema::InstantiatingTemplate::InstantiatingTemplate(clang::Sema&, clang::SourceLocation, clang::TemplateDecl*, clang::NamedDecl*, clang::TemplateArgument const*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang4Sema21InstantiatingTemplate5ClearEv", "clang::Sema::InstantiatingTemplate::Clear()"},
    {"_ZN5clang4Sema23PrintInstantiationStackEv", "clang::Sema::PrintInstantiationStack()"},
    {"_ZNK5clang4Sema15isSFINAEContextEv", "clang::Sema::isSFINAEContext() const"},
    {"_ZN5clang4Sema9SubstTypeEPNS_14TypeSourceInfoERKNS_30MultiLevelTemplateArgumentListENS_14SourceLocationENS_15DeclarationNameE", "clang::Sema::SubstType(clang::TypeSourceInfo*, clang::MultiLevelTemplateArgumentList const&, clang::SourceLocation, clang::DeclarationName)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE13TransformTypeEPNS_14TypeSourceInfoE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformType(clang::TypeSourceInfo*)"},
    {"_ZN5clang4Sema9SubstTypeENS_7TypeLocERKNS_30MultiLevelTemplateArgumentListENS_14SourceLocationENS_15DeclarationNameE", "clang::Sema::SubstType(clang::TypeLoc, clang::MultiLevelTemplateArgumentList const&, clang::SourceLocation, clang::DeclarationName)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE13TransformTypeERNS_14TypeLocBuilderENS_7TypeLocE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformType(clang::TypeLocBuilder&, clang::TypeLoc)"},
    {"_ZN5clang4Sema9SubstTypeENS_8QualTypeERKNS_30MultiLevelTemplateArgumentListENS_14SourceLocationENS_15DeclarationNameE", "clang::Sema::SubstType(clang::QualType, clang::MultiLevelTemplateArgumentList const&, clang::SourceLocation, clang::DeclarationName)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE13TransformTypeENS_8QualTypeE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformType(clang::QualType)"},
    {"_ZN5clang4Sema21SubstFunctionDeclTypeEPNS_14TypeSourceInfoERKNS_30MultiLevelTemplateArgumentListENS_14SourceLocationENS_15DeclarationNameE", "clang::Sema::SubstFunctionDeclType(clang::TypeSourceInfo*, clang::MultiLevelTemplateArgumentList const&, clang::SourceLocation, clang::DeclarationName)"},
    {"_ZN5clang4Sema16SubstParmVarDeclEPNS_11ParmVarDeclERKNS_30MultiLevelTemplateArgumentListEN4llvm8OptionalIjEE", "clang::Sema::SubstParmVarDecl(clang::ParmVarDecl*, clang::MultiLevelTemplateArgumentList const&, llvm::Optional<unsigned int>)"},
    {"_ZN5clang23LocalInstantiationScope24InstantiatedLocalPackArgEPKNS_4DeclEPS1_", "clang::LocalInstantiationScope::InstantiatedLocalPackArg(clang::Decl const*, clang::Decl*)"},
    {"_ZN5clang23LocalInstantiationScope17InstantiatedLocalEPKNS_4DeclEPS1_", "clang::LocalInstantiationScope::InstantiatedLocal(clang::Decl const*, clang::Decl*)"},
    {"_ZN5clang4Sema14SubstParmTypesENS_14SourceLocationEPPNS_11ParmVarDeclEjRKNS_30MultiLevelTemplateArgumentListERN4llvm15SmallVectorImplINS_8QualTypeEEEPNS9_IS3_EE", "clang::Sema::SubstParmTypes(clang::SourceLocation, clang::ParmVarDecl**, unsigned int, clang::MultiLevelTemplateArgumentList const&, llvm::SmallVectorImpl<clang::QualType>&, llvm::SmallVectorImpl<clang::ParmVarDecl*>*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE27TransformFunctionTypeParamsENS_14SourceLocationEPPNS_11ParmVarDeclEjPKNS_8QualTypeERN4llvm15SmallVectorImplIS8_EEPNSC_IS6_EE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformFunctionTypeParams(clang::SourceLocation, clang::ParmVarDecl**, unsigned int, clang::QualType const*, llvm::SmallVectorImpl<clang::QualType>&, llvm::SmallVectorImpl<clang::ParmVarDecl*>*)"},
    {"_ZN5clang4Sema19SubstBaseSpecifiersEPNS_13CXXRecordDeclES2_RKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::SubstBaseSpecifiers(clang::CXXRecordDecl*, clang::CXXRecordDecl*, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang4Sema16InstantiateClassENS_14SourceLocationEPNS_13CXXRecordDeclES3_RKNS_30MultiLevelTemplateArgumentListENS_26TemplateSpecializationKindEb", "clang::Sema::InstantiateClass(clang::SourceLocation, clang::CXXRecordDecl*, clang::CXXRecordDecl*, clang::MultiLevelTemplateArgumentList const&, clang::TemplateSpecializationKind, bool)"},
    {"_ZN5clang4Sema38InstantiateClassTemplateSpecializationENS_14SourceLocationEPNS_31ClassTemplateSpecializationDeclENS_26TemplateSpecializationKindEb", "clang::Sema::InstantiateClassTemplateSpecialization(clang::SourceLocation, clang::ClassTemplateSpecializationDecl*, clang::TemplateSpecializationKind, bool)"},
    {"_ZN5clang4Sema23InstantiateClassMembersENS_14SourceLocationEPNS_13CXXRecordDeclERKNS_30MultiLevelTemplateArgumentListENS_26TemplateSpecializationKindE", "clang::Sema::InstantiateClassMembers(clang::SourceLocation, clang::CXXRecordDecl*, clang::MultiLevelTemplateArgumentList const&, clang::TemplateSpecializationKind)"},
    {"_ZN5clang4Sema45InstantiateClassTemplateSpecializationMembersENS_14SourceLocationEPNS_31ClassTemplateSpecializationDeclENS_26TemplateSpecializationKindE", "clang::Sema::InstantiateClassTemplateSpecializationMembers(clang::SourceLocation, clang::ClassTemplateSpecializationDecl*, clang::TemplateSpecializationKind)"},
    {"_ZN5clang4Sema9SubstStmtEPNS_4StmtERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::SubstStmt(clang::Stmt*, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE13TransformStmtEPNS_4StmtE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformStmt(clang::Stmt*)"},
    {"_ZN5clang4Sema9SubstExprEPNS_4ExprERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::SubstExpr(clang::Expr*, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE13TransformExprEPNS_4ExprE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformExpr(clang::Expr*)"},
    {"_ZN5clang4Sema10SubstExprsEPPNS_4ExprEjbRKNS_30MultiLevelTemplateArgumentListERN4llvm15SmallVectorImplIS2_EE", "clang::Sema::SubstExprs(clang::Expr**, unsigned int, bool, clang::MultiLevelTemplateArgumentList const&, llvm::SmallVectorImpl<clang::Expr*>&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE14TransformExprsEPPNS_4ExprEjbRN4llvm15SmallVectorImplIS5_EEPb", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformExprs(clang::Expr**, unsigned int, bool, llvm::SmallVectorImpl<clang::Expr*>&, bool*)"},
    {"_ZN5clang4Sema24SubstNestedNameSpecifierEPNS_19NestedNameSpecifierENS_11SourceRangeERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::SubstNestedNameSpecifier(clang::NestedNameSpecifier*, clang::SourceRange, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE28TransformNestedNameSpecifierEPNS_19NestedNameSpecifierENS_11SourceRangeENS_8QualTypeEPNS_9NamedDeclE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformNestedNameSpecifier(clang::NestedNameSpecifier*, clang::SourceRange, clang::QualType, clang::NamedDecl*)"},
    {"_ZN5clang4Sema24SubstDeclarationNameInfoERKNS_19DeclarationNameInfoERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::SubstDeclarationNameInfo(clang::DeclarationNameInfo const&, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE28TransformDeclarationNameInfoERKNS_19DeclarationNameInfoE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformDeclarationNameInfo(clang::DeclarationNameInfo const&)"},
    {"_ZN5clang4Sema17SubstTemplateNameENS_12TemplateNameENS_14SourceLocationERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::SubstTemplateName(clang::TemplateName, clang::SourceLocation, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN12_GLOBAL__N_120TemplateInstantiator21TransformTemplateNameEN5clang12TemplateNameENS1_8QualTypeEPNS1_9NamedDeclE", "(anonymous namespace)::TemplateInstantiator::TransformTemplateName(clang::TemplateName, clang::QualType, clang::NamedDecl*)"},
    {"_ZN5clang4Sema5SubstEPKNS_19TemplateArgumentLocEjRNS_24TemplateArgumentListInfoERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::Subst(clang::TemplateArgumentLoc const*, unsigned int, clang::TemplateArgumentListInfo&, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang23LocalInstantiationScope18getInstantiationOfEPKNS_4DeclE", "clang::LocalInstantiationScope::getInstantiationOf(clang::Decl const*)"},
    {"_ZN5clang23LocalInstantiationScope19findInstantiationOfEPKNS_4DeclE", "clang::LocalInstantiationScope::findInstantiationOf(clang::Decl const*)"},
    {"_ZN5clang23LocalInstantiationScope28MakeInstantiatedLocalArgPackEPKNS_4DeclE", "clang::LocalInstantiationScope::MakeInstantiatedLocalArgPack(clang::Decl const*)"},
    {"_ZN5clang23LocalInstantiationScope27SetPartiallySubstitutedPackEPNS_9NamedDeclEPKNS_16TemplateArgumentEj", "clang::LocalInstantiationScope::SetPartiallySubstitutedPack(clang::NamedDecl*, clang::TemplateArgument const*, unsigned int)"},
    {"_ZNK5clang23LocalInstantiationScope27getPartiallySubstitutedPackEPPKNS_16TemplateArgumentEPj", "clang::LocalInstantiationScope::getPartiallySubstitutedPack(clang::TemplateArgument const**, unsigned int*) const"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE26TransformTemplateArgumentsIPKNS_19TemplateArgumentLocEEEbT_S8_RNS_24TemplateArgumentListInfoE", "bool clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformTemplateArguments<clang::TemplateArgumentLoc const*>(clang::TemplateArgumentLoc const*, clang::TemplateArgumentLoc const*, clang::TemplateArgumentListInfo&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE26TransformTemplateArgumentsINS_33TemplateArgumentLocInventIteratorIS2_PKNS_16TemplateArgumentEEEEEbT_SA_RNS_24TemplateArgumentListInfoE", "bool clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformTemplateArguments<clang::TemplateArgumentLocInventIterator<(anonymous namespace)::TemplateInstantiator, clang::TemplateArgument const*>>(clang::TemplateArgumentLocInventIterator<(anonymous namespace)::TemplateInstantiator, clang::TemplateArgument const*>, clang::TemplateArgumentLocInventIterator<(anonymous namespace)::TemplateInstantiator, clang::TemplateArgument const*>, clang::TemplateArgumentListInfo&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE25TransformTemplateArgumentERKNS_19TemplateArgumentLocERS4_", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformTemplateArgument(clang::TemplateArgumentLoc const&, clang::TemplateArgumentLoc&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE20RebuildPackExpansionENS_19TemplateArgumentLocENS_14SourceLocationEN4llvm8OptionalIjEE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::RebuildPackExpansion(clang::TemplateArgumentLoc, clang::SourceLocation, llvm::Optional<unsigned int>)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE34ForgetPartiallySubstitutedPackRAIIC1ERS2_", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::ForgetPartiallySubstitutedPackRAII::ForgetPartiallySubstitutedPackRAII((anonymous namespace)::TemplateInstantiator&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE34ForgetPartiallySubstitutedPackRAIID1Ev", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::ForgetPartiallySubstitutedPackRAII::~ForgetPartiallySubstitutedPackRAII()"},
    {"_ZN12_GLOBAL__N_120TemplateInstantiator13TransformDeclEN5clang14SourceLocationEPNS1_4DeclE", "(anonymous namespace)::TemplateInstantiator::TransformDecl(clang::SourceLocation, clang::Decl*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE25InventTemplateArgumentLocERKNS_16TemplateArgumentERNS_19TemplateArgumentLocE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::InventTemplateArgumentLoc(clang::TemplateArgument const&, clang::TemplateArgumentLoc&)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE26TransformTypeInObjectScopeEPNS_14TypeSourceInfoENS_8QualTypeEPNS_9NamedDeclEPNS_19NestedNameSpecifierE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformTypeInObjectScope(clang::TypeSourceInfo*, clang::QualType, clang::NamedDecl*, clang::NestedNameSpecifier*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE35TransformTemplateSpecializationTypeERNS_14TypeLocBuilderENS_29TemplateSpecializationTypeLocENS_12TemplateNameE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformTemplateSpecializationType(clang::TypeLocBuilder&, clang::TemplateSpecializationTypeLoc, clang::TemplateName)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE44TransformDependentTemplateSpecializationTypeERNS_14TypeLocBuilderENS_38DependentTemplateSpecializationTypeLocEPNS_19NestedNameSpecifierE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformDependentTemplateSpecializationType(clang::TypeLocBuilder&, clang::DependentTemplateSpecializationTypeLoc, clang::NestedNameSpecifier*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE23TransformBinaryOperatorEPNS_14BinaryOperatorE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformBinaryOperator(clang::BinaryOperator*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE21TransformCompoundStmtEPNS_12CompoundStmtEb", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformCompoundStmt(clang::CompoundStmt*, bool)"},
    {"_ZN12_GLOBAL__N_120TemplateInstantiator28TransformTemplateParmRefExprEPN5clang11DeclRefExprEPNS1_23NonTypeTemplateParmDeclE", "(anonymous namespace)::TemplateInstantiator::TransformTemplateParmRefExpr(clang::DeclRefExpr*, clang::NonTypeTemplateParmDecl*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE20TransformDeclRefExprEPNS_11DeclRefExprE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformDeclRefExpr(clang::DeclRefExpr*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE25TransformCXXNamedCastExprEPNS_16CXXNamedCastExprE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformCXXNamedCastExpr(clang::CXXNamedCastExpr*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE17TransformCallExprEPNS_8CallExprE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformCallExpr(clang::CallExpr*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE21TransformCXXCatchStmtEPNS_12CXXCatchStmtE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformCXXCatchStmt(clang::CXXCatchStmt*)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE26TransformFunctionProtoTypeERNS_14TypeLocBuilderENS_20FunctionProtoTypeLocE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformFunctionProtoType(clang::TypeLocBuilder&, clang::FunctionProtoTypeLoc)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE16RebuildArrayTypeENS_8QualTypeENS_9ArrayType17ArraySizeModifierEPKN4llvm5APIntEPNS_4ExprEjNS_11SourceRangeE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::RebuildArrayType(clang::QualType, clang::ArrayType::ArraySizeModifier, llvm::APInt const*, clang::Expr*, unsigned int, clang::SourceRange)"},
    {"_ZN5clang13TreeTransformIN12_GLOBAL__N_120TemplateInstantiatorEE22TransformReferenceTypeERNS_14TypeLocBuilderENS_16ReferenceTypeLocE", "clang::TreeTransform<(anonymous namespace)::TemplateInstantiator>::TransformReferenceType(clang::TypeLocBuilder&, clang::ReferenceTypeLoc)"},
    {"_ZN5clang14TypeLocBuilder12pushFullCopyENS_7TypeLocE", "clang::TypeLocBuilder::pushFullCopy(clang::TypeLoc)"},
    {"_ZN5clang11DeclVisitorINS_24TemplateDeclInstantiatorEPNS_4DeclEE5VisitES3_", "clang::DeclVisitor<clang::TemplateDeclInstantiator, clang::Decl*>::Visit(clang::Decl*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclENS_12PointerUnionIPS2_PNS_11SmallVectorIS6_Lj4EEEEENS_12DenseMapInfoIS4_EENSB_ISA_EEE16InsertIntoBucketERKS4_RKSA_PSt4pairIS4_SA_E", "llvm::DenseMap<clang::Decl const*, llvm::PointerUnion<clang::Decl*, llvm::SmallVector<clang::Decl*, 4u>*>, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::PointerUnion<clang::Decl*, llvm::SmallVector<clang::Decl*, 4u>*>>>::InsertIntoBucket(clang::Decl const* const&, llvm::PointerUnion<clang::Decl*, llvm::SmallVector<clang::Decl*, 4u>*> const&, std::pair<clang::Decl const*, llvm::PointerUnion<clang::Decl*, llvm::SmallVector<clang::Decl*, 4u>*>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclENS_12PointerUnionIPS2_PNS_11SmallVectorIS6_Lj4EEEEENS_12DenseMapInfoIS4_EENSB_ISA_EEE4growEj", "llvm::DenseMap<clang::Decl const*, llvm::PointerUnion<clang::Decl*, llvm::SmallVector<clang::Decl*, 4u>*>, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::PointerUnion<clang::Decl*, llvm::SmallVector<clang::Decl*, 4u>*>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIN5clang19TemplateArgumentLocEE9push_backERKS2_", "llvm::SmallVectorImpl<clang::TemplateArgumentLoc>::push_back(clang::TemplateArgumentLoc const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang19TemplateArgumentLocELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::TemplateArgumentLoc, false>::grow(unsigned long)"},
    {"_ZSt24__uninitialized_copy_auxIPN5clang19TemplateArgumentLocES2_ET0_T_S4_S3_St12__false_type", "clang::TemplateArgumentLoc* std::__uninitialized_copy_aux<clang::TemplateArgumentLoc*, clang::TemplateArgumentLoc*>(clang::TemplateArgumentLoc*, clang::TemplateArgumentLoc*, clang::TemplateArgumentLoc*, std::__false_type)"},
    {"_ZN5clang19TemplateArgumentLocC2ERKNS_16TemplateArgumentENS_11SourceRangeENS_14SourceLocationES5_", "clang::TemplateArgumentLoc::TemplateArgumentLoc(clang::TemplateArgument const&, clang::SourceRange, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang14TypeLocBuilder8pushImplENS_8QualTypeEm", "clang::TypeLocBuilder::pushImpl(clang::QualType, unsigned long)"},
    {"_ZN5clang4Expr19getValueKindForTypeENS_8QualTypeE", "clang::Expr::getValueKindForType(clang::QualType)"},
    {"_ZN5clang12LookupResultD2Ev", "clang::LookupResult::~LookupResult()"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang4Sema17OffsetOfComponentELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::Sema::OffsetOfComponent, false>::grow(unsigned long)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang10DesignatorELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::Designator, false>::grow(unsigned long)"},
    {"_ZN5clang24TemplateDeclInstantiator9VisitDeclEPNS_4DeclE", "clang::TemplateDeclInstantiator::VisitDecl(clang::Decl*)"},
    {"_ZN4llvm8DenseMapIPN5clang11ParmVarDeclENS_11SmallVectorIS3_Lj1EEENS_12DenseMapInfoIS3_EENS6_IS5_EEE16FindAndConstructERKS3_", "llvm::DenseMap<clang::ParmVarDecl*, llvm::SmallVector<clang::ParmVarDecl*, 1u>, llvm::DenseMapInfo<clang::ParmVarDecl*>, llvm::DenseMapInfo<llvm::SmallVector<clang::ParmVarDecl*, 1u>>>::FindAndConstruct(clang::ParmVarDecl* const&)"},
    {"_ZN4llvm8DenseMapIPN5clang11ParmVarDeclENS_11SmallVectorIS3_Lj1EEENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::ParmVarDecl*, llvm::SmallVector<clang::ParmVarDecl*, 1u>, llvm::DenseMapInfo<clang::ParmVarDecl*>, llvm::DenseMapInfo<llvm::SmallVector<clang::ParmVarDecl*, 1u>>>::InsertIntoBucket(clang::ParmVarDecl* const&, llvm::SmallVector<clang::ParmVarDecl*, 1u> const&, std::pair<clang::ParmVarDecl*, llvm::SmallVector<clang::ParmVarDecl*, 1u>>*)"},
    {"_ZN4llvm8DenseMapIPN5clang11ParmVarDeclENS_11SmallVectorIS3_Lj1EEENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::ParmVarDecl*, llvm::SmallVector<clang::ParmVarDecl*, 1u>, llvm::DenseMapInfo<clang::ParmVarDecl*>, llvm::DenseMapInfo<llvm::SmallVector<clang::ParmVarDecl*, 1u>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang11ParmVarDeclEEaSERKS4_", "llvm::SmallVectorImpl<clang::ParmVarDecl*>::operator=(llvm::SmallVectorImpl<clang::ParmVarDecl*> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang4Sema27ActiveTemplateInstantiationELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::Sema::ActiveTemplateInstantiation, false>::grow(unsigned long)"},
    {"_ZN5clang4sema21TemplateDeductionInfoD2Ev", "clang::sema::TemplateDeductionInfo::~TemplateDeductionInfo()"},
    {"_ZN5clang23LocalInstantiationScope4ExitEv", "clang::LocalInstantiationScope::Exit()"},
    {"_ZN5clang24TemplateDeclInstantiator14SubstQualifierEPKNS_14DeclaratorDeclEPS1_", "clang::TemplateDeclInstantiator::SubstQualifier(clang::DeclaratorDecl const*, clang::DeclaratorDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator14SubstQualifierEPKNS_7TagDeclEPS1_", "clang::TemplateDeclInstantiator::SubstQualifier(clang::TagDecl const*, clang::TagDecl*)"},
    {"_ZN5clang4Sema16InstantiateAttrsERKNS_30MultiLevelTemplateArgumentListEPNS_4DeclES5_", "clang::Sema::InstantiateAttrs(clang::MultiLevelTemplateArgumentList const&, clang::Decl*, clang::Decl*)"},
    {"_ZN5clang24TemplateDeclInstantiator24VisitTranslationUnitDeclEPNS_19TranslationUnitDeclE", "clang::TemplateDeclInstantiator::VisitTranslationUnitDecl(clang::TranslationUnitDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator18VisitNamespaceDeclEPNS_13NamespaceDeclE", "clang::TemplateDeclInstantiator::VisitNamespaceDecl(clang::NamespaceDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator23VisitNamespaceAliasDeclEPNS_18NamespaceAliasDeclE", "clang::TemplateDeclInstantiator::VisitNamespaceAliasDecl(clang::NamespaceAliasDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator16VisitTypedefDeclEPNS_11TypedefDeclE", "clang::TemplateDeclInstantiator::VisitTypedefDecl(clang::TypedefDecl*)"},
    {"_ZN5clang4Sema20FindInstantiatedDeclENS_14SourceLocationEPNS_9NamedDeclERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::FindInstantiatedDecl(clang::SourceLocation, clang::NamedDecl*, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang24TemplateDeclInstantiator12VisitVarDeclEPNS_7VarDeclE", "clang::TemplateDeclInstantiator::VisitVarDecl(clang::VarDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator18VisitCXXRecordDeclEPNS_13CXXRecordDeclE", "clang::TemplateDeclInstantiator::VisitCXXRecordDecl(clang::CXXRecordDecl*)"},
    {"_Z22InstantiateInitializerRN5clang4SemaEPNS_4ExprERKNS_30MultiLevelTemplateArgumentListERNS_14SourceLocationERNS_15ASTOwningVectorIS3_Lj8EEES8_", "InstantiateInitializer(clang::Sema&, clang::Expr*, clang::MultiLevelTemplateArgumentList const&, clang::SourceLocation&, clang::ASTOwningVector<clang::Expr*, 8u>&, clang::SourceLocation&)"},
    {"_ZN5clang24TemplateDeclInstantiator19VisitAccessSpecDeclEPNS_14AccessSpecDeclE", "clang::TemplateDeclInstantiator::VisitAccessSpecDecl(clang::AccessSpecDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator14VisitFieldDeclEPNS_9FieldDeclE", "clang::TemplateDeclInstantiator::VisitFieldDecl(clang::FieldDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator22VisitIndirectFieldDeclEPNS_17IndirectFieldDeclE", "clang::TemplateDeclInstantiator::VisitIndirectFieldDecl(clang::IndirectFieldDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator15VisitFriendDeclEPNS_10FriendDeclE", "clang::TemplateDeclInstantiator::VisitFriendDecl(clang::FriendDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator21VisitStaticAssertDeclEPNS_16StaticAssertDeclE", "clang::TemplateDeclInstantiator::VisitStaticAssertDecl(clang::StaticAssertDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator13VisitEnumDeclEPNS_8EnumDeclE", "clang::TemplateDeclInstantiator::VisitEnumDecl(clang::EnumDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator21VisitEnumConstantDeclEPNS_16EnumConstantDeclE", "clang::TemplateDeclInstantiator::VisitEnumConstantDecl(clang::EnumConstantDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator22VisitClassTemplateDeclEPNS_17ClassTemplateDeclE", "clang::TemplateDeclInstantiator::VisitClassTemplateDecl(clang::ClassTemplateDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator19SubstTemplateParamsEPNS_21TemplateParameterListE", "clang::TemplateDeclInstantiator::SubstTemplateParams(clang::TemplateParameterList*)"},
    {"_ZN5clang4Sema23FindInstantiatedContextENS_14SourceLocationEPNS_11DeclContextERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::FindInstantiatedContext(clang::SourceLocation, clang::DeclContext*, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang24TemplateDeclInstantiator43VisitClassTemplatePartialSpecializationDeclEPNS_38ClassTemplatePartialSpecializationDeclE", "clang::TemplateDeclInstantiator::VisitClassTemplatePartialSpecializationDecl(clang::ClassTemplatePartialSpecializationDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator45InstantiateClassTemplatePartialSpecializationEPNS_17ClassTemplateDeclEPNS_38ClassTemplatePartialSpecializationDeclE", "clang::TemplateDeclInstantiator::InstantiateClassTemplatePartialSpecialization(clang::ClassTemplateDecl*, clang::ClassTemplatePartialSpecializationDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator25VisitFunctionTemplateDeclEPNS_20FunctionTemplateDeclE", "clang::TemplateDeclInstantiator::VisitFunctionTemplateDecl(clang::FunctionTemplateDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator18VisitCXXMethodDeclEPNS_13CXXMethodDeclEPNS_21TemplateParameterListE", "clang::TemplateDeclInstantiator::VisitCXXMethodDecl(clang::CXXMethodDecl*, clang::TemplateParameterList*)"},
    {"_ZN5clang24TemplateDeclInstantiator17VisitFunctionDeclEPNS_12FunctionDeclEPNS_21TemplateParameterListE", "clang::TemplateDeclInstantiator::VisitFunctionDecl(clang::FunctionDecl*, clang::TemplateParameterList*)"},
    {"_ZN5clang24TemplateDeclInstantiator17SubstFunctionTypeEPNS_12FunctionDeclERN4llvm15SmallVectorImplIPNS_11ParmVarDeclEEE", "clang::TemplateDeclInstantiator::SubstFunctionType(clang::FunctionDecl*, llvm::SmallVectorImpl<clang::ParmVarDecl*>&)"},
    {"_ZN5clang24TemplateDeclInstantiator25InitFunctionInstantiationEPNS_12FunctionDeclES2_", "clang::TemplateDeclInstantiator::InitFunctionInstantiation(clang::FunctionDecl*, clang::FunctionDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator23InitMethodInstantiationEPNS_13CXXMethodDeclES2_", "clang::TemplateDeclInstantiator::InitMethodInstantiation(clang::CXXMethodDecl*, clang::CXXMethodDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator23VisitCXXConstructorDeclEPNS_18CXXConstructorDeclE", "clang::TemplateDeclInstantiator::VisitCXXConstructorDecl(clang::CXXConstructorDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator22VisitCXXDestructorDeclEPNS_17CXXDestructorDeclE", "clang::TemplateDeclInstantiator::VisitCXXDestructorDecl(clang::CXXDestructorDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator22VisitCXXConversionDeclEPNS_17CXXConversionDeclE", "clang::TemplateDeclInstantiator::VisitCXXConversionDecl(clang::CXXConversionDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator16VisitParmVarDeclEPNS_11ParmVarDeclE", "clang::TemplateDeclInstantiator::VisitParmVarDecl(clang::ParmVarDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator25VisitTemplateTypeParmDeclEPNS_20TemplateTypeParmDeclE", "clang::TemplateDeclInstantiator::VisitTemplateTypeParmDecl(clang::TemplateTypeParmDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator28VisitNonTypeTemplateParmDeclEPNS_23NonTypeTemplateParmDeclE", "clang::TemplateDeclInstantiator::VisitNonTypeTemplateParmDecl(clang::NonTypeTemplateParmDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator29VisitTemplateTemplateParmDeclEPNS_24TemplateTemplateParmDeclE", "clang::TemplateDeclInstantiator::VisitTemplateTemplateParmDecl(clang::TemplateTemplateParmDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator23VisitUsingDirectiveDeclEPNS_18UsingDirectiveDeclE", "clang::TemplateDeclInstantiator::VisitUsingDirectiveDecl(clang::UsingDirectiveDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator14VisitUsingDeclEPNS_9UsingDeclE", "clang::TemplateDeclInstantiator::VisitUsingDecl(clang::UsingDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator20VisitUsingShadowDeclEPNS_15UsingShadowDeclE", "clang::TemplateDeclInstantiator::VisitUsingShadowDecl(clang::UsingShadowDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator32VisitUnresolvedUsingTypenameDeclEPNS_27UnresolvedUsingTypenameDeclE", "clang::TemplateDeclInstantiator::VisitUnresolvedUsingTypenameDecl(clang::UnresolvedUsingTypenameDecl*)"},
    {"_ZN5clang24TemplateDeclInstantiator29VisitUnresolvedUsingValueDeclEPNS_24UnresolvedUsingValueDeclE", "clang::TemplateDeclInstantiator::VisitUnresolvedUsingValueDecl(clang::UnresolvedUsingValueDecl*)"},
    {"_ZN5clang4Sema9SubstDeclEPNS_4DeclEPNS_11DeclContextERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::SubstDecl(clang::Decl*, clang::DeclContext*, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang4Sema29InstantiateFunctionDefinitionENS_14SourceLocationEPNS_12FunctionDeclEbb", "clang::Sema::InstantiateFunctionDefinition(clang::SourceLocation, clang::FunctionDecl*, bool, bool)"},
    {"_ZN5clang4Sema26InstantiateMemInitializersEPNS_18CXXConstructorDeclEPKS1_RKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::InstantiateMemInitializers(clang::CXXConstructorDecl*, clang::CXXConstructorDecl const*, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang4Sema27PerformDependentDiagnosticsEPKNS_11DeclContextERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::PerformDependentDiagnostics(clang::DeclContext const*, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang4Sema28PerformPendingInstantiationsEb", "clang::Sema::PerformPendingInstantiations(bool)"},
    {"_ZN5clang4Sema37InstantiateStaticDataMemberDefinitionENS_14SourceLocationEPNS_7VarDeclEbb", "clang::Sema::InstantiateStaticDataMemberDefinition(clang::SourceLocation, clang::VarDecl*, bool, bool)"},
    {"_Z17isInstantiationOfRN5clang10ASTContextEPNS_9NamedDeclEPNS_4DeclE", "isInstantiationOf(clang::ASTContext&, clang::NamedDecl*, clang::Decl*)"},
    {"_ZN4llvm15SmallVectorImplISt4pairIPN5clang13CXXRecordDeclENS2_14SourceLocationEEE4swapERS7_", "llvm::SmallVectorImpl<std::pair<clang::CXXRecordDecl*, clang::SourceLocation>>::swap(llvm::SmallVectorImpl<std::pair<clang::CXXRecordDecl*, clang::SourceLocation>>&)"},
    {"_ZN5clang4Sema31DiagnoseUnexpandedParameterPackENS_14SourceLocationEPNS_14TypeSourceInfoENS0_30UnexpandedParameterPackContextE", "clang::Sema::DiagnoseUnexpandedParameterPack(clang::SourceLocation, clang::TypeSourceInfo*, clang::Sema::UnexpandedParameterPackContext)"},
    {"_Z32DiagnoseUnexpandedParameterPacksRN5clang4SemaENS_14SourceLocationENS0_30UnexpandedParameterPackContextERKN4llvm15SmallVectorImplISt4pairINS4_12PointerUnionIPKNS_20TemplateTypeParmTypeEPNS_9NamedDeclEEES2_EEE", "DiagnoseUnexpandedParameterPacks(clang::Sema&, clang::SourceLocation, clang::Sema::UnexpandedParameterPackContext, llvm::SmallVectorImpl<std::pair<llvm::PointerUnion<clang::TemplateTypeParmType const*, clang::NamedDecl*>, clang::SourceLocation>> const&)"},
    {"_ZN5clang4Sema31DiagnoseUnexpandedParameterPackEPNS_4ExprENS0_30UnexpandedParameterPackContextE", "clang::Sema::DiagnoseUnexpandedParameterPack(clang::Expr*, clang::Sema::UnexpandedParameterPackContext)"},
    {"_ZN5clang4Sema31DiagnoseUnexpandedParameterPackERKNS_12CXXScopeSpecENS0_30UnexpandedParameterPackContextE", "clang::Sema::DiagnoseUnexpandedParameterPack(clang::CXXScopeSpec const&, clang::Sema::UnexpandedParameterPackContext)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitorEE27TraverseNestedNameSpecifierEPNS_19NestedNameSpecifierE", "clang::RecursiveASTVisitor<(anonymous namespace)::CollectUnexpandedParameterPacksVisitor>::TraverseNestedNameSpecifier(clang::NestedNameSpecifier*)"},
    {"_ZN5clang4Sema31DiagnoseUnexpandedParameterPackERKNS_19DeclarationNameInfoENS0_30UnexpandedParameterPackContextE", "clang::Sema::DiagnoseUnexpandedParameterPack(clang::DeclarationNameInfo const&, clang::Sema::UnexpandedParameterPackContext)"},
    {"_ZN5clang4Sema31DiagnoseUnexpandedParameterPackENS_14SourceLocationENS_12TemplateNameENS0_30UnexpandedParameterPackContextE", "clang::Sema::DiagnoseUnexpandedParameterPack(clang::SourceLocation, clang::TemplateName, clang::Sema::UnexpandedParameterPackContext)"},
    {"_ZN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitor20TraverseTemplateNameEN5clang12TemplateNameE", "(anonymous namespace)::CollectUnexpandedParameterPacksVisitor::TraverseTemplateName(clang::TemplateName)"},
    {"_ZN5clang4Sema31DiagnoseUnexpandedParameterPackENS_19TemplateArgumentLocENS0_30UnexpandedParameterPackContextE", "clang::Sema::DiagnoseUnexpandedParameterPack(clang::TemplateArgumentLoc, clang::Sema::UnexpandedParameterPackContext)"},
    {"_ZN5clang4Sema31collectUnexpandedParameterPacksENS_16TemplateArgumentERN4llvm15SmallVectorImplISt4pairINS2_12PointerUnionIPKNS_20TemplateTypeParmTypeEPNS_9NamedDeclEEENS_14SourceLocationEEEE", "clang::Sema::collectUnexpandedParameterPacks(clang::TemplateArgument, llvm::SmallVectorImpl<std::pair<llvm::PointerUnion<clang::TemplateTypeParmType const*, clang::NamedDecl*>, clang::SourceLocation>>&)"},
    {"_ZN5clang4Sema31collectUnexpandedParameterPacksENS_19TemplateArgumentLocERN4llvm15SmallVectorImplISt4pairINS2_12PointerUnionIPKNS_20TemplateTypeParmTypeEPNS_9NamedDeclEEENS_14SourceLocationEEEE", "clang::Sema::collectUnexpandedParameterPacks(clang::TemplateArgumentLoc, llvm::SmallVectorImpl<std::pair<llvm::PointerUnion<clang::TemplateTypeParmType const*, clang::NamedDecl*>, clang::SourceLocation>>&)"},
    {"_ZN5clang4Sema31collectUnexpandedParameterPacksENS_8QualTypeERN4llvm15SmallVectorImplISt4pairINS2_12PointerUnionIPKNS_20TemplateTypeParmTypeEPNS_9NamedDeclEEENS_14SourceLocationEEEE", "clang::Sema::collectUnexpandedParameterPacks(clang::QualType, llvm::SmallVectorImpl<std::pair<llvm::PointerUnion<clang::TemplateTypeParmType const*, clang::NamedDecl*>, clang::SourceLocation>>&)"},
    {"_ZN5clang4Sema31collectUnexpandedParameterPacksENS_7TypeLocERN4llvm15SmallVectorImplISt4pairINS2_12PointerUnionIPKNS_20TemplateTypeParmTypeEPNS_9NamedDeclEEENS_14SourceLocationEEEE", "clang::Sema::collectUnexpandedParameterPacks(clang::TypeLoc, llvm::SmallVectorImpl<std::pair<llvm::PointerUnion<clang::TemplateTypeParmType const*, clang::NamedDecl*>, clang::SourceLocation>>&)"},
    {"_ZN5clang4Sema18ActOnPackExpansionERKNS_22ParsedTemplateArgumentENS_14SourceLocationE", "clang::Sema::ActOnPackExpansion(clang::ParsedTemplateArgument const&, clang::SourceLocation)"},
    {"_ZN5clang4Sema18ActOnPackExpansionENS_9OpaquePtrINS_8QualTypeEEENS_14SourceLocationE", "clang::Sema::ActOnPackExpansion(clang::OpaquePtr<clang::QualType>, clang::SourceLocation)"},
    {"_ZN5clang4Sema18ActOnPackExpansionEPNS_4ExprENS_14SourceLocationE", "clang::Sema::ActOnPackExpansion(clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema18CheckPackExpansionEPNS_14TypeSourceInfoENS_14SourceLocationEN4llvm8OptionalIjEE", "clang::Sema::CheckPackExpansion(clang::TypeSourceInfo*, clang::SourceLocation, llvm::Optional<unsigned int>)"},
    {"_ZN5clang4Sema18CheckPackExpansionENS_8QualTypeENS_11SourceRangeENS_14SourceLocationEN4llvm8OptionalIjEE", "clang::Sema::CheckPackExpansion(clang::QualType, clang::SourceRange, clang::SourceLocation, llvm::Optional<unsigned int>)"},
    {"_ZN5clang4Sema18CheckPackExpansionEPNS_4ExprENS_14SourceLocationEN4llvm8OptionalIjEE", "clang::Sema::CheckPackExpansion(clang::Expr*, clang::SourceLocation, llvm::Optional<unsigned int>)"},
    {"_ZN5clang4Sema31CheckParameterPacksForExpansionENS_14SourceLocationENS_11SourceRangeEPKSt4pairIN4llvm12PointerUnionIPKNS_20TemplateTypeParmTypeEPNS_9NamedDeclEEES1_EjRKNS_30MultiLevelTemplateArgumentListERbSI_RNS4_8OptionalIjEE", "clang::Sema::CheckParameterPacksForExpansion(clang::SourceLocation, clang::SourceRange, std::pair<llvm::PointerUnion<clang::TemplateTypeParmType const*, clang::NamedDecl*>, clang::SourceLocation> const*, unsigned int, clang::MultiLevelTemplateArgumentList const&, bool&, bool&, llvm::Optional<unsigned int>&)"},
    {"_ZN5clang4Sema26getNumArgumentsInExpansionENS_8QualTypeERKNS_30MultiLevelTemplateArgumentListE", "clang::Sema::getNumArgumentsInExpansion(clang::QualType, clang::MultiLevelTemplateArgumentList const&)"},
    {"_ZN5clang4Sema32containsUnexpandedParameterPacksERNS_10DeclaratorE", "clang::Sema::containsUnexpandedParameterPacks(clang::Declarator&)"},
    {"_ZN5clang4Sema28ActOnSizeofParameterPackExprEPNS_5ScopeENS_14SourceLocationERNS_14IdentifierInfoES3_S3_", "clang::Sema::ActOnSizeofParameterPackExpr(clang::Scope*, clang::SourceLocation, clang::IdentifierInfo&, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitorEE24TraverseTemplateArgumentERKNS_16TemplateArgumentE", "clang::RecursiveASTVisitor<(anonymous namespace)::CollectUnexpandedParameterPacksVisitor>::TraverseTemplateArgument(clang::TemplateArgument const&)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitorEE27TraverseTemplateArgumentLocERKNS_19TemplateArgumentLocE", "clang::RecursiveASTVisitor<(anonymous namespace)::CollectUnexpandedParameterPacksVisitor>::TraverseTemplateArgumentLoc(clang::TemplateArgumentLoc const&)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitorEE12TraverseTypeENS_8QualTypeE", "clang::RecursiveASTVisitor<(anonymous namespace)::CollectUnexpandedParameterPacksVisitor>::TraverseType(clang::QualType)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitorEE12TraverseStmtEPNS_4StmtE", "clang::RecursiveASTVisitor<(anonymous namespace)::CollectUnexpandedParameterPacksVisitor>::TraverseStmt(clang::Stmt*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitorEE12TraverseDeclEPNS_4DeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::CollectUnexpandedParameterPacksVisitor>::TraverseDecl(clang::Decl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitorEE24TraverseDeclaratorHelperEPNS_14DeclaratorDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::CollectUnexpandedParameterPacksVisitor>::TraverseDeclaratorHelper(clang::DeclaratorDecl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitorEE22TraverseFunctionHelperEPNS_12FunctionDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::CollectUnexpandedParameterPacksVisitor>::TraverseFunctionHelper(clang::FunctionDecl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitorEE23TraverseCXXRecordHelperEPNS_13CXXRecordDeclE", "clang::RecursiveASTVisitor<(anonymous namespace)::CollectUnexpandedParameterPacksVisitor>::TraverseCXXRecordHelper(clang::CXXRecordDecl*)"},
    {"_ZN5clang19RecursiveASTVisitorIN12_GLOBAL__N_138CollectUnexpandedParameterPacksVisitorEE15TraverseTypeLocENS_7TypeLocE", "clang::RecursiveASTVisitor<(anonymous namespace)::CollectUnexpandedParameterPacksVisitor>::TraverseTypeLoc(clang::TypeLoc)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairINS_12PointerUnionIPKN5clang20TemplateTypeParmTypeEPNS3_9NamedDeclEEENS3_14SourceLocationEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<llvm::PointerUnion<clang::TemplateTypeParmType const*, clang::NamedDecl*>, clang::SourceLocation>, false>::grow(unsigned long)"},
    {"_ZN5clang4Sema19adjustParameterTypeENS_8QualTypeE", "clang::Sema::adjustParameterType(clang::QualType)"},
    {"_ZN5clang4Sema18BuildQualifiedTypeENS_8QualTypeENS_14SourceLocationENS_10QualifiersE", "clang::Sema::BuildQualifiedType(clang::QualType, clang::SourceLocation, clang::Qualifiers)"},
    {"_ZN5clang4Sema14BuildParenTypeENS_8QualTypeE", "clang::Sema::BuildParenType(clang::QualType)"},
    {"_ZN5clang4Sema16BuildPointerTypeENS_8QualTypeENS_14SourceLocationENS_15DeclarationNameE", "clang::Sema::BuildPointerType(clang::QualType, clang::SourceLocation, clang::DeclarationName)"},
    {"_ZN5clang4Sema18BuildReferenceTypeENS_8QualTypeEbNS_14SourceLocationENS_15DeclarationNameE", "clang::Sema::BuildReferenceType(clang::QualType, bool, clang::SourceLocation, clang::DeclarationName)"},
    {"_ZN5clang4Sema14BuildArrayTypeENS_8QualTypeENS_9ArrayType17ArraySizeModifierEPNS_4ExprEjNS_11SourceRangeENS_15DeclarationNameE", "clang::Sema::BuildArrayType(clang::QualType, clang::ArrayType::ArraySizeModifier, clang::Expr*, unsigned int, clang::SourceRange, clang::DeclarationName)"},
    {"_ZN5clang4Sema19RequireCompleteTypeENS_14SourceLocationENS_8QualTypeEj", "clang::Sema::RequireCompleteType(clang::SourceLocation, clang::QualType, unsigned int)"},
    {"_ZN5clang4Sema18BuildExtVectorTypeENS_8QualTypeEPNS_4ExprENS_14SourceLocationE", "clang::Sema::BuildExtVectorType(clang::QualType, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema17BuildFunctionTypeENS_8QualTypeEPS1_jbjNS_16RefQualifierKindENS_14SourceLocationENS_15DeclarationNameENS_12FunctionType7ExtInfoE", "clang::Sema::BuildFunctionType(clang::QualType, clang::QualType*, unsigned int, bool, unsigned int, clang::RefQualifierKind, clang::SourceLocation, clang::DeclarationName, clang::FunctionType::ExtInfo)"},
    {"_ZN5clang4Sema22BuildMemberPointerTypeENS_8QualTypeES1_NS_14SourceLocationENS_15DeclarationNameE", "clang::Sema::BuildMemberPointerType(clang::QualType, clang::QualType, clang::SourceLocation, clang::DeclarationName)"},
    {"_ZN5clang4Sema21BuildBlockPointerTypeENS_8QualTypeENS_14SourceLocationENS_15DeclarationNameE", "clang::Sema::BuildBlockPointerType(clang::QualType, clang::SourceLocation, clang::DeclarationName)"},
    {"_ZN5clang4Sema17GetTypeFromParserENS_9OpaquePtrINS_8QualTypeEEEPPNS_14TypeSourceInfoE", "clang::Sema::GetTypeFromParser(clang::OpaquePtr<clang::QualType>, clang::TypeSourceInfo**)"},
    {"_ZN5clang4Sema20GetTypeForDeclaratorERNS_10DeclaratorEPNS_5ScopeEPPNS_7TagDeclE", "clang::Sema::GetTypeForDeclarator(clang::Declarator&, clang::Scope*, clang::TagDecl**)"},
    {"_Z16processTypeAttrsRN12_GLOBAL__N_119TypeProcessingStateERN5clang8QualTypeEbPNS2_13AttributeListE", "processTypeAttrs((anonymous namespace)::TypeProcessingState&, clang::QualType&, bool, clang::AttributeList*)"},
    {"_ZN5clang4Sema30GetTypeSourceInfoForDeclaratorERNS_10DeclaratorENS_8QualTypeEPNS_14TypeSourceInfoE", "clang::Sema::GetTypeSourceInfoForDeclarator(clang::Declarator&, clang::QualType, clang::TypeSourceInfo*)"},
    {"_ZN5clang14TypeLocVisitorIN12_GLOBAL__N_117TypeSpecLocFillerEvE5VisitENS_13UnqualTypeLocE", "clang::TypeLocVisitor<(anonymous namespace)::TypeSpecLocFiller, void>::Visit(clang::UnqualTypeLoc)"},
    {"_ZN5clang4Sema16CreateParsedTypeENS_8QualTypeEPNS_14TypeSourceInfoE", "clang::Sema::CreateParsedType(clang::QualType, clang::TypeSourceInfo*)"},
    {"_ZNK5clang11LocInfoType19getAsStringInternalERSsRKNS_14PrintingPolicyE", "clang::LocInfoType::getAsStringInternal(std::string&, clang::PrintingPolicy const&) const"},
    {"_ZN5clang4Sema13ActOnTypeNameEPNS_5ScopeERNS_10DeclaratorE", "clang::Sema::ActOnTypeName(clang::Scope*, clang::Declarator&)"},
    {"_ZN5clang4Sema19RequireCompleteTypeENS_14SourceLocationENS_8QualTypeERKNS_17PartialDiagnosticESt4pairIS1_S3_E", "clang::Sema::RequireCompleteType(clang::SourceLocation, clang::QualType, clang::PartialDiagnostic const&, std::pair<clang::SourceLocation, clang::PartialDiagnostic>)"},
    {"_ZN5clang4Sema19RequireCompleteTypeENS_14SourceLocationENS_8QualTypeERKNS_17PartialDiagnosticE", "clang::Sema::RequireCompleteType(clang::SourceLocation, clang::QualType, clang::PartialDiagnostic const&)"},
    {"_ZN5clang4Sema17getElaboratedTypeENS_21ElaboratedTypeKeywordERKNS_12CXXScopeSpecENS_8QualTypeE", "clang::Sema::getElaboratedType(clang::ElaboratedTypeKeyword, clang::CXXScopeSpec const&, clang::QualType)"},
    {"_ZN5clang4Sema19BuildTypeofExprTypeEPNS_4ExprENS_14SourceLocationE", "clang::Sema::BuildTypeofExprType(clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang4Sema17BuildDecltypeTypeEPNS_4ExprENS_14SourceLocationE", "clang::Sema::BuildDecltypeType(clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang14TypeLocVisitorIN12_GLOBAL__N_119DeclaratorLocFillerEvE18VisitVectorTypeLocENS_13VectorTypeLocE", "clang::TypeLocVisitor<(anonymous namespace)::DeclaratorLocFiller, void>::VisitVectorTypeLoc(clang::VectorTypeLoc)"},
    {"_ZN5clang14TypeLocVisitorIN12_GLOBAL__N_119DeclaratorLocFillerEvE22VisitObjCObjectTypeLocENS_17ObjCObjectTypeLocE", "clang::TypeLocVisitor<(anonymous namespace)::DeclaratorLocFiller, void>::VisitObjCObjectTypeLoc(clang::ObjCObjectTypeLoc)"},
    {"_ZN12_GLOBAL__N_119DeclaratorLocFiller12VisitTypeLocEN5clang7TypeLocE", "(anonymous namespace)::DeclaratorLocFiller::VisitTypeLoc(clang::TypeLoc)"},
    {"_ZN5clang14TypeLocVisitorIN12_GLOBAL__N_119DeclaratorLocFillerEvE15VisitTagTypeLocENS_10TagTypeLocE", "clang::TypeLocVisitor<(anonymous namespace)::DeclaratorLocFiller, void>::VisitTagTypeLoc(clang::TagTypeLoc)"},
    {"_ZN12_GLOBAL__N_117TypeSpecLocFiller19VisitBuiltinTypeLocEN5clang14BuiltinTypeLocE", "(anonymous namespace)::TypeSpecLocFiller::VisitBuiltinTypeLoc(clang::BuiltinTypeLoc)"},
    {"_ZN12_GLOBAL__N_117TypeSpecLocFiller22VisitElaboratedTypeLocEN5clang17ElaboratedTypeLocE", "(anonymous namespace)::TypeSpecLocFiller::VisitElaboratedTypeLoc(clang::ElaboratedTypeLoc)"},
    {"_ZN12_GLOBAL__N_117TypeSpecLocFiller34VisitTemplateSpecializationTypeLocEN5clang29TemplateSpecializationTypeLocE", "(anonymous namespace)::TypeSpecLocFiller::VisitTemplateSpecializationTypeLoc(clang::TemplateSpecializationTypeLoc)"},
    {"_ZN12_GLOBAL__N_117TypeSpecLocFiller25VisitDependentNameTypeLocEN5clang20DependentNameTypeLocE", "(anonymous namespace)::TypeSpecLocFiller::VisitDependentNameTypeLoc(clang::DependentNameTypeLoc)"},
    {"_ZN12_GLOBAL__N_117TypeSpecLocFiller43VisitDependentTemplateSpecializationTypeLocEN5clang38DependentTemplateSpecializationTypeLocE", "(anonymous namespace)::TypeSpecLocFiller::VisitDependentTemplateSpecializationTypeLoc(clang::DependentTemplateSpecializationTypeLoc)"},
    {"_ZN12_GLOBAL__N_117TypeSpecLocFiller22VisitObjCObjectTypeLocEN5clang17ObjCObjectTypeLocE", "(anonymous namespace)::TypeSpecLocFiller::VisitObjCObjectTypeLoc(clang::ObjCObjectTypeLoc)"},
    {"_ZN5clang14TypeLocVisitorIN12_GLOBAL__N_117TypeSpecLocFillerEvE5VisitENS_7TypeLocE", "clang::TypeLocVisitor<(anonymous namespace)::TypeSpecLocFiller, void>::Visit(clang::TypeLoc)"},
    {"_Z25handleObjCPointerTypeAttrRN12_GLOBAL__N_119TypeProcessingStateERN5clang13AttributeListERNS2_8QualTypeE", "handleObjCPointerTypeAttr((anonymous namespace)::TypeProcessingState&, clang::AttributeList&, clang::QualType&)"},
    {"_Z24HandleNeonVectorTypeAttrRN5clang8QualTypeERKNS_13AttributeListERNS_4SemaENS_10VectorType10VectorKindEPKc", "HandleNeonVectorTypeAttr(clang::QualType&, clang::AttributeList const&, clang::Sema&, clang::VectorType::VectorKind, char const*)"},
    {"_Z22handleFunctionTypeAttrRN12_GLOBAL__N_119TypeProcessingStateERN5clang13AttributeListERNS2_8QualTypeE", "handleFunctionTypeAttr((anonymous namespace)::TypeProcessingState&, clang::AttributeList&, clang::QualType&)"},
    {"_ZN12_GLOBAL__N_121FunctionTypeUnwrapper4wrapERN5clang10ASTContextENS1_8QualTypeEj", "(anonymous namespace)::FunctionTypeUnwrapper::wrap(clang::ASTContext&, clang::QualType, unsigned int)"},
    {"_ZN12_GLOBAL__N_121FunctionTypeUnwrapper4wrapERN5clang10ASTContextEPKNS1_4TypeEj", "(anonymous namespace)::FunctionTypeUnwrapper::wrap(clang::ASTContext&, clang::Type const*, unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIN5clang15DeclaratorChunkEE6insertEPS2_RKS2_", "llvm::SmallVectorImpl<clang::DeclaratorChunk>::insert(clang::DeclaratorChunk*, clang::DeclaratorChunk const&)"},
    {"_ZN5clang20TargetAttributesSemaD0Ev", "clang::TargetAttributesSema::~TargetAttributesSema()"},
    {"_ZN5clang20TargetAttributesSemaD1Ev", "clang::TargetAttributesSema::~TargetAttributesSema()"},
    {"_ZN5clang20TargetAttributesSemaD2Ev", "clang::TargetAttributesSema::~TargetAttributesSema()"},
    {"_ZNK5clang20TargetAttributesSema20ProcessDeclAttributeEPNS_5ScopeEPNS_4DeclERKNS_13AttributeListERNS_4SemaE", "clang::TargetAttributesSema::ProcessDeclAttribute(clang::Scope*, clang::Decl*, clang::AttributeList const&, clang::Sema&) const"},
    {"_ZNK5clang4Sema23getTargetAttributesSemaEv", "clang::Sema::getTargetAttributesSema() const"},
    {"_ZN12_GLOBAL__N_117X86AttributesSemaD1Ev", "(anonymous namespace)::X86AttributesSema::~X86AttributesSema()"},
    {"_ZN12_GLOBAL__N_117X86AttributesSemaD0Ev", "(anonymous namespace)::X86AttributesSema::~X86AttributesSema()"},
    {"_ZNK12_GLOBAL__N_117X86AttributesSema20ProcessDeclAttributeEPN5clang5ScopeEPNS1_4DeclERKNS1_13AttributeListERNS1_4SemaE", "(anonymous namespace)::X86AttributesSema::ProcessDeclAttribute(clang::Scope*, clang::Decl*, clang::AttributeList const&, clang::Sema&) const"},
    {"_ZN12_GLOBAL__N_120MBlazeAttributesSemaD1Ev", "(anonymous namespace)::MBlazeAttributesSema::~MBlazeAttributesSema()"},
    {"_ZN12_GLOBAL__N_120MBlazeAttributesSemaD0Ev", "(anonymous namespace)::MBlazeAttributesSema::~MBlazeAttributesSema()"},
    {"_ZNK12_GLOBAL__N_120MBlazeAttributesSema20ProcessDeclAttributeEPN5clang5ScopeEPNS1_4DeclERKNS1_13AttributeListERNS1_4SemaE", "(anonymous namespace)::MBlazeAttributesSema::ProcessDeclAttribute(clang::Scope*, clang::Decl*, clang::AttributeList const&, clang::Sema&) const"},
    {"_ZN12_GLOBAL__N_120MSP430AttributesSemaD1Ev", "(anonymous namespace)::MSP430AttributesSema::~MSP430AttributesSema()"},
    {"_ZN12_GLOBAL__N_120MSP430AttributesSemaD0Ev", "(anonymous namespace)::MSP430AttributesSema::~MSP430AttributesSema()"},
    {"_ZNK12_GLOBAL__N_120MSP430AttributesSema20ProcessDeclAttributeEPN5clang5ScopeEPNS1_4DeclERKNS1_13AttributeListERNS1_4SemaE", "(anonymous namespace)::MSP430AttributesSema::ProcessDeclAttribute(clang::Scope*, clang::Decl*, clang::AttributeList const&, clang::Sema&) const"},
    {"_ZN5clang4ento34RegisterAdjustedReturnValueCheckerERNS0_10ExprEngineE", "clang::ento::RegisterAdjustedReturnValueChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_126AdjustedReturnValueCheckerD1Ev", "(anonymous namespace)::AdjustedReturnValueChecker::~AdjustedReturnValueChecker()"},
    {"_ZN12_GLOBAL__N_126AdjustedReturnValueCheckerD0Ev", "(anonymous namespace)::AdjustedReturnValueChecker::~AdjustedReturnValueChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126AdjustedReturnValueCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::AdjustedReturnValueChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126AdjustedReturnValueCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::AdjustedReturnValueChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126AdjustedReturnValueCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::AdjustedReturnValueChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126AdjustedReturnValueCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::AdjustedReturnValueChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento22CreateAnalysisConsumerERKNS_12PreprocessorERKSsRKNS_15AnalyzerOptionsE", "clang::ento::CreateAnalysisConsumer(clang::Preprocessor const&, std::string const&, clang::AnalyzerOptions const&)"},
    {"_Z13ActionCFGDumpRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionCFGDump((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z13ActionCFGViewRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionCFGView((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z26ActionDisplayLiveVariablesRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionDisplayLiveVariables((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z29ActionSecuritySyntacticChecksRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionSecuritySyntacticChecks((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z27ActionLLVMConventionCheckerRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerERNS2_19TranslationUnitDeclE", "ActionLLVMConventionChecker((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::TranslationUnitDecl&)"},
    {"_Z20ActionWarnDeadStoresRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionWarnDeadStores((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z20ActionWarnUninitValsRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionWarnUninitVals((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z22ActionWarnObjCMethSigsRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionWarnObjCMethSigs((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z21ActionWarnObjCDeallocRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionWarnObjCDealloc((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z25ActionWarnObjCUnusedIvarsRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionWarnObjCUnusedIvars((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z20ActionObjCMemCheckerRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionObjCMemChecker((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z23ActionWarnSizeofPointerRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclE", "ActionWarnSizeofPointer((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)"},
    {"_Z23ActionObjCMemCheckerAuxRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS2_4DeclEb", "ActionObjCMemCheckerAux((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*, bool)"},
    {"_ZN12_GLOBAL__N_111UbigraphVizD1Ev", "(anonymous namespace)::UbigraphViz::~UbigraphViz()"},
    {"_ZN12_GLOBAL__N_111UbigraphVizD0Ev", "(anonymous namespace)::UbigraphViz::~UbigraphViz()"},
    {"_ZN12_GLOBAL__N_111UbigraphViz7AddEdgeEPN5clang4ento12ExplodedNodeES4_", "(anonymous namespace)::UbigraphViz::AddEdge(clang::ento::ExplodedNode*, clang::ento::ExplodedNode*)"},
    {"_ZNSt6vectorIPFvRN12_GLOBAL__N_116AnalysisConsumerERN5clang4ento15AnalysisManagerEPNS3_4DeclEESaISA_EE9push_backERKSA_", "std::vector<void (*)((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*), std::allocator<void (*)((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)>>::push_back(void (* const&)((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*))"},
    {"_ZN12_GLOBAL__N_116AnalysisConsumerD1Ev", "(anonymous namespace)::AnalysisConsumer::~AnalysisConsumer()"},
    {"_ZN12_GLOBAL__N_116AnalysisConsumerD0Ev", "(anonymous namespace)::AnalysisConsumer::~AnalysisConsumer()"},
    {"_ZN12_GLOBAL__N_116AnalysisConsumer10InitializeERN5clang10ASTContextE", "(anonymous namespace)::AnalysisConsumer::Initialize(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_116AnalysisConsumer21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::AnalysisConsumer::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_116AnalysisConsumer17HandleDeclContextERN5clang10ASTContextEPNS1_11DeclContextE", "(anonymous namespace)::AnalysisConsumer::HandleDeclContext(clang::ASTContext&, clang::DeclContext*)"},
    {"_ZN12_GLOBAL__N_116AnalysisConsumer15DisplayFunctionEPKN5clang4DeclE", "(anonymous namespace)::AnalysisConsumer::DisplayFunction(clang::Decl const*)"},
    {"_ZN12_GLOBAL__N_116AnalysisConsumer10HandleCodeEPN5clang4DeclERSt6vectorIPFvRS0_RNS1_4ento15AnalysisManagerES3_ESaISA_EE", "(anonymous namespace)::AnalysisConsumer::HandleCode(clang::Decl*, std::vector<void (*)((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*), std::allocator<void (*)((anonymous namespace)::AnalysisConsumer&, clang::ento::AnalysisManager&, clang::Decl*)>>&)"},
    {"_Z10FindBlocksPN5clang11DeclContextERN4llvm15SmallVectorImplIPNS_4DeclEEE", "FindBlocks(clang::DeclContext*, llvm::SmallVectorImpl<clang::Decl*>&)"},
    {"_ZN5clang4ento11BugReporter22GeneratePathDiagnosticERNS0_14PathDiagnosticERN4llvm15SmallVectorImplIPNS0_9BugReportEEE", "clang::ento::BugReporter::GeneratePathDiagnostic(clang::ento::PathDiagnostic&, llvm::SmallVectorImpl<clang::ento::BugReport*>&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEEC2Ev", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::BugType*>>::ImutAVLFactory()"},
    {"_ZN4llvm8DenseMapIPvjNS_12DenseMapInfoIS1_EENS2_IjEEE16InsertIntoBucketERKS1_RKjPSt4pairIS1_jE", "llvm::DenseMap<void*, unsigned int, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(void* const&, unsigned int const&, std::pair<void*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPvjNS_12DenseMapInfoIS1_EENS2_IjEEE4growEj", "llvm::DenseMap<void*, unsigned int, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN5clang4ento15AnalysisManagerD1Ev", "clang::ento::AnalysisManager::~AnalysisManager()"},
    {"_ZN5clang4ento15AnalysisManagerD0Ev", "clang::ento::AnalysisManager::~AnalysisManager()"},
    {"_ZN5clang4ento15AnalysisManager13getDiagnosticEv", "clang::ento::AnalysisManager::getDiagnostic()"},
    {"_ZN5clang4ento15AnalysisManager23getPathDiagnosticClientEv", "clang::ento::AnalysisManager::getPathDiagnosticClient()"},
    {"_ZN5clang4ento15AnalysisManager13getASTContextEv", "clang::ento::AnalysisManager::getASTContext()"},
    {"_ZN5clang4ento15AnalysisManager16getSourceManagerEv", "clang::ento::AnalysisManager::getSourceManager()"},
    {"_ZN5clang4ento15AnalysisManagerD2Ev", "clang::ento::AnalysisManager::~AnalysisManager()"},
    {"_ZN4llvm10FoldingSetIN5clang15LocationContextEED1Ev", "llvm::FoldingSet<clang::LocationContext>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang15LocationContextEED0Ev", "llvm::FoldingSet<clang::LocationContext>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang15LocationContextEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::LocationContext>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang15LocationContextEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::LocationContext>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang15LocationContextEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::LocationContext>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento28RegisterAnalyzerStatsCheckerERNS0_10ExprEngineE", "clang::ento::RegisterAnalyzerStatsChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_120AnalyzerStatsCheckerD1Ev", "(anonymous namespace)::AnalyzerStatsChecker::~AnalyzerStatsChecker()"},
    {"_ZN12_GLOBAL__N_120AnalyzerStatsCheckerD0Ev", "(anonymous namespace)::AnalyzerStatsChecker::~AnalyzerStatsChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120AnalyzerStatsCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::AnalyzerStatsChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120AnalyzerStatsCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::AnalyzerStatsChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_120AnalyzerStatsChecker16VisitEndAnalysisERN5clang4ento13ExplodedGraphERNS2_11BugReporterERNS2_10ExprEngineE", "(anonymous namespace)::AnalyzerStatsChecker::VisitEndAnalysis(clang::ento::ExplodedGraph&, clang::ento::BugReporter&, clang::ento::ExprEngine&)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120AnalyzerStatsCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::AnalyzerStatsChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120AnalyzerStatsCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::AnalyzerStatsChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento25RegisterArrayBoundCheckerERNS0_10ExprEngineE", "clang::ento::RegisterArrayBoundChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_117ArrayBoundCheckerD1Ev", "(anonymous namespace)::ArrayBoundChecker::~ArrayBoundChecker()"},
    {"_ZN12_GLOBAL__N_117ArrayBoundCheckerD0Ev", "(anonymous namespace)::ArrayBoundChecker::~ArrayBoundChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117ArrayBoundCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ArrayBoundChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117ArrayBoundCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ArrayBoundChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_117ArrayBoundChecker13visitLocationERN5clang4ento14CheckerContextEPKNS1_4StmtENS2_4SValEb", "(anonymous namespace)::ArrayBoundChecker::visitLocation(clang::ento::CheckerContext&, clang::Stmt const*, clang::ento::SVal, bool)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117ArrayBoundCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ArrayBoundChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117ArrayBoundCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ArrayBoundChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento27RegisterArrayBoundCheckerV2ERNS0_10ExprEngineE", "clang::ento::RegisterArrayBoundCheckerV2(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_119ArrayBoundCheckerV2D1Ev", "(anonymous namespace)::ArrayBoundCheckerV2::~ArrayBoundCheckerV2()"},
    {"_ZN12_GLOBAL__N_119ArrayBoundCheckerV2D0Ev", "(anonymous namespace)::ArrayBoundCheckerV2::~ArrayBoundCheckerV2()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ArrayBoundCheckerV2EE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ArrayBoundCheckerV2>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ArrayBoundCheckerV2EE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ArrayBoundCheckerV2>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_119ArrayBoundCheckerV213visitLocationERN5clang4ento14CheckerContextEPKNS1_4StmtENS2_4SValEb", "(anonymous namespace)::ArrayBoundCheckerV2::visitLocation(clang::ento::CheckerContext&, clang::Stmt const*, clang::ento::SVal, bool)"},
    {"_ZN12_GLOBAL__N_119ArrayBoundCheckerV29reportOOBERN5clang4ento14CheckerContextEPKNS2_7GRStateENS0_8OOB_KindE", "(anonymous namespace)::ArrayBoundCheckerV2::reportOOB(clang::ento::CheckerContext&, clang::ento::GRState const*, (anonymous namespace)::ArrayBoundCheckerV2::OOB_Kind)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ArrayBoundCheckerV2EED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ArrayBoundCheckerV2>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ArrayBoundCheckerV2EED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ArrayBoundCheckerV2>::~CheckerVisitor()"},
    {"_ZN5clang4ento10BuiltinBugC2EPKc", "clang::ento::BuiltinBug::BuiltinBug(char const*)"},
    {"_ZN5clang4ento10BuiltinBugD1Ev", "clang::ento::BuiltinBug::~BuiltinBug()"},
    {"_ZN5clang4ento10BuiltinBugD0Ev", "clang::ento::BuiltinBug::~BuiltinBug()"},
    {"_ZN5clang4ento26RegisterAttrNonNullCheckerERNS0_10ExprEngineE", "clang::ento::RegisterAttrNonNullChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_118AttrNonNullCheckerD1Ev", "(anonymous namespace)::AttrNonNullChecker::~AttrNonNullChecker()"},
    {"_ZN12_GLOBAL__N_118AttrNonNullCheckerD0Ev", "(anonymous namespace)::AttrNonNullChecker::~AttrNonNullChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118AttrNonNullCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::AttrNonNullChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118AttrNonNullCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::AttrNonNullChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118AttrNonNullCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::AttrNonNullChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118AttrNonNullCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::AttrNonNullChecker>::~CheckerVisitor()"},
    {"_ZNK5clang4Decl7getAttrINS_11NonNullAttrEEEPT_v", "clang::NonNullAttr* clang::Decl::getAttr<clang::NonNullAttr>() const"},
    {"_ZN5clang4ento19RegisterAppleChecksERNS0_10ExprEngineERKNS_4DeclE", "clang::ento::RegisterAppleChecks(clang::ento::ExprEngine&, clang::Decl const&)"},
    {"_ZN12_GLOBAL__N_119ClassReleaseCheckerD1Ev", "(anonymous namespace)::ClassReleaseChecker::~ClassReleaseChecker()"},
    {"_ZN12_GLOBAL__N_119ClassReleaseCheckerD0Ev", "(anonymous namespace)::ClassReleaseChecker::~ClassReleaseChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ClassReleaseCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ClassReleaseChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ClassReleaseCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ClassReleaseChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_119ClassReleaseChecker19preVisitObjCMessageERN5clang4ento14CheckerContextENS2_11ObjCMessageE", "(anonymous namespace)::ClassReleaseChecker::preVisitObjCMessage(clang::ento::CheckerContext&, clang::ento::ObjCMessage)"},
    {"_ZN12_GLOBAL__N_19APIMisuseD1Ev", "(anonymous namespace)::APIMisuse::~APIMisuse()"},
    {"_ZN12_GLOBAL__N_19APIMisuseD0Ev", "(anonymous namespace)::APIMisuse::~APIMisuse()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ClassReleaseCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ClassReleaseChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ClassReleaseCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ClassReleaseChecker>::~CheckerVisitor()"},
    {"_ZN12_GLOBAL__N_122CFRetainReleaseCheckerD1Ev", "(anonymous namespace)::CFRetainReleaseChecker::~CFRetainReleaseChecker()"},
    {"_ZN12_GLOBAL__N_122CFRetainReleaseCheckerD0Ev", "(anonymous namespace)::CFRetainReleaseChecker::~CFRetainReleaseChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_122CFRetainReleaseCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CFRetainReleaseChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_122CFRetainReleaseCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CFRetainReleaseChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_122CFRetainReleaseCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CFRetainReleaseChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_122CFRetainReleaseCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CFRetainReleaseChecker>::~CheckerVisitor()"},
    {"_ZN12_GLOBAL__N_121CFNumberCreateCheckerD1Ev", "(anonymous namespace)::CFNumberCreateChecker::~CFNumberCreateChecker()"},
    {"_ZN12_GLOBAL__N_121CFNumberCreateCheckerD0Ev", "(anonymous namespace)::CFNumberCreateChecker::~CFNumberCreateChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_121CFNumberCreateCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CFNumberCreateChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_121CFNumberCreateCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CFNumberCreateChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_121CFNumberCreateCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CFNumberCreateChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_121CFNumberCreateCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CFNumberCreateChecker>::~CheckerVisitor()"},
    {"_ZN12_GLOBAL__N_113NilArgCheckerD1Ev", "(anonymous namespace)::NilArgChecker::~NilArgChecker()"},
    {"_ZN12_GLOBAL__N_113NilArgCheckerD0Ev", "(anonymous namespace)::NilArgChecker::~NilArgChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113NilArgCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::NilArgChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113NilArgCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::NilArgChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_113NilArgChecker19preVisitObjCMessageERN5clang4ento14CheckerContextENS2_11ObjCMessageE", "(anonymous namespace)::NilArgChecker::preVisitObjCMessage(clang::ento::CheckerContext&, clang::ento::ObjCMessage)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113NilArgCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::NilArgChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113NilArgCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::NilArgChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerContext12generateNodeEb", "clang::ento::CheckerContext::generateNode(bool)"},
    {"_ZN5clang4ento30RegisterBuiltinFunctionCheckerERNS0_10ExprEngineE", "clang::ento::RegisterBuiltinFunctionChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_122BuiltinFunctionCheckerD1Ev", "(anonymous namespace)::BuiltinFunctionChecker::~BuiltinFunctionChecker()"},
    {"_ZN12_GLOBAL__N_122BuiltinFunctionCheckerD0Ev", "(anonymous namespace)::BuiltinFunctionChecker::~BuiltinFunctionChecker()"},
    {"_ZN12_GLOBAL__N_122BuiltinFunctionChecker12evalCallExprERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::BuiltinFunctionChecker::evalCallExpr(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN5clang4ento22RegisterCStringCheckerERNS0_10ExprEngineE", "clang::ento::RegisterCStringChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_114CStringCheckerD1Ev", "(anonymous namespace)::CStringChecker::~CStringChecker()"},
    {"_ZN12_GLOBAL__N_114CStringCheckerD0Ev", "(anonymous namespace)::CStringChecker::~CStringChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114CStringCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CStringChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114CStringCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CStringChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker15evalDeadSymbolsERN5clang4ento14CheckerContextERNS2_12SymbolReaperE", "(anonymous namespace)::CStringChecker::evalDeadSymbols(clang::ento::CheckerContext&, clang::ento::SymbolReaper&)"},
    {"_ZN12_GLOBAL__N_114CStringChecker15MarkLiveSymbolsEPKN5clang4ento7GRStateERNS2_12SymbolReaperE", "(anonymous namespace)::CStringChecker::MarkLiveSymbols(clang::ento::GRState const*, clang::ento::SymbolReaper&)"},
    {"_ZN12_GLOBAL__N_114CStringChecker12evalCallExprERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::CStringChecker::evalCallExpr(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker23wantsRegionChangeUpdateEPKN5clang4ento7GRStateE", "(anonymous namespace)::CStringChecker::wantsRegionChangeUpdate(clang::ento::GRState const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker17EvalRegionChangesEPKN5clang4ento7GRStateEPKPKNS2_9MemRegionESA_Pb", "(anonymous namespace)::CStringChecker::EvalRegionChanges(clang::ento::GRState const*, clang::ento::MemRegion const* const*, clang::ento::MemRegion const* const*, bool*)"},
    {"_ZNK5clang4ento7GRState3setIN12_GLOBAL__N_113CStringLengthEEEPKS1_NS0_12GRStateTraitIT_E9data_typeE", "clang::ento::GRState const* clang::ento::GRState::set<(anonymous namespace)::CStringLength>(clang::ento::GRStateTrait<(anonymous namespace)::CStringLength>::data_type) const"},
    {"_ZN12_GLOBAL__N_114CStringChecker10evalMemcpyERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::CStringChecker::evalMemcpy(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker10evalMemcmpERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::CStringChecker::evalMemcmp(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker11evalMemmoveERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::CStringChecker::evalMemmove(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker10evalStrcpyERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::CStringChecker::evalStrcpy(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker10evalStpcpyERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::CStringChecker::evalStpcpy(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker13evalstrLengthERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::CStringChecker::evalstrLength(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker9evalBcopyERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::CStringChecker::evalBcopy(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker14evalCopyCommonERN5clang4ento14CheckerContextEPKNS2_7GRStateEPKNS1_4ExprESA_SA_b", "(anonymous namespace)::CStringChecker::evalCopyCommon(clang::ento::CheckerContext&, clang::ento::GRState const*, clang::Expr const*, clang::Expr const*, clang::Expr const*, bool)"},
    {"_ZN12_GLOBAL__N_114CStringChecker10assumeZeroERN5clang4ento14CheckerContextEPKNS2_7GRStateENS2_4SValENS1_8QualTypeE", "(anonymous namespace)::CStringChecker::assumeZero(clang::ento::CheckerContext&, clang::ento::GRState const*, clang::ento::SVal, clang::QualType)"},
    {"_ZN12_GLOBAL__N_114CStringChecker17CheckBufferAccessERN5clang4ento14CheckerContextEPKNS2_7GRStateEPKNS1_4ExprESA_SA_b", "(anonymous namespace)::CStringChecker::CheckBufferAccess(clang::ento::CheckerContext&, clang::ento::GRState const*, clang::Expr const*, clang::Expr const*, clang::Expr const*, bool)"},
    {"_ZN12_GLOBAL__N_114CStringChecker16InvalidateBufferERN5clang4ento14CheckerContextEPKNS2_7GRStateEPKNS1_4ExprENS2_4SValE", "(anonymous namespace)::CStringChecker::InvalidateBuffer(clang::ento::CheckerContext&, clang::ento::GRState const*, clang::Expr const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_114CStringChecker14emitOverlapBugERN5clang4ento14CheckerContextEPKNS2_7GRStateEPKNS1_4StmtESA_", "(anonymous namespace)::CStringChecker::emitOverlapBug(clang::ento::CheckerContext&, clang::ento::GRState const*, clang::Stmt const*, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_114CStringChecker12checkNonNullERN5clang4ento14CheckerContextEPKNS2_7GRStateEPKNS1_4ExprENS2_4SValE", "(anonymous namespace)::CStringChecker::checkNonNull(clang::ento::CheckerContext&, clang::ento::GRState const*, clang::Expr const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_114CStringChecker13CheckLocationERN5clang4ento14CheckerContextEPKNS2_7GRStateEPKNS1_4ExprENS2_4SValEb", "(anonymous namespace)::CStringChecker::CheckLocation(clang::ento::CheckerContext&, clang::ento::GRState const*, clang::Expr const*, clang::ento::SVal, bool)"},
    {"_ZN12_GLOBAL__N_114CStringChecker16getCStringLengthERN5clang4ento14CheckerContextERPKNS2_7GRStateEPKNS1_4ExprENS2_4SValE", "(anonymous namespace)::CStringChecker::getCStringLength(clang::ento::CheckerContext&, clang::ento::GRState const*&, clang::Expr const*, clang::ento::SVal)"},
    {"_ZNK5clang4ento7GRState3setIN12_GLOBAL__N_113CStringLengthEEEPKS1_NS0_12GRStateTraitIT_E8key_typeENS9_10value_typeE", "clang::ento::GRState const* clang::ento::GRState::set<(anonymous namespace)::CStringLength>(clang::ento::GRStateTrait<(anonymous namespace)::CStringLength>::key_type, clang::ento::GRStateTrait<(anonymous namespace)::CStringLength>::value_type) const"},
    {"_ZN12_GLOBAL__N_114CStringChecker16evalStrcpyCommonERN5clang4ento14CheckerContextEPKNS1_8CallExprEb", "(anonymous namespace)::CStringChecker::evalStrcpyCommon(clang::ento::CheckerContext&, clang::CallExpr const*, bool)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114CStringCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CStringChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114CStringCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CStringChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_9MemRegionENS0_4SValENS2_16ImutKeyValueInfoIS6_S7_EEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::MemRegion const*, clang::ento::SVal, llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_9MemRegionENS0_4SValENS2_16ImutKeyValueInfoIS6_S7_EEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::MemRegion const*, clang::ento::SVal, llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>>::DeleteContext(void*)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_9MemRegionENS0_4SValENS2_16ImutKeyValueInfoIS6_S7_EEEEE3SetESA_S6_S7_RNSA_7FactoryE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::MemRegion const*, clang::ento::SVal, llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>>::Set(llvm::ImmutableMap<clang::ento::MemRegion const*, clang::ento::SVal, llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>, clang::ento::MemRegion const*, clang::ento::SVal, llvm::ImmutableMap<clang::ento::MemRegion const*, clang::ento::SVal, llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::Factory&)"},
    {"_ZN5clang4ento29RegisterCallAndMessageCheckerERNS0_10ExprEngineE", "clang::ento::RegisterCallAndMessageChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_121CallAndMessageCheckerD1Ev", "(anonymous namespace)::CallAndMessageChecker::~CallAndMessageChecker()"},
    {"_ZN12_GLOBAL__N_121CallAndMessageCheckerD0Ev", "(anonymous namespace)::CallAndMessageChecker::~CallAndMessageChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_121CallAndMessageCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CallAndMessageChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_121CallAndMessageCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CallAndMessageChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_121CallAndMessageChecker19preVisitObjCMessageERN5clang4ento14CheckerContextENS2_11ObjCMessageE", "(anonymous namespace)::CallAndMessageChecker::preVisitObjCMessage(clang::ento::CheckerContext&, clang::ento::ObjCMessage)"},
    {"_ZN12_GLOBAL__N_121CallAndMessageChecker15evalNilReceiverERN5clang4ento14CheckerContextENS2_11ObjCMessageE", "(anonymous namespace)::CallAndMessageChecker::evalNilReceiver(clang::ento::CheckerContext&, clang::ento::ObjCMessage)"},
    {"_ZN12_GLOBAL__N_121CallAndMessageChecker18emitNilReceiverBugERN5clang4ento14CheckerContextERKNS2_11ObjCMessageEPNS2_12ExplodedNodeE", "(anonymous namespace)::CallAndMessageChecker::emitNilReceiverBug(clang::ento::CheckerContext&, clang::ento::ObjCMessage const&, clang::ento::ExplodedNode*)"},
    {"_ZN12_GLOBAL__N_121CallAndMessageChecker19PreVisitProcessArgsERN5clang4ento14CheckerContextENS2_17CallOrObjCMessageEPKcRPNS2_7BugTypeE", "(anonymous namespace)::CallAndMessageChecker::PreVisitProcessArgs(clang::ento::CheckerContext&, clang::ento::CallOrObjCMessage, char const*, clang::ento::BugType*&)"},
    {"_ZZN12_GLOBAL__N_121CallAndMessageChecker18PreVisitProcessArgERN5clang4ento14CheckerContextENS2_4SValENS1_11SourceRangeEPKNS1_4ExprEPKcRPNS2_7BugTypeEEN22FindUninitializedField4FindEPKNS2_11TypedRegionE", "(anonymous namespace)::CallAndMessageChecker::PreVisitProcessArg(clang::ento::CheckerContext&, clang::ento::SVal, clang::SourceRange, clang::Expr const*, char const*, clang::ento::BugType*&)::FindUninitializedField::Find(clang::ento::TypedRegion const*)"},
    {"_ZN12_GLOBAL__N_121CallAndMessageChecker11EmitBadCallEPN5clang4ento7BugTypeERNS2_14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::CallAndMessageChecker::EmitBadCall(clang::ento::BugType*, clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_121CallAndMessageCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CallAndMessageChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_121CallAndMessageCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CallAndMessageChecker>::~CheckerVisitor()"},
    {"_ZNK5clang4ento17CallOrObjCMessage10getArgSValEj", "clang::ento::CallOrObjCMessage::getArgSVal(unsigned int) const"},
    {"_ZN5clang4ento23RegisterCastSizeCheckerERNS0_10ExprEngineE", "clang::ento::RegisterCastSizeChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_115CastSizeCheckerD1Ev", "(anonymous namespace)::CastSizeChecker::~CastSizeChecker()"},
    {"_ZN12_GLOBAL__N_115CastSizeCheckerD0Ev", "(anonymous namespace)::CastSizeChecker::~CastSizeChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_115CastSizeCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CastSizeChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_115CastSizeCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CastSizeChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_115CastSizeChecker16PreVisitCastExprERN5clang4ento14CheckerContextEPKNS1_8CastExprE", "(anonymous namespace)::CastSizeChecker::PreVisitCastExpr(clang::ento::CheckerContext&, clang::CastExpr const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_115CastSizeCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CastSizeChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_115CastSizeCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CastSizeChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento10BuiltinBugC2EPKcS3_", "clang::ento::BuiltinBug::BuiltinBug(char const*, char const*)"},
    {"_ZN5clang4ento27RegisterCastToStructCheckerERNS0_10ExprEngineE", "clang::ento::RegisterCastToStructChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_119CastToStructCheckerD1Ev", "(anonymous namespace)::CastToStructChecker::~CastToStructChecker()"},
    {"_ZN12_GLOBAL__N_119CastToStructCheckerD0Ev", "(anonymous namespace)::CastToStructChecker::~CastToStructChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119CastToStructCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CastToStructChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119CastToStructCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::CastToStructChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_119CastToStructChecker16PreVisitCastExprERN5clang4ento14CheckerContextEPKNS1_8CastExprE", "(anonymous namespace)::CastToStructChecker::PreVisitCastExpr(clang::ento::CheckerContext&, clang::CastExpr const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119CastToStructCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CastToStructChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119CastToStructCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::CastToStructChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento16CheckObjCDeallocEPKNS_22ObjCImplementationDeclERKNS_11LangOptionsERNS0_11BugReporterE", "clang::ento::CheckObjCDealloc(clang::ObjCImplementationDecl const*, clang::LangOptions const&, clang::ento::BugReporter&)"},
    {"_Z12scan_deallocPN5clang4StmtENS_8SelectorE", "scan_dealloc(clang::Stmt*, clang::Selector)"},
    {"_Z17scan_ivar_releasePN5clang4StmtEPNS_12ObjCIvarDeclEPKNS_16ObjCPropertyDeclENS_8SelectorEPNS_14IdentifierInfoERNS_10ASTContextE", "scan_ivar_release(clang::Stmt*, clang::ObjCIvarDecl*, clang::ObjCPropertyDecl const*, clang::Selector, clang::IdentifierInfo*, clang::ASTContext&)"},
    {"_ZN5clang4ento26CheckObjCInstMethSignatureEPKNS_22ObjCImplementationDeclERNS0_11BugReporterE", "clang::ento::CheckObjCInstMethSignature(clang::ObjCImplementationDecl const*, clang::ento::BugReporter&)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEPNS1_14ObjCMethodDeclENS_12DenseMapInfoIS2_EENS5_IS4_EEE16InsertIntoBucketERKS2_RKS4_PSt4pairIS2_S4_E", "llvm::DenseMap<clang::Selector, clang::ObjCMethodDecl*, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<clang::ObjCMethodDecl*>>::InsertIntoBucket(clang::Selector const&, clang::ObjCMethodDecl* const&, std::pair<clang::Selector, clang::ObjCMethodDecl*>*)"},
    {"_ZN4llvm8DenseMapIN5clang8SelectorEPNS1_14ObjCMethodDeclENS_12DenseMapInfoIS2_EENS5_IS4_EEE4growEj", "llvm::DenseMap<clang::Selector, clang::ObjCMethodDecl*, llvm::DenseMapInfo<clang::Selector>, llvm::DenseMapInfo<clang::ObjCMethodDecl*>>::grow(unsigned int)"},
    {"_ZN5clang4ento23CheckSecuritySyntaxOnlyEPKNS_4DeclERNS0_11BugReporterE", "clang::ento::CheckSecuritySyntaxOnly(clang::Decl const*, clang::ento::BugReporter&)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_17WalkASTEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::WalkAST, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_17WalkAST13VisitCallExprEPN5clang8CallExprE", "(anonymous namespace)::WalkAST::VisitCallExpr(clang::CallExpr*)"},
    {"_ZN12_GLOBAL__N_17WalkAST13VisitChildrenEPN5clang4StmtE", "(anonymous namespace)::WalkAST::VisitChildren(clang::Stmt*)"},
    {"_Z17GetIncrementedVarPKN5clang4ExprEPKNS_7VarDeclES5_", "GetIncrementedVar(clang::Expr const*, clang::VarDecl const*, clang::VarDecl const*)"},
    {"_ZN5clang4ento18CheckSizeofPointerEPKNS_4DeclERNS0_11BugReporterE", "clang::ento::CheckSizeofPointer(clang::Decl const*, clang::ento::BugReporter&)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_17WalkASTEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::WalkAST, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_17WalkAST13VisitChildrenEPN5clang4StmtE", "(anonymous namespace)::WalkAST::VisitChildren(clang::Stmt*)"},
    {"_ZN5clang4ento21RegisterChrootCheckerERNS0_10ExprEngineE", "clang::ento::RegisterChrootChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_113ChrootCheckerD1Ev", "(anonymous namespace)::ChrootChecker::~ChrootChecker()"},
    {"_ZN12_GLOBAL__N_113ChrootCheckerD0Ev", "(anonymous namespace)::ChrootChecker::~ChrootChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113ChrootCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ChrootChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113ChrootCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ChrootChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_113ChrootChecker12evalCallExprERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::ChrootChecker::evalCallExpr(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_113ChrootChecker16PreVisitCallExprERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::ChrootChecker::PreVisitCallExpr(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113ChrootCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ChrootChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113ChrootCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ChrootChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento15CheckDeadStoresERNS_3CFGERNS_13LiveVariablesERNS_9ParentMapERNS0_11BugReporterE", "clang::ento::CheckDeadStores(clang::CFG&, clang::LiveVariables&, clang::ParentMap&, clang::ento::BugReporter&)"},
    {"_ZN12_GLOBAL__N_112DeadStoreObsD1Ev", "(anonymous namespace)::DeadStoreObs::~DeadStoreObs()"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_111FindEscapedEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::FindEscaped, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_111FindEscaped18VisitUnaryOperatorEPN5clang13UnaryOperatorE", "(anonymous namespace)::FindEscaped::VisitUnaryOperator(clang::UnaryOperator*)"},
    {"_ZN5clang14CFGStmtVisitorIN12_GLOBAL__N_111FindEscapedEvE13VisitChildrenEPNS_4StmtE", "clang::CFGStmtVisitor<(anonymous namespace)::FindEscaped, void>::VisitChildren(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_112DeadStoreObsD0Ev", "(anonymous namespace)::DeadStoreObs::~DeadStoreObs()"},
    {"_ZN12_GLOBAL__N_112DeadStoreObs11ObserveStmtEPN5clang4StmtERKNS1_24LiveVariables_ValueTypes14AnalysisDataTyERKNS1_23StmtDeclBitVector_Types5ValTyE", "(anonymous namespace)::DeadStoreObs::ObserveStmt(clang::Stmt*, clang::LiveVariables_ValueTypes::AnalysisDataTy const&, clang::StmtDeclBitVector_Types::ValTy const&)"},
    {"_ZN12_GLOBAL__N_112DeadStoreObs12CheckVarDeclEPN5clang7VarDeclEPNS1_4ExprES5_NS0_13DeadStoreKindERKNS1_24LiveVariables_ValueTypes14AnalysisDataTyERKNS1_23StmtDeclBitVector_Types5ValTyE", "(anonymous namespace)::DeadStoreObs::CheckVarDecl(clang::VarDecl*, clang::Expr*, clang::Expr*, (anonymous namespace)::DeadStoreObs::DeadStoreKind, clang::LiveVariables_ValueTypes::AnalysisDataTy const&, clang::StmtDeclBitVector_Types::ValTy const&)"},
    {"_ZN12_GLOBAL__N_112DeadStoreObs6ReportEPN5clang7VarDeclENS0_13DeadStoreKindENS1_14SourceLocationENS1_11SourceRangeE", "(anonymous namespace)::DeadStoreObs::Report(clang::VarDecl*, (anonymous namespace)::DeadStoreObs::DeadStoreKind, clang::SourceLocation, clang::SourceRange)"},
    {"_ZN5clang24LiveVariables_ValueTypes10ObserverTy12ObserverKillEPNS_11DeclRefExprE", "clang::LiveVariables_ValueTypes::ObserverTy::ObserverKill(clang::DeclRefExpr*)"},
    {"_ZN5clang24LiveVariables_ValueTypes10ObserverTyD1Ev", "clang::LiveVariables_ValueTypes::ObserverTy::~ObserverTy()"},
    {"_ZN5clang24LiveVariables_ValueTypes10ObserverTyD0Ev", "clang::LiveVariables_ValueTypes::ObserverTy::~ObserverTy()"},
    {"_ZN5clang24LiveVariables_ValueTypes10ObserverTy11ObserveStmtEPNS_4StmtERKNS0_14AnalysisDataTyERKNS_23StmtDeclBitVector_Types5ValTyE", "clang::LiveVariables_ValueTypes::ObserverTy::ObserveStmt(clang::Stmt*, clang::LiveVariables_ValueTypes::AnalysisDataTy const&, clang::StmtDeclBitVector_Types::ValTy const&)"},
    {"_ZN5clang4ento26RegisterDereferenceCheckerERNS0_10ExprEngineE", "clang::ento::RegisterDereferenceChecker(clang::ento::ExprEngine&)"},
    {"_ZN5clang4ento27GetImplicitNullDereferencesERNS0_10ExprEngineE", "clang::ento::GetImplicitNullDereferences(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_118DereferenceCheckerD1Ev", "(anonymous namespace)::DereferenceChecker::~DereferenceChecker()"},
    {"_ZN12_GLOBAL__N_118DereferenceCheckerD0Ev", "(anonymous namespace)::DereferenceChecker::~DereferenceChecker()"},
    {"_ZN12_GLOBAL__N_118DereferenceChecker13visitLocationERN5clang4ento14CheckerContextEPKNS1_4StmtENS2_4SValEb", "(anonymous namespace)::DereferenceChecker::visitLocation(clang::ento::CheckerContext&, clang::Stmt const*, clang::ento::SVal, bool)"},
    {"_ZN12_GLOBAL__N_118DereferenceChecker14AddDerefSourceERN4llvm11raw_ostreamERNS1_15SmallVectorImplIN5clang11SourceRangeEEEPKNS5_4ExprEb", "(anonymous namespace)::DereferenceChecker::AddDerefSource(llvm::raw_ostream&, llvm::SmallVectorImpl<clang::SourceRange>&, clang::Expr const*, bool)"},
    {"_ZN5clang4ento22RegisterDivZeroCheckerERNS0_10ExprEngineE", "clang::ento::RegisterDivZeroChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_114DivZeroCheckerD1Ev", "(anonymous namespace)::DivZeroChecker::~DivZeroChecker()"},
    {"_ZN12_GLOBAL__N_114DivZeroCheckerD0Ev", "(anonymous namespace)::DivZeroChecker::~DivZeroChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114DivZeroCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::DivZeroChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114DivZeroCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::DivZeroChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_114DivZeroChecker22PreVisitBinaryOperatorERN5clang4ento14CheckerContextEPKNS1_14BinaryOperatorE", "(anonymous namespace)::DivZeroChecker::PreVisitBinaryOperator(clang::ento::CheckerContext&, clang::BinaryOperator const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114DivZeroCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::DivZeroChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114DivZeroCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::DivZeroChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento26RegisterExperimentalChecksERNS0_10ExprEngineE", "clang::ento::RegisterExperimentalChecks(clang::ento::ExprEngine&)"},
    {"_ZN5clang4ento34RegisterExperimentalInternalChecksERNS0_10ExprEngineE", "clang::ento::RegisterExperimentalInternalChecks(clang::ento::ExprEngine&)"},
    {"_ZN5clang4ento10ExprEngine12CheckerVisitEPKNS_4StmtERNS0_15ExplodedNodeSetES6_NS1_12CallbackKindE", "clang::ento::ExprEngine::CheckerVisit(clang::Stmt const*, clang::ento::ExplodedNodeSet&, clang::ento::ExplodedNodeSet&, clang::ento::ExprEngine::CallbackKind)"},
    {"_ZN5clang4ento10ExprEngine23CheckerVisitObjCMessageERKNS0_11ObjCMessageERNS0_15ExplodedNodeSetES6_b", "clang::ento::ExprEngine::CheckerVisitObjCMessage(clang::ento::ObjCMessage const&, clang::ento::ExplodedNodeSet&, clang::ento::ExplodedNodeSet&, bool)"},
    {"_ZN5clang4ento10ExprEngine22CheckerEvalNilReceiverERKNS0_11ObjCMessageERNS0_15ExplodedNodeSetEPKNS0_7GRStateEPNS0_12ExplodedNodeE", "clang::ento::ExprEngine::CheckerEvalNilReceiver(clang::ento::ObjCMessage const&, clang::ento::ExplodedNodeSet&, clang::ento::GRState const*, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento10ExprEngine15CheckerEvalCallEPKNS_8CallExprERNS0_15ExplodedNodeSetEPNS0_12ExplodedNodeE", "clang::ento::ExprEngine::CheckerEvalCall(clang::CallExpr const*, clang::ento::ExplodedNodeSet&, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento10ExprEngine16CheckerVisitBindEPKNS_4StmtERNS0_15ExplodedNodeSetES6_NS0_4SValES7_b", "clang::ento::ExprEngine::CheckerVisitBind(clang::Stmt const*, clang::ento::ExplodedNodeSet&, clang::ento::ExplodedNodeSet&, clang::ento::SVal, clang::ento::SVal, bool)"},
    {"_ZN5clang4ento10ExprEngineC1ERNS0_15AnalysisManagerEPNS0_13TransferFuncsE", "clang::ento::ExprEngine::ExprEngine(clang::ento::AnalysisManager&, clang::ento::TransferFuncs*)"},
    {"_ZN5clang4ento10ExprEngineC2ERNS0_15AnalysisManagerEPNS0_13TransferFuncsE", "clang::ento::ExprEngine::ExprEngine(clang::ento::AnalysisManager&, clang::ento::TransferFuncs*)"},
    {"_ZN5clang4ento10ExprEngineD0Ev", "clang::ento::ExprEngine::~ExprEngine()"},
    {"_ZN5clang4ento10ExprEngineD1Ev", "clang::ento::ExprEngine::~ExprEngine()"},
    {"_ZN5clang4ento10ExprEngineD2Ev", "clang::ento::ExprEngine::~ExprEngine()"},
    {"_ZN5clang4ento10ExprEngine15getInitialStateEPKNS_15LocationContextE", "clang::ento::ExprEngine::getInitialState(clang::LocationContext const*)"},
    {"_ZN5clang4ento10ExprEngine13processAssumeEPKNS0_7GRStateENS0_4SValEb", "clang::ento::ExprEngine::processAssume(clang::ento::GRState const*, clang::ento::SVal, bool)"},
    {"_ZN5clang4ento10ExprEngine23wantsRegionChangeUpdateEPKNS0_7GRStateE", "clang::ento::ExprEngine::wantsRegionChangeUpdate(clang::ento::GRState const*)"},
    {"_ZN5clang4ento10ExprEngine20processRegionChangesEPKNS0_7GRStateEPKPKNS0_9MemRegionES9_", "clang::ento::ExprEngine::processRegionChanges(clang::ento::GRState const*, clang::ento::MemRegion const* const*, clang::ento::MemRegion const* const*)"},
    {"_ZN5clang4ento10ExprEngine18processEndWorklistEb", "clang::ento::ExprEngine::processEndWorklist(bool)"},
    {"_ZN5clang4ento10ExprEngine17processCFGElementENS_10CFGElementERNS0_15StmtNodeBuilderE", "clang::ento::ExprEngine::processCFGElement(clang::CFGElement, clang::ento::StmtNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine11ProcessStmtENS_7CFGStmtERNS0_15StmtNodeBuilderE", "clang::ento::ExprEngine::ProcessStmt(clang::CFGStmt, clang::ento::StmtNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine18ProcessInitializerENS_14CFGInitializerERNS0_15StmtNodeBuilderE", "clang::ento::ExprEngine::ProcessInitializer(clang::CFGInitializer, clang::ento::StmtNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine19ProcessImplicitDtorENS_15CFGImplicitDtorERNS0_15StmtNodeBuilderE", "clang::ento::ExprEngine::ProcessImplicitDtor(clang::CFGImplicitDtor, clang::ento::StmtNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine5VisitEPKNS_4StmtEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::Visit(clang::Stmt const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine23ProcessAutomaticObjDtorENS_19CFGAutomaticObjDtorERNS0_15StmtNodeBuilderE", "clang::ento::ExprEngine::ProcessAutomaticObjDtor(clang::CFGAutomaticObjDtor, clang::ento::StmtNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine15ProcessBaseDtorENS_11CFGBaseDtorERNS0_15StmtNodeBuilderE", "clang::ento::ExprEngine::ProcessBaseDtor(clang::CFGBaseDtor, clang::ento::StmtNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine17ProcessMemberDtorENS_13CFGMemberDtorERNS0_15StmtNodeBuilderE", "clang::ento::ExprEngine::ProcessMemberDtor(clang::CFGMemberDtor, clang::ento::StmtNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine20ProcessTemporaryDtorENS_16CFGTemporaryDtorERNS0_15StmtNodeBuilderE", "clang::ento::ExprEngine::ProcessTemporaryDtor(clang::CFGTemporaryDtor, clang::ento::StmtNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine8MakeNodeERNS0_15ExplodedNodeSetEPKNS_4StmtEPNS0_12ExplodedNodeEPKNS0_7GRStateENS_12ProgramPoint4KindEPKv", "clang::ento::ExprEngine::MakeNode(clang::ento::ExplodedNodeSet&, clang::Stmt const*, clang::ento::ExplodedNode*, clang::ento::GRState const*, clang::ProgramPoint::Kind, void const*)"},
    {"_ZN5clang4ento10ExprEngine27VisitObjCAtSynchronizedStmtEPKNS_22ObjCAtSynchronizedStmtEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitObjCAtSynchronizedStmt(clang::ObjCAtSynchronizedStmt const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine24VisitObjCPropertyRefExprEPKNS_19ObjCPropertyRefExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitObjCPropertyRefExpr(clang::ObjCPropertyRefExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine27VisitLvalArraySubscriptExprEPKNS_18ArraySubscriptExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitLvalArraySubscriptExpr(clang::ArraySubscriptExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine12VisitAsmStmtEPKNS_7AsmStmtEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitAsmStmt(clang::AsmStmt const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine22VisitCommonDeclRefExprEPKNS_4ExprEPKNS_9NamedDeclEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCommonDeclRefExpr(clang::Expr const*, clang::NamedDecl const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine14VisitBlockExprEPKNS_9BlockExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitBlockExpr(clang::BlockExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine16VisitLogicalExprEPKNS_14BinaryOperatorEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitLogicalExpr(clang::BinaryOperator const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine19VisitBinaryOperatorEPKNS_14BinaryOperatorEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitBinaryOperator(clang::BinaryOperator const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine17evalEagerlyAssumeERNS0_15ExplodedNodeSetES3_PKNS_4ExprE", "clang::ento::ExprEngine::evalEagerlyAssume(clang::ento::ExplodedNodeSet&, clang::ento::ExplodedNodeSet&, clang::Expr const*)"},
    {"_ZN5clang4ento10ExprEngine9VisitCallEPKNS_8CallExprEPNS0_12ExplodedNodeENS_17ConstExprIteratorES7_RNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCall(clang::CallExpr const*, clang::ento::ExplodedNode*, clang::ConstExprIterator, clang::ConstExprIterator, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine16VisitGuardedExprEPKNS_4ExprES4_S4_PNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitGuardedExpr(clang::Expr const*, clang::Expr const*, clang::Expr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine24VisitCompoundLiteralExprEPKNS_19CompoundLiteralExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCompoundLiteralExpr(clang::CompoundLiteralExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine13VisitDeclStmtEPKNS_8DeclStmtEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitDeclStmt(clang::DeclStmt const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine13VisitCondInitEPKNS_7VarDeclEPKNS_4StmtEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCondInit(clang::VarDecl const*, clang::Stmt const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine9VisitCastEPKNS_8CastExprEPKNS_4ExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCast(clang::CastExpr const*, clang::Expr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine17VisitInitListExprEPKNS_12InitListExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitInitListExpr(clang::InitListExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine15VisitMemberExprEPKNS_10MemberExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitMemberExpr(clang::MemberExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine24VisitLvalObjCIvarRefExprEPKNS_15ObjCIvarRefExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitLvalObjCIvarRefExpr(clang::ObjCIvarRefExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine26VisitObjCForCollectionStmtEPKNS_21ObjCForCollectionStmtEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitObjCForCollectionStmt(clang::ObjCForCollectionStmt const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine20VisitObjCMessageExprEPKNS_15ObjCMessageExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitObjCMessageExpr(clang::ObjCMessageExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine15VisitReturnStmtEPKNS_10ReturnStmtEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitReturnStmt(clang::ReturnStmt const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine17VisitOffsetOfExprEPKNS_12OffsetOfExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitOffsetOfExpr(clang::OffsetOfExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine22VisitSizeOfAlignOfExprEPKNS_17SizeOfAlignOfExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitSizeOfAlignOfExpr(clang::SizeOfAlignOfExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine18VisitUnaryOperatorEPKNS_13UnaryOperatorEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitUnaryOperator(clang::UnaryOperator const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine23processCFGBlockEntranceERNS0_15ExplodedNodeSetERNS0_18GenericNodeBuilderINS_13BlockEntranceEEE", "clang::ento::ExprEngine::processCFGBlockEntrance(clang::ento::ExplodedNodeSet&, clang::ento::GenericNodeBuilder<clang::BlockEntrance>&)"},
    {"_ZN5clang4ento10ExprEngine10MarkBranchEPKNS0_7GRStateEPKNS_4StmtEb", "clang::ento::ExprEngine::MarkBranch(clang::ento::GRState const*, clang::Stmt const*, bool)"},
    {"_ZN5clang4ento10ExprEngine13processBranchEPKNS_4StmtES4_RNS0_17BranchNodeBuilderE", "clang::ento::ExprEngine::processBranch(clang::Stmt const*, clang::Stmt const*, clang::ento::BranchNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine19processIndirectGotoERNS0_23IndirectGotoNodeBuilderE", "clang::ento::ExprEngine::processIndirectGoto(clang::ento::IndirectGotoNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine20processEndOfFunctionERNS0_24EndOfFunctionNodeBuilderE", "clang::ento::ExprEngine::processEndOfFunction(clang::ento::EndOfFunctionNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine13processSwitchERNS0_17SwitchNodeBuilderE", "clang::ento::ExprEngine::processSwitch(clang::ento::SwitchNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine16processCallEnterERNS0_20CallEnterNodeBuilderE", "clang::ento::ExprEngine::processCallEnter(clang::ento::CallEnterNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine15processCallExitERNS0_19CallExitNodeBuilderE", "clang::ento::ExprEngine::processCallExit(clang::ento::CallExitNodeBuilder&)"},
    {"_ZN5clang4ento10ExprEngine8evalLoadERNS0_15ExplodedNodeSetEPKNS_4ExprEPNS0_12ExplodedNodeEPKNS0_7GRStateENS0_4SValEPKvNS_8QualTypeE", "clang::ento::ExprEngine::evalLoad(clang::ento::ExplodedNodeSet&, clang::Expr const*, clang::ento::ExplodedNode*, clang::ento::GRState const*, clang::ento::SVal, void const*, clang::QualType)"},
    {"_ZN5clang4ento10ExprEngine8evalBindERNS0_15ExplodedNodeSetEPKNS_4StmtEPNS0_12ExplodedNodeEPKNS0_7GRStateENS0_4SValESC_b", "clang::ento::ExprEngine::evalBind(clang::ento::ExplodedNodeSet&, clang::Stmt const*, clang::ento::ExplodedNode*, clang::ento::GRState const*, clang::ento::SVal, clang::ento::SVal, bool)"},
    {"_ZN5clang4ento10ExprEngine9evalStoreERNS0_15ExplodedNodeSetEPKNS_4ExprES6_PNS0_12ExplodedNodeEPKNS0_7GRStateENS0_4SValESC_PKv", "clang::ento::ExprEngine::evalStore(clang::ento::ExplodedNodeSet&, clang::Expr const*, clang::Expr const*, clang::ento::ExplodedNode*, clang::ento::GRState const*, clang::ento::SVal, clang::ento::SVal, void const*)"},
    {"_ZN5clang4ento10ExprEngine16VisitObjCMessageERKNS0_11ObjCMessageERNS0_15ExplodedNodeSetES6_", "clang::ento::ExprEngine::VisitObjCMessage(clang::ento::ObjCMessage const&, clang::ento::ExplodedNodeSet&, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine12evalLocationERNS0_15ExplodedNodeSetEPKNS_4StmtEPNS0_12ExplodedNodeEPKNS0_7GRStateENS0_4SValEPKvb", "clang::ento::ExprEngine::evalLocation(clang::ento::ExplodedNodeSet&, clang::Stmt const*, clang::ento::ExplodedNode*, clang::ento::GRState const*, clang::ento::SVal, void const*, bool)"},
    {"_ZN5clang4ento10ExprEngine14evalLoadCommonERNS0_15ExplodedNodeSetEPKNS_4ExprEPNS0_12ExplodedNodeEPKNS0_7GRStateENS0_4SValEPKvNS_8QualTypeE", "clang::ento::ExprEngine::evalLoadCommon(clang::ento::ExplodedNodeSet&, clang::Expr const*, clang::ento::ExplodedNode*, clang::ento::GRState const*, clang::ento::SVal, void const*, clang::QualType)"},
    {"_ZN5clang4ento10ExprEngine10InlineCallERNS0_15ExplodedNodeSetEPKNS_8CallExprEPNS0_12ExplodedNodeE", "clang::ento::ExprEngine::InlineCall(clang::ento::ExplodedNodeSet&, clang::CallExpr const*, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento10ExprEngine29VisitObjCForCollectionStmtAuxEPKNS_21ObjCForCollectionStmtEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetENS0_4SValE", "clang::ento::ExprEngine::VisitObjCForCollectionStmtAux(clang::ObjCForCollectionStmt const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&, clang::ento::SVal)"},
    {"_ZN4llvm15SmallVectorImplIN12_GLOBAL__N_113ObjCMsgWLItemEE9push_backERKS2_", "llvm::SmallVectorImpl<(anonymous namespace)::ObjCMsgWLItem>::push_back((anonymous namespace)::ObjCMsgWLItem const&)"},
    {"_ZN5clang4ento10ExprEngine25VisitAsmStmtHelperOutputsEPKNS_7AsmStmtENS_17ConstExprIteratorES5_PNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitAsmStmtHelperOutputs(clang::AsmStmt const*, clang::ConstExprIterator, clang::ConstExprIterator, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine24VisitAsmStmtHelperInputsEPKNS_7AsmStmtENS_17ConstExprIteratorES5_PNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitAsmStmtHelperInputs(clang::AsmStmt const*, clang::ConstExprIterator, clang::ConstExprIterator, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZNK5clang4ento10ExprEngine13lookupCheckerEPv", "clang::ento::ExprEngine::lookupChecker(void*) const"},
    {"_ZN5clang4ento10ExprEngine9ViewGraphEb", "clang::ento::ExprEngine::ViewGraph(bool)"},
    {"_ZN5clang4ento10ExprEngine9ViewGraphEPPNS0_12ExplodedNodeES4_", "clang::ento::ExprEngine::ViewGraph(clang::ento::ExplodedNode**, clang::ento::ExplodedNode**)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN12_GLOBAL__N_114InitListWLItemELb0EE4growEm", "llvm::SmallVectorTemplateBase<(anonymous namespace)::InitListWLItem, false>::grow(unsigned long)"},
    {"_ZN5clang4ento15ExplodedNodeSet6insertERKS1_", "clang::ento::ExplodedNodeSet::insert(clang::ento::ExplodedNodeSet const&)"},
    {"_ZN5clang4ento7Checker8GR_VisitERNS0_15ExplodedNodeSetERNS0_15StmtNodeBuilderERNS0_10ExprEngineEPKNS_4StmtEPNS0_12ExplodedNodeEPvbRb", "clang::ento::Checker::GR_Visit(clang::ento::ExplodedNodeSet&, clang::ento::StmtNodeBuilder&, clang::ento::ExprEngine&, clang::Stmt const*, clang::ento::ExplodedNode*, void*, bool, bool&)"},
    {"_ZN5clang4ento7Checker19GR_visitObjCMessageERNS0_15ExplodedNodeSetERNS0_15StmtNodeBuilderERNS0_10ExprEngineERKNS0_11ObjCMessageEPNS0_12ExplodedNodeEPvb", "clang::ento::Checker::GR_visitObjCMessage(clang::ento::ExplodedNodeSet&, clang::ento::StmtNodeBuilder&, clang::ento::ExprEngine&, clang::ento::ObjCMessage const&, clang::ento::ExplodedNode*, void*, bool)"},
    {"_ZN5clang4ento10ExprEngine18getAnalysisManagerEv", "clang::ento::ExprEngine::getAnalysisManager()"},
    {"_ZN5clang4ento10ExprEngine15getStateManagerEv", "clang::ento::ExprEngine::getStateManager()"},
    {"_ZN4llvm8DenseMapIjPSt6vectorISt4pairIPvPN5clang4ento7CheckerEESaIS8_EENS_12DenseMapInfoIjEENSC_ISB_EEE16InsertIntoBucketERKjRKSB_PS2_IjSB_E", "llvm::DenseMap<unsigned int, std::vector<std::pair<void*, clang::ento::Checker*>, std::allocator<std::pair<void*, clang::ento::Checker*>>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<std::vector<std::pair<void*, clang::ento::Checker*>, std::allocator<std::pair<void*, clang::ento::Checker*>>>*>>::InsertIntoBucket(unsigned int const&, std::vector<std::pair<void*, clang::ento::Checker*>, std::allocator<std::pair<void*, clang::ento::Checker*>>>* const&, std::pair<unsigned int, std::vector<std::pair<void*, clang::ento::Checker*>, std::allocator<std::pair<void*, clang::ento::Checker*>>>*>*)"},
    {"_ZN4llvm8DenseMapIjPSt6vectorISt4pairIPvPN5clang4ento7CheckerEESaIS8_EENS_12DenseMapInfoIjEENSC_ISB_EEE4growEj", "llvm::DenseMap<unsigned int, std::vector<std::pair<void*, clang::ento::Checker*>, std::allocator<std::pair<void*, clang::ento::Checker*>>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<std::vector<std::pair<void*, clang::ento::Checker*>, std::allocator<std::pair<void*, clang::ento::Checker*>>>*>>::grow(unsigned int)"},
    {"_ZN4llvm20ImmutableListFactoryIN5clang4ento4SValEE6concatERKS3_NS_13ImmutableListIS3_EE", "llvm::ImmutableListFactory<clang::ento::SVal>::concat(clang::ento::SVal const&, llvm::ImmutableList<clang::ento::SVal>)"},
    {"_ZN5clang4ento18StmtNodeBuilderRefD2Ev", "clang::ento::StmtNodeBuilderRef::~StmtNodeBuilderRef()"},
    {"_ZN5clang4ento12SymbolReaperC2EPKNS_15LocationContextEPKNS_4StmtERNS0_13SymbolManagerE", "clang::ento::SymbolReaper::SymbolReaper(clang::LocationContext const*, clang::Stmt const*, clang::ento::SymbolManager&)"},
    {"_ZN5clang4ento9SubEngineD1Ev", "clang::ento::SubEngine::~SubEngine()"},
    {"_ZN5clang4ento9SubEngineD0Ev", "clang::ento::SubEngine::~SubEngine()"},
    {"_ZN5clang4ento10CoreEngineD2Ev", "clang::ento::CoreEngine::~CoreEngine()"},
    {"_ZN5clang4ento14GRStateManagerC2ERNS_10ASTContextEPFPNS0_12StoreManagerERS1_EPFPNS0_17ConstraintManagerES6_RNS0_9SubEngineEERN4llvm16BumpPtrAllocatorESC_", "clang::ento::GRStateManager::GRStateManager(clang::ASTContext&, clang::ento::StoreManager* (*)(clang::ento::GRStateManager&), clang::ento::ConstraintManager* (*)(clang::ento::GRStateManager&, clang::ento::SubEngine&), llvm::BumpPtrAllocator&, clang::ento::SubEngine&)"},
    {"_ZN4llvm10FoldingSetIN5clang4ento7GRStateEED1Ev", "llvm::FoldingSet<clang::ento::GRState>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang4ento7GRStateEED0Ev", "llvm::FoldingSet<clang::ento::GRState>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento7GRStateEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::GRState>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento7GRStateEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::ento::GRState>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento7GRStateEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::GRState>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang4ento12ExplodedNodeEED1Ev", "llvm::FoldingSet<clang::ento::ExplodedNode>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang4ento12ExplodedNodeEED0Ev", "llvm::FoldingSet<clang::ento::ExplodedNode>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento12ExplodedNodeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::ExplodedNode>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento12ExplodedNodeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::ento::ExplodedNode>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento12ExplodedNodeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::ExplodedNode>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento27RegisterFixedAddressCheckerERNS0_10ExprEngineE", "clang::ento::RegisterFixedAddressChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_119FixedAddressCheckerD1Ev", "(anonymous namespace)::FixedAddressChecker::~FixedAddressChecker()"},
    {"_ZN12_GLOBAL__N_119FixedAddressCheckerD0Ev", "(anonymous namespace)::FixedAddressChecker::~FixedAddressChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119FixedAddressCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::FixedAddressChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119FixedAddressCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::FixedAddressChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_119FixedAddressChecker22PreVisitBinaryOperatorERN5clang4ento14CheckerContextEPKNS1_14BinaryOperatorE", "(anonymous namespace)::FixedAddressChecker::PreVisitBinaryOperator(clang::ento::CheckerContext&, clang::BinaryOperator const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119FixedAddressCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::FixedAddressChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119FixedAddressCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::FixedAddressChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14AnalysisAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::ento::AnalysisAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang4ento14AnalysisActionD1Ev", "clang::ento::AnalysisAction::~AnalysisAction()"},
    {"_ZN5clang4ento14AnalysisActionD0Ev", "clang::ento::AnalysisAction::~AnalysisAction()"},
    {"_ZN5clang4ento34RegisterIdempotentOperationCheckerERNS0_10ExprEngineE", "clang::ento::RegisterIdempotentOperationChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_126IdempotentOperationCheckerD1Ev", "(anonymous namespace)::IdempotentOperationChecker::~IdempotentOperationChecker()"},
    {"_ZN12_GLOBAL__N_126IdempotentOperationCheckerD0Ev", "(anonymous namespace)::IdempotentOperationChecker::~IdempotentOperationChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126IdempotentOperationCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::IdempotentOperationChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126IdempotentOperationCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::IdempotentOperationChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_126IdempotentOperationChecker16VisitEndAnalysisERN5clang4ento13ExplodedGraphERNS2_11BugReporterERNS2_10ExprEngineE", "(anonymous namespace)::IdempotentOperationChecker::VisitEndAnalysis(clang::ento::ExplodedGraph&, clang::ento::BugReporter&, clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_126IdempotentOperationChecker23CFGReachabilityAnalysis11isReachableEPKN5clang8CFGBlockES5_", "(anonymous namespace)::IdempotentOperationChecker::CFGReachabilityAnalysis::isReachable(clang::CFGBlock const*, clang::CFGBlock const*)"},
    {"_ZZN12_GLOBAL__N_126IdempotentOperationChecker25PathWasCompletelyAnalyzedEPKN5clang3CFGEPKNS1_8CFGBlockEPKNS1_10CFGStmtMapERKNS1_4ento10CoreEngineEEN7VisitWLD1Ev", "(anonymous namespace)::IdempotentOperationChecker::PathWasCompletelyAnalyzed(clang::CFG const*, clang::CFGBlock const*, clang::CFGStmtMap const*, clang::ento::CoreEngine const&)::VisitWL::~VisitWL()"},
    {"_ZZN12_GLOBAL__N_126IdempotentOperationChecker25PathWasCompletelyAnalyzedEPKN5clang3CFGEPKNS1_8CFGBlockEPKNS1_10CFGStmtMapERKNS1_4ento10CoreEngineEEN7VisitWLD0Ev", "(anonymous namespace)::IdempotentOperationChecker::PathWasCompletelyAnalyzed(clang::CFG const*, clang::CFGBlock const*, clang::CFGStmtMap const*, clang::ento::CoreEngine const&)::VisitWL::~VisitWL()"},
    {"_ZZN12_GLOBAL__N_126IdempotentOperationChecker25PathWasCompletelyAnalyzedEPKN5clang3CFGEPKNS1_8CFGBlockEPKNS1_10CFGStmtMapERKNS1_4ento10CoreEngineEEN7VisitWL5visitERKNSB_12WorkListUnitE", "(anonymous namespace)::IdempotentOperationChecker::PathWasCompletelyAnalyzed(clang::CFG const*, clang::CFGBlock const*, clang::CFGStmtMap const*, clang::ento::CoreEngine const&)::VisitWL::visit(clang::ento::WorkListUnit const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang14BinaryOperatorEN12_GLOBAL__N_126IdempotentOperationChecker18BinaryOperatorDataENS_12DenseMapInfoIS4_EENS8_IS7_EEEixERKS4_", "llvm::DenseMap<clang::BinaryOperator const*, (anonymous namespace)::IdempotentOperationChecker::BinaryOperatorData, llvm::DenseMapInfo<clang::BinaryOperator const*>, llvm::DenseMapInfo<(anonymous namespace)::IdempotentOperationChecker::BinaryOperatorData>>::operator[](clang::BinaryOperator const* const&)"},
    {"_ZN12_GLOBAL__N_126IdempotentOperationChecker22PreVisitBinaryOperatorERN5clang4ento14CheckerContextEPKNS1_14BinaryOperatorE", "(anonymous namespace)::IdempotentOperationChecker::PreVisitBinaryOperator(clang::ento::CheckerContext&, clang::BinaryOperator const*)"},
    {"_ZN12_GLOBAL__N_126IdempotentOperationChecker7CanVaryEPKN5clang4ExprEPNS1_15AnalysisContextE", "(anonymous namespace)::IdempotentOperationChecker::CanVary(clang::Expr const*, clang::AnalysisContext*)"},
    {"_ZN12_GLOBAL__N_126IdempotentOperationChecker23containsNonLocalVarDeclEPKN5clang4StmtE", "(anonymous namespace)::IdempotentOperationChecker::containsNonLocalVarDecl(clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126IdempotentOperationCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::IdempotentOperationChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126IdempotentOperationCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::IdempotentOperationChecker>::~CheckerVisitor()"},
    {"_ZNSt6vectorISt4pairIPFvRN5clang4ento18BugReporterContextEPKvPKNS2_12ExplodedNodeEES6_ESaISC_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSC_SE_EERKSC_", "std::vector<std::pair<void (*)(clang::ento::BugReporterContext&, void const*, clang::ento::ExplodedNode const*), void const*>, std::allocator<std::pair<void (*)(clang::ento::BugReporterContext&, void const*, clang::ento::ExplodedNode const*), void const*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<void (*)(clang::ento::BugReporterContext&, void const*, clang::ento::ExplodedNode const*), void const*>*, std::vector<std::pair<void (*)(clang::ento::BugReporterContext&, void const*, clang::ento::ExplodedNode const*), void const*>, std::allocator<std::pair<void (*)(clang::ento::BugReporterContext&, void const*, clang::ento::ExplodedNode const*), void const*>>>>, std::pair<void (*)(clang::ento::BugReporterContext&, void const*, clang::ento::ExplodedNode const*), void const*> const&)"},
    {"_ZN4llvm8DenseMapIjNS_8SmallSetIjLj32EEENS_12DenseMapInfoIjEENS3_IS2_EEE16FindAndConstructERKj", "llvm::DenseMap<unsigned int, llvm::SmallSet<unsigned int, 32u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallSet<unsigned int, 32u>>>::FindAndConstruct(unsigned int const&)"},
    {"_ZN4llvm8DenseMapIjNS_8SmallSetIjLj32EEENS_12DenseMapInfoIjEENS3_IS2_EEE16InsertIntoBucketERKjRKS2_PSt4pairIjS2_E", "llvm::DenseMap<unsigned int, llvm::SmallSet<unsigned int, 32u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallSet<unsigned int, 32u>>>::InsertIntoBucket(unsigned int const&, llvm::SmallSet<unsigned int, 32u> const&, std::pair<unsigned int, llvm::SmallSet<unsigned int, 32u>>*)"},
    {"_ZN4llvm8DenseMapIjNS_8SmallSetIjLj32EEENS_12DenseMapInfoIjEENS3_IS2_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::SmallSet<unsigned int, 32u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallSet<unsigned int, 32u>>>::grow(unsigned int)"},
    {"_ZNSt5dequeIPKN5clang8CFGBlockESaIS3_EE9push_backERKS3_", "std::deque<clang::CFGBlock const*, std::allocator<clang::CFGBlock const*>>::push_back(clang::CFGBlock const* const&)"},
    {"_ZNSt5dequeIPKN5clang8CFGBlockESaIS3_EE17_M_reallocate_mapEmb", "std::deque<clang::CFGBlock const*, std::allocator<clang::CFGBlock const*>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZNSt11_Deque_baseIPKN5clang8CFGBlockESaIS3_EE17_M_initialize_mapEm", "std::_Deque_base<clang::CFGBlock const*, std::allocator<clang::CFGBlock const*>>::_M_initialize_map(unsigned long)"},
    {"_ZN4llvm8DenseMapIjNS_8SmallSetIjLj32EEENS_12DenseMapInfoIjEENS3_IS2_EEED1Ev", "llvm::DenseMap<unsigned int, llvm::SmallSet<unsigned int, 32u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallSet<unsigned int, 32u>>>::~DenseMap()"},
    {"_ZN5clang4ento20CheckLLVMConventionsERNS_19TranslationUnitDeclERNS0_11BugReporterE", "clang::ento::CheckLLVMConventions(clang::TranslationUnitDecl&, clang::ento::BugReporter&)"},
    {"_Z13ScanCodeDeclsPN5clang11DeclContextERNS_4ento11BugReporterE", "ScanCodeDecls(clang::DeclContext*, clang::ento::BugReporter&)"},
    {"_Z11IsPartOfASTPKN5clang13CXXRecordDeclE", "IsPartOfAST(clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_115ASTFieldVisitor5VisitEPN5clang9FieldDeclE", "(anonymous namespace)::ASTFieldVisitor::Visit(clang::FieldDecl*)"},
    {"_Z11IsStdStringN5clang8QualTypeE", "IsStdString(clang::QualType)"},
    {"_Z11InNamespacePKN5clang4DeclEN4llvm9StringRefE", "InNamespace(clang::Decl const*, llvm::StringRef)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_123StringRefCheckerVisitorEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::StringRefCheckerVisitor, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_123StringRefCheckerVisitor13VisitChildrenEPN5clang4StmtE", "(anonymous namespace)::StringRefCheckerVisitor::VisitChildren(clang::Stmt*)"},
    {"_ZN5clang4ento24RegisterMacOSXAPICheckerERNS0_10ExprEngineE", "clang::ento::RegisterMacOSXAPIChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_116MacOSXAPICheckerD1Ev", "(anonymous namespace)::MacOSXAPIChecker::~MacOSXAPIChecker()"},
    {"_ZN12_GLOBAL__N_116MacOSXAPICheckerD0Ev", "(anonymous namespace)::MacOSXAPIChecker::~MacOSXAPIChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_116MacOSXAPICheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::MacOSXAPIChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_116MacOSXAPICheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::MacOSXAPIChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_Z17CheckDispatchOnceRN5clang4ento14CheckerContextEPKNS_8CallExprERPNS0_7BugTypeEPKNS_14IdentifierInfoE", "CheckDispatchOnce(clang::ento::CheckerContext&, clang::CallExpr const*, clang::ento::BugType*&, clang::IdentifierInfo const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_116MacOSXAPICheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::MacOSXAPIChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_116MacOSXAPICheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::MacOSXAPIChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento21RegisterMallocCheckerERNS0_10ExprEngineE", "clang::ento::RegisterMallocChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_113MallocCheckerD1Ev", "(anonymous namespace)::MallocChecker::~MallocChecker()"},
    {"_ZN12_GLOBAL__N_113MallocCheckerD0Ev", "(anonymous namespace)::MallocChecker::~MallocChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113MallocCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::MallocChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113MallocCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::MallocChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_113MallocChecker13visitLocationERN5clang4ento14CheckerContextEPKNS1_4StmtENS2_4SValEb", "(anonymous namespace)::MallocChecker::visitLocation(clang::ento::CheckerContext&, clang::Stmt const*, clang::ento::SVal, bool)"},
    {"_ZN12_GLOBAL__N_113MallocChecker12PreVisitBindERN5clang4ento14CheckerContextEPKNS1_4StmtENS2_4SValES8_", "(anonymous namespace)::MallocChecker::PreVisitBind(clang::ento::CheckerContext&, clang::Stmt const*, clang::ento::SVal, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_113MallocChecker15evalDeadSymbolsERN5clang4ento14CheckerContextERNS2_12SymbolReaperE", "(anonymous namespace)::MallocChecker::evalDeadSymbols(clang::ento::CheckerContext&, clang::ento::SymbolReaper&)"},
    {"_ZN12_GLOBAL__N_113MallocChecker11evalEndPathERN5clang4ento24EndOfFunctionNodeBuilderEPvRNS2_10ExprEngineE", "(anonymous namespace)::MallocChecker::evalEndPath(clang::ento::EndOfFunctionNodeBuilder&, void*, clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_113MallocChecker12evalCallExprERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::MallocChecker::evalCallExpr(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_113MallocChecker10evalAssumeEPKN5clang4ento7GRStateENS2_4SValEbPb", "(anonymous namespace)::MallocChecker::evalAssume(clang::ento::GRState const*, clang::ento::SVal, bool, bool*)"},
    {"_ZNK5clang4ento7GRState3setIN12_GLOBAL__N_111RegionStateEEEPKS1_NS0_12GRStateTraitIT_E8key_typeENS9_10value_typeE", "clang::ento::GRState const* clang::ento::GRState::set<(anonymous namespace)::RegionState>(clang::ento::GRStateTrait<(anonymous namespace)::RegionState>::key_type, clang::ento::GRStateTrait<(anonymous namespace)::RegionState>::value_type) const"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>::destroy()"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEEENS_12DenseMapInfoIjEENSD_ISC_EEEixERKj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*>>::operator[](unsigned int const&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEEESaISC_EE9push_backERKSC_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*>>::push_back(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>* const&)"},
    {"_ZN4llvm26ImutAVLTreeInOrderIteratorINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEEppEv", "llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>::operator++()"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_18RefStateENS2_16ImutKeyValueInfoIS6_S8_EEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefState, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_18RefStateENS2_16ImutKeyValueInfoIS6_S8_EEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefState, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>>::DeleteContext(void*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEE12add_internalERKSt4pairIS6_S8_EPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>::add_internal(std::pair<clang::ento::SymbolData const*, (anonymous namespace)::RefState> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEE13markImmutableEPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEE10createNodeEPNS_11ImutAVLTreeIS9_EERKSt4pairIS6_S8_ESD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*, std::pair<clang::ento::SymbolData const*, (anonymous namespace)::RefState> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEE11balanceTreeEPNS_11ImutAVLTreeIS9_EERKSt4pairIS6_S8_ESD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*, std::pair<clang::ento::SymbolData const*, (anonymous namespace)::RefState> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*)"},
    {"_ZN12_GLOBAL__N_113MallocChecker10FreeMemAuxERN5clang4ento14CheckerContextEPKNS1_8CallExprEPKNS2_7GRStateEjb", "(anonymous namespace)::MallocChecker::FreeMemAux(clang::ento::CheckerContext&, clang::CallExpr const*, clang::ento::GRState const*, unsigned int, bool)"},
    {"_ZN12_GLOBAL__N_113MallocChecker13ReportBadFreeERN5clang4ento14CheckerContextENS2_4SValENS1_11SourceRangeE", "(anonymous namespace)::MallocChecker::ReportBadFree(clang::ento::CheckerContext&, clang::ento::SVal, clang::SourceRange)"},
    {"_ZN12_GLOBAL__N_113MallocChecker12MallocMemAuxERN5clang4ento14CheckerContextEPKNS1_8CallExprENS2_4SValES8_PKNS2_7GRStateE", "(anonymous namespace)::MallocChecker::MallocMemAux(clang::ento::CheckerContext&, clang::CallExpr const*, clang::ento::SVal, clang::ento::SVal, clang::ento::GRState const*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEE15remove_internalERKS6_PNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>::remove_internal(clang::ento::SymbolData const* const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RefStateEEEE16removeMinBindingEPNS_11ImutAVLTreeIS9_EERSD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>::removeMinBinding(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefState>>*&)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113MallocCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::MallocChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113MallocCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::MallocChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento31RegisterNSAutoreleasePoolChecksERNS0_10ExprEngineE", "clang::ento::RegisterNSAutoreleasePoolChecks(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_124NSAutoreleasePoolCheckerD1Ev", "(anonymous namespace)::NSAutoreleasePoolChecker::~NSAutoreleasePoolChecker()"},
    {"_ZN12_GLOBAL__N_124NSAutoreleasePoolCheckerD0Ev", "(anonymous namespace)::NSAutoreleasePoolChecker::~NSAutoreleasePoolChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_124NSAutoreleasePoolCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::NSAutoreleasePoolChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_124NSAutoreleasePoolCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::NSAutoreleasePoolChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_124NSAutoreleasePoolChecker19preVisitObjCMessageERN5clang4ento14CheckerContextENS2_11ObjCMessageE", "(anonymous namespace)::NSAutoreleasePoolChecker::preVisitObjCMessage(clang::ento::CheckerContext&, clang::ento::ObjCMessage)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_124NSAutoreleasePoolCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::NSAutoreleasePoolChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_124NSAutoreleasePoolCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::NSAutoreleasePoolChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento21RegisterNSErrorChecksERNS0_11BugReporterERNS0_10ExprEngineERKNS_4DeclE", "clang::ento::RegisterNSErrorChecks(clang::ento::BugReporter&, clang::ento::ExprEngine&, clang::Decl const&)"},
    {"_ZN12_GLOBAL__N_114NSErrorCheckerC1ERKN5clang4DeclEbRNS1_4ento10ExprEngineE", "(anonymous namespace)::NSErrorChecker::NSErrorChecker(clang::Decl const&, bool, clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_114NSErrorCheckerD1Ev", "(anonymous namespace)::NSErrorChecker::~NSErrorChecker()"},
    {"_ZN12_GLOBAL__N_114NSErrorCheckerD0Ev", "(anonymous namespace)::NSErrorChecker::~NSErrorChecker()"},
    {"_ZN12_GLOBAL__N_114NSErrorChecker12FlushReportsERN5clang4ento11BugReporterE", "(anonymous namespace)::NSErrorChecker::FlushReports(clang::ento::BugReporter&)"},
    {"_ZN12_GLOBAL__N_114NSErrorChecker20CheckNSErrorArgumentEN5clang8QualTypeE", "(anonymous namespace)::NSErrorChecker::CheckNSErrorArgument(clang::QualType)"},
    {"_ZN5clang4ento31RegisterNoReturnFunctionCheckerERNS0_10ExprEngineE", "clang::ento::RegisterNoReturnFunctionChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_123NoReturnFunctionCheckerD1Ev", "(anonymous namespace)::NoReturnFunctionChecker::~NoReturnFunctionChecker()"},
    {"_ZN12_GLOBAL__N_123NoReturnFunctionCheckerD0Ev", "(anonymous namespace)::NoReturnFunctionChecker::~NoReturnFunctionChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_123NoReturnFunctionCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::NoReturnFunctionChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_123NoReturnFunctionCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::NoReturnFunctionChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_123NoReturnFunctionCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::NoReturnFunctionChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_123NoReturnFunctionCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::NoReturnFunctionChecker>::~CheckerVisitor()"},
    {"_ZNK5clang4Decl7getAttrINS_20AnalyzerNoReturnAttrEEEPT_v", "clang::AnalyzerNoReturnAttr* clang::Decl::getAttr<clang::AnalyzerNoReturnAttr>() const"},
    {"_ZN5clang4ento23RegisterOSAtomicCheckerERNS0_10ExprEngineE", "clang::ento::RegisterOSAtomicChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_115OSAtomicCheckerD1Ev", "(anonymous namespace)::OSAtomicChecker::~OSAtomicChecker()"},
    {"_ZN12_GLOBAL__N_115OSAtomicCheckerD0Ev", "(anonymous namespace)::OSAtomicChecker::~OSAtomicChecker()"},
    {"_ZN12_GLOBAL__N_115OSAtomicChecker12evalCallExprERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::OSAtomicChecker::evalCallExpr(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN5clang4ento25RegisterObjCAtSyncCheckerERNS0_10ExprEngineE", "clang::ento::RegisterObjCAtSyncChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_117ObjCAtSyncCheckerD1Ev", "(anonymous namespace)::ObjCAtSyncChecker::~ObjCAtSyncChecker()"},
    {"_ZN12_GLOBAL__N_117ObjCAtSyncCheckerD0Ev", "(anonymous namespace)::ObjCAtSyncChecker::~ObjCAtSyncChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117ObjCAtSyncCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ObjCAtSyncChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117ObjCAtSyncCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ObjCAtSyncChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117ObjCAtSyncCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ObjCAtSyncChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117ObjCAtSyncCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ObjCAtSyncChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento27registerObjCSelfInitCheckerERNS0_10ExprEngineE", "clang::ento::registerObjCSelfInitChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_119ObjCSelfInitCheckerD1Ev", "(anonymous namespace)::ObjCSelfInitChecker::~ObjCSelfInitChecker()"},
    {"_ZN12_GLOBAL__N_119ObjCSelfInitCheckerD0Ev", "(anonymous namespace)::ObjCSelfInitChecker::~ObjCSelfInitChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ObjCSelfInitCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ObjCSelfInitChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ObjCSelfInitCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ObjCSelfInitChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_119ObjCSelfInitChecker20postVisitObjCMessageERN5clang4ento14CheckerContextENS2_11ObjCMessageE", "(anonymous namespace)::ObjCSelfInitChecker::postVisitObjCMessage(clang::ento::CheckerContext&, clang::ento::ObjCMessage)"},
    {"_ZN12_GLOBAL__N_119ObjCSelfInitChecker13visitLocationERN5clang4ento14CheckerContextEPKNS1_4StmtENS2_4SValEb", "(anonymous namespace)::ObjCSelfInitChecker::visitLocation(clang::ento::CheckerContext&, clang::Stmt const*, clang::ento::SVal, bool)"},
    {"_Z11addSelfFlagN5clang4ento4SValEN12_GLOBAL__N_112SelfFlagEnumERNS0_14CheckerContextE", "addSelfFlag(clang::ento::SVal, (anonymous namespace)::SelfFlagEnum, clang::ento::CheckerContext&)"},
    {"_Z12getSelfFlagsN5clang4ento4SValERNS0_14CheckerContextE", "getSelfFlags(clang::ento::SVal, clang::ento::CheckerContext&)"},
    {"_Z27shouldRunOnFunctionOrMethodPKN5clang9NamedDeclE", "shouldRunOnFunctionOrMethod(clang::NamedDecl const*)"},
    {"_Z19checkForInvalidSelfPKN5clang4ExprERNS_4ento14CheckerContextEPKc", "checkForInvalidSelf(clang::Expr const*, clang::ento::CheckerContext&, char const*)"},
    {"_ZN12_GLOBAL__N_111InitSelfBugD1Ev", "(anonymous namespace)::InitSelfBug::~InitSelfBug()"},
    {"_ZN12_GLOBAL__N_111InitSelfBugD0Ev", "(anonymous namespace)::InitSelfBug::~InitSelfBug()"},
    {"_ZN12_GLOBAL__N_119ObjCSelfInitChecker20PostVisitGenericCallERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::ObjCSelfInitChecker::PostVisitGenericCall(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_119ObjCSelfInitChecker19PreVisitGenericCallERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::ObjCSelfInitChecker::PreVisitGenericCall(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ObjCSelfInitCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ObjCSelfInitChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119ObjCSelfInitCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ObjCSelfInitChecker>::~CheckerVisitor()"},
    {"_ZNSt6vectorISt4pairIPvPN5clang4ento7CheckerEESaIS6_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS6_S8_EERKS6_", "std::vector<std::pair<void*, clang::ento::Checker*>, std::allocator<std::pair<void*, clang::ento::Checker*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<void*, clang::ento::Checker*>*, std::vector<std::pair<void*, clang::ento::Checker*>, std::allocator<std::pair<void*, clang::ento::Checker*>>>>, std::pair<void*, clang::ento::Checker*> const&)"},
    {"_ZN5clang4ento7Checker19preVisitObjCMessageERNS0_14CheckerContextENS0_11ObjCMessageE", "clang::ento::Checker::preVisitObjCMessage(clang::ento::CheckerContext&, clang::ento::ObjCMessage)"},
    {"_ZN5clang4ento7Checker12PreVisitBindERNS0_14CheckerContextEPKNS_4StmtENS0_4SValES7_", "clang::ento::Checker::PreVisitBind(clang::ento::CheckerContext&, clang::Stmt const*, clang::ento::SVal, clang::ento::SVal)"},
    {"_ZN5clang4ento7Checker15evalDeadSymbolsERNS0_14CheckerContextERNS0_12SymbolReaperE", "clang::ento::Checker::evalDeadSymbols(clang::ento::CheckerContext&, clang::ento::SymbolReaper&)"},
    {"_ZN5clang4ento7Checker11evalEndPathERNS0_24EndOfFunctionNodeBuilderEPvRNS0_10ExprEngineE", "clang::ento::Checker::evalEndPath(clang::ento::EndOfFunctionNodeBuilder&, void*, clang::ento::ExprEngine&)"},
    {"_ZN5clang4ento7Checker15MarkLiveSymbolsEPKNS0_7GRStateERNS0_12SymbolReaperE", "clang::ento::Checker::MarkLiveSymbols(clang::ento::GRState const*, clang::ento::SymbolReaper&)"},
    {"_ZN5clang4ento7Checker20VisitBranchConditionERNS0_17BranchNodeBuilderERNS0_10ExprEngineEPKNS_4StmtEPv", "clang::ento::Checker::VisitBranchCondition(clang::ento::BranchNodeBuilder&, clang::ento::ExprEngine&, clang::Stmt const*, void*)"},
    {"_ZN5clang4ento7Checker15evalNilReceiverERNS0_14CheckerContextENS0_11ObjCMessageE", "clang::ento::Checker::evalNilReceiver(clang::ento::CheckerContext&, clang::ento::ObjCMessage)"},
    {"_ZN5clang4ento7Checker12evalCallExprERNS0_14CheckerContextEPKNS_8CallExprE", "clang::ento::Checker::evalCallExpr(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN5clang4ento7Checker10evalAssumeEPKNS0_7GRStateENS0_4SValEbPb", "clang::ento::Checker::evalAssume(clang::ento::GRState const*, clang::ento::SVal, bool, bool*)"},
    {"_ZN5clang4ento7Checker23wantsRegionChangeUpdateEPKNS0_7GRStateE", "clang::ento::Checker::wantsRegionChangeUpdate(clang::ento::GRState const*)"},
    {"_ZN5clang4ento7Checker17EvalRegionChangesEPKNS0_7GRStateEPKPKNS0_9MemRegionES9_Pb", "clang::ento::Checker::EvalRegionChanges(clang::ento::GRState const*, clang::ento::MemRegion const* const*, clang::ento::MemRegion const* const*, bool*)"},
    {"_ZN5clang4ento7Checker16VisitEndAnalysisERNS0_13ExplodedGraphERNS0_11BugReporterERNS0_10ExprEngineE", "clang::ento::Checker::VisitEndAnalysis(clang::ento::ExplodedGraph&, clang::ento::BugReporter&, clang::ento::ExprEngine&)"},
    {"_ZN5clang4ento14CheckerContext13addTransitionEPKNS0_7GRStateEPKv", "clang::ento::CheckerContext::addTransition(clang::ento::GRState const*, void const*)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::destroy()"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEEESaISA_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSA_SC_EERKSA_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>**, std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*>>>, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>* const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEEENS_12DenseMapInfoIjEENSB_ISA_EEE16InsertIntoBucketERKjRKSA_PSt4pairIjSA_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEEENS_12DenseMapInfoIjEENSB_ISA_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*>>::grow(unsigned int)"},
    {"_ZN5clang4ento14GRStateManager3setIN4llvm12ImmutableMapIPKNS0_10SymbolDataEjNS3_16ImutKeyValueInfoIS7_jEEEEEEPKNS0_7GRStateESD_NS0_12GRStateTraitIT_E8key_typeENSG_10value_typeENSG_12context_typeE", "clang::ento::GRState const* clang::ento::GRStateManager::set<llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>(clang::ento::GRState const*, clang::ento::GRStateTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>::key_type, clang::ento::GRStateTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>::value_type, clang::ento::GRStateTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>::context_type)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEjNS2_16ImutKeyValueInfoIS6_jEEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEjNS2_16ImutKeyValueInfoIS6_jEEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>::DeleteContext(void*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::~ImutAVLFactory()"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEjNS2_16ImutKeyValueInfoIS6_jEEEEE3SetES9_S6_jRNS9_7FactoryE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>::Set(llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>, clang::ento::SymbolData const*, unsigned int, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::Factory&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEE3addEPNS_11ImutAVLTreeIS7_EERKSt4pairIS6_jE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::add(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*, std::pair<clang::ento::SymbolData const*, unsigned int> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEE22compareTreeWithSectionEPNS_11ImutAVLTreeIS7_EERNS_26ImutAVLTreeInOrderIteratorIS7_EESE_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>&)"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::operator++()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEE12add_internalERKSt4pairIS6_jEPNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::add_internal(std::pair<clang::ento::SymbolData const*, unsigned int> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEE13markImmutableEPNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEE10createNodeEPNS_11ImutAVLTreeIS7_EERKSt4pairIS6_jESB_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*, std::pair<clang::ento::SymbolData const*, unsigned int> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEE11balanceTreeEPNS_11ImutAVLTreeIS7_EERKSt4pairIS6_jESB_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*, std::pair<clang::ento::SymbolData const*, unsigned int> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>*)"},
    {"_ZN4llvm10FoldingSetIN5clang4ento19BugReportEquivClassEED1Ev", "llvm::FoldingSet<clang::ento::BugReportEquivClass>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang4ento19BugReportEquivClassEED0Ev", "llvm::FoldingSet<clang::ento::BugReportEquivClass>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento19BugReportEquivClassEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::BugReportEquivClass>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento19BugReportEquivClassEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::ento::BugReportEquivClass>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento19BugReportEquivClassEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::BugReportEquivClass>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento17EnhancedBugReportD1Ev", "clang::ento::EnhancedBugReport::~EnhancedBugReport()"},
    {"_ZN5clang4ento17EnhancedBugReportD0Ev", "clang::ento::EnhancedBugReport::~EnhancedBugReport()"},
    {"_ZN5clang4ento9BugReport24isOwnedByReporterContextEv", "clang::ento::BugReport::isOwnedByReporterContext()"},
    {"_ZNK5clang4ento9BugReport7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::BugReport::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento9BugReport23getExtraDescriptiveTextEv", "clang::ento::BugReport::getExtraDescriptiveText()"},
    {"_ZNK5clang4ento15RangedBugReport9getRangesEv", "clang::ento::RangedBugReport::getRanges() const"},
    {"_ZN5clang4ento17EnhancedBugReport23registerInitialVisitorsERNS0_18BugReporterContextEPKNS0_12ExplodedNodeE", "clang::ento::EnhancedBugReport::registerInitialVisitors(clang::ento::BugReporterContext&, clang::ento::ExplodedNode const*)"},
    {"_ZN5clang4ento9BugReport23registerInitialVisitorsERNS0_18BugReporterContextEPKNS0_12ExplodedNodeE", "clang::ento::BugReport::registerInitialVisitors(clang::ento::BugReporterContext&, clang::ento::ExplodedNode const*)"},
    {"_ZN5clang4ento18BugReporterVisitor24isOwnedByReporterContextEv", "clang::ento::BugReporterVisitor::isOwnedByReporterContext()"},
    {"_ZN5clang4ento7Checker20postVisitObjCMessageERNS0_14CheckerContextENS0_11ObjCMessageE", "clang::ento::Checker::postVisitObjCMessage(clang::ento::CheckerContext&, clang::ento::ObjCMessage)"},
    {"_ZN5clang4ento7Checker13visitLocationERNS0_14CheckerContextEPKNS_4StmtENS0_4SValEb", "clang::ento::Checker::visitLocation(clang::ento::CheckerContext&, clang::Stmt const*, clang::ento::SVal, bool)"},
    {"_ZN5clang4ento7Checker9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::Checker::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento7Checker10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::Checker::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento19CheckObjCUnusedIvarEPKNS_22ObjCImplementationDeclERNS0_11BugReporterE", "clang::ento::CheckObjCUnusedIvar(clang::ObjCImplementationDecl const*, clang::ento::BugReporter&)"},
    {"_Z4ScanRN4llvm8DenseMapIPKN5clang12ObjCIvarDeclE9IVarStateNS_12DenseMapInfoIS4_EENS6_IS5_EEEEPKNS1_17ObjCContainerDeclE", "Scan(llvm::DenseMap<clang::ObjCIvarDecl const*, IVarState, llvm::DenseMapInfo<clang::ObjCIvarDecl const*>, llvm::DenseMapInfo<IVarState>>&, clang::ObjCContainerDecl const*)"},
    {"_Z4ScanRN4llvm8DenseMapIPKN5clang12ObjCIvarDeclE9IVarStateNS_12DenseMapInfoIS4_EENS6_IS5_EEEEPKNS1_4StmtE", "Scan(llvm::DenseMap<clang::ObjCIvarDecl const*, IVarState, llvm::DenseMapInfo<clang::ObjCIvarDecl const*>, llvm::DenseMapInfo<IVarState>>&, clang::Stmt const*)"},
    {"_ZNK5clang4Decl7getAttrINS_10UnusedAttrEEEPT_v", "clang::UnusedAttr* clang::Decl::getAttr<clang::UnusedAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_12IBOutletAttrEEEPT_v", "clang::IBOutletAttr* clang::Decl::getAttr<clang::IBOutletAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_22IBOutletCollectionAttrEEEPT_v", "clang::IBOutletCollectionAttr* clang::Decl::getAttr<clang::IBOutletCollectionAttr>() const"},
    {"_ZN4llvm8DenseMapIPKN5clang12ObjCIvarDeclE9IVarStateNS_12DenseMapInfoIS4_EENS6_IS5_EEE16InsertIntoBucketERKS4_RKS5_PSt4pairIS4_S5_E", "llvm::DenseMap<clang::ObjCIvarDecl const*, IVarState, llvm::DenseMapInfo<clang::ObjCIvarDecl const*>, llvm::DenseMapInfo<IVarState>>::InsertIntoBucket(clang::ObjCIvarDecl const* const&, IVarState const&, std::pair<clang::ObjCIvarDecl const*, IVarState>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang12ObjCIvarDeclE9IVarStateNS_12DenseMapInfoIS4_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::ObjCIvarDecl const*, IVarState, llvm::DenseMapInfo<clang::ObjCIvarDecl const*>, llvm::DenseMapInfo<IVarState>>::grow(unsigned int)"},
    {"_ZN5clang4ento27RegisterPointerArithCheckerERNS0_10ExprEngineE", "clang::ento::RegisterPointerArithChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_119PointerArithCheckerD1Ev", "(anonymous namespace)::PointerArithChecker::~PointerArithChecker()"},
    {"_ZN12_GLOBAL__N_119PointerArithCheckerD0Ev", "(anonymous namespace)::PointerArithChecker::~PointerArithChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119PointerArithCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::PointerArithChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119PointerArithCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::PointerArithChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_119PointerArithChecker22PreVisitBinaryOperatorERN5clang4ento14CheckerContextEPKNS1_14BinaryOperatorE", "(anonymous namespace)::PointerArithChecker::PreVisitBinaryOperator(clang::ento::CheckerContext&, clang::BinaryOperator const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119PointerArithCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::PointerArithChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_119PointerArithCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::PointerArithChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento25RegisterPointerSubCheckerERNS0_10ExprEngineE", "clang::ento::RegisterPointerSubChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_117PointerSubCheckerD1Ev", "(anonymous namespace)::PointerSubChecker::~PointerSubChecker()"},
    {"_ZN12_GLOBAL__N_117PointerSubCheckerD0Ev", "(anonymous namespace)::PointerSubChecker::~PointerSubChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117PointerSubCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::PointerSubChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117PointerSubCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::PointerSubChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_117PointerSubChecker22PreVisitBinaryOperatorERN5clang4ento14CheckerContextEPKNS1_14BinaryOperatorE", "(anonymous namespace)::PointerSubChecker::PreVisitBinaryOperator(clang::ento::CheckerContext&, clang::BinaryOperator const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117PointerSubCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::PointerSubChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_117PointerSubCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::PointerSubChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento26RegisterPthreadLockCheckerERNS0_10ExprEngineE", "clang::ento::RegisterPthreadLockChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_118PthreadLockCheckerD1Ev", "(anonymous namespace)::PthreadLockChecker::~PthreadLockChecker()"},
    {"_ZN12_GLOBAL__N_118PthreadLockCheckerD0Ev", "(anonymous namespace)::PthreadLockChecker::~PthreadLockChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118PthreadLockCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::PthreadLockChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118PthreadLockCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::PthreadLockChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_118PthreadLockChecker11AcquireLockERN5clang4ento14CheckerContextEPKNS1_8CallExprENS2_4SValEb", "(anonymous namespace)::PthreadLockChecker::AcquireLock(clang::ento::CheckerContext&, clang::CallExpr const*, clang::ento::SVal, bool)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118PthreadLockCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::PthreadLockChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118PthreadLockCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::PthreadLockChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableSetIPKNS0_9MemRegionENS2_17ImutContainerInfoIS6_EEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableSetIPKNS0_9MemRegionENS2_17ImutContainerInfoIS6_EEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>>>::DeleteContext(void*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE6removeEPNS_11ImutAVLTreeIS7_EES6_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::remove(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*, clang::ento::MemRegion const*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE15remove_internalES6_PNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::remove_internal(clang::ento::MemRegion const*, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE16removeMinBindingEPNS_11ImutAVLTreeIS7_EERSB_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::removeMinBinding(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*&)"},
    {"_ZN5clang4ento33RegisterReturnPointerRangeCheckerERNS0_10ExprEngineE", "clang::ento::RegisterReturnPointerRangeChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_125ReturnPointerRangeCheckerD1Ev", "(anonymous namespace)::ReturnPointerRangeChecker::~ReturnPointerRangeChecker()"},
    {"_ZN12_GLOBAL__N_125ReturnPointerRangeCheckerD0Ev", "(anonymous namespace)::ReturnPointerRangeChecker::~ReturnPointerRangeChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_125ReturnPointerRangeCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ReturnPointerRangeChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_125ReturnPointerRangeCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ReturnPointerRangeChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_125ReturnPointerRangeCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ReturnPointerRangeChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_125ReturnPointerRangeCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ReturnPointerRangeChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento26RegisterReturnUndefCheckerERNS0_10ExprEngineE", "clang::ento::RegisterReturnUndefChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_118ReturnUndefCheckerD1Ev", "(anonymous namespace)::ReturnUndefChecker::~ReturnUndefChecker()"},
    {"_ZN12_GLOBAL__N_118ReturnUndefCheckerD0Ev", "(anonymous namespace)::ReturnUndefChecker::~ReturnUndefChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118ReturnUndefCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ReturnUndefChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118ReturnUndefCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::ReturnUndefChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118ReturnUndefCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ReturnUndefChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118ReturnUndefCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::ReturnUndefChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento28RegisterStackAddrLeakCheckerERNS0_10ExprEngineE", "clang::ento::RegisterStackAddrLeakChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_120StackAddrLeakCheckerD1Ev", "(anonymous namespace)::StackAddrLeakChecker::~StackAddrLeakChecker()"},
    {"_ZN12_GLOBAL__N_120StackAddrLeakCheckerD0Ev", "(anonymous namespace)::StackAddrLeakChecker::~StackAddrLeakChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120StackAddrLeakCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::StackAddrLeakChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120StackAddrLeakCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::StackAddrLeakChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_120StackAddrLeakChecker11evalEndPathERN5clang4ento24EndOfFunctionNodeBuilderEPvRNS2_10ExprEngineE", "(anonymous namespace)::StackAddrLeakChecker::evalEndPath(clang::ento::EndOfFunctionNodeBuilder&, void*, clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_120StackAddrLeakChecker7GenNameERN4llvm11raw_ostreamEPKN5clang4ento9MemRegionERNS4_13SourceManagerE", "(anonymous namespace)::StackAddrLeakChecker::GenName(llvm::raw_ostream&, clang::ento::MemRegion const*, clang::SourceManager&)"},
    {"_ZZN12_GLOBAL__N_120StackAddrLeakChecker11evalEndPathERN5clang4ento24EndOfFunctionNodeBuilderEPvRNS2_10ExprEngineEEN8CallBackD1Ev", "(anonymous namespace)::StackAddrLeakChecker::evalEndPath(clang::ento::EndOfFunctionNodeBuilder&, void*, clang::ento::ExprEngine&)::CallBack::~CallBack()"},
    {"_ZZN12_GLOBAL__N_120StackAddrLeakChecker11evalEndPathERN5clang4ento24EndOfFunctionNodeBuilderEPvRNS2_10ExprEngineEEN8CallBackD0Ev", "(anonymous namespace)::StackAddrLeakChecker::evalEndPath(clang::ento::EndOfFunctionNodeBuilder&, void*, clang::ento::ExprEngine&)::CallBack::~CallBack()"},
    {"_ZZN12_GLOBAL__N_120StackAddrLeakChecker11evalEndPathERN5clang4ento24EndOfFunctionNodeBuilderEPvRNS2_10ExprEngineEEN8CallBack13HandleBindingERNS2_12StoreManagerEPKvPKNS2_9MemRegionENS2_4SValE", "(anonymous namespace)::StackAddrLeakChecker::evalEndPath(clang::ento::EndOfFunctionNodeBuilder&, void*, clang::ento::ExprEngine&)::CallBack::HandleBinding(clang::ento::StoreManager&, void const*, clang::ento::MemRegion const*, clang::ento::SVal)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120StackAddrLeakCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::StackAddrLeakChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120StackAddrLeakCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::StackAddrLeakChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento21RegisterStreamCheckerERNS0_10ExprEngineE", "clang::ento::RegisterStreamChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_113StreamCheckerD1Ev", "(anonymous namespace)::StreamChecker::~StreamChecker()"},
    {"_ZN12_GLOBAL__N_113StreamCheckerD0Ev", "(anonymous namespace)::StreamChecker::~StreamChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113StreamCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::StreamChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113StreamCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::StreamChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_113StreamChecker15evalDeadSymbolsERN5clang4ento14CheckerContextERNS2_12SymbolReaperE", "(anonymous namespace)::StreamChecker::evalDeadSymbols(clang::ento::CheckerContext&, clang::ento::SymbolReaper&)"},
    {"_ZN12_GLOBAL__N_113StreamChecker11evalEndPathERN5clang4ento24EndOfFunctionNodeBuilderEPvRNS2_10ExprEngineE", "(anonymous namespace)::StreamChecker::evalEndPath(clang::ento::EndOfFunctionNodeBuilder&, void*, clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_113StreamChecker12evalCallExprERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::StreamChecker::evalCallExpr(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_113StreamChecker15CheckNullStreamEN5clang4ento4SValEPKNS2_7GRStateERNS2_14CheckerContextE", "(anonymous namespace)::StreamChecker::CheckNullStream(clang::ento::SVal, clang::ento::GRState const*, clang::ento::CheckerContext&)"},
    {"_ZNK5clang4ento7GRState3setIN12_GLOBAL__N_111StreamStateEEEPKS1_NS0_12GRStateTraitIT_E8key_typeENS9_10value_typeE", "clang::ento::GRState const* clang::ento::GRState::set<(anonymous namespace)::StreamState>(clang::ento::GRStateTrait<(anonymous namespace)::StreamState>::key_type, clang::ento::GRStateTrait<(anonymous namespace)::StreamState>::value_type) const"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_111StreamStateENS2_16ImutKeyValueInfoIS6_S8_EEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::StreamState, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_111StreamStateENS2_16ImutKeyValueInfoIS6_S8_EEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::StreamState, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>>::DeleteContext(void*)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_111StreamStateEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>::destroy()"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_111StreamStateEEEEENS_12DenseMapInfoIjEENSD_ISC_EEEixERKj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>*>>::operator[](unsigned int const&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_111StreamStateEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_111StreamStateEEEEESaISC_EE9push_backERKSC_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>*>>::push_back(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>* const&)"},
    {"_ZN4llvm26ImutAVLTreeInOrderIteratorINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_111StreamStateEEEEppEv", "llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>::operator++()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_111StreamStateEEEE12add_internalERKSt4pairIS6_S8_EPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>::add_internal(std::pair<clang::ento::SymbolData const*, (anonymous namespace)::StreamState> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_111StreamStateEEEE13markImmutableEPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_111StreamStateEEEE10createNodeEPNS_11ImutAVLTreeIS9_EERKSt4pairIS6_S8_ESD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>*, std::pair<clang::ento::SymbolData const*, (anonymous namespace)::StreamState> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_111StreamStateEEEE11balanceTreeEPNS_11ImutAVLTreeIS9_EERKSt4pairIS6_S8_ESD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>*, std::pair<clang::ento::SymbolData const*, (anonymous namespace)::StreamState> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::StreamState>>*)"},
    {"_ZN12_GLOBAL__N_113StreamChecker11OpenFileAuxERN5clang4ento14CheckerContextEPKNS1_8CallExprE", "(anonymous namespace)::StreamChecker::OpenFileAux(clang::ento::CheckerContext&, clang::CallExpr const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113StreamCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::StreamChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_113StreamCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::StreamChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento26RegisterUndefBranchCheckerERNS0_10ExprEngineE", "clang::ento::RegisterUndefBranchChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_118UndefBranchCheckerD1Ev", "(anonymous namespace)::UndefBranchChecker::~UndefBranchChecker()"},
    {"_ZN12_GLOBAL__N_118UndefBranchCheckerD0Ev", "(anonymous namespace)::UndefBranchChecker::~UndefBranchChecker()"},
    {"_ZN12_GLOBAL__N_118UndefBranchChecker20VisitBranchConditionERN5clang4ento17BranchNodeBuilderERNS2_10ExprEngineEPKNS1_4StmtEPv", "(anonymous namespace)::UndefBranchChecker::VisitBranchCondition(clang::ento::BranchNodeBuilder&, clang::ento::ExprEngine&, clang::Stmt const*, void*)"},
    {"_ZN12_GLOBAL__N_118UndefBranchChecker13FindUndefExpr8FindExprEPKN5clang4ExprE", "(anonymous namespace)::UndefBranchChecker::FindUndefExpr::FindExpr(clang::Expr const*)"},
    {"_ZN5clang4ento36RegisterUndefCapturedBlockVarCheckerERNS0_10ExprEngineE", "clang::ento::RegisterUndefCapturedBlockVarChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_128UndefCapturedBlockVarCheckerD1Ev", "(anonymous namespace)::UndefCapturedBlockVarChecker::~UndefCapturedBlockVarChecker()"},
    {"_ZN12_GLOBAL__N_128UndefCapturedBlockVarCheckerD0Ev", "(anonymous namespace)::UndefCapturedBlockVarChecker::~UndefCapturedBlockVarChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_128UndefCapturedBlockVarCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefCapturedBlockVarChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_128UndefCapturedBlockVarCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefCapturedBlockVarChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_Z20FindBlockDeclRefExprPKN5clang4StmtEPKNS_7VarDeclE", "FindBlockDeclRefExpr(clang::Stmt const*, clang::VarDecl const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_128UndefCapturedBlockVarCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefCapturedBlockVarChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_128UndefCapturedBlockVarCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefCapturedBlockVarChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento26RegisterUndefResultCheckerERNS0_10ExprEngineE", "clang::ento::RegisterUndefResultChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_118UndefResultCheckerD1Ev", "(anonymous namespace)::UndefResultChecker::~UndefResultChecker()"},
    {"_ZN12_GLOBAL__N_118UndefResultCheckerD0Ev", "(anonymous namespace)::UndefResultChecker::~UndefResultChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118UndefResultCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefResultChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118UndefResultCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefResultChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_118UndefResultChecker23PostVisitBinaryOperatorERN5clang4ento14CheckerContextEPKNS1_14BinaryOperatorE", "(anonymous namespace)::UndefResultChecker::PostVisitBinaryOperator(clang::ento::CheckerContext&, clang::BinaryOperator const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118UndefResultCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefResultChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_118UndefResultCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefResultChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento38RegisterUndefinedArraySubscriptCheckerERNS0_10ExprEngineE", "clang::ento::RegisterUndefinedArraySubscriptChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_130UndefinedArraySubscriptCheckerD1Ev", "(anonymous namespace)::UndefinedArraySubscriptChecker::~UndefinedArraySubscriptChecker()"},
    {"_ZN12_GLOBAL__N_130UndefinedArraySubscriptCheckerD0Ev", "(anonymous namespace)::UndefinedArraySubscriptChecker::~UndefinedArraySubscriptChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_130UndefinedArraySubscriptCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefinedArraySubscriptChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_130UndefinedArraySubscriptCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefinedArraySubscriptChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_130UndefinedArraySubscriptCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefinedArraySubscriptChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_130UndefinedArraySubscriptCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefinedArraySubscriptChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento34RegisterUndefinedAssignmentCheckerERNS0_10ExprEngineE", "clang::ento::RegisterUndefinedAssignmentChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_126UndefinedAssignmentCheckerD1Ev", "(anonymous namespace)::UndefinedAssignmentChecker::~UndefinedAssignmentChecker()"},
    {"_ZN12_GLOBAL__N_126UndefinedAssignmentCheckerD0Ev", "(anonymous namespace)::UndefinedAssignmentChecker::~UndefinedAssignmentChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126UndefinedAssignmentCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefinedAssignmentChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126UndefinedAssignmentCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefinedAssignmentChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_126UndefinedAssignmentChecker12PreVisitBindERN5clang4ento14CheckerContextEPKNS1_4StmtENS2_4SValES8_", "(anonymous namespace)::UndefinedAssignmentChecker::PreVisitBind(clang::ento::CheckerContext&, clang::Stmt const*, clang::ento::SVal, clang::ento::SVal)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126UndefinedAssignmentCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefinedAssignmentChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_126UndefinedAssignmentCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::UndefinedAssignmentChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento22RegisterUnixAPICheckerERNS0_10ExprEngineE", "clang::ento::RegisterUnixAPIChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_114UnixAPICheckerD1Ev", "(anonymous namespace)::UnixAPIChecker::~UnixAPIChecker()"},
    {"_ZN12_GLOBAL__N_114UnixAPICheckerD0Ev", "(anonymous namespace)::UnixAPIChecker::~UnixAPIChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114UnixAPICheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::UnixAPIChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114UnixAPICheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::UnixAPIChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_Z9CheckOpenRN5clang4ento14CheckerContextERN12_GLOBAL__N_114UnixAPICheckerEPKNS_8CallExprERPNS0_7BugTypeE", "CheckOpen(clang::ento::CheckerContext&, (anonymous namespace)::UnixAPIChecker&, clang::CallExpr const*, clang::ento::BugType*&)"},
    {"_Z16CheckPthreadOnceRN5clang4ento14CheckerContextERN12_GLOBAL__N_114UnixAPICheckerEPKNS_8CallExprERPNS0_7BugTypeE", "CheckPthreadOnce(clang::ento::CheckerContext&, (anonymous namespace)::UnixAPIChecker&, clang::CallExpr const*, clang::ento::BugType*&)"},
    {"_Z15CheckMallocZeroRN5clang4ento14CheckerContextERN12_GLOBAL__N_114UnixAPICheckerEPKNS_8CallExprERPNS0_7BugTypeE", "CheckMallocZero(clang::ento::CheckerContext&, (anonymous namespace)::UnixAPIChecker&, clang::CallExpr const*, clang::ento::BugType*&)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114UnixAPICheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::UnixAPIChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114UnixAPICheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::UnixAPIChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento30RegisterUnreachableCodeCheckerERNS0_10ExprEngineE", "clang::ento::RegisterUnreachableCodeChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_122UnreachableCodeCheckerD1Ev", "(anonymous namespace)::UnreachableCodeChecker::~UnreachableCodeChecker()"},
    {"_ZN12_GLOBAL__N_122UnreachableCodeCheckerD0Ev", "(anonymous namespace)::UnreachableCodeChecker::~UnreachableCodeChecker()"},
    {"_ZN12_GLOBAL__N_122UnreachableCodeChecker16VisitEndAnalysisERN5clang4ento13ExplodedGraphERNS2_11BugReporterERNS2_10ExprEngineE", "(anonymous namespace)::UnreachableCodeChecker::VisitEndAnalysis(clang::ento::ExplodedGraph&, clang::ento::BugReporter&, clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_122UnreachableCodeChecker26FindUnreachableEntryPointsEPKN5clang8CFGBlockE", "(anonymous namespace)::UnreachableCodeChecker::FindUnreachableEntryPoints(clang::CFGBlock const*)"},
    {"_ZN4llvm8SmallSetIjLj256EE6insertERKj", "llvm::SmallSet<unsigned int, 256u>::insert(unsigned int const&)"},
    {"_ZN5clang4ento12containsStmtINS_17SizeOfAlignOfExprEEEbPKNS_4StmtE", "bool clang::ento::containsStmt<clang::SizeOfAlignOfExpr>(clang::Stmt const*)"},
    {"_ZN5clang4ento22RegisterVLASizeCheckerERNS0_10ExprEngineE", "clang::ento::RegisterVLASizeChecker(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_114VLASizeCheckerD1Ev", "(anonymous namespace)::VLASizeChecker::~VLASizeChecker()"},
    {"_ZN12_GLOBAL__N_114VLASizeCheckerD0Ev", "(anonymous namespace)::VLASizeChecker::~VLASizeChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114VLASizeCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::VLASizeChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114VLASizeCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::VLASizeChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114VLASizeCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::VLASizeChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_114VLASizeCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::VLASizeChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento10ExprEngine12VisitAggExprEPKNS_4ExprEPKNS0_9MemRegionEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitAggExpr(clang::Expr const*, clang::ento::MemRegion const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_114AggExprVisitorEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::AggExprVisitor, void>::Visit(clang::Stmt*)"},
    {"_ZN5clang4ento15AnalysisManager29getAnalysisContextInAnotherTUEPKNS_4DeclE", "clang::ento::AnalysisManager::getAnalysisContextInAnotherTU(clang::Decl const*)"},
    {"_ZN5clang4ento28CreateBasicConstraintManagerERNS0_14GRStateManagerERNS0_9SubEngineE", "clang::ento::CreateBasicConstraintManager(clang::ento::GRStateManager&, clang::ento::SubEngine&)"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManagerD1Ev", "(anonymous namespace)::BasicConstraintManager::~BasicConstraintManager()"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManagerD0Ev", "(anonymous namespace)::BasicConstraintManager::~BasicConstraintManager()"},
    {"_ZNK12_GLOBAL__N_122BasicConstraintManager9getSymValEPKN5clang4ento7GRStateEPKNS2_10SymbolDataE", "(anonymous namespace)::BasicConstraintManager::getSymVal(clang::ento::GRState const*, clang::ento::SymbolData const*) const"},
    {"_ZNK12_GLOBAL__N_122BasicConstraintManager7isEqualEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntE", "(anonymous namespace)::BasicConstraintManager::isEqual(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&) const"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManager18removeDeadBindingsEPKN5clang4ento7GRStateERNS2_12SymbolReaperE", "(anonymous namespace)::BasicConstraintManager::removeDeadBindings(clang::ento::GRState const*, clang::ento::SymbolReaper&)"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManager5printEPKN5clang4ento7GRStateERN4llvm11raw_ostreamEPKcSA_", "(anonymous namespace)::BasicConstraintManager::print(clang::ento::GRState const*, llvm::raw_ostream&, char const*, char const*)"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManager11assumeSymNEEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::BasicConstraintManager::assumeSymNE(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManager11assumeSymEQEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::BasicConstraintManager::assumeSymEQ(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManager11assumeSymLTEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::BasicConstraintManager::assumeSymLT(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManager11assumeSymGTEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::BasicConstraintManager::assumeSymGT(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManager11assumeSymLEEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::BasicConstraintManager::assumeSymLE(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManager11assumeSymGEEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::BasicConstraintManager::assumeSymGE(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122BasicConstraintManager5AddEQEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntE", "(anonymous namespace)::BasicConstraintManager::AddEQ(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&)"},
    {"_ZNK5clang4ento7GRState3getIN12_GLOBAL__N_110ConstNotEqEEENS0_12GRStateTraitIT_E11lookup_typeENS7_8key_typeE", "clang::ento::GRStateTrait<(anonymous namespace)::ConstNotEq>::lookup_type clang::ento::GRState::get<(anonymous namespace)::ConstNotEq>(clang::ento::GRStateTrait<(anonymous namespace)::ConstNotEq>::key_type) const"},
    {"_ZNK5clang4ento7GRState3getIN12_GLOBAL__N_17ConstEqEEENS0_12GRStateTraitIT_E11lookup_typeENS7_8key_typeE", "clang::ento::GRStateTrait<(anonymous namespace)::ConstEq>::lookup_type clang::ento::GRState::get<(anonymous namespace)::ConstEq>(clang::ento::GRStateTrait<(anonymous namespace)::ConstEq>::key_type) const"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEPKNS2_6APSIntENS2_16ImutKeyValueInfoIS6_S9_EEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::APSInt const*, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEPKNS2_6APSIntENS2_16ImutKeyValueInfoIS6_S9_EEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::APSInt const*, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>>::DeleteContext(void*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::~ImutAVLFactory()"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEPKNS2_6APSIntENS2_16ImutKeyValueInfoIS6_S9_EEEEE3SetESC_S6_S9_RNSC_7FactoryE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::APSInt const*, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>>::Set(llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::APSInt const*, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>, clang::ento::SymbolData const*, llvm::APSInt const*, llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::APSInt const*, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::Factory&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::destroy()"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS0_6APSIntEEEEESaISD_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSD_SF_EERKSD_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>**, std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*>>>, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>* const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEEENS_12DenseMapInfoIjEENSE_ISD_EEE16InsertIntoBucketERKjRKSD_PSt4pairIjSD_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEEENS_12DenseMapInfoIjEENSE_ISD_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*>>::grow(unsigned int)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE3addEPNS_11ImutAVLTreeISA_EERKSt4pairIS6_S9_E", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::add(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*, std::pair<clang::ento::SymbolData const*, llvm::APSInt const*> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE16getCanonicalTreeEPNS_11ImutAVLTreeISA_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE22compareTreeWithSectionEPNS_11ImutAVLTreeISA_EERNS_26ImutAVLTreeInOrderIteratorISA_EESH_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>&)"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::operator++()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE12add_internalERKSt4pairIS6_S9_EPNS_11ImutAVLTreeISA_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::add_internal(std::pair<clang::ento::SymbolData const*, llvm::APSInt const*> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE13markImmutableEPNS_11ImutAVLTreeISA_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE10createNodeEPNS_11ImutAVLTreeISA_EERKSt4pairIS6_S9_ESE_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*, std::pair<clang::ento::SymbolData const*, llvm::APSInt const*> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE11balanceTreeEPNS_11ImutAVLTreeISA_EERKSt4pairIS6_S9_ESE_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*, std::pair<clang::ento::SymbolData const*, llvm::APSInt const*> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataENS2_12ImmutableSetIPNS2_6APSIntENS2_17ImutContainerInfoIS9_EEEENS2_16ImutKeyValueInfoIS6_SC_EEEEE6LookupESF_S6_", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>>::Lookup(llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>, clang::ento::SymbolData const*)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::destroy()"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS0_12ImmutableSetIPNS0_6APSIntENS0_17ImutContainerInfoISA_EEEEEEEESaISG_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSG_SI_EERKSG_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>**, std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*>>>, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>* const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoISA_EEEEEEEENS_12DenseMapInfoIjEENSH_ISG_EEE16InsertIntoBucketERKjRKSG_PSt4pairIjSG_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoISA_EEEEEEEENS_12DenseMapInfoIjEENSH_ISG_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*>>::grow(unsigned int)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataENS2_12ImmutableSetIPNS2_6APSIntENS2_17ImutContainerInfoIS9_EEEENS2_16ImutKeyValueInfoIS6_SC_EEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataENS2_12ImmutableSetIPNS2_6APSIntENS2_17ImutContainerInfoIS9_EEEENS2_16ImutKeyValueInfoIS6_SC_EEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>>::DeleteContext(void*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::~ImutAVLFactory()"},
    {"_ZN4llvm12ImmutableMapIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS8_EEEENS_16ImutKeyValueInfoIS5_SB_EEE7Factory3addESE_RKS5_RKSB_", "llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::Factory::add(llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>, clang::ento::SymbolData const* const&, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE3addEPNS_11ImutAVLTreeISD_EERKSt4pairIS6_SC_E", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::add(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*, std::pair<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE16getCanonicalTreeEPNS_11ImutAVLTreeISD_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE22compareTreeWithSectionEPNS_11ImutAVLTreeISD_EERNS_26ImutAVLTreeInOrderIteratorISD_EESK_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>&)"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::operator++()"},
    {"_ZNK4llvm11ImutAVLTreeINS_17ImutContainerInfoIPNS_6APSIntEEEE7isEqualERKS5_", "llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>::isEqual(llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>> const&) const"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_17ImutContainerInfoIPNS_6APSIntEEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutContainerInfo<llvm::APSInt*>>::operator++()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE12add_internalERKSt4pairIS6_SC_EPNS_11ImutAVLTreeISD_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::add_internal(std::pair<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE13markImmutableEPNS_11ImutAVLTreeISD_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE10createNodeEPNS_11ImutAVLTreeISD_EERKSt4pairIS6_SC_ESH_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*, std::pair<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE11balanceTreeEPNS_11ImutAVLTreeISD_EERKSt4pairIS6_SC_ESH_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*, std::pair<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*)"},
    {"_ZN4llvm11ImutAVLTreeINS_17ImutContainerInfoIPNS_6APSIntEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>::destroy()"},
    {"_ZN4llvm11ImutAVLTreeINS_17ImutContainerInfoIPNS_6APSIntEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_17ImutContainerInfoIPNS0_6APSIntEEEEESaIS7_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS7_S9_EERKS7_", "std::vector<llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>**, std::vector<llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*>>>, llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>* const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_17ImutContainerInfoIPNS_6APSIntEEEEENS_12DenseMapInfoIjEENS8_IS7_EEE16InsertIntoBucketERKjRKS7_PSt4pairIjS7_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_17ImutContainerInfoIPNS_6APSIntEEEEENS_12DenseMapInfoIjEENS8_IS7_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*>>::grow(unsigned int)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPNS_6APSIntEEEE3addEPNS_11ImutAVLTreeIS4_EEPKS2_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<llvm::APSInt*>>::add(llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*, llvm::APSInt const*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPNS_6APSIntEEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS4_EE", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<llvm::APSInt*>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPNS_6APSIntEEEE22compareTreeWithSectionEPNS_11ImutAVLTreeIS4_EERNS_26ImutAVLTreeInOrderIteratorIS4_EESB_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<llvm::APSInt*>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutContainerInfo<llvm::APSInt*>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutContainerInfo<llvm::APSInt*>>&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPNS_6APSIntEEEE12add_internalEPKS2_PNS_11ImutAVLTreeIS4_EE", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<llvm::APSInt*>>::add_internal(llvm::APSInt const*, llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPNS_6APSIntEEEE13markImmutableEPNS_11ImutAVLTreeIS4_EE", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<llvm::APSInt*>>::markImmutable(llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPNS_6APSIntEEEE10createNodeEPNS_11ImutAVLTreeIS4_EEPKS2_S8_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<llvm::APSInt*>>::createNode(llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*, llvm::APSInt const*, llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPNS_6APSIntEEEE11balanceTreeEPNS_11ImutAVLTreeIS4_EEPKS2_S8_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<llvm::APSInt*>>::balanceTree(llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*, llvm::APSInt const*, llvm::ImutAVLTree<llvm::ImutContainerInfo<llvm::APSInt*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE6removeEPNS_11ImutAVLTreeISD_EERKS6_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::remove(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*, clang::ento::SymbolData const* const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE15remove_internalERKS6_PNS_11ImutAVLTreeISD_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::remove_internal(clang::ento::SymbolData const* const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableSetIPNS_6APSIntENS_17ImutContainerInfoIS9_EEEEEEE16removeMinBindingEPNS_11ImutAVLTreeISD_EERSH_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>::removeMinBinding(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableSet<llvm::APSInt*, llvm::ImutContainerInfo<llvm::APSInt*>>>>*&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE6removeEPNS_11ImutAVLTreeISA_EERKS6_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::remove(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*, clang::ento::SymbolData const* const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE15remove_internalERKS6_PNS_11ImutAVLTreeISA_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::remove_internal(clang::ento::SymbolData const* const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEPKNS_6APSIntEEEE16removeMinBindingEPNS_11ImutAVLTreeISA_EERSE_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>::removeMinBinding(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>*&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEPKNS2_6APSIntENS2_16ImutKeyValueInfoIS6_S9_EEEEE6LookupESC_S6_", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::APSInt const*, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>>::Lookup(llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::APSInt const*, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::APSInt const*>>, clang::ento::SymbolData const*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPNS_6APSIntEEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<llvm::APSInt*>>::~ImutAVLFactory()"},
    {"_ZN5clang4ento23CreateBasicStoreManagerERNS0_14GRStateManagerE", "clang::ento::CreateBasicStoreManager(clang::ento::GRStateManager&)"},
    {"_ZN5clang4ento12StoreManager15BindingsHandlerD0Ev", "clang::ento::StoreManager::BindingsHandler::~BindingsHandler()"},
    {"_ZN5clang4ento12StoreManager15BindingsHandlerD1Ev", "clang::ento::StoreManager::BindingsHandler::~BindingsHandler()"},
    {"_ZN5clang4ento12StoreManager15BindingsHandlerD2Ev", "clang::ento::StoreManager::BindingsHandler::~BindingsHandler()"},
    {"_ZN12_GLOBAL__N_117BasicStoreManagerD1Ev", "(anonymous namespace)::BasicStoreManager::~BasicStoreManager()"},
    {"_ZN12_GLOBAL__N_117BasicStoreManagerD0Ev", "(anonymous namespace)::BasicStoreManager::~BasicStoreManager()"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager8RetrieveEPKvN5clang4ento3LocENS3_8QualTypeE", "(anonymous namespace)::BasicStoreManager::Retrieve(void const*, clang::ento::Loc, clang::QualType)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager4BindEPKvN5clang4ento3LocENS4_4SValE", "(anonymous namespace)::BasicStoreManager::Bind(void const*, clang::ento::Loc, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager6RemoveEPKvN5clang4ento3LocE", "(anonymous namespace)::BasicStoreManager::Remove(void const*, clang::ento::Loc)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager19BindCompoundLiteralEPKvPKN5clang19CompoundLiteralExprEPKNS3_15LocationContextENS3_4ento4SValE", "(anonymous namespace)::BasicStoreManager::BindCompoundLiteral(void const*, clang::CompoundLiteralExpr const*, clang::LocationContext const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager15getInitialStoreEPKN5clang15LocationContextE", "(anonymous namespace)::BasicStoreManager::getInitialStore(clang::LocationContext const*)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager15getSubRegionMapEPKv", "(anonymous namespace)::BasicStoreManager::getSubRegionMap(void const*)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager14ArrayToPointerEN5clang4ento3LocE", "(anonymous namespace)::BasicStoreManager::ArrayToPointer(clang::ento::Loc)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager18removeDeadBindingsEPKvPKN5clang17StackFrameContextERNS3_4ento12SymbolReaperERN4llvm15SmallVectorImplIPKNS7_9MemRegionEEE", "(anonymous namespace)::BasicStoreManager::removeDeadBindings(void const*, clang::StackFrameContext const*, clang::ento::SymbolReaper&, llvm::SmallVectorImpl<clang::ento::MemRegion const*>&)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager8BindDeclEPKvPKN5clang4ento9VarRegionENS4_4SValE", "(anonymous namespace)::BasicStoreManager::BindDecl(void const*, clang::ento::VarRegion const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager18BindDeclWithNoInitEPKvPKN5clang4ento9VarRegionE", "(anonymous namespace)::BasicStoreManager::BindDeclWithNoInit(void const*, clang::ento::VarRegion const*)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager17InvalidateRegionsEPKvPKPKN5clang4ento9MemRegionES9_PKNS3_4ExprEjPN4llvm8DenseSetIPKNS4_10SymbolDataENSD_12DenseMapInfoISH_EEEEbPNSD_11SmallVectorIS7_Lj8EEE", "(anonymous namespace)::BasicStoreManager::InvalidateRegions(void const*, clang::ento::MemRegion const* const*, clang::ento::MemRegion const* const*, clang::Expr const*, unsigned int, llvm::DenseSet<clang::ento::SymbolData const*, llvm::DenseMapInfo<clang::ento::SymbolData const*>>*, bool, llvm::SmallVector<clang::ento::MemRegion const*, 8u>*)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager5printEPKvRN4llvm11raw_ostreamEPKcS7_", "(anonymous namespace)::BasicStoreManager::print(void const*, llvm::raw_ostream&, char const*, char const*)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager12iterBindingsEPKvRN5clang4ento12StoreManager15BindingsHandlerE", "(anonymous namespace)::BasicStoreManager::iterBindings(void const*, clang::ento::StoreManager::BindingsHandler&)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager16InvalidateRegionEPKvPKN5clang4ento9MemRegionEPKNS3_4ExprEjPN4llvm8DenseSetIPKNS4_10SymbolDataENSB_12DenseMapInfoISF_EEEE", "(anonymous namespace)::BasicStoreManager::InvalidateRegion(void const*, clang::ento::MemRegion const*, clang::Expr const*, unsigned int, llvm::DenseSet<clang::ento::SymbolData const*, llvm::DenseMapInfo<clang::ento::SymbolData const*>>*)"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager16BindDeclInternalEPKvPKN5clang4ento9VarRegionEPNS4_4SValE", "(anonymous namespace)::BasicStoreManager::BindDeclInternal(void const*, clang::ento::VarRegion const*, clang::ento::SVal*)"},
    {"_ZN12_GLOBAL__N_122BasicStoreSubRegionMapD1Ev", "(anonymous namespace)::BasicStoreSubRegionMap::~BasicStoreSubRegionMap()"},
    {"_ZN12_GLOBAL__N_122BasicStoreSubRegionMapD0Ev", "(anonymous namespace)::BasicStoreSubRegionMap::~BasicStoreSubRegionMap()"},
    {"_ZNK12_GLOBAL__N_122BasicStoreSubRegionMap14iterSubRegionsEPKN5clang4ento9MemRegionERNS2_12SubRegionMap7VisitorE", "(anonymous namespace)::BasicStoreSubRegionMap::iterSubRegions(clang::ento::MemRegion const*, clang::ento::SubRegionMap::Visitor&) const"},
    {"_ZN12_GLOBAL__N_117BasicStoreManager12scanForIvarsEPN5clang4StmtEPKNS1_4DeclEPKNS1_4ento9MemRegionEPKv", "(anonymous namespace)::BasicStoreManager::scanForIvars(clang::Stmt*, clang::Decl const*, clang::ento::MemRegion const*, void const*)"},
    {"_ZN5clang4ento12StoreManager11BindDefaultEPKvPKNS0_9MemRegionENS0_4SValE", "clang::ento::StoreManager::BindDefault(void const*, clang::ento::MemRegion const*, clang::ento::SVal)"},
    {"_ZN5clang4ento12StoreManager12getLValueVarEPKNS_7VarDeclEPKNS_15LocationContextE", "clang::ento::StoreManager::getLValueVar(clang::VarDecl const*, clang::LocationContext const*)"},
    {"_ZN5clang4ento12StoreManager15getLValueStringEPKNS_13StringLiteralE", "clang::ento::StoreManager::getLValueString(clang::StringLiteral const*)"},
    {"_ZN5clang4ento12StoreManager13getLValueIvarEPKNS_12ObjCIvarDeclENS0_4SValE", "clang::ento::StoreManager::getLValueIvar(clang::ObjCIvarDecl const*, clang::ento::SVal)"},
    {"_ZN5clang4ento12StoreManager14getLValueFieldEPKNS_9FieldDeclENS0_4SValE", "clang::ento::StoreManager::getLValueField(clang::FieldDecl const*, clang::ento::SVal)"},
    {"_ZN5clang4ento12StoreManager17getSizeInElementsEPKNS0_7GRStateEPKNS0_9MemRegionENS_8QualTypeE", "clang::ento::StoreManager::getSizeInElements(clang::ento::GRState const*, clang::ento::MemRegion const*, clang::QualType)"},
    {"_ZN5clang4ento12StoreManager17evalDerivedToBaseENS0_4SValENS_8QualTypeE", "clang::ento::StoreManager::evalDerivedToBase(clang::ento::SVal, clang::QualType)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::destroy()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS4_4SValEEEEESaISB_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSB_SD_EERKSB_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>**, std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*>>>, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>* const&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE13computeDigestEPS9_SA_RKSt4pairIS6_S7_E", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::computeDigest(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, std::pair<clang::ento::MemRegion const*, clang::ento::SVal> const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS4_4SValEEEEENS_12DenseMapInfoIjEENSC_ISB_EEE16InsertIntoBucketERKjRKSB_PSt4pairIjSB_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS4_4SValEEEEENS_12DenseMapInfoIjEENSC_ISB_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*>>::grow(unsigned int)"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::operator++()"},
    {"_ZN5clang4ento12SubRegionMapD1Ev", "clang::ento::SubRegionMap::~SubRegionMap()"},
    {"_ZN5clang4ento12SubRegionMapD0Ev", "clang::ento::SubRegionMap::~SubRegionMap()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE6removeEPNS_11ImutAVLTreeIS8_EERKS6_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::remove(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, clang::ento::MemRegion const* const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS8_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE22compareTreeWithSectionEPNS_11ImutAVLTreeIS8_EERNS_26ImutAVLTreeInOrderIteratorIS8_EESF_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE15remove_internalERKS6_PNS_11ImutAVLTreeIS8_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::remove_internal(clang::ento::MemRegion const* const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE13markImmutableEPNS_11ImutAVLTreeIS8_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE11balanceTreeEPNS_11ImutAVLTreeIS8_EERKSt4pairIS6_S7_ESC_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, std::pair<clang::ento::MemRegion const*, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE10createNodeEPNS_11ImutAVLTreeIS8_EERKSt4pairIS6_S7_ESC_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, std::pair<clang::ento::MemRegion const*, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE16removeMinBindingEPNS_11ImutAVLTreeIS8_EERSC_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::removeMinBinding(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE3addEPNS_11ImutAVLTreeIS8_EERKSt4pairIS6_S7_E", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::add(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*, std::pair<clang::ento::MemRegion const*, clang::ento::SVal> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEE12add_internalERKSt4pairIS6_S7_EPNS_11ImutAVLTreeIS8_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::add_internal(std::pair<clang::ento::MemRegion const*, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>*)"},
    {"_ZN5clang4ento12StoreManagerD1Ev", "clang::ento::StoreManager::~StoreManager()"},
    {"_ZN5clang4ento12StoreManagerD0Ev", "clang::ento::StoreManager::~StoreManager()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS3_4SValEEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, clang::ento::SVal>>::~ImutAVLFactory()"},
    {"_ZN5clang4ento15CompoundValData7ProfileERN4llvm16FoldingSetNodeIDENS_8QualTypeENS2_13ImmutableListINS0_4SValEEE", "clang::ento::CompoundValData::Profile(llvm::FoldingSetNodeID&, clang::QualType, llvm::ImmutableList<clang::ento::SVal>)"},
    {"_ZN5clang4ento19LazyCompoundValData7ProfileERN4llvm16FoldingSetNodeIDEPKvPKNS0_11TypedRegionE", "clang::ento::LazyCompoundValData::Profile(llvm::FoldingSetNodeID&, void const*, clang::ento::TypedRegion const*)"},
    {"_ZN5clang4ento17BasicValueFactoryD1Ev", "clang::ento::BasicValueFactory::~BasicValueFactory()"},
    {"_ZN5clang4ento17BasicValueFactoryD2Ev", "clang::ento::BasicValueFactory::~BasicValueFactory()"},
    {"_ZN5clang4ento17BasicValueFactory8getValueERKN4llvm6APSIntE", "clang::ento::BasicValueFactory::getValue(llvm::APSInt const&)"},
    {"_ZN5clang4ento17BasicValueFactory8getValueERKN4llvm5APIntEb", "clang::ento::BasicValueFactory::getValue(llvm::APInt const&, bool)"},
    {"_ZN5clang4ento17BasicValueFactory8getValueEyjb", "clang::ento::BasicValueFactory::getValue(unsigned long long, unsigned int, bool)"},
    {"_ZN5clang4ento17BasicValueFactory8getValueEyNS_8QualTypeE", "clang::ento::BasicValueFactory::getValue(unsigned long long, clang::QualType)"},
    {"_ZN5clang4ento17BasicValueFactory18getCompoundValDataENS_8QualTypeEN4llvm13ImmutableListINS0_4SValEEE", "clang::ento::BasicValueFactory::getCompoundValData(clang::QualType, llvm::ImmutableList<clang::ento::SVal>)"},
    {"_ZN5clang4ento17BasicValueFactory22getLazyCompoundValDataEPKvPKNS0_11TypedRegionE", "clang::ento::BasicValueFactory::getLazyCompoundValData(void const*, clang::ento::TypedRegion const*)"},
    {"_ZN5clang4ento17BasicValueFactory10evalAPSIntENS_18BinaryOperatorKindERKN4llvm6APSIntES6_", "clang::ento::BasicValueFactory::evalAPSInt(clang::BinaryOperatorKind, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN5clang4ento17BasicValueFactory25getPersistentSValWithDataERKNS0_4SValEm", "clang::ento::BasicValueFactory::getPersistentSValWithData(clang::ento::SVal const&, unsigned long)"},
    {"_ZN5clang4ento17BasicValueFactory21getPersistentSValPairERKNS0_4SValES4_", "clang::ento::BasicValueFactory::getPersistentSValPair(clang::ento::SVal const&, clang::ento::SVal const&)"},
    {"_ZN5clang4ento17BasicValueFactory17getPersistentSValENS0_4SValE", "clang::ento::BasicValueFactory::getPersistentSVal(clang::ento::SVal)"},
    {"_ZN4llvm10FoldingSetIN5clang4ento19LazyCompoundValDataEED1Ev", "llvm::FoldingSet<clang::ento::LazyCompoundValData>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang4ento15CompoundValDataEED1Ev", "llvm::FoldingSet<clang::ento::CompoundValData>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetINS_21FoldingSetNodeWrapperINS_6APSIntEEEED1Ev", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<llvm::APSInt>>::~FoldingSet()"},
    {"_ZN4llvm21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValES4_EED1Ev", "llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, clang::ento::SVal>>::~FoldingSetNodeWrapper()"},
    {"_ZN4llvm21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValES4_EED0Ev", "llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, clang::ento::SVal>>::~FoldingSetNodeWrapper()"},
    {"_ZN4llvm10FoldingSetINS_21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValES5_EEEED1Ev", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, clang::ento::SVal>>>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetINS_21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValES5_EEEED0Ev", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, clang::ento::SVal>>>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetINS_21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValES5_EEEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, clang::ento::SVal>>>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValES5_EEEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERSC_", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, clang::ento::SVal>>>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValES5_EEEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, clang::ento::SVal>>>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValEmEED1Ev", "llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, unsigned long>>::~FoldingSetNodeWrapper()"},
    {"_ZN4llvm21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValEmEED0Ev", "llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, unsigned long>>::~FoldingSetNodeWrapper()"},
    {"_ZN4llvm10FoldingSetINS_21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValEmEEEED1Ev", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, unsigned long>>>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetINS_21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValEmEEEED0Ev", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, unsigned long>>>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetINS_21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValEmEEEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, unsigned long>>>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValEmEEEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERSC_", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, unsigned long>>>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_21FoldingSetNodeWrapperISt4pairIN5clang4ento4SValEmEEEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<std::pair<clang::ento::SVal, unsigned long>>>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm21FoldingSetNodeWrapperINS_6APSIntEED1Ev", "llvm::FoldingSetNodeWrapper<llvm::APSInt>::~FoldingSetNodeWrapper()"},
    {"_ZN4llvm21FoldingSetNodeWrapperINS_6APSIntEED0Ev", "llvm::FoldingSetNodeWrapper<llvm::APSInt>::~FoldingSetNodeWrapper()"},
    {"_ZN4llvm10FoldingSetINS_17ImmutableListImplIN5clang4ento4SValEEEED1Ev", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::SVal>>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetINS_17ImmutableListImplIN5clang4ento4SValEEEED0Ev", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::SVal>>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetINS_17ImmutableListImplIN5clang4ento4SValEEEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::SVal>>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_17ImmutableListImplIN5clang4ento4SValEEEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERSA_", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::SVal>>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_17ImmutableListImplIN5clang4ento4SValEEEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::SVal>>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetINS_21FoldingSetNodeWrapperINS_6APSIntEEEED0Ev", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<llvm::APSInt>>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetINS_21FoldingSetNodeWrapperINS_6APSIntEEEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<llvm::APSInt>>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_21FoldingSetNodeWrapperINS_6APSIntEEEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<llvm::APSInt>>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_21FoldingSetNodeWrapperINS_6APSIntEEEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::FoldingSetNodeWrapper<llvm::APSInt>>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang4ento15CompoundValDataEED0Ev", "llvm::FoldingSet<clang::ento::CompoundValData>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento15CompoundValDataEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::CompoundValData>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento15CompoundValDataEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::ento::CompoundValData>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento15CompoundValDataEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::CompoundValData>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang4ento19LazyCompoundValDataEED0Ev", "llvm::FoldingSet<clang::ento::LazyCompoundValData>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento19LazyCompoundValDataEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::LazyCompoundValData>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento19LazyCompoundValDataEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::ento::LazyCompoundValData>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento19LazyCompoundValDataEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::LazyCompoundValData>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento12BlockCounter13getNumVisitedEPKNS_17StackFrameContextEj", "clang::ento::BlockCounter::getNumVisited(clang::StackFrameContext const*, unsigned int) const"},
    {"_ZN5clang4ento12BlockCounter7FactoryC1ERN4llvm16BumpPtrAllocatorE", "clang::ento::BlockCounter::Factory::Factory(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento12BlockCounter7FactoryC2ERN4llvm16BumpPtrAllocatorE", "clang::ento::BlockCounter::Factory::Factory(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento12BlockCounter7FactoryD1Ev", "clang::ento::BlockCounter::Factory::~Factory()"},
    {"_ZN5clang4ento12BlockCounter7FactoryD2Ev", "clang::ento::BlockCounter::Factory::~Factory()"},
    {"_ZN5clang4ento12BlockCounter7Factory14IncrementCountES1_PKNS_17StackFrameContextEj", "clang::ento::BlockCounter::Factory::IncrementCount(clang::ento::BlockCounter, clang::StackFrameContext const*, unsigned int)"},
    {"_ZN5clang4ento12BlockCounter7Factory15GetEmptyCounterEv", "clang::ento::BlockCounter::Factory::GetEmptyCounter()"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIN12_GLOBAL__N_18CountKeyEjEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>::computeDigest()"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIN12_GLOBAL__N_18CountKeyEjEEEENS_12DenseMapInfoIjEENS8_IS7_EEEixERKj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>*>>::operator[](unsigned int const&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIN12_GLOBAL__N_18CountKeyEjEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>::destroy()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIN12_GLOBAL__N_18CountKeyEjEEEESaIS7_EE9push_backERKS7_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>*>>::push_back(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>* const&)"},
    {"_ZN4llvm26ImutAVLTreeInOrderIteratorINS_16ImutKeyValueInfoIN12_GLOBAL__N_18CountKeyEjEEEppEv", "llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>::operator++()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_18CountKeyEjEEE12add_internalERKSt4pairIS3_jEPNS_11ImutAVLTreeIS4_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>::add_internal(std::pair<(anonymous namespace)::CountKey, unsigned int> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_18CountKeyEjEEE13markImmutableEPNS_11ImutAVLTreeIS4_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_18CountKeyEjEEE10createNodeEPNS_11ImutAVLTreeIS4_EERKSt4pairIS3_jES8_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>*, std::pair<(anonymous namespace)::CountKey, unsigned int> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_18CountKeyEjEEE11balanceTreeEPNS_11ImutAVLTreeIS4_EERKSt4pairIS3_jES8_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>*, std::pair<(anonymous namespace)::CountKey, unsigned int> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::CountKey, unsigned int>>*)"},
    {"_ZN5clang4ento18BugReporterVisitorD0Ev", "clang::ento::BugReporterVisitor::~BugReporterVisitor()"},
    {"_ZN5clang4ento18BugReporterVisitorD1Ev", "clang::ento::BugReporterVisitor::~BugReporterVisitor()"},
    {"_ZN5clang4ento18BugReporterVisitorD2Ev", "clang::ento::BugReporterVisitor::~BugReporterVisitor()"},
    {"_ZN5clang4ento18BugReporterContextD0Ev", "clang::ento::BugReporterContext::~BugReporterContext()"},
    {"_ZN5clang4ento18BugReporterContextD1Ev", "clang::ento::BugReporterContext::~BugReporterContext()"},
    {"_ZN5clang4ento18BugReporterContextD2Ev", "clang::ento::BugReporterContext::~BugReporterContext()"},
    {"_ZN5clang4ento18BugReporterContext10addVisitorEPNS0_18BugReporterVisitorE", "clang::ento::BugReporterContext::addVisitor(clang::ento::BugReporterVisitor*)"},
    {"_ZN5clang4ento7BugTypeD0Ev", "clang::ento::BugType::~BugType()"},
    {"_ZN5clang4ento7BugTypeD1Ev", "clang::ento::BugType::~BugType()"},
    {"_ZN5clang4ento7BugTypeD2Ev", "clang::ento::BugType::~BugType()"},
    {"_ZN5clang4ento19BugReportEquivClassD1Ev", "clang::ento::BugReportEquivClass::~BugReportEquivClass()"},
    {"_ZN5clang4ento7BugType12FlushReportsERNS0_11BugReporterE", "clang::ento::BugType::FlushReports(clang::ento::BugReporter&)"},
    {"_ZN5clang4ento9BugReportD0Ev", "clang::ento::BugReport::~BugReport()"},
    {"_ZN5clang4ento9BugReportD1Ev", "clang::ento::BugReport::~BugReport()"},
    {"_ZN5clang4ento9BugReportD2Ev", "clang::ento::BugReport::~BugReport()"},
    {"_ZN5clang4ento15RangedBugReportD0Ev", "clang::ento::RangedBugReport::~RangedBugReport()"},
    {"_ZN5clang4ento15RangedBugReportD1Ev", "clang::ento::RangedBugReport::~RangedBugReport()"},
    {"_ZN5clang4ento15RangedBugReportD2Ev", "clang::ento::RangedBugReport::~RangedBugReport()"},
    {"_ZNK5clang4ento9BugReport7getStmtEv", "clang::ento::BugReport::getStmt() const"},
    {"_ZN5clang4ento9BugReport10getEndPathERNS0_18BugReporterContextEPKNS0_12ExplodedNodeE", "clang::ento::BugReport::getEndPath(clang::ento::BugReporterContext&, clang::ento::ExplodedNode const*)"},
    {"_ZNK5clang4ento9BugReport9getRangesEv", "clang::ento::BugReport::getRanges() const"},
    {"_ZNK5clang4ento9BugReport11getLocationEv", "clang::ento::BugReport::getLocation() const"},
    {"_ZN5clang4ento9BugReport9VisitNodeEPKNS0_12ExplodedNodeES4_RNS0_18BugReporterContextE", "clang::ento::BugReport::VisitNode(clang::ento::ExplodedNode const*, clang::ento::ExplodedNode const*, clang::ento::BugReporterContext&)"},
    {"_ZN5clang4ento19BugReportEquivClassD2Ev", "clang::ento::BugReportEquivClass::~BugReportEquivClass()"},
    {"_ZN5clang4ento13GRBugReporterD0Ev", "clang::ento::GRBugReporter::~GRBugReporter()"},
    {"_ZN5clang4ento13GRBugReporterD1Ev", "clang::ento::GRBugReporter::~GRBugReporter()"},
    {"_ZN5clang4ento13GRBugReporterD2Ev", "clang::ento::GRBugReporter::~GRBugReporter()"},
    {"_ZN5clang4ento11BugReporterD2Ev", "clang::ento::BugReporter::~BugReporter()"},
    {"_ZN5clang4ento15BugReporterDataD0Ev", "clang::ento::BugReporterData::~BugReporterData()"},
    {"_ZN5clang4ento15BugReporterDataD1Ev", "clang::ento::BugReporterData::~BugReporterData()"},
    {"_ZN5clang4ento15BugReporterDataD2Ev", "clang::ento::BugReporterData::~BugReporterData()"},
    {"_ZN5clang4ento13GRBugReporter8getGraphEv", "clang::ento::GRBugReporter::getGraph()"},
    {"_ZN5clang4ento13GRBugReporter15getStateManagerEv", "clang::ento::GRBugReporter::getStateManager()"},
    {"_ZN5clang4ento11BugReporterD0Ev", "clang::ento::BugReporter::~BugReporter()"},
    {"_ZN5clang4ento11BugReporterD1Ev", "clang::ento::BugReporter::~BugReporter()"},
    {"_ZN5clang4ento11BugReporter12FlushReportsEv", "clang::ento::BugReporter::FlushReports()"},
    {"_ZN5clang4ento11BugReporter11FlushReportERNS0_19BugReportEquivClassE", "clang::ento::BugReporter::FlushReport(clang::ento::BugReportEquivClass&)"},
    {"_ZN5clang4ento13GRBugReporter22GeneratePathDiagnosticERNS0_14PathDiagnosticERN4llvm15SmallVectorImplIPNS0_9BugReportEEE", "clang::ento::GRBugReporter::GeneratePathDiagnostic(clang::ento::PathDiagnostic&, llvm::SmallVectorImpl<clang::ento::BugReport*>&)"},
    {"_ZN12_GLOBAL__N_121PathDiagnosticBuilderD1Ev", "(anonymous namespace)::PathDiagnosticBuilder::~PathDiagnosticBuilder()"},
    {"_ZN5clang4ento11BugReporter8RegisterEPNS0_7BugTypeE", "clang::ento::BugReporter::Register(clang::ento::BugType*)"},
    {"_ZN5clang4ento11BugReporter10EmitReportEPNS0_9BugReportE", "clang::ento::BugReporter::EmitReport(clang::ento::BugReport*)"},
    {"_ZN5clang4ento11BugReporter15EmitBasicReportEN4llvm9StringRefES3_NS_14SourceLocationEPNS_11SourceRangeEj", "clang::ento::BugReporter::EmitBasicReport(llvm::StringRef, llvm::StringRef, clang::SourceLocation, clang::SourceRange*, unsigned int)"},
    {"_ZN5clang4ento11BugReporter15EmitBasicReportEN4llvm9StringRefES3_S3_NS_14SourceLocationEPNS_11SourceRangeEj", "clang::ento::BugReporter::EmitBasicReport(llvm::StringRef, llvm::StringRef, llvm::StringRef, clang::SourceLocation, clang::SourceRange*, unsigned int)"},
    {"_ZN4llvm10FoldingSetIN12_GLOBAL__N_113DiagCacheItemEED1Ev", "llvm::FoldingSet<(anonymous namespace)::DiagCacheItem>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN12_GLOBAL__N_113DiagCacheItemEED0Ev", "llvm::FoldingSet<(anonymous namespace)::DiagCacheItem>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN12_GLOBAL__N_113DiagCacheItemEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<(anonymous namespace)::DiagCacheItem>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN12_GLOBAL__N_113DiagCacheItemEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<(anonymous namespace)::DiagCacheItem>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN12_GLOBAL__N_113DiagCacheItemEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<(anonymous namespace)::DiagCacheItem>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm15SmallVectorImplIN12_GLOBAL__N_112FRIEC_WLItemEE9push_backERKS2_", "llvm::SmallVectorImpl<(anonymous namespace)::FRIEC_WLItem>::push_back((anonymous namespace)::FRIEC_WLItem const&)"},
    {"_ZN12_GLOBAL__N_114NodeMapClosureD1Ev", "(anonymous namespace)::NodeMapClosure::~NodeMapClosure()"},
    {"_ZN12_GLOBAL__N_121PathDiagnosticBuilderD0Ev", "(anonymous namespace)::PathDiagnosticBuilder::~PathDiagnosticBuilder()"},
    {"_ZN12_GLOBAL__N_121PathDiagnosticBuilder15getNodeResolverEv", "(anonymous namespace)::PathDiagnosticBuilder::getNodeResolver()"},
    {"_ZN12_GLOBAL__N_114NodeMapClosureD0Ev", "(anonymous namespace)::NodeMapClosure::~NodeMapClosure()"},
    {"_ZN12_GLOBAL__N_114NodeMapClosure15getOriginalNodeEPKN5clang4ento12ExplodedNodeE", "(anonymous namespace)::NodeMapClosure::getOriginalNode(clang::ento::ExplodedNode const*)"},
    {"_Z11GetNextStmtPKN5clang4ento12ExplodedNodeE", "GetNextStmt(clang::ento::ExplodedNode const*)"},
    {"_ZN12_GLOBAL__N_121PathDiagnosticBuilder24getEnclosingStmtLocationEPKN5clang4StmtE", "(anonymous namespace)::PathDiagnosticBuilder::getEnclosingStmtLocation(clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_121PathDiagnosticBuilder18ExecutionContinuesERN4llvm18raw_string_ostreamEPKN5clang4ento12ExplodedNodeE", "(anonymous namespace)::PathDiagnosticBuilder::ExecutionContinues(llvm::raw_string_ostream&, clang::ento::ExplodedNode const*)"},
    {"_ZN12_GLOBAL__N_118ScanNotableSymbolsD1Ev", "(anonymous namespace)::ScanNotableSymbols::~ScanNotableSymbols()"},
    {"_ZN12_GLOBAL__N_118ScanNotableSymbolsD0Ev", "(anonymous namespace)::ScanNotableSymbols::~ScanNotableSymbols()"},
    {"_ZN12_GLOBAL__N_118ScanNotableSymbols13HandleBindingERN5clang4ento12StoreManagerEPKvPKNS2_9MemRegionENS2_4SValE", "(anonymous namespace)::ScanNotableSymbols::HandleBinding(clang::ento::StoreManager&, void const*, clang::ento::MemRegion const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_120NotableSymbolHandlerD1Ev", "(anonymous namespace)::NotableSymbolHandler::~NotableSymbolHandler()"},
    {"_ZN12_GLOBAL__N_120NotableSymbolHandlerD0Ev", "(anonymous namespace)::NotableSymbolHandler::~NotableSymbolHandler()"},
    {"_ZN12_GLOBAL__N_120NotableSymbolHandler13HandleBindingERN5clang4ento12StoreManagerEPKvPKNS2_9MemRegionENS2_4SValE", "(anonymous namespace)::NotableSymbolHandler::HandleBinding(clang::ento::StoreManager&, void const*, clang::ento::MemRegion const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_111EdgeBuilder7addEdgeEN5clang4ento22PathDiagnosticLocationEb", "(anonymous namespace)::EdgeBuilder::addEdge(clang::ento::PathDiagnosticLocation, bool)"},
    {"_ZN12_GLOBAL__N_111EdgeBuilder10addContextEPKN5clang4StmtE", "(anonymous namespace)::EdgeBuilder::addContext(clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_111EdgeBuilder18addExtendedContextEPKN5clang4StmtE", "(anonymous namespace)::EdgeBuilder::addExtendedContext(clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_111EdgeBuilder10rawAddEdgeEN5clang4ento22PathDiagnosticLocationE", "(anonymous namespace)::EdgeBuilder::rawAddEdge(clang::ento::PathDiagnosticLocation)"},
    {"_ZN12_GLOBAL__N_111EdgeBuilder15cleanUpLocationEN5clang4ento22PathDiagnosticLocationEb", "(anonymous namespace)::EdgeBuilder::cleanUpLocation(clang::ento::PathDiagnosticLocation, bool)"},
    {"_ZN12_GLOBAL__N_111EdgeBuilder16containsLocationERKN5clang4ento22PathDiagnosticLocationES5_", "(anonymous namespace)::EdgeBuilder::containsLocation(clang::ento::PathDiagnosticLocation const&, clang::ento::PathDiagnosticLocation const&)"},
    {"_ZNSt6vectorIN12_GLOBAL__N_115ContextLocationESaIS1_EE9push_backERKS1_", "std::vector<(anonymous namespace)::ContextLocation, std::allocator<(anonymous namespace)::ContextLocation>>::push_back((anonymous namespace)::ContextLocation const&)"},
    {"_ZN4llvm10FoldingSetIN5clang4ento18BugReporterVisitorEED1Ev", "llvm::FoldingSet<clang::ento::BugReporterVisitor>::~FoldingSet()"},
    {"_ZN5clang4ento14PathDiagnostic7addMetaEN4llvm9StringRefE", "clang::ento::PathDiagnostic::addMeta(llvm::StringRef)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEE3addEPNS_11ImutAVLTreeIS6_EEPKS4_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::BugType*>>::add(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*, clang::ento::BugType const*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS6_EE", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::BugType*>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*)"},
    {"_ZN4llvm11ImutAVLTreeINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>::computeDigest()"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEE22compareTreeWithSectionEPNS_11ImutAVLTreeIS6_EERNS_26ImutAVLTreeInOrderIteratorIS6_EESD_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::BugType*>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutContainerInfo<clang::ento::BugType*>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutContainerInfo<clang::ento::BugType*>>&)"},
    {"_ZN4llvm11ImutAVLTreeINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>::destroy()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_17ImutContainerInfoIPN5clang4ento7BugTypeEEEEESaIS9_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS9_SB_EERKS9_", "std::vector<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>**, std::vector<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*>>>, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>* const&)"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutContainerInfo<clang::ento::BugType*>>::operator++()"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEEENS_12DenseMapInfoIjEENSA_IS9_EEE16InsertIntoBucketERKjRKS9_PSt4pairIjS9_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEEENS_12DenseMapInfoIjEENSA_IS9_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*>>::grow(unsigned int)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEE12add_internalEPKS4_PNS_11ImutAVLTreeIS6_EE", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::BugType*>>::add_internal(clang::ento::BugType const*, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEE13markImmutableEPNS_11ImutAVLTreeIS6_EE", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::BugType*>>::markImmutable(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEE10createNodeEPNS_11ImutAVLTreeIS6_EEPKS4_SA_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::BugType*>>::createNode(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*, clang::ento::BugType const*, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEE11balanceTreeEPNS_11ImutAVLTreeIS6_EEPKS4_SA_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::BugType*>>::balanceTree(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*, clang::ento::BugType const*, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::BugType*>>*)"},
    {"_ZN4llvm20ImmutableListFactoryIPN5clang4ento18BugReporterVisitorEE6concatERKS4_NS_13ImmutableListIS4_EE", "llvm::ImmutableListFactory<clang::ento::BugReporterVisitor*>::concat(clang::ento::BugReporterVisitor* const&, llvm::ImmutableList<clang::ento::BugReporterVisitor*>)"},
    {"_ZN4llvm10FoldingSetINS_17ImmutableListImplIPN5clang4ento18BugReporterVisitorEEEED1Ev", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::BugReporterVisitor*>>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetINS_17ImmutableListImplIPN5clang4ento18BugReporterVisitorEEEED0Ev", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::BugReporterVisitor*>>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetINS_17ImmutableListImplIPN5clang4ento18BugReporterVisitorEEEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::BugReporterVisitor*>>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_17ImmutableListImplIPN5clang4ento18BugReporterVisitorEEEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERSB_", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::BugReporterVisitor*>>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_17ImmutableListImplIPN5clang4ento18BugReporterVisitorEEEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::BugReporterVisitor*>>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang11SourceRangeELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::SourceRange, false>::grow(unsigned long)"},
    {"_ZN5clang4ento13DiagBugReportD1Ev", "clang::ento::DiagBugReport::~DiagBugReport()"},
    {"_ZN5clang4ento13DiagBugReportD0Ev", "clang::ento::DiagBugReport::~DiagBugReport()"},
    {"_ZNK5clang4ento13DiagBugReport11getLocationEv", "clang::ento::DiagBugReport::getLocation() const"},
    {"_ZNSt5dequeISsSaISsEE16_M_push_back_auxERKSs", "std::deque<std::string, std::allocator<std::string>>::_M_push_back_aux(std::string const&)"},
    {"_ZNSt5dequeISsSaISsEE17_M_reallocate_mapEmb", "std::deque<std::string, std::allocator<std::string>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento12ExplodedNodeEjNS_12DenseMapInfoIS5_EENS6_IjEEE16InsertIntoBucketERKS5_RKjPSt4pairIS5_jE", "llvm::DenseMap<clang::ento::ExplodedNode const*, unsigned int, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::ento::ExplodedNode const* const&, unsigned int const&, std::pair<clang::ento::ExplodedNode const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento12ExplodedNodeEjNS_12DenseMapInfoIS5_EENS6_IjEEE4growEj", "llvm::DenseMap<clang::ento::ExplodedNode const*, unsigned int, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN5clang4ento9BugReport12NodeResolverD1Ev", "clang::ento::BugReport::NodeResolver::~NodeResolver()"},
    {"_ZN5clang4ento9BugReport12NodeResolverD0Ev", "clang::ento::BugReport::NodeResolver::~NodeResolver()"},
    {"_ZN5clang4ento14PathDiagnostic10push_frontEPNS0_19PathDiagnosticPieceE", "clang::ento::PathDiagnostic::push_front(clang::ento::PathDiagnosticPiece*)"},
    {"_ZNSt6vectorISt4pairIPN5clang4ento24PathDiagnosticMacroPieceENS1_14SourceLocationEESaIS6_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS6_S8_EERKS6_", "std::vector<std::pair<clang::ento::PathDiagnosticMacroPiece*, clang::SourceLocation>, std::allocator<std::pair<clang::ento::PathDiagnosticMacroPiece*, clang::SourceLocation>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<clang::ento::PathDiagnosticMacroPiece*, clang::SourceLocation>*, std::vector<std::pair<clang::ento::PathDiagnosticMacroPiece*, clang::SourceLocation>, std::allocator<std::pair<clang::ento::PathDiagnosticMacroPiece*, clang::SourceLocation>>>>, std::pair<clang::ento::PathDiagnosticMacroPiece*, clang::SourceLocation> const&)"},
    {"_ZN5clang4ento24PathDiagnosticMacroPieceC2ERKNS0_22PathDiagnosticLocationE", "clang::ento::PathDiagnosticMacroPiece::PathDiagnosticMacroPiece(clang::ento::PathDiagnosticLocation const&)"},
    {"_ZNK5clang4ento23PathDiagnosticSpotPiece11getLocationEv", "clang::ento::PathDiagnosticSpotPiece::getLocation() const"},
    {"_ZN5clang4ento24PathDiagnosticMacroPiece16flattenLocationsEv", "clang::ento::PathDiagnosticMacroPiece::flattenLocations()"},
    {"_ZN5clang4ento23PathDiagnosticSpotPiece16flattenLocationsEv", "clang::ento::PathDiagnosticSpotPiece::flattenLocations()"},
    {"_ZN5clang4ento23PathDiagnosticSpotPieceD1Ev", "clang::ento::PathDiagnosticSpotPiece::~PathDiagnosticSpotPiece()"},
    {"_ZN5clang4ento23PathDiagnosticSpotPieceD0Ev", "clang::ento::PathDiagnosticSpotPiece::~PathDiagnosticSpotPiece()"},
    {"_ZNSt6vectorIPN5clang4ento19PathDiagnosticPieceESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<clang::ento::PathDiagnosticPiece*, std::allocator<clang::ento::PathDiagnosticPiece*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::ento::PathDiagnosticPiece**, std::vector<clang::ento::PathDiagnosticPiece*, std::allocator<clang::ento::PathDiagnosticPiece*>>>, clang::ento::PathDiagnosticPiece* const&)"},
    {"_ZNK5clang4ento30PathDiagnosticControlFlowPiece11getLocationEv", "clang::ento::PathDiagnosticControlFlowPiece::getLocation() const"},
    {"_ZN5clang4ento30PathDiagnosticControlFlowPiece16flattenLocationsEv", "clang::ento::PathDiagnosticControlFlowPiece::flattenLocations()"},
    {"_ZNSt6vectorIN5clang4ento26PathDiagnosticLocationPairESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::ento::PathDiagnosticLocationPair, std::allocator<clang::ento::PathDiagnosticLocationPair>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::ento::PathDiagnosticLocationPair*, std::vector<clang::ento::PathDiagnosticLocationPair, std::allocator<clang::ento::PathDiagnosticLocationPair>>>, clang::ento::PathDiagnosticLocationPair const&)"},
    {"_ZNSt5dequeIPN5clang4ento19PathDiagnosticPieceESaIS3_EE17_M_reallocate_mapEmb", "std::deque<clang::ento::PathDiagnosticPiece*, std::allocator<clang::ento::PathDiagnosticPiece*>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZNSt5dequeIPN5clang4ento19PathDiagnosticPieceESaIS3_EE9push_backERKS3_", "std::deque<clang::ento::PathDiagnosticPiece*, std::allocator<clang::ento::PathDiagnosticPiece*>>::push_back(clang::ento::PathDiagnosticPiece* const&)"},
    {"_ZN4llvm10FoldingSetIN5clang4ento18BugReporterVisitorEED0Ev", "llvm::FoldingSet<clang::ento::BugReporterVisitor>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento18BugReporterVisitorEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::BugReporterVisitor>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento18BugReporterVisitorEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::ento::BugReporterVisitor>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento18BugReporterVisitorEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::BugReporterVisitor>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento12ExplodedNodeES5_NS_12DenseMapInfoIS5_EES7_E16InsertIntoBucketERKS5_SA_PSt4pairIS5_S5_E", "llvm::DenseMap<clang::ento::ExplodedNode const*, clang::ento::ExplodedNode const*, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>>::InsertIntoBucket(clang::ento::ExplodedNode const* const&, clang::ento::ExplodedNode const* const&, std::pair<clang::ento::ExplodedNode const*, clang::ento::ExplodedNode const*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento12ExplodedNodeES5_NS_12DenseMapInfoIS5_EES7_E4growEj", "llvm::DenseMap<clang::ento::ExplodedNode const*, clang::ento::ExplodedNode const*, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKvjNS_12DenseMapInfoIS2_EENS3_IjEEE16InsertIntoBucketERKS2_RKjPSt4pairIS2_jE", "llvm::DenseMap<void const*, unsigned int, llvm::DenseMapInfo<void const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(void const* const&, unsigned int const&, std::pair<void const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKvjNS_12DenseMapInfoIS2_EENS3_IjEEE4growEj", "llvm::DenseMap<void const*, unsigned int, llvm::DenseMapInfo<void const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZNSt5dequeIPKN5clang4ento12ExplodedNodeESaIS4_EE9push_backERKS4_", "std::deque<clang::ento::ExplodedNode const*, std::allocator<clang::ento::ExplodedNode const*>>::push_back(clang::ento::ExplodedNode const* const&)"},
    {"_ZNSt5dequeIPKN5clang4ento12ExplodedNodeESaIS4_EE17_M_reallocate_mapEmb", "std::deque<clang::ento::ExplodedNode const*, std::allocator<clang::ento::ExplodedNode const*>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZNSt11_Deque_baseIPKN5clang4ento12ExplodedNodeESaIS4_EE17_M_initialize_mapEm", "std::_Deque_base<clang::ento::ExplodedNode const*, std::allocator<clang::ento::ExplodedNode const*>>::_M_initialize_map(unsigned long)"},
    {"_ZNSt5dequeIPKN5clang4ento12ExplodedNodeESaIS4_EEC2ERKS6_", "std::deque<clang::ento::ExplodedNode const*, std::allocator<clang::ento::ExplodedNode const*>>::deque(std::deque<clang::ento::ExplodedNode const*, std::allocator<clang::ento::ExplodedNode const*>> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPN5clang4ento7BugTypeEEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::BugType*>>::~ImutAVLFactory()"},
    {"_ZNSt6vectorIN5clang11SourceRangeESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<clang::SourceRange, std::allocator<clang::SourceRange>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::SourceRange*, std::vector<clang::SourceRange, std::allocator<clang::SourceRange>>>, clang::SourceRange const&)"},
    {"_ZN5clang4ento11bugreporter12GetDerefExprEPKNS0_12ExplodedNodeE", "clang::ento::bugreporter::GetDerefExpr(clang::ento::ExplodedNode const*)"},
    {"_ZN5clang4ento11bugreporter12GetDenomExprEPKNS0_12ExplodedNodeE", "clang::ento::bugreporter::GetDenomExpr(clang::ento::ExplodedNode const*)"},
    {"_ZN5clang4ento11bugreporter13GetCalleeExprEPKNS0_12ExplodedNodeE", "clang::ento::bugreporter::GetCalleeExpr(clang::ento::ExplodedNode const*)"},
    {"_ZN5clang4ento11bugreporter13GetRetValExprEPKNS0_12ExplodedNodeE", "clang::ento::bugreporter::GetRetValExpr(clang::ento::ExplodedNode const*)"},
    {"_ZN5clang4ento11bugreporter29registerTrackNullOrUndefValueERNS0_18BugReporterContextEPKvPKNS0_12ExplodedNodeE", "clang::ento::bugreporter::registerTrackNullOrUndefValue(clang::ento::BugReporterContext&, void const*, clang::ento::ExplodedNode const*)"},
    {"_ZN5clang4ento11bugreporter21registerFindLastStoreERNS0_18BugReporterContextEPKvPKNS0_12ExplodedNodeE", "clang::ento::bugreporter::registerFindLastStore(clang::ento::BugReporterContext&, void const*, clang::ento::ExplodedNode const*)"},
    {"_ZN5clang4ento11bugreporter26registerNilReceiverVisitorERNS0_18BugReporterContextE", "clang::ento::bugreporter::registerNilReceiverVisitor(clang::ento::BugReporterContext&)"},
    {"_ZN5clang4ento11bugreporter25registerVarDeclsLastStoreERNS0_18BugReporterContextEPKvPKNS0_12ExplodedNodeE", "clang::ento::bugreporter::registerVarDeclsLastStore(clang::ento::BugReporterContext&, void const*, clang::ento::ExplodedNode const*)"},
    {"_ZN12_GLOBAL__N_118NilReceiverVisitorD1Ev", "(anonymous namespace)::NilReceiverVisitor::~NilReceiverVisitor()"},
    {"_ZN12_GLOBAL__N_118NilReceiverVisitorD0Ev", "(anonymous namespace)::NilReceiverVisitor::~NilReceiverVisitor()"},
    {"_ZN12_GLOBAL__N_118NilReceiverVisitor9VisitNodeEPKN5clang4ento12ExplodedNodeES5_RNS2_18BugReporterContextE", "(anonymous namespace)::NilReceiverVisitor::VisitNode(clang::ento::ExplodedNode const*, clang::ento::ExplodedNode const*, clang::ento::BugReporterContext&)"},
    {"_ZNK12_GLOBAL__N_118NilReceiverVisitor7ProfileERN4llvm16FoldingSetNodeIDE", "(anonymous namespace)::NilReceiverVisitor::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN12_GLOBAL__N_122FindLastStoreBRVisitorD1Ev", "(anonymous namespace)::FindLastStoreBRVisitor::~FindLastStoreBRVisitor()"},
    {"_ZN12_GLOBAL__N_122FindLastStoreBRVisitorD0Ev", "(anonymous namespace)::FindLastStoreBRVisitor::~FindLastStoreBRVisitor()"},
    {"_ZN12_GLOBAL__N_122FindLastStoreBRVisitor9VisitNodeEPKN5clang4ento12ExplodedNodeES5_RNS2_18BugReporterContextE", "(anonymous namespace)::FindLastStoreBRVisitor::VisitNode(clang::ento::ExplodedNode const*, clang::ento::ExplodedNode const*, clang::ento::BugReporterContext&)"},
    {"_ZNK12_GLOBAL__N_122FindLastStoreBRVisitor7ProfileERN4llvm16FoldingSetNodeIDE", "(anonymous namespace)::FindLastStoreBRVisitor::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN12_GLOBAL__N_124TrackConstraintBRVisitorD1Ev", "(anonymous namespace)::TrackConstraintBRVisitor::~TrackConstraintBRVisitor()"},
    {"_ZN12_GLOBAL__N_124TrackConstraintBRVisitorD0Ev", "(anonymous namespace)::TrackConstraintBRVisitor::~TrackConstraintBRVisitor()"},
    {"_ZN12_GLOBAL__N_124TrackConstraintBRVisitor9VisitNodeEPKN5clang4ento12ExplodedNodeES5_RNS2_18BugReporterContextE", "(anonymous namespace)::TrackConstraintBRVisitor::VisitNode(clang::ento::ExplodedNode const*, clang::ento::ExplodedNode const*, clang::ento::BugReporterContext&)"},
    {"_ZNK12_GLOBAL__N_124TrackConstraintBRVisitor7ProfileERN4llvm16FoldingSetNodeIDE", "(anonymous namespace)::TrackConstraintBRVisitor::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNSt5dequeIPKN5clang4StmtESaIS3_EE9push_backERKS3_", "std::deque<clang::Stmt const*, std::allocator<clang::Stmt const*>>::push_back(clang::Stmt const* const&)"},
    {"_ZNSt5dequeIPKN5clang4StmtESaIS3_EE17_M_reallocate_mapEmb", "std::deque<clang::Stmt const*, std::allocator<clang::Stmt const*>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZNSt11_Deque_baseIPKN5clang4StmtESaIS3_EE17_M_initialize_mapEm", "std::_Deque_base<clang::Stmt const*, std::allocator<clang::Stmt const*>>::_M_initialize_map(unsigned long)"},
    {"_ZN5clang4ento16MakeCFRefCountTFERNS_10ASTContextEbRKNS_11LangOptionsE", "clang::ento::MakeCFRefCountTF(clang::ASTContext&, bool, clang::LangOptions const&)"},
    {"_ZN12_GLOBAL__N_110CFRefCountD1Ev", "(anonymous namespace)::CFRefCount::~CFRefCount()"},
    {"_ZN12_GLOBAL__N_110CFRefCountD0Ev", "(anonymous namespace)::CFRefCount::~CFRefCount()"},
    {"_ZN12_GLOBAL__N_110CFRefCount16RegisterPrintersERSt6vectorIPN5clang4ento7GRState7PrinterESaIS6_EE", "(anonymous namespace)::CFRefCount::RegisterPrinters(std::vector<clang::ento::GRState::Printer*, std::allocator<clang::ento::GRState::Printer*>>&)"},
    {"_ZN12_GLOBAL__N_110CFRefCount14RegisterChecksERN5clang4ento10ExprEngineE", "(anonymous namespace)::CFRefCount::RegisterChecks(clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_110CFRefCount8evalCallERN5clang4ento15ExplodedNodeSetERNS2_10ExprEngineERNS2_15StmtNodeBuilderEPKNS1_8CallExprENS2_4SValEPNS2_12ExplodedNodeE", "(anonymous namespace)::CFRefCount::evalCall(clang::ento::ExplodedNodeSet&, clang::ento::ExprEngine&, clang::ento::StmtNodeBuilder&, clang::CallExpr const*, clang::ento::SVal, clang::ento::ExplodedNode*)"},
    {"_ZN12_GLOBAL__N_110CFRefCount15evalObjCMessageERN5clang4ento15ExplodedNodeSetERNS2_10ExprEngineERNS2_15StmtNodeBuilderENS2_11ObjCMessageEPNS2_12ExplodedNodeEPKNS2_7GRStateE", "(anonymous namespace)::CFRefCount::evalObjCMessage(clang::ento::ExplodedNodeSet&, clang::ento::ExprEngine&, clang::ento::StmtNodeBuilder&, clang::ento::ObjCMessage, clang::ento::ExplodedNode*, clang::ento::GRState const*)"},
    {"_ZN12_GLOBAL__N_110CFRefCount8evalBindERN5clang4ento18StmtNodeBuilderRefENS2_4SValES5_", "(anonymous namespace)::CFRefCount::evalBind(clang::ento::StmtNodeBuilderRef&, clang::ento::SVal, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_110CFRefCount11evalEndPathERN5clang4ento10ExprEngineERNS2_24EndOfFunctionNodeBuilderE", "(anonymous namespace)::CFRefCount::evalEndPath(clang::ento::ExprEngine&, clang::ento::EndOfFunctionNodeBuilder&)"},
    {"_ZN12_GLOBAL__N_110CFRefCount15evalDeadSymbolsERN5clang4ento15ExplodedNodeSetERNS2_10ExprEngineERNS2_15StmtNodeBuilderEPNS2_12ExplodedNodeEPKNS2_7GRStateERNS2_12SymbolReaperE", "(anonymous namespace)::CFRefCount::evalDeadSymbols(clang::ento::ExplodedNodeSet&, clang::ento::ExprEngine&, clang::ento::StmtNodeBuilder&, clang::ento::ExplodedNode*, clang::ento::GRState const*, clang::ento::SymbolReaper&)"},
    {"_ZN12_GLOBAL__N_110CFRefCount10evalReturnERN5clang4ento15ExplodedNodeSetERNS2_10ExprEngineERNS2_15StmtNodeBuilderEPKNS1_10ReturnStmtEPNS2_12ExplodedNodeE", "(anonymous namespace)::CFRefCount::evalReturn(clang::ento::ExplodedNodeSet&, clang::ento::ExprEngine&, clang::ento::StmtNodeBuilder&, clang::ReturnStmt const*, clang::ento::ExplodedNode*)"},
    {"_ZN12_GLOBAL__N_110CFRefCount10evalAssumeEPKN5clang4ento7GRStateENS2_4SValEb", "(anonymous namespace)::CFRefCount::evalAssume(clang::ento::GRState const*, clang::ento::SVal, bool)"},
    {"_ZN4llvm12ImmutableMapIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValENS_16ImutKeyValueInfoIS5_S7_EEE7Factory6removeESA_RKS5_", "llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::Factory::remove(llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>, clang::ento::SymbolData const* const&)"},
    {"_ZNK5clang4ento7GRState3setIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_16RefValENS3_16ImutKeyValueInfoIS7_S9_EEEEEEPKS1_NS0_12GRStateTraitIT_E9data_typeE", "clang::ento::GRState const* clang::ento::GRState::set<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>>(clang::ento::GRStateTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>>::data_type) const"},
    {"_ZN4llvm26ImutAVLTreeInOrderIteratorINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEEppEv", "llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::operator++()"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::destroy()"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEEENS_12DenseMapInfoIjEENSD_ISC_EEEixERKj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*>>::operator[](unsigned int const&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEEESaISC_EE9push_backERKSC_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*>>::push_back(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>* const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEE15remove_internalERKS6_PNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::remove_internal(clang::ento::SymbolData const* const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEE13markImmutableEPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEE11balanceTreeEPNS_11ImutAVLTreeIS9_EERKSt4pairIS6_S8_ESD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*, std::pair<clang::ento::SymbolData const*, (anonymous namespace)::RefVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEE10createNodeEPNS_11ImutAVLTreeIS9_EERKSt4pairIS6_S8_ESD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*, std::pair<clang::ento::SymbolData const*, (anonymous namespace)::RefVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEE16removeMinBindingEPNS_11ImutAVLTreeIS9_EERSD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::removeMinBinding(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_16RefValENS2_16ImutKeyValueInfoIS6_S8_EEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_16RefValENS2_16ImutKeyValueInfoIS6_S8_EEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>>::DeleteContext(void*)"},
    {"_ZNK5clang4ento7GRState3setIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_16RefValENS3_16ImutKeyValueInfoIS7_S9_EEEEEEPKS1_NS0_12GRStateTraitIT_E8key_typeENSH_10value_typeE", "clang::ento::GRState const* clang::ento::GRState::set<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>>(clang::ento::GRStateTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>>::key_type, clang::ento::GRStateTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>>::value_type) const"},
    {"_ZN12_GLOBAL__N_110CFRefCount23HandleAutoreleaseCountsEPKN5clang4ento7GRStateENS_26GenericNodeBuilderRefCountEPNS2_12ExplodedNodeERNS2_10ExprEngineEPKNS2_10SymbolDataENS_6RefValERb", "(anonymous namespace)::CFRefCount::HandleAutoreleaseCounts(clang::ento::GRState const*, (anonymous namespace)::GenericNodeBuilderRefCount, clang::ento::ExplodedNode*, clang::ento::ExprEngine&, clang::ento::SymbolData const*, (anonymous namespace)::RefVal, bool&)"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager16getMethodSummaryEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::RetainSummaryManager::getMethodSummary(clang::ObjCMethodDecl const*)"},
    {"_ZN12_GLOBAL__N_115CFRefLeakReportC1ERNS_8CFRefBugERKNS_10CFRefCountEPN5clang4ento12ExplodedNodeEPKNS7_10SymbolDataERNS7_10ExprEngineE", "(anonymous namespace)::CFRefLeakReport::CFRefLeakReport((anonymous namespace)::CFRefBug&, (anonymous namespace)::CFRefCount const&, clang::ento::ExplodedNode*, clang::ento::SymbolData const*, clang::ento::ExprEngine&)"},
    {"_ZN12_GLOBAL__N_111CFRefReportD1Ev", "(anonymous namespace)::CFRefReport::~CFRefReport()"},
    {"_ZN12_GLOBAL__N_111CFRefReportD0Ev", "(anonymous namespace)::CFRefReport::~CFRefReport()"},
    {"_ZN12_GLOBAL__N_111CFRefReport9VisitNodeEPKN5clang4ento12ExplodedNodeES5_RNS2_18BugReporterContextE", "(anonymous namespace)::CFRefReport::VisitNode(clang::ento::ExplodedNode const*, clang::ento::ExplodedNode const*, clang::ento::BugReporterContext&)"},
    {"_ZN12_GLOBAL__N_111CFRefReport23getExtraDescriptiveTextEv", "(anonymous namespace)::CFRefReport::getExtraDescriptiveText()"},
    {"_ZN12_GLOBAL__N_111CFRefReport10getEndPathERN5clang4ento18BugReporterContextEPKNS2_12ExplodedNodeE", "(anonymous namespace)::CFRefReport::getEndPath(clang::ento::BugReporterContext&, clang::ento::ExplodedNode const*)"},
    {"_ZNK12_GLOBAL__N_111CFRefReport9getRangesEv", "(anonymous namespace)::CFRefReport::getRanges() const"},
    {"_Z17GetAllocationSiteRN5clang4ento14GRStateManagerEPKNS0_12ExplodedNodeEPKNS0_10SymbolDataE", "GetAllocationSite(clang::ento::GRStateManager&, clang::ento::ExplodedNode const*, clang::ento::SymbolData const*)"},
    {"_ZN12_GLOBAL__N_115CFRefLeakReportD1Ev", "(anonymous namespace)::CFRefLeakReport::~CFRefLeakReport()"},
    {"_ZN12_GLOBAL__N_115CFRefLeakReportD0Ev", "(anonymous namespace)::CFRefLeakReport::~CFRefLeakReport()"},
    {"_ZN12_GLOBAL__N_115CFRefLeakReport10getEndPathERN5clang4ento18BugReporterContextEPKNS2_12ExplodedNodeE", "(anonymous namespace)::CFRefLeakReport::getEndPath(clang::ento::BugReporterContext&, clang::ento::ExplodedNode const*)"},
    {"_ZNK12_GLOBAL__N_115CFRefLeakReport11getLocationEv", "(anonymous namespace)::CFRefLeakReport::getLocation() const"},
    {"_ZN12_GLOBAL__N_117FindUniqueBindingD1Ev", "(anonymous namespace)::FindUniqueBinding::~FindUniqueBinding()"},
    {"_ZN12_GLOBAL__N_117FindUniqueBindingD0Ev", "(anonymous namespace)::FindUniqueBinding::~FindUniqueBinding()"},
    {"_ZN12_GLOBAL__N_117FindUniqueBinding13HandleBindingERN5clang4ento12StoreManagerEPKvPKNS2_9MemRegionENS2_4SValE", "(anonymous namespace)::FindUniqueBinding::HandleBinding(clang::ento::StoreManager&, void const*, clang::ento::MemRegion const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager24getInstanceMethodSummaryEN5clang8SelectorEPNS1_14IdentifierInfoEPKNS1_17ObjCInterfaceDeclEPKNS1_14ObjCMethodDeclENS1_8QualTypeE", "(anonymous namespace)::RetainSummaryManager::getInstanceMethodSummary(clang::Selector, clang::IdentifierInfo*, clang::ObjCInterfaceDecl const*, clang::ObjCMethodDecl const*, clang::QualType)"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager21getClassMethodSummaryEN5clang8SelectorEPNS1_14IdentifierInfoEPKNS1_17ObjCInterfaceDeclEPKNS1_14ObjCMethodDeclENS1_8QualTypeE", "(anonymous namespace)::RetainSummaryManager::getClassMethodSummary(clang::Selector, clang::IdentifierInfo*, clang::ObjCInterfaceDecl const*, clang::ObjCMethodDecl const*, clang::QualType)"},
    {"_ZN12_GLOBAL__N_116ObjCSummaryCache4findEPKN5clang17ObjCInterfaceDeclEPNS1_14IdentifierInfoENS1_8SelectorE", "(anonymous namespace)::ObjCSummaryCache::find(clang::ObjCInterfaceDecl const*, clang::IdentifierInfo*, clang::Selector)"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager22getCommonMethodSummaryEPKN5clang14ObjCMethodDeclENS1_8SelectorENS1_8QualTypeE", "(anonymous namespace)::RetainSummaryManager::getCommonMethodSummary(clang::ObjCMethodDecl const*, clang::Selector, clang::QualType)"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager28updateSummaryFromAnnotationsERNS_13RetainSummaryEPKN5clang14ObjCMethodDeclE", "(anonymous namespace)::RetainSummaryManager::updateSummaryFromAnnotations((anonymous namespace)::RetainSummary&, clang::ObjCMethodDecl const*)"},
    {"_ZN4llvm8DenseMapIN12_GLOBAL__N_114ObjCSummaryKeyEPNS1_13RetainSummaryENS_12DenseMapInfoIS2_EENS5_IS4_EEEixERKS2_", "llvm::DenseMap<(anonymous namespace)::ObjCSummaryKey, (anonymous namespace)::RetainSummary*, llvm::DenseMapInfo<(anonymous namespace)::ObjCSummaryKey>, llvm::DenseMapInfo<(anonymous namespace)::RetainSummary*>>::operator[]((anonymous namespace)::ObjCSummaryKey const&)"},
    {"_ZNK4llvm8DenseMapIN12_GLOBAL__N_114ObjCSummaryKeyEPNS1_13RetainSummaryENS_12DenseMapInfoIS2_EENS5_IS4_EEE15LookupBucketForERKS2_RPSt4pairIS2_S4_E", "llvm::DenseMap<(anonymous namespace)::ObjCSummaryKey, (anonymous namespace)::RetainSummary*, llvm::DenseMapInfo<(anonymous namespace)::ObjCSummaryKey>, llvm::DenseMapInfo<(anonymous namespace)::RetainSummary*>>::LookupBucketFor((anonymous namespace)::ObjCSummaryKey const&, std::pair<(anonymous namespace)::ObjCSummaryKey, (anonymous namespace)::RetainSummary*>*&) const"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_16RefValEEEE12add_internalERKSt4pairIS6_S8_EPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>::add_internal(std::pair<clang::ento::SymbolData const*, (anonymous namespace)::RefVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>*)"},
    {"_ZN12_GLOBAL__N_110CFRefCount17HandleSymbolDeathEPKN5clang4ento7GRStateEPKNS2_10SymbolDataENS_6RefValERN4llvm15SmallVectorImplIS8_EE", "(anonymous namespace)::CFRefCount::HandleSymbolDeath(clang::ento::GRState const*, clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::SmallVectorImpl<clang::ento::SymbolData const*>&)"},
    {"_ZN12_GLOBAL__N_110CFRefCount12ProcessLeaksEPKN5clang4ento7GRStateERN4llvm15SmallVectorImplIPKNS2_10SymbolDataEEERNS_26GenericNodeBuilderRefCountERNS2_10ExprEngineEPNS2_12ExplodedNodeE", "(anonymous namespace)::CFRefCount::ProcessLeaks(clang::ento::GRState const*, llvm::SmallVectorImpl<clang::ento::SymbolData const*>&, (anonymous namespace)::GenericNodeBuilderRefCount&, clang::ento::ExprEngine&, clang::ento::ExplodedNode*)"},
    {"_ZNK5clang4ento7GRState6removeIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_16RefValENS3_16ImutKeyValueInfoIS7_S9_EEEEEEPKS1_NS0_12GRStateTraitIT_E8key_typeE", "clang::ento::GRState const* clang::ento::GRState::remove<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>>(clang::ento::GRStateTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RefVal, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RefVal>>>::key_type) const"},
    {"_ZN12_GLOBAL__N_120StopTrackingCallbackD1Ev", "(anonymous namespace)::StopTrackingCallback::~StopTrackingCallback()"},
    {"_ZN12_GLOBAL__N_120StopTrackingCallback11VisitSymbolEPKN5clang4ento10SymbolDataE", "(anonymous namespace)::StopTrackingCallback::VisitSymbol(clang::ento::SymbolData const*)"},
    {"_ZN12_GLOBAL__N_120StopTrackingCallbackD0Ev", "(anonymous namespace)::StopTrackingCallback::~StopTrackingCallback()"},
    {"_ZN12_GLOBAL__N_110CFRefCount11evalSummaryERN5clang4ento15ExplodedNodeSetERNS2_10ExprEngineERNS2_15StmtNodeBuilderEPKNS1_4ExprERKNS2_17CallOrObjCMessageENS_16InstanceReceiverERKNS_13RetainSummaryEPKNS2_9MemRegionEPNS2_12ExplodedNodeEPKNS2_7GRStateE", "(anonymous namespace)::CFRefCount::evalSummary(clang::ento::ExplodedNodeSet&, clang::ento::ExprEngine&, clang::ento::StmtNodeBuilder&, clang::Expr const*, clang::ento::CallOrObjCMessage const&, (anonymous namespace)::InstanceReceiver, (anonymous namespace)::RetainSummary const&, clang::ento::MemRegion const*, clang::ento::ExplodedNode*, clang::ento::GRState const*)"},
    {"_ZN12_GLOBAL__N_110CFRefCount6UpdateEPKN5clang4ento7GRStateEPKNS2_10SymbolDataENS_6RefValE9ArgEffectRNS9_4KindE", "(anonymous namespace)::CFRefCount::Update(clang::ento::GRState const*, clang::ento::SymbolData const*, (anonymous namespace)::RefVal, ArgEffect, (anonymous namespace)::RefVal::Kind&)"},
    {"_ZN12_GLOBAL__N_116InstanceReceiver20getSValAsScalarOrLocEPKN5clang4ento7GRStateE", "(anonymous namespace)::InstanceReceiver::getSValAsScalarOrLoc(clang::ento::GRState const*)"},
    {"_Z13GetReturnTypePKN5clang4ExprERNS_10ASTContextE", "GetReturnType(clang::Expr const*, clang::ASTContext&)"},
    {"_ZNK5clang4ento7GRState3getIN12_GLOBAL__N_123AutoreleasePoolContentsEEENS0_12GRStateTraitIT_E11lookup_typeENS7_8key_typeE", "clang::ento::GRStateTrait<(anonymous namespace)::AutoreleasePoolContents>::lookup_type clang::ento::GRState::get<(anonymous namespace)::AutoreleasePoolContents>(clang::ento::GRStateTrait<(anonymous namespace)::AutoreleasePoolContents>::key_type) const"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager15getUnarySummaryEPKN5clang12FunctionTypeENS0_13UnaryFuncKindE", "(anonymous namespace)::RetainSummaryManager::getUnarySummary(clang::FunctionType const*, (anonymous namespace)::RetainSummaryManager::UnaryFuncKind)"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager25getCFCreateGetRuleSummaryEPKN5clang12FunctionDeclEN4llvm9StringRefE", "(anonymous namespace)::RetainSummaryManager::getCFCreateGetRuleSummary(clang::FunctionDecl const*, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_120RetainReleaseCheckerD1Ev", "(anonymous namespace)::RetainReleaseChecker::~RetainReleaseChecker()"},
    {"_ZN12_GLOBAL__N_120RetainReleaseCheckerD0Ev", "(anonymous namespace)::RetainReleaseChecker::~RetainReleaseChecker()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120RetainReleaseCheckerEE9_PreVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::RetainReleaseChecker>::_PreVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120RetainReleaseCheckerEE10_PostVisitERNS0_14CheckerContextEPKNS_4StmtE", "clang::ento::CheckerVisitor<(anonymous namespace)::RetainReleaseChecker>::_PostVisit(clang::ento::CheckerContext&, clang::Stmt const*)"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120RetainReleaseCheckerEED1Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::RetainReleaseChecker>::~CheckerVisitor()"},
    {"_ZN5clang4ento14CheckerVisitorIN12_GLOBAL__N_120RetainReleaseCheckerEED0Ev", "clang::ento::CheckerVisitor<(anonymous namespace)::RetainReleaseChecker>::~CheckerVisitor()"},
    {"_ZN12_GLOBAL__N_118LeakWithinFunctionD1Ev", "(anonymous namespace)::LeakWithinFunction::~LeakWithinFunction()"},
    {"_ZN12_GLOBAL__N_118LeakWithinFunctionD0Ev", "(anonymous namespace)::LeakWithinFunction::~LeakWithinFunction()"},
    {"_ZNK12_GLOBAL__N_14Leak14getDescriptionEv", "(anonymous namespace)::Leak::getDescription() const"},
    {"_ZNK12_GLOBAL__N_14Leak6isLeakEv", "(anonymous namespace)::Leak::isLeak() const"},
    {"_ZN12_GLOBAL__N_14LeakD1Ev", "(anonymous namespace)::Leak::~Leak()"},
    {"_ZN12_GLOBAL__N_14LeakD0Ev", "(anonymous namespace)::Leak::~Leak()"},
    {"_ZN12_GLOBAL__N_18CFRefBugD1Ev", "(anonymous namespace)::CFRefBug::~CFRefBug()"},
    {"_ZN12_GLOBAL__N_18CFRefBugD0Ev", "(anonymous namespace)::CFRefBug::~CFRefBug()"},
    {"_ZNK12_GLOBAL__N_18CFRefBug6isLeakEv", "(anonymous namespace)::CFRefBug::isLeak() const"},
    {"_ZN12_GLOBAL__N_112LeakAtReturnD1Ev", "(anonymous namespace)::LeakAtReturn::~LeakAtReturn()"},
    {"_ZN12_GLOBAL__N_112LeakAtReturnD0Ev", "(anonymous namespace)::LeakAtReturn::~LeakAtReturn()"},
    {"_ZN12_GLOBAL__N_124ReturnedNotOwnedForOwnedD1Ev", "(anonymous namespace)::ReturnedNotOwnedForOwned::~ReturnedNotOwnedForOwned()"},
    {"_ZN12_GLOBAL__N_124ReturnedNotOwnedForOwnedD0Ev", "(anonymous namespace)::ReturnedNotOwnedForOwned::~ReturnedNotOwnedForOwned()"},
    {"_ZNK12_GLOBAL__N_124ReturnedNotOwnedForOwned14getDescriptionEv", "(anonymous namespace)::ReturnedNotOwnedForOwned::getDescription() const"},
    {"_ZN12_GLOBAL__N_115OverAutoreleaseD1Ev", "(anonymous namespace)::OverAutorelease::~OverAutorelease()"},
    {"_ZN12_GLOBAL__N_115OverAutoreleaseD0Ev", "(anonymous namespace)::OverAutorelease::~OverAutorelease()"},
    {"_ZNK12_GLOBAL__N_115OverAutorelease14getDescriptionEv", "(anonymous namespace)::OverAutorelease::getDescription() const"},
    {"_ZN12_GLOBAL__N_115DeallocNotOwnedD1Ev", "(anonymous namespace)::DeallocNotOwned::~DeallocNotOwned()"},
    {"_ZN12_GLOBAL__N_115DeallocNotOwnedD0Ev", "(anonymous namespace)::DeallocNotOwned::~DeallocNotOwned()"},
    {"_ZNK12_GLOBAL__N_115DeallocNotOwned14getDescriptionEv", "(anonymous namespace)::DeallocNotOwned::getDescription() const"},
    {"_ZN12_GLOBAL__N_19DeallocGCD1Ev", "(anonymous namespace)::DeallocGC::~DeallocGC()"},
    {"_ZN12_GLOBAL__N_19DeallocGCD0Ev", "(anonymous namespace)::DeallocGC::~DeallocGC()"},
    {"_ZNK12_GLOBAL__N_19DeallocGC14getDescriptionEv", "(anonymous namespace)::DeallocGC::getDescription() const"},
    {"_ZN12_GLOBAL__N_110BadReleaseD1Ev", "(anonymous namespace)::BadRelease::~BadRelease()"},
    {"_ZN12_GLOBAL__N_110BadReleaseD0Ev", "(anonymous namespace)::BadRelease::~BadRelease()"},
    {"_ZNK12_GLOBAL__N_110BadRelease14getDescriptionEv", "(anonymous namespace)::BadRelease::getDescription() const"},
    {"_ZN12_GLOBAL__N_115UseAfterReleaseD1Ev", "(anonymous namespace)::UseAfterRelease::~UseAfterRelease()"},
    {"_ZN12_GLOBAL__N_115UseAfterReleaseD0Ev", "(anonymous namespace)::UseAfterRelease::~UseAfterRelease()"},
    {"_ZNK12_GLOBAL__N_115UseAfterRelease14getDescriptionEv", "(anonymous namespace)::UseAfterRelease::getDescription() const"},
    {"_ZN12_GLOBAL__N_110CFRefCount15BindingsPrinterD1Ev", "(anonymous namespace)::CFRefCount::BindingsPrinter::~BindingsPrinter()"},
    {"_ZN12_GLOBAL__N_110CFRefCount15BindingsPrinterD0Ev", "(anonymous namespace)::CFRefCount::BindingsPrinter::~BindingsPrinter()"},
    {"_ZN12_GLOBAL__N_110CFRefCount15BindingsPrinter5PrintERN4llvm11raw_ostreamEPKN5clang4ento7GRStateEPKcSB_", "(anonymous namespace)::CFRefCount::BindingsPrinter::Print(llvm::raw_ostream&, clang::ento::GRState const*, char const*, char const*)"},
    {"_Z9PrintPoolRN4llvm11raw_ostreamEPKN5clang4ento10SymbolDataEPKNS3_7GRStateE", "PrintPool(llvm::raw_ostream&, clang::ento::SymbolData const*, clang::ento::GRState const*)"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager15addPanicSummaryEPKcz", "(anonymous namespace)::RetainSummaryManager::addPanicSummary(char const*, ...)"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager18addInstMethSummaryEPKcPNS_13RetainSummaryEz", "(anonymous namespace)::RetainSummaryManager::addInstMethSummary(char const*, (anonymous namespace)::RetainSummary*, ...)"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager16addMethodSummaryEPN5clang14IdentifierInfoERNS_16ObjCSummaryCacheEPNS_13RetainSummaryEP13__va_list_tag", "(anonymous namespace)::RetainSummaryManager::addMethodSummary(clang::IdentifierInfo*, (anonymous namespace)::ObjCSummaryCache&, (anonymous namespace)::RetainSummary*, __va_list_tag*)"},
    {"_ZN12_GLOBAL__N_120RetainSummaryManager17addClsMethSummaryEPN5clang14IdentifierInfoEPNS_13RetainSummaryEz", "(anonymous namespace)::RetainSummaryManager::addClsMethSummary(clang::IdentifierInfo*, (anonymous namespace)::RetainSummary*, ...)"},
    {"_ZNK5clang4Decl7getAttrINS_18NSConsumesSelfAttrEEEPT_v", "clang::NSConsumesSelfAttr* clang::Decl::getAttr<clang::NSConsumesSelfAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_14NSConsumedAttrEEEPT_v", "clang::NSConsumedAttr* clang::Decl::getAttr<clang::NSConsumedAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_14CFConsumedAttrEEEPT_v", "clang::CFConsumedAttr* clang::Decl::getAttr<clang::CFConsumedAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_21NSReturnsRetainedAttrEEEPT_v", "clang::NSReturnsRetainedAttr* clang::Decl::getAttr<clang::NSReturnsRetainedAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_24NSReturnsNotRetainedAttrEEEPT_v", "clang::NSReturnsNotRetainedAttr* clang::Decl::getAttr<clang::NSReturnsNotRetainedAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_21CFReturnsRetainedAttrEEEPT_v", "clang::CFReturnsRetainedAttr* clang::Decl::getAttr<clang::CFReturnsRetainedAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_24CFReturnsNotRetainedAttrEEEPT_v", "clang::CFReturnsNotRetainedAttr* clang::Decl::getAttr<clang::CFReturnsNotRetainedAttr>() const"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIj9ArgEffectEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::destroy()"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIj9ArgEffectEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIj9ArgEffectEEEESaIS6_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS6_S8_EERKS6_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>**, std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*>>>, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>* const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIj9ArgEffectEEEENS_12DenseMapInfoIjEENS7_IS6_EEE16InsertIntoBucketERKjRKS6_PSt4pairIjS6_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIj9ArgEffectEEEENS_12DenseMapInfoIjEENS7_IS6_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*>>::grow(unsigned int)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIj9ArgEffectEEE3addEPNS_11ImutAVLTreeIS3_EERKSt4pairIjS2_E", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::add(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*, std::pair<unsigned int, ArgEffect> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIj9ArgEffectEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS3_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIj9ArgEffectEEE22compareTreeWithSectionEPNS_11ImutAVLTreeIS3_EERNS_26ImutAVLTreeInOrderIteratorIS3_EESA_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>&)"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_16ImutKeyValueInfoIj9ArgEffectEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::operator++()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIj9ArgEffectEEE12add_internalERKSt4pairIjS2_EPNS_11ImutAVLTreeIS3_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::add_internal(std::pair<unsigned int, ArgEffect> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIj9ArgEffectEEE13markImmutableEPNS_11ImutAVLTreeIS3_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIj9ArgEffectEEE10createNodeEPNS_11ImutAVLTreeIS3_EERKSt4pairIjS2_ES7_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*, std::pair<unsigned int, ArgEffect> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIj9ArgEffectEEE11balanceTreeEPNS_11ImutAVLTreeIS3_EERKSt4pairIjS2_ES7_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*, std::pair<unsigned int, ArgEffect> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>*)"},
    {"_ZNK5clang4ento17CallOrObjCMessage17getArgSourceRangeEj", "clang::ento::CallOrObjCMessage::getArgSourceRange(unsigned int) const"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataENS3_IS6_jNS2_16ImutKeyValueInfoIS6_jEEEENS7_IS6_S9_EEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataENS3_IS6_jNS2_16ImutKeyValueInfoIS6_jEEEENS7_IS6_S9_EEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>>::DeleteContext(void*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::~ImutAVLFactory()"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::destroy()"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS0_12ImmutableMapIS7_jNS2_IS7_jEEEEEEEESaISD_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSD_SF_EERKSD_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>**, std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*>>>, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>* const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS7_jNS2_IS7_jEEEEEEEENS_12DenseMapInfoIjEENSE_ISD_EEE16InsertIntoBucketERKjRKSD_PSt4pairIjSD_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS7_jNS2_IS7_jEEEEEEEENS_12DenseMapInfoIjEENSE_ISD_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*>>::grow(unsigned int)"},
    {"_ZN4llvm12ImmutableMapIPKN5clang4ento10SymbolDataENS0_IS5_jNS_16ImutKeyValueInfoIS5_jEEEENS6_IS5_S8_EEE7Factory3addESA_RKS5_RKS8_", "llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::Factory::add(llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>, clang::ento::SymbolData const* const&, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEE3addEPNS_11ImutAVLTreeISA_EERKSt4pairIS6_S9_E", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::add(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*, std::pair<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEE16getCanonicalTreeEPNS_11ImutAVLTreeISA_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEE22compareTreeWithSectionEPNS_11ImutAVLTreeISA_EERNS_26ImutAVLTreeInOrderIteratorISA_EESH_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>&)"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::operator++()"},
    {"_ZNK4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEE7isEqualERKS8_", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::isEqual(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>> const&) const"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEE12add_internalERKSt4pairIS6_S9_EPNS_11ImutAVLTreeISA_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::add_internal(std::pair<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEE13markImmutableEPNS_11ImutAVLTreeISA_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEE10createNodeEPNS_11ImutAVLTreeISA_EERKSt4pairIS6_S9_ESE_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*, std::pair<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataENS_12ImmutableMapIS6_jNS1_IS6_jEEEEEEE11balanceTreeEPNS_11ImutAVLTreeISA_EERKSt4pairIS6_S9_ESE_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*, std::pair<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>*)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataENS3_IS6_jNS2_16ImutKeyValueInfoIS6_jEEEENS7_IS6_S9_EEEEE6LookupESB_S6_", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>>::Lookup(llvm::ImmutableMap<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, llvm::ImmutableMap<clang::ento::SymbolData const*, unsigned int, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>>>, clang::ento::SymbolData const*)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm13ImmutableListIPKNS0_10SymbolDataEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableList<clang::ento::SymbolData const*>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm13ImmutableListIPKNS0_10SymbolDataEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableList<clang::ento::SymbolData const*>>::DeleteContext(void*)"},
    {"_ZN4llvm10FoldingSetINS_17ImmutableListImplIPKN5clang4ento10SymbolDataEEEED1Ev", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::SymbolData const*>>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetINS_17ImmutableListImplIPKN5clang4ento10SymbolDataEEEED0Ev", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::SymbolData const*>>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetINS_17ImmutableListImplIPKN5clang4ento10SymbolDataEEEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::SymbolData const*>>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_17ImmutableListImplIPKN5clang4ento10SymbolDataEEEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERSC_", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::SymbolData const*>>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetINS_17ImmutableListImplIPKN5clang4ento10SymbolDataEEEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<llvm::ImmutableListImpl<clang::ento::SymbolData const*>>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm20ImmutableListFactoryIPKN5clang4ento10SymbolDataEE6concatERKS5_NS_13ImmutableListIS5_EE", "llvm::ImmutableListFactory<clang::ento::SymbolData const*>::concat(clang::ento::SymbolData const* const&, llvm::ImmutableList<clang::ento::SymbolData const*>)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento10SymbolDataEcNS_12DenseMapInfoIS5_EENS6_IcEEE6insertERKSt4pairIS5_cE", "llvm::DenseMap<clang::ento::SymbolData const*, char, llvm::DenseMapInfo<clang::ento::SymbolData const*>, llvm::DenseMapInfo<char>>::insert(std::pair<clang::ento::SymbolData const*, char> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento10SymbolDataEcNS_12DenseMapInfoIS5_EENS6_IcEEE16InsertIntoBucketERKS5_RKcPSt4pairIS5_cE", "llvm::DenseMap<clang::ento::SymbolData const*, char, llvm::DenseMapInfo<clang::ento::SymbolData const*>, llvm::DenseMapInfo<char>>::InsertIntoBucket(clang::ento::SymbolData const* const&, char const&, std::pair<clang::ento::SymbolData const*, char>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento10SymbolDataEcNS_12DenseMapInfoIS5_EENS6_IcEEE4growEj", "llvm::DenseMap<clang::ento::SymbolData const*, char, llvm::DenseMapInfo<clang::ento::SymbolData const*>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZN5clang4ento7GRState7PrinterD1Ev", "clang::ento::GRState::Printer::~Printer()"},
    {"_ZN5clang4ento7GRState7PrinterD0Ev", "clang::ento::GRState::Printer::~Printer()"},
    {"_ZNSt6vectorIPN5clang4ento7GRState7PrinterESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<clang::ento::GRState::Printer*, std::allocator<clang::ento::GRState::Printer*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::ento::GRState::Printer**, std::vector<clang::ento::GRState::Printer*, std::allocator<clang::ento::GRState::Printer*>>>, clang::ento::GRState::Printer* const&)"},
    {"_ZN5clang4ento13TransferFuncsD1Ev", "clang::ento::TransferFuncs::~TransferFuncs()"},
    {"_ZN5clang4ento13TransferFuncsD0Ev", "clang::ento::TransferFuncs::~TransferFuncs()"},
    {"_ZN5clang4ento13TransferFuncs16RegisterPrintersERSt6vectorIPNS0_7GRState7PrinterESaIS5_EE", "clang::ento::TransferFuncs::RegisterPrinters(std::vector<clang::ento::GRState::Printer*, std::allocator<clang::ento::GRState::Printer*>>&)"},
    {"_ZN5clang4ento13TransferFuncs14RegisterChecksERNS0_10ExprEngineE", "clang::ento::TransferFuncs::RegisterChecks(clang::ento::ExprEngine&)"},
    {"_ZN5clang4ento13TransferFuncs8evalCallERNS0_15ExplodedNodeSetERNS0_10ExprEngineERNS0_15StmtNodeBuilderEPKNS_8CallExprENS0_4SValEPNS0_12ExplodedNodeE", "clang::ento::TransferFuncs::evalCall(clang::ento::ExplodedNodeSet&, clang::ento::ExprEngine&, clang::ento::StmtNodeBuilder&, clang::CallExpr const*, clang::ento::SVal, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento13TransferFuncs15evalObjCMessageERNS0_15ExplodedNodeSetERNS0_10ExprEngineERNS0_15StmtNodeBuilderENS0_11ObjCMessageEPNS0_12ExplodedNodeEPKNS0_7GRStateE", "clang::ento::TransferFuncs::evalObjCMessage(clang::ento::ExplodedNodeSet&, clang::ento::ExprEngine&, clang::ento::StmtNodeBuilder&, clang::ento::ObjCMessage, clang::ento::ExplodedNode*, clang::ento::GRState const*)"},
    {"_ZN5clang4ento13TransferFuncs8evalBindERNS0_18StmtNodeBuilderRefENS0_4SValES4_", "clang::ento::TransferFuncs::evalBind(clang::ento::StmtNodeBuilderRef&, clang::ento::SVal, clang::ento::SVal)"},
    {"_ZN5clang4ento13TransferFuncs11evalEndPathERNS0_10ExprEngineERNS0_24EndOfFunctionNodeBuilderE", "clang::ento::TransferFuncs::evalEndPath(clang::ento::ExprEngine&, clang::ento::EndOfFunctionNodeBuilder&)"},
    {"_ZN5clang4ento13TransferFuncs15evalDeadSymbolsERNS0_15ExplodedNodeSetERNS0_10ExprEngineERNS0_15StmtNodeBuilderEPNS0_12ExplodedNodeEPKNS0_7GRStateERNS0_12SymbolReaperE", "clang::ento::TransferFuncs::evalDeadSymbols(clang::ento::ExplodedNodeSet&, clang::ento::ExprEngine&, clang::ento::StmtNodeBuilder&, clang::ento::ExplodedNode*, clang::ento::GRState const*, clang::ento::SymbolReaper&)"},
    {"_ZN5clang4ento13TransferFuncs10evalReturnERNS0_15ExplodedNodeSetERNS0_10ExprEngineERNS0_15StmtNodeBuilderEPKNS_10ReturnStmtEPNS0_12ExplodedNodeE", "clang::ento::TransferFuncs::evalReturn(clang::ento::ExplodedNodeSet&, clang::ento::ExprEngine&, clang::ento::StmtNodeBuilder&, clang::ReturnStmt const*, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento13TransferFuncs10evalAssumeEPKNS0_7GRStateENS0_4SValEb", "clang::ento::TransferFuncs::evalAssume(clang::ento::GRState const*, clang::ento::SVal, bool)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIj9ArgEffectEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<unsigned int, ArgEffect>>::~ImutAVLFactory()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEjEEEC2Ev", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, unsigned int>>::ImutAVLFactory()"},
    {"_ZN5clang4ento10ExprEngine13evalArgumentsENS_17ConstExprIteratorES2_PKNS_17FunctionProtoTypeEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetEb", "clang::ento::ExprEngine::evalArguments(clang::ConstExprIterator, clang::ConstExprIterator, clang::FunctionProtoType const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&, bool)"},
    {"_ZN5clang4ento10ExprEngine16getCXXThisRegionEPKNS_13CXXRecordDeclEPKNS_17StackFrameContextE", "clang::ento::ExprEngine::getCXXThisRegion(clang::CXXRecordDecl const*, clang::StackFrameContext const*)"},
    {"_ZN5clang4ento10ExprEngine16getCXXThisRegionEPKNS_13CXXMethodDeclEPKNS_17StackFrameContextE", "clang::ento::ExprEngine::getCXXThisRegion(clang::CXXMethodDecl const*, clang::StackFrameContext const*)"},
    {"_ZN5clang4ento10ExprEngine24CreateCXXTemporaryObjectEPKNS_4ExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::CreateCXXTemporaryObject(clang::Expr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine21VisitCXXConstructExprEPKNS_16CXXConstructExprEPKNS0_9MemRegionEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCXXConstructExpr(clang::CXXConstructExpr const*, clang::ento::MemRegion const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine18VisitCXXDestructorEPKNS_17CXXDestructorDeclEPKNS0_9MemRegionEPKNS_4StmtEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCXXDestructor(clang::CXXDestructorDecl const*, clang::ento::MemRegion const*, clang::Stmt const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine22VisitCXXMemberCallExprEPKNS_17CXXMemberCallExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCXXMemberCallExpr(clang::CXXMemberCallExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine14evalMethodCallEPKNS_8CallExprEPKNS_13CXXMethodDeclEPKNS_4ExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetESE_", "clang::ento::ExprEngine::evalMethodCall(clang::CallExpr const*, clang::CXXMethodDecl const*, clang::Expr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine24VisitCXXOperatorCallExprEPKNS_19CXXOperatorCallExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCXXOperatorCallExpr(clang::CXXOperatorCallExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine15VisitCXXNewExprEPKNS_10CXXNewExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCXXNewExpr(clang::CXXNewExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine18VisitCXXDeleteExprEPKNS_13CXXDeleteExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCXXDeleteExpr(clang::CXXDeleteExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento10ExprEngine16VisitCXXThisExprEPKNS_11CXXThisExprEPNS0_12ExplodedNodeERNS0_15ExplodedNodeSetE", "clang::ento::ExprEngine::VisitCXXThisExpr(clang::CXXThisExpr const*, clang::ento::ExplodedNode*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN12_GLOBAL__N_114CallExprWLItemELb0EE4growEm", "llvm::SmallVectorTemplateBase<(anonymous namespace)::CallExprWLItem, false>::grow(unsigned long)"},
    {"_ZN5clang4ento7CheckerD0Ev", "clang::ento::Checker::~Checker()"},
    {"_ZN5clang4ento7CheckerD1Ev", "clang::ento::Checker::~Checker()"},
    {"_ZN5clang4ento7CheckerD2Ev", "clang::ento::Checker::~Checker()"},
    {"_ZN5clang4ento14CheckerContextD1Ev", "clang::ento::CheckerContext::~CheckerContext()"},
    {"_ZN5clang4ento14CheckerContextD2Ev", "clang::ento::CheckerContext::~CheckerContext()"},
    {"_ZN5clang4ento13containsMacroEPKNS_4StmtE", "clang::ento::containsMacro(clang::Stmt const*)"},
    {"_ZN5clang4ento12containsEnumEPKNS_4StmtE", "clang::ento::containsEnum(clang::Stmt const*)"},
    {"_ZN5clang4ento19containsStaticLocalEPKNS_4StmtE", "clang::ento::containsStaticLocal(clang::Stmt const*)"},
    {"_ZN5clang4ento23containsBuiltinOffsetOfEPKNS_4StmtE", "clang::ento::containsBuiltinOffsetOf(clang::Stmt const*)"},
    {"_ZN5clang4ento8WorkList7VisitorD0Ev", "clang::ento::WorkList::Visitor::~Visitor()"},
    {"_ZN5clang4ento8WorkList7VisitorD1Ev", "clang::ento::WorkList::Visitor::~Visitor()"},
    {"_ZN5clang4ento8WorkList7VisitorD2Ev", "clang::ento::WorkList::Visitor::~Visitor()"},
    {"_ZN5clang4ento8WorkListD0Ev", "clang::ento::WorkList::~WorkList()"},
    {"_ZN5clang4ento8WorkListD1Ev", "clang::ento::WorkList::~WorkList()"},
    {"_ZN5clang4ento8WorkListD2Ev", "clang::ento::WorkList::~WorkList()"},
    {"_ZN5clang4ento8WorkList7makeDFSEv", "clang::ento::WorkList::makeDFS()"},
    {"_ZN5clang4ento8WorkList7makeBFSEv", "clang::ento::WorkList::makeBFS()"},
    {"_ZN5clang4ento8WorkList23makeBFSBlockDFSContentsEv", "clang::ento::WorkList::makeBFSBlockDFSContents()"},
    {"_ZN5clang4ento10CoreEngine15ExecuteWorkListEPKNS_15LocationContextEjPKNS0_7GRStateE", "clang::ento::CoreEngine::ExecuteWorkList(clang::LocationContext const*, unsigned int, clang::ento::GRState const*)"},
    {"_ZN5clang4ento10CoreEngine12generateNodeERKNS_12ProgramPointEPKNS0_7GRStateEPNS0_12ExplodedNodeE", "clang::ento::CoreEngine::generateNode(clang::ProgramPoint const&, clang::ento::GRState const*, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento10CoreEngine15HandleBlockEdgeERKNS_9BlockEdgeEPNS0_12ExplodedNodeE", "clang::ento::CoreEngine::HandleBlockEdge(clang::BlockEdge const&, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento10CoreEngine19HandleBlockEntranceERKNS_13BlockEntranceEPNS0_12ExplodedNodeE", "clang::ento::CoreEngine::HandleBlockEntrance(clang::BlockEntrance const&, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento10CoreEngine15HandleCallEnterERKNS_9CallEnterEPKNS_8CFGBlockEjPNS0_12ExplodedNodeE", "clang::ento::CoreEngine::HandleCallEnter(clang::CallEnter const&, clang::CFGBlock const*, unsigned int, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento10CoreEngine14HandleCallExitERKNS_8CallExitEPNS0_12ExplodedNodeE", "clang::ento::CoreEngine::HandleCallExit(clang::CallExit const&, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento10CoreEngine14HandlePostStmtEPKNS_8CFGBlockEjPNS0_12ExplodedNodeE", "clang::ento::CoreEngine::HandlePostStmt(clang::CFGBlock const*, unsigned int, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento10CoreEngine31ExecuteWorkListWithInitialStateEPKNS_15LocationContextEjPKNS0_7GRStateERNS0_15ExplodedNodeSetE", "clang::ento::CoreEngine::ExecuteWorkListWithInitialState(clang::LocationContext const*, unsigned int, clang::ento::GRState const*, clang::ento::ExplodedNodeSet&)"},
    {"_ZN5clang4ento24EndOfFunctionNodeBuilderD1Ev", "clang::ento::EndOfFunctionNodeBuilder::~EndOfFunctionNodeBuilder()"},
    {"_ZN5clang4ento15StmtNodeBuilderC1EPKNS_8CFGBlockEjPNS0_12ExplodedNodeEPNS0_10CoreEngineERNS0_14GRStateManagerE", "clang::ento::StmtNodeBuilder::StmtNodeBuilder(clang::CFGBlock const*, unsigned int, clang::ento::ExplodedNode*, clang::ento::CoreEngine*, clang::ento::GRStateManager&)"},
    {"_ZN5clang4ento15StmtNodeBuilderD1Ev", "clang::ento::StmtNodeBuilder::~StmtNodeBuilder()"},
    {"_ZN5clang4ento10CoreEngine15HandleBlockExitEPKNS_8CFGBlockEPNS0_12ExplodedNodeE", "clang::ento::CoreEngine::HandleBlockExit(clang::CFGBlock const*, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento10CoreEngine12HandleBranchEPKNS_4StmtES4_PKNS_8CFGBlockEPNS0_12ExplodedNodeE", "clang::ento::CoreEngine::HandleBranch(clang::Stmt const*, clang::Stmt const*, clang::CFGBlock const*, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento17BranchNodeBuilderD1Ev", "clang::ento::BranchNodeBuilder::~BranchNodeBuilder()"},
    {"_ZN5clang4ento22GenericNodeBuilderImpl16generateNodeImplEPKNS0_7GRStateEPNS0_12ExplodedNodeENS_12ProgramPointEb", "clang::ento::GenericNodeBuilderImpl::generateNodeImpl(clang::ento::GRState const*, clang::ento::ExplodedNode*, clang::ProgramPoint, bool)"},
    {"_ZN5clang4ento15StmtNodeBuilderC2EPKNS_8CFGBlockEjPNS0_12ExplodedNodeEPNS0_10CoreEngineERNS0_14GRStateManagerE", "clang::ento::StmtNodeBuilder::StmtNodeBuilder(clang::CFGBlock const*, unsigned int, clang::ento::ExplodedNode*, clang::ento::CoreEngine*, clang::ento::GRStateManager&)"},
    {"_ZN5clang4ento15StmtNodeBuilderD2Ev", "clang::ento::StmtNodeBuilder::~StmtNodeBuilder()"},
    {"_ZN5clang4ento15StmtNodeBuilder22GenerateAutoTransitionEPNS0_12ExplodedNodeE", "clang::ento::StmtNodeBuilder::GenerateAutoTransition(clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento15StmtNodeBuilder8MakeNodeERNS0_15ExplodedNodeSetEPKNS_4StmtEPNS0_12ExplodedNodeEPKNS0_7GRStateENS_12ProgramPoint4KindE", "clang::ento::StmtNodeBuilder::MakeNode(clang::ento::ExplodedNodeSet&, clang::Stmt const*, clang::ento::ExplodedNode*, clang::ento::GRState const*, clang::ProgramPoint::Kind)"},
    {"_ZN5clang4ento15StmtNodeBuilder20generateNodeInternalEPKNS_4StmtEPKNS0_7GRStateEPNS0_12ExplodedNodeENS_12ProgramPoint4KindEPKv", "clang::ento::StmtNodeBuilder::generateNodeInternal(clang::Stmt const*, clang::ento::GRState const*, clang::ento::ExplodedNode*, clang::ProgramPoint::Kind, void const*)"},
    {"_ZN5clang4ento15StmtNodeBuilder20generateNodeInternalERKNS_12ProgramPointEPKNS0_7GRStateEPNS0_12ExplodedNodeE", "clang::ento::StmtNodeBuilder::generateNodeInternal(clang::ProgramPoint const&, clang::ento::GRState const*, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento17BranchNodeBuilder12generateNodeEPKNS0_7GRStateEb", "clang::ento::BranchNodeBuilder::generateNode(clang::ento::GRState const*, bool)"},
    {"_ZN5clang4ento17BranchNodeBuilderD2Ev", "clang::ento::BranchNodeBuilder::~BranchNodeBuilder()"},
    {"_ZN5clang4ento23IndirectGotoNodeBuilder12generateNodeERKNS1_8iteratorEPKNS0_7GRStateEb", "clang::ento::IndirectGotoNodeBuilder::generateNode(clang::ento::IndirectGotoNodeBuilder::iterator const&, clang::ento::GRState const*, bool)"},
    {"_ZN5clang4ento17SwitchNodeBuilder20generateCaseStmtNodeERKNS1_8iteratorEPKNS0_7GRStateE", "clang::ento::SwitchNodeBuilder::generateCaseStmtNode(clang::ento::SwitchNodeBuilder::iterator const&, clang::ento::GRState const*)"},
    {"_ZN5clang4ento17SwitchNodeBuilder23generateDefaultCaseNodeEPKNS0_7GRStateEb", "clang::ento::SwitchNodeBuilder::generateDefaultCaseNode(clang::ento::GRState const*, bool)"},
    {"_ZN5clang4ento24EndOfFunctionNodeBuilderD2Ev", "clang::ento::EndOfFunctionNodeBuilder::~EndOfFunctionNodeBuilder()"},
    {"_ZN5clang4ento24EndOfFunctionNodeBuilder20GenerateCallExitNodeEPKNS0_7GRStateE", "clang::ento::EndOfFunctionNodeBuilder::GenerateCallExitNode(clang::ento::GRState const*)"},
    {"_ZN5clang4ento24EndOfFunctionNodeBuilder12generateNodeEPKNS0_7GRStateEPKvPNS0_12ExplodedNodeE", "clang::ento::EndOfFunctionNodeBuilder::generateNode(clang::ento::GRState const*, void const*, clang::ento::ExplodedNode*)"},
    {"_ZN5clang4ento20CallEnterNodeBuilder12generateNodeEPKNS0_7GRStateE", "clang::ento::CallEnterNodeBuilder::generateNode(clang::ento::GRState const*)"},
    {"_ZN5clang4ento19CallExitNodeBuilder12generateNodeEPKNS0_7GRStateE", "clang::ento::CallExitNodeBuilder::generateNode(clang::ento::GRState const*)"},
    {"_ZN12_GLOBAL__N_119BFSBlockDFSContentsD1Ev", "(anonymous namespace)::BFSBlockDFSContents::~BFSBlockDFSContents()"},
    {"_ZN12_GLOBAL__N_119BFSBlockDFSContentsD0Ev", "(anonymous namespace)::BFSBlockDFSContents::~BFSBlockDFSContents()"},
    {"_ZNK12_GLOBAL__N_119BFSBlockDFSContents7hasWorkEv", "(anonymous namespace)::BFSBlockDFSContents::hasWork() const"},
    {"_ZN12_GLOBAL__N_119BFSBlockDFSContents7enqueueERKN5clang4ento12WorkListUnitE", "(anonymous namespace)::BFSBlockDFSContents::enqueue(clang::ento::WorkListUnit const&)"},
    {"_ZN12_GLOBAL__N_119BFSBlockDFSContents7dequeueEv", "(anonymous namespace)::BFSBlockDFSContents::dequeue()"},
    {"_ZN12_GLOBAL__N_119BFSBlockDFSContents20visitItemsInWorkListERN5clang4ento8WorkList7VisitorE", "(anonymous namespace)::BFSBlockDFSContents::visitItemsInWorkList(clang::ento::WorkList::Visitor&)"},
    {"_ZN12_GLOBAL__N_13BFSD1Ev", "(anonymous namespace)::BFS::~BFS()"},
    {"_ZN12_GLOBAL__N_13BFSD0Ev", "(anonymous namespace)::BFS::~BFS()"},
    {"_ZNK12_GLOBAL__N_13BFS7hasWorkEv", "(anonymous namespace)::BFS::hasWork() const"},
    {"_ZN12_GLOBAL__N_13BFS7enqueueERKN5clang4ento12WorkListUnitE", "(anonymous namespace)::BFS::enqueue(clang::ento::WorkListUnit const&)"},
    {"_ZN12_GLOBAL__N_13BFS7dequeueEv", "(anonymous namespace)::BFS::dequeue()"},
    {"_ZN12_GLOBAL__N_13BFS20visitItemsInWorkListERN5clang4ento8WorkList7VisitorE", "(anonymous namespace)::BFS::visitItemsInWorkList(clang::ento::WorkList::Visitor&)"},
    {"_ZN12_GLOBAL__N_13DFSD1Ev", "(anonymous namespace)::DFS::~DFS()"},
    {"_ZN12_GLOBAL__N_13DFSD0Ev", "(anonymous namespace)::DFS::~DFS()"},
    {"_ZNK12_GLOBAL__N_13DFS7hasWorkEv", "(anonymous namespace)::DFS::hasWork() const"},
    {"_ZN12_GLOBAL__N_13DFS7enqueueERKN5clang4ento12WorkListUnitE", "(anonymous namespace)::DFS::enqueue(clang::ento::WorkListUnit const&)"},
    {"_ZN12_GLOBAL__N_13DFS7dequeueEv", "(anonymous namespace)::DFS::dequeue()"},
    {"_ZN12_GLOBAL__N_13DFS20visitItemsInWorkListERN5clang4ento8WorkList7VisitorE", "(anonymous namespace)::DFS::visitItemsInWorkList(clang::ento::WorkList::Visitor&)"},
    {"_ZNSt6vectorISt4pairIN5clang9BlockEdgeEPKNS1_4ento12ExplodedNodeEESaIS7_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS7_S9_EERKS7_", "std::vector<std::pair<clang::BlockEdge, clang::ento::ExplodedNode const*>, std::allocator<std::pair<clang::BlockEdge, clang::ento::ExplodedNode const*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<clang::BlockEdge, clang::ento::ExplodedNode const*>*, std::vector<std::pair<clang::BlockEdge, clang::ento::ExplodedNode const*>, std::allocator<std::pair<clang::BlockEdge, clang::ento::ExplodedNode const*>>>>, std::pair<clang::BlockEdge, clang::ento::ExplodedNode const*> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang4ento12WorkListUnitELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::ento::WorkListUnit, false>::grow(unsigned long)"},
    {"_ZNSt5dequeIN5clang4ento12WorkListUnitESaIS2_EE17_M_reallocate_mapEmb", "std::deque<clang::ento::WorkListUnit, std::allocator<clang::ento::WorkListUnit>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZNSt11_Deque_baseIN5clang4ento12WorkListUnitESaIS2_EE17_M_initialize_mapEm", "std::_Deque_base<clang::ento::WorkListUnit, std::allocator<clang::ento::WorkListUnit>>::_M_initialize_map(unsigned long)"},
    {"_ZNK5clang4ento11Environment10lookupExprEPKNS_4StmtE", "clang::ento::Environment::lookupExpr(clang::Stmt const*) const"},
    {"_ZNK5clang4ento11Environment7getSValEPKNS_4StmtERNS0_11SValBuilderE", "clang::ento::Environment::getSVal(clang::Stmt const*, clang::ento::SValBuilder&) const"},
    {"_ZN5clang4ento18EnvironmentManager8bindExprENS0_11EnvironmentEPKNS_4StmtENS0_4SValEb", "clang::ento::EnvironmentManager::bindExpr(clang::ento::Environment, clang::Stmt const*, clang::ento::SVal, bool)"},
    {"_ZN5clang4ento18EnvironmentManager19bindExprAndLocationENS0_11EnvironmentEPKNS_4StmtENS0_4SValES6_", "clang::ento::EnvironmentManager::bindExprAndLocation(clang::ento::Environment, clang::Stmt const*, clang::ento::SVal, clang::ento::SVal)"},
    {"_ZN5clang4ento18EnvironmentManager18removeDeadBindingsENS0_11EnvironmentERNS0_12SymbolReaperEPKNS0_7GRStateERN4llvm15SmallVectorImplIPKNS0_9MemRegionEEE", "clang::ento::EnvironmentManager::removeDeadBindings(clang::ento::Environment, clang::ento::SymbolReaper&, clang::ento::GRState const*, llvm::SmallVectorImpl<clang::ento::MemRegion const*>&)"},
    {"_ZN12_GLOBAL__N_116MarkLiveCallbackD1Ev", "(anonymous namespace)::MarkLiveCallback::~MarkLiveCallback()"},
    {"_ZN12_GLOBAL__N_116MarkLiveCallback11VisitSymbolEPKN5clang4ento10SymbolDataE", "(anonymous namespace)::MarkLiveCallback::VisitSymbol(clang::ento::SymbolData const*)"},
    {"_ZN12_GLOBAL__N_116MarkLiveCallbackD0Ev", "(anonymous namespace)::MarkLiveCallback::~MarkLiveCallback()"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairIPKN5clang4StmtENS2_4ento4SValEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<clang::Stmt const*, clang::ento::SVal>, false>::grow(unsigned long)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE3addEPNS_11ImutAVLTreeIS8_EERKSt4pairIS5_S7_E", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::add(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, std::pair<clang::Stmt const*, clang::ento::SVal> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS8_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE22compareTreeWithSectionEPNS_11ImutAVLTreeIS8_EERNS_26ImutAVLTreeInOrderIteratorIS8_EESF_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE12add_internalERKSt4pairIS5_S7_EPNS_11ImutAVLTreeIS8_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::add_internal(std::pair<clang::Stmt const*, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE13markImmutableEPNS_11ImutAVLTreeIS8_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE10createNodeEPNS_11ImutAVLTreeIS8_EERKSt4pairIS5_S7_ESC_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, std::pair<clang::Stmt const*, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE11balanceTreeEPNS_11ImutAVLTreeIS8_EERKSt4pairIS5_S7_ESC_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, std::pair<clang::Stmt const*, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE6removeEPNS_11ImutAVLTreeIS8_EERKS5_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::remove(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, clang::Stmt const* const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE15remove_internalERKS5_PNS_11ImutAVLTreeIS8_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::remove_internal(clang::Stmt const* const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE16removeMinBindingEPNS_11ImutAVLTreeIS8_EERSC_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::removeMinBinding(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*&)"},
    {"_ZN5clang4ento12ExplodedNode7AuditorD0Ev", "clang::ento::ExplodedNode::Auditor::~Auditor()"},
    {"_ZN5clang4ento12ExplodedNode7AuditorD1Ev", "clang::ento::ExplodedNode::Auditor::~Auditor()"},
    {"_ZN5clang4ento12ExplodedNode7AuditorD2Ev", "clang::ento::ExplodedNode::Auditor::~Auditor()"},
    {"_ZN5clang4ento12ExplodedNode10SetAuditorEPNS1_7AuditorE", "clang::ento::ExplodedNode::SetAuditor(clang::ento::ExplodedNode::Auditor*)"},
    {"_ZN5clang4ento13ExplodedGraphD1Ev", "clang::ento::ExplodedGraph::~ExplodedGraph()"},
    {"_ZN5clang4ento13ExplodedGraphD2Ev", "clang::ento::ExplodedGraph::~ExplodedGraph()"},
    {"_ZN5clang4ento13ExplodedGraph29reclaimRecentlyAllocatedNodesEv", "clang::ento::ExplodedGraph::reclaimRecentlyAllocatedNodes()"},
    {"_ZN5clang4ento12ExplodedNode14addPredecessorEPS1_RNS0_13ExplodedGraphE", "clang::ento::ExplodedNode::addPredecessor(clang::ento::ExplodedNode*, clang::ento::ExplodedGraph&)"},
    {"_ZN5clang4ento12ExplodedNode9NodeGroup7addNodeEPS1_RNS0_13ExplodedGraphE", "clang::ento::ExplodedNode::NodeGroup::addNode(clang::ento::ExplodedNode*, clang::ento::ExplodedGraph&)"},
    {"_ZN5clang4ento12ExplodedNode9NodeGroup11replaceNodeEPS1_", "clang::ento::ExplodedNode::NodeGroup::replaceNode(clang::ento::ExplodedNode*)"},
    {"_ZNK5clang4ento12ExplodedNode9NodeGroup4sizeEv", "clang::ento::ExplodedNode::NodeGroup::size() const"},
    {"_ZNK5clang4ento12ExplodedNode9NodeGroup5beginEv", "clang::ento::ExplodedNode::NodeGroup::begin() const"},
    {"_ZNK5clang4ento12ExplodedNode9NodeGroup3endEv", "clang::ento::ExplodedNode::NodeGroup::end() const"},
    {"_ZN5clang4ento13ExplodedGraph7getNodeERKNS_12ProgramPointEPKNS0_7GRStateEPb", "clang::ento::ExplodedGraph::getNode(clang::ProgramPoint const&, clang::ento::GRState const*, bool*)"},
    {"_ZNK5clang4ento13ExplodedGraph4TrimEPKPKNS0_12ExplodedNodeES6_PN4llvm8DenseMapIPKvSA_NS7_12DenseMapInfoISA_EESC_EE", "clang::ento::ExplodedGraph::Trim(clang::ento::ExplodedNode const* const*, clang::ento::ExplodedNode const* const*, llvm::DenseMap<void const*, void const*, llvm::DenseMapInfo<void const*>, llvm::DenseMapInfo<void const*>>*) const"},
    {"_ZNK5clang4ento13ExplodedGraph12TrimInternalEPKPKNS0_12ExplodedNodeES6_PNS0_21InterExplodedGraphMapEPN4llvm8DenseMapIPKvSC_NS9_12DenseMapInfoISC_EESE_EE", "clang::ento::ExplodedGraph::TrimInternal(clang::ento::ExplodedNode const* const*, clang::ento::ExplodedNode const* const*, clang::ento::InterExplodedGraphMap*, llvm::DenseMap<void const*, void const*, llvm::DenseMapInfo<void const*>, llvm::DenseMapInfo<void const*>>*) const"},
    {"_ZNK5clang4ento21InterExplodedGraphMap13getMappedNodeEPKNS0_12ExplodedNodeE", "clang::ento::InterExplodedGraphMap::getMappedNode(clang::ento::ExplodedNode const*) const"},
    {"_ZN4llvm8DenseMapIPKvS2_NS_12DenseMapInfoIS2_EES4_E16InsertIntoBucketERKS2_S7_PSt4pairIS2_S2_E", "llvm::DenseMap<void const*, void const*, llvm::DenseMapInfo<void const*>, llvm::DenseMapInfo<void const*>>::InsertIntoBucket(void const* const&, void const* const&, std::pair<void const*, void const*>*)"},
    {"_ZN4llvm8DenseMapIPKvS2_NS_12DenseMapInfoIS2_EES4_E4growEj", "llvm::DenseMap<void const*, void const*, llvm::DenseMapInfo<void const*>, llvm::DenseMapInfo<void const*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento12ExplodedNodeEPS3_NS_12DenseMapInfoIS5_EENS7_IS6_EEE16InsertIntoBucketERKS5_RKS6_PSt4pairIS5_S6_E", "llvm::DenseMap<clang::ento::ExplodedNode const*, clang::ento::ExplodedNode*, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>, llvm::DenseMapInfo<clang::ento::ExplodedNode*>>::InsertIntoBucket(clang::ento::ExplodedNode const* const&, clang::ento::ExplodedNode* const&, std::pair<clang::ento::ExplodedNode const*, clang::ento::ExplodedNode*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento12ExplodedNodeEPS3_NS_12DenseMapInfoIS5_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::ento::ExplodedNode const*, clang::ento::ExplodedNode*, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>, llvm::DenseMapInfo<clang::ento::ExplodedNode*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento12ExplodedNodeEcNS_12DenseMapInfoIS5_EENS6_IcEEE6insertERKSt4pairIS5_cE", "llvm::DenseMap<clang::ento::ExplodedNode const*, char, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>, llvm::DenseMapInfo<char>>::insert(std::pair<clang::ento::ExplodedNode const*, char> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento12ExplodedNodeEcNS_12DenseMapInfoIS5_EENS6_IcEEE16InsertIntoBucketERKS5_RKcPSt4pairIS5_cE", "llvm::DenseMap<clang::ento::ExplodedNode const*, char, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>, llvm::DenseMapInfo<char>>::InsertIntoBucket(clang::ento::ExplodedNode const* const&, char const&, std::pair<clang::ento::ExplodedNode const*, char>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento12ExplodedNodeEcNS_12DenseMapInfoIS5_EENS6_IcEEE4growEj", "llvm::DenseMap<clang::ento::ExplodedNode const*, char, llvm::DenseMapInfo<clang::ento::ExplodedNode const*>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZNSt6vectorIPN5clang4ento12ExplodedNodeESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<clang::ento::ExplodedNode*, std::allocator<clang::ento::ExplodedNode*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::ento::ExplodedNode**, std::vector<clang::ento::ExplodedNode*, std::allocator<clang::ento::ExplodedNode*>>>, clang::ento::ExplodedNode* const&)"},
    {"_ZNK4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPvS2_EEE7isEqualERKS4_", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>::isEqual(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>> const&) const"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_16ImutKeyValueInfoIPvS2_EEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutKeyValueInfo<void*, void*>>::operator++()"},
    {"_ZN5clang4ento21InterExplodedGraphMapD1Ev", "clang::ento::InterExplodedGraphMap::~InterExplodedGraphMap()"},
    {"_ZN5clang4ento21InterExplodedGraphMapD0Ev", "clang::ento::InterExplodedGraphMap::~InterExplodedGraphMap()"},
    {"_ZN5clang4ento22CreateFlatStoreManagerERNS0_14GRStateManagerE", "clang::ento::CreateFlatStoreManager(clang::ento::GRStateManager&)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManagerD1Ev", "(anonymous namespace)::FlatStoreManager::~FlatStoreManager()"},
    {"_ZN12_GLOBAL__N_116FlatStoreManagerD0Ev", "(anonymous namespace)::FlatStoreManager::~FlatStoreManager()"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager8RetrieveEPKvN5clang4ento3LocENS3_8QualTypeE", "(anonymous namespace)::FlatStoreManager::Retrieve(void const*, clang::ento::Loc, clang::QualType)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager4BindEPKvN5clang4ento3LocENS4_4SValE", "(anonymous namespace)::FlatStoreManager::Bind(void const*, clang::ento::Loc, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager6RemoveEPKvN5clang4ento3LocE", "(anonymous namespace)::FlatStoreManager::Remove(void const*, clang::ento::Loc)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager19BindCompoundLiteralEPKvPKN5clang19CompoundLiteralExprEPKNS3_15LocationContextENS3_4ento4SValE", "(anonymous namespace)::FlatStoreManager::BindCompoundLiteral(void const*, clang::CompoundLiteralExpr const*, clang::LocationContext const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager15getInitialStoreEPKN5clang15LocationContextE", "(anonymous namespace)::FlatStoreManager::getInitialStore(clang::LocationContext const*)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager15getSubRegionMapEPKv", "(anonymous namespace)::FlatStoreManager::getSubRegionMap(void const*)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager14ArrayToPointerEN5clang4ento3LocE", "(anonymous namespace)::FlatStoreManager::ArrayToPointer(clang::ento::Loc)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager18removeDeadBindingsEPKvPKN5clang17StackFrameContextERNS3_4ento12SymbolReaperERN4llvm15SmallVectorImplIPKNS7_9MemRegionEEE", "(anonymous namespace)::FlatStoreManager::removeDeadBindings(void const*, clang::StackFrameContext const*, clang::ento::SymbolReaper&, llvm::SmallVectorImpl<clang::ento::MemRegion const*>&)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager8BindDeclEPKvPKN5clang4ento9VarRegionENS4_4SValE", "(anonymous namespace)::FlatStoreManager::BindDecl(void const*, clang::ento::VarRegion const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager18BindDeclWithNoInitEPKvPKN5clang4ento9VarRegionE", "(anonymous namespace)::FlatStoreManager::BindDeclWithNoInit(void const*, clang::ento::VarRegion const*)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager17InvalidateRegionsEPKvPKPKN5clang4ento9MemRegionES9_PKNS3_4ExprEjPN4llvm8DenseSetIPKNS4_10SymbolDataENSD_12DenseMapInfoISH_EEEEbPNSD_11SmallVectorIS7_Lj8EEE", "(anonymous namespace)::FlatStoreManager::InvalidateRegions(void const*, clang::ento::MemRegion const* const*, clang::ento::MemRegion const* const*, clang::Expr const*, unsigned int, llvm::DenseSet<clang::ento::SymbolData const*, llvm::DenseMapInfo<clang::ento::SymbolData const*>>*, bool, llvm::SmallVector<clang::ento::MemRegion const*, 8u>*)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager5printEPKvRN4llvm11raw_ostreamEPKcS7_", "(anonymous namespace)::FlatStoreManager::print(void const*, llvm::raw_ostream&, char const*, char const*)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager12iterBindingsEPKvRN5clang4ento12StoreManager15BindingsHandlerE", "(anonymous namespace)::FlatStoreManager::iterBindings(void const*, clang::ento::StoreManager::BindingsHandler&)"},
    {"_ZN12_GLOBAL__N_116FlatStoreManager16RegionToIntervalEPKN5clang4ento9MemRegionE", "(anonymous namespace)::FlatStoreManager::RegionToInterval(clang::ento::MemRegion const*)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::destroy()"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS0_20ImmutableIntervalMapINS4_4SValEEEEEEESaISD_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSD_SF_EERKSD_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>**, std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*>>>, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>* const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS4_4SValEEEEEEENS_12DenseMapInfoIjEENSE_ISD_EEE16InsertIntoBucketERKjRKSD_PSt4pairIjSD_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS4_4SValEEEEEEENS_12DenseMapInfoIjEENSE_ISD_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*>>::grow(unsigned int)"},
    {"_ZN4llvm12ImmutableMapIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS2_4SValEEENS_16ImutKeyValueInfoIS5_S8_EEE7Factory3addESB_RKS5_RKS8_", "llvm::ImmutableMap<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>, llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::Factory::add(llvm::ImmutableMap<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>, llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>, clang::ento::MemRegion const* const&, llvm::ImmutableIntervalMap<clang::ento::SVal> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEE3addEPNS_11ImutAVLTreeISA_EERKSt4pairIS6_S9_E", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::add(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*, std::pair<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEE16getCanonicalTreeEPNS_11ImutAVLTreeISA_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEE22compareTreeWithSectionEPNS_11ImutAVLTreeISA_EERNS_26ImutAVLTreeInOrderIteratorISA_EESH_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>&)"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::operator++()"},
    {"_ZNK4llvm11ImutAVLTreeINS_16ImutIntervalInfoIN5clang4ento4SValEEEE7isEqualERKS6_", "llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>::isEqual(llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>> const&) const"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_16ImutIntervalInfoIN5clang4ento4SValEEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutIntervalInfo<clang::ento::SVal>>::operator++()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEE12add_internalERKSt4pairIS6_S9_EPNS_11ImutAVLTreeISA_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::add_internal(std::pair<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEE13markImmutableEPNS_11ImutAVLTreeISA_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEE10createNodeEPNS_11ImutAVLTreeISA_EERKSt4pairIS6_S9_ESE_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*, std::pair<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEE11balanceTreeEPNS_11ImutAVLTreeISA_EERKSt4pairIS6_S9_ESE_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*, std::pair<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>*)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutIntervalInfoIN5clang4ento4SValEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>::destroy()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutIntervalInfoIN5clang4ento4SValEEEEESaIS8_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS8_SA_EERKS8_", "std::vector<llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>**, std::vector<llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*>>>, llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>* const&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutIntervalInfoIN5clang4ento4SValEEEE13computeDigestEPS6_S7_RKSt4pairINS_8IntervalES4_E", "llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>::computeDigest(llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*, llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*, std::pair<llvm::Interval, clang::ento::SVal> const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutIntervalInfoIN5clang4ento4SValEEEEENS_12DenseMapInfoIjEENS9_IS8_EEE16InsertIntoBucketERKjRKS8_PSt4pairIjS8_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutIntervalInfoIN5clang4ento4SValEEEEENS_12DenseMapInfoIjEENS9_IS8_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*>>::grow(unsigned int)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutIntervalInfoIN5clang4ento4SValEEEE3addEPNS_11ImutAVLTreeIS5_EERKSt4pairINS_8IntervalES4_E", "llvm::ImutAVLFactory<llvm::ImutIntervalInfo<clang::ento::SVal>>::add(llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*, std::pair<llvm::Interval, clang::ento::SVal> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutIntervalInfoIN5clang4ento4SValEEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS5_EE", "llvm::ImutAVLFactory<llvm::ImutIntervalInfo<clang::ento::SVal>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutIntervalInfoIN5clang4ento4SValEEEE22compareTreeWithSectionEPNS_11ImutAVLTreeIS5_EERNS_26ImutAVLTreeInOrderIteratorIS5_EESC_", "llvm::ImutAVLFactory<llvm::ImutIntervalInfo<clang::ento::SVal>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutIntervalInfo<clang::ento::SVal>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutIntervalInfo<clang::ento::SVal>>&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutIntervalInfoIN5clang4ento4SValEEEE12add_internalERKSt4pairINS_8IntervalES4_EPNS_11ImutAVLTreeIS5_EE", "llvm::ImutAVLFactory<llvm::ImutIntervalInfo<clang::ento::SVal>>::add_internal(std::pair<llvm::Interval, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutIntervalInfoIN5clang4ento4SValEEEE13markImmutableEPNS_11ImutAVLTreeIS5_EE", "llvm::ImutAVLFactory<llvm::ImutIntervalInfo<clang::ento::SVal>>::markImmutable(llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutIntervalInfoIN5clang4ento4SValEEEE10createNodeEPNS_11ImutAVLTreeIS5_EERKSt4pairINS_8IntervalES4_ES9_", "llvm::ImutAVLFactory<llvm::ImutIntervalInfo<clang::ento::SVal>>::createNode(llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*, std::pair<llvm::Interval, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutIntervalInfoIN5clang4ento4SValEEEE11balanceTreeEPNS_11ImutAVLTreeIS5_EERKSt4pairINS_8IntervalES4_ES9_", "llvm::ImutAVLFactory<llvm::ImutIntervalInfo<clang::ento::SVal>>::balanceTree(llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*, std::pair<llvm::Interval, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutIntervalInfo<clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento9MemRegionENS_20ImmutableIntervalMapINS3_4SValEEEEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::MemRegion const*, llvm::ImmutableIntervalMap<clang::ento::SVal>>>::~ImutAVLFactory()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutIntervalInfoIN5clang4ento4SValEEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutIntervalInfo<clang::ento::SVal>>::~ImutAVLFactory()"},
    {"_ZN5clang4ento17ConstraintManagerD0Ev", "clang::ento::ConstraintManager::~ConstraintManager()"},
    {"_ZN5clang4ento17ConstraintManagerD1Ev", "clang::ento::ConstraintManager::~ConstraintManager()"},
    {"_ZN5clang4ento17ConstraintManagerD2Ev", "clang::ento::ConstraintManager::~ConstraintManager()"},
    {"_ZN5clang4ento14GRStateManagerD1Ev", "clang::ento::GRStateManager::~GRStateManager()"},
    {"_ZN5clang4ento14GRStateManagerD2Ev", "clang::ento::GRStateManager::~GRStateManager()"},
    {"_ZN5clang4ento14GRStateManager18removeDeadBindingsEPKNS0_7GRStateEPKNS_17StackFrameContextERNS0_12SymbolReaperE", "clang::ento::GRStateManager::removeDeadBindings(clang::ento::GRState const*, clang::StackFrameContext const*, clang::ento::SymbolReaper&)"},
    {"_ZN5clang4ento14GRStateManager18getPersistentStateERNS0_7GRStateE", "clang::ento::GRStateManager::getPersistentState(clang::ento::GRState&)"},
    {"_ZN5clang4ento14GRStateManager12MarshalStateEPKNS0_7GRStateEPKNS_17StackFrameContextE", "clang::ento::GRStateManager::MarshalState(clang::ento::GRState const*, clang::StackFrameContext const*)"},
    {"_ZNK5clang4ento7GRState19bindCompoundLiteralEPKNS_19CompoundLiteralExprEPKNS_15LocationContextENS0_4SValE", "clang::ento::GRState::bindCompoundLiteral(clang::CompoundLiteralExpr const*, clang::LocationContext const*, clang::ento::SVal) const"},
    {"_ZNK5clang4ento7GRState13makeWithStoreEPKv", "clang::ento::GRState::makeWithStore(void const*) const"},
    {"_ZNK5clang4ento7GRState8bindDeclEPKNS0_9VarRegionENS0_4SValE", "clang::ento::GRState::bindDecl(clang::ento::VarRegion const*, clang::ento::SVal) const"},
    {"_ZNK5clang4ento7GRState18bindDeclWithNoInitEPKNS0_9VarRegionE", "clang::ento::GRState::bindDeclWithNoInit(clang::ento::VarRegion const*) const"},
    {"_ZNK5clang4ento7GRState7bindLocENS0_3LocENS0_4SValE", "clang::ento::GRState::bindLoc(clang::ento::Loc, clang::ento::SVal) const"},
    {"_ZNK5clang4ento7GRState11bindDefaultENS0_4SValES2_", "clang::ento::GRState::bindDefault(clang::ento::SVal, clang::ento::SVal) const"},
    {"_ZNK5clang4ento7GRState17InvalidateRegionsEPKPKNS0_9MemRegionES6_PKNS_4ExprEjPN4llvm8DenseSetIPKNS0_10SymbolDataENSA_12DenseMapInfoISE_EEEEb", "clang::ento::GRState::InvalidateRegions(clang::ento::MemRegion const* const*, clang::ento::MemRegion const* const*, clang::Expr const*, unsigned int, llvm::DenseSet<clang::ento::SymbolData const*, llvm::DenseMapInfo<clang::ento::SymbolData const*>>*, bool) const"},
    {"_ZNK5clang4ento7GRState9unbindLocENS0_3LocE", "clang::ento::GRState::unbindLoc(clang::ento::Loc) const"},
    {"_ZNK5clang4ento7GRState15enterStackFrameEPKNS_17StackFrameContextE", "clang::ento::GRState::enterStackFrame(clang::StackFrameContext const*) const"},
    {"_ZNK5clang4ento7GRState20getSValAsScalarOrLocEPKNS0_9MemRegionE", "clang::ento::GRState::getSValAsScalarOrLoc(clang::ento::MemRegion const*) const"},
    {"_ZNK5clang4ento7GRState7getSValENS0_3LocENS_8QualTypeE", "clang::ento::GRState::getSVal(clang::ento::Loc, clang::QualType) const"},
    {"_ZNK5clang4ento7GRState8BindExprEPKNS_4StmtENS0_4SValEb", "clang::ento::GRState::BindExpr(clang::Stmt const*, clang::ento::SVal, bool) const"},
    {"_ZNK5clang4ento7GRState19bindExprAndLocationEPKNS_4StmtENS0_4SValES5_", "clang::ento::GRState::bindExprAndLocation(clang::Stmt const*, clang::ento::SVal, clang::ento::SVal) const"},
    {"_ZNK5clang4ento7GRState13assumeInBoundENS0_20DefinedOrUnknownSValES2_b", "clang::ento::GRState::assumeInBound(clang::ento::DefinedOrUnknownSVal, clang::ento::DefinedOrUnknownSVal, bool) const"},
    {"_ZN5clang4ento14GRStateManager15getInitialStateEPKNS_15LocationContextE", "clang::ento::GRStateManager::getInitialState(clang::LocationContext const*)"},
    {"_ZN5clang4ento14GRStateManager19recycleUnusedStatesEv", "clang::ento::GRStateManager::recycleUnusedStates()"},
    {"_ZNK5clang4ento7GRState5printERN4llvm11raw_ostreamERNS_3CFGEPKcS8_", "clang::ento::GRState::print(llvm::raw_ostream&, clang::CFG&, char const*, char const*) const"},
    {"_ZNK5clang4ento7GRState8printDOTERN4llvm11raw_ostreamERNS_3CFGE", "clang::ento::GRState::printDOT(llvm::raw_ostream&, clang::CFG&) const"},
    {"_ZNK5clang4ento7GRState11printStdErrERNS_3CFGE", "clang::ento::GRState::printStdErr(clang::CFG&) const"},
    {"_ZNK5clang4ento7GRState7FindGDMEPv", "clang::ento::GRState::FindGDM(void*) const"},
    {"_ZN5clang4ento14GRStateManager14FindGDMContextEPvPFS2_RN4llvm16BumpPtrAllocatorEEPFvS2_E", "clang::ento::GRStateManager::FindGDMContext(void*, void* (*)(llvm::BumpPtrAllocator&), void (*)(void*))"},
    {"_ZN5clang4ento14GRStateManager6addGDMEPKNS0_7GRStateEPvS5_", "clang::ento::GRStateManager::addGDM(clang::ento::GRState const*, void*, void*)"},
    {"_ZN5clang4ento14GRStateManager9removeGDMEPKNS0_7GRStateEPv", "clang::ento::GRStateManager::removeGDM(clang::ento::GRState const*, void*)"},
    {"_ZNK5clang4ento7GRState20scanReachableSymbolsENS0_4SValERNS0_13SymbolVisitorE", "clang::ento::GRState::scanReachableSymbols(clang::ento::SVal, clang::ento::SymbolVisitor&) const"},
    {"_ZN12_GLOBAL__N_120ScanReachableSymbols4scanEN5clang4ento4SValE", "(anonymous namespace)::ScanReachableSymbols::scan(clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_120ScanReachableSymbolsD1Ev", "(anonymous namespace)::ScanReachableSymbols::~ScanReachableSymbols()"},
    {"_ZNK5clang4ento7GRState20scanReachableSymbolsEPKNS0_4SValES4_RNS0_13SymbolVisitorE", "clang::ento::GRState::scanReachableSymbols(clang::ento::SVal const*, clang::ento::SVal const*, clang::ento::SymbolVisitor&) const"},
    {"_ZNK5clang4ento7GRState20scanReachableSymbolsEPKPKNS0_9MemRegionES6_RNS0_13SymbolVisitorE", "clang::ento::GRState::scanReachableSymbols(clang::ento::MemRegion const* const*, clang::ento::MemRegion const* const*, clang::ento::SymbolVisitor&) const"},
    {"_ZN12_GLOBAL__N_120ScanReachableSymbols4scanEPKN5clang4ento9MemRegionE", "(anonymous namespace)::ScanReachableSymbols::scan(clang::ento::MemRegion const*)"},
    {"_ZN12_GLOBAL__N_120ScanReachableSymbolsD0Ev", "(anonymous namespace)::ScanReachableSymbols::~ScanReachableSymbols()"},
    {"_ZN12_GLOBAL__N_120ScanReachableSymbols5VisitEPKN5clang4ento9MemRegionES5_", "(anonymous namespace)::ScanReachableSymbols::Visit(clang::ento::MemRegion const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento17BasicValueFactory7ConvertENS_8QualTypeERKN4llvm6APSIntE", "clang::ento::BasicValueFactory::Convert(clang::QualType, llvm::APSInt const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEE6removeEPNS_11ImutAVLTreeIS3_EERKS2_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::remove(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*, void* const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEE16getCanonicalTreeEPNS_11ImutAVLTreeIS3_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPvS2_EEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>::computeDigest()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEE22compareTreeWithSectionEPNS_11ImutAVLTreeIS3_EERNS_26ImutAVLTreeInOrderIteratorIS3_EESA_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<void*, void*>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<void*, void*>>&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPvS2_EEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>::destroy()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPvS3_EEEESaIS6_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS6_S8_EERKS6_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>**, std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*>>>, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>* const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPvS3_EEEENS_12DenseMapInfoIjEENS7_IS6_EEE16InsertIntoBucketERKjRKS6_PSt4pairIjS6_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPvS3_EEEENS_12DenseMapInfoIjEENS7_IS6_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*>>::grow(unsigned int)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEE15remove_internalERKS2_PNS_11ImutAVLTreeIS3_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::remove_internal(void* const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEE13markImmutableEPNS_11ImutAVLTreeIS3_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEE11balanceTreeEPNS_11ImutAVLTreeIS3_EERKSt4pairIS2_S2_ES7_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*, std::pair<void*, void*> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEE10createNodeEPNS_11ImutAVLTreeIS3_EERKSt4pairIS2_S2_ES7_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*, std::pair<void*, void*> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEE16removeMinBindingEPNS_11ImutAVLTreeIS3_EERS7_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::removeMinBinding(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEE3addEPNS_11ImutAVLTreeIS3_EERKSt4pairIS2_S2_E", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::add(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*, std::pair<void*, void*> const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEE12add_internalERKSt4pairIS2_S2_EPNS_11ImutAVLTreeIS3_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::add_internal(std::pair<void*, void*> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<void*, void*>>*)"},
    {"_ZN4llvm8DenseMapIPvSt4pairIS1_PFvS1_EENS_12DenseMapInfoIS1_EENS6_IS5_EEE16InsertIntoBucketERKS1_RKS5_PS2_IS1_S5_E", "llvm::DenseMap<void*, std::pair<void*, void (*)(void*)>, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<std::pair<void*, void (*)(void*)>>>::InsertIntoBucket(void* const&, std::pair<void*, void (*)(void*)> const&, std::pair<void*, std::pair<void*, void (*)(void*)>>*)"},
    {"_ZN4llvm8DenseMapIPvSt4pairIS1_PFvS1_EENS_12DenseMapInfoIS1_EENS6_IS5_EEE4growEj", "llvm::DenseMap<void*, std::pair<void*, void (*)(void*)>, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<std::pair<void*, void (*)(void*)>>>::grow(unsigned int)"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::operator++()"},
    {"_ZNSt6vectorIPN5clang4ento7GRStateESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<clang::ento::GRState*, std::allocator<clang::ento::GRState*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::ento::GRState**, std::vector<clang::ento::GRState*, std::allocator<clang::ento::GRState*>>>, clang::ento::GRState* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento9MemRegionEcNS_12DenseMapInfoIS5_EENS6_IcEEE6insertERKSt4pairIS5_cE", "llvm::DenseMap<clang::ento::MemRegion const*, char, llvm::DenseMapInfo<clang::ento::MemRegion const*>, llvm::DenseMapInfo<char>>::insert(std::pair<clang::ento::MemRegion const*, char> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento9MemRegionEcNS_12DenseMapInfoIS5_EENS6_IcEEE16InsertIntoBucketERKS5_RKcPSt4pairIS5_cE", "llvm::DenseMap<clang::ento::MemRegion const*, char, llvm::DenseMapInfo<clang::ento::MemRegion const*>, llvm::DenseMapInfo<char>>::InsertIntoBucket(clang::ento::MemRegion const* const&, char const&, std::pair<clang::ento::MemRegion const*, char>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento9MemRegionEcNS_12DenseMapInfoIS5_EENS6_IcEEE4growEj", "llvm::DenseMap<clang::ento::MemRegion const*, char, llvm::DenseMapInfo<clang::ento::MemRegion const*>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZN5clang4ento12SubRegionMap7VisitorD1Ev", "clang::ento::SubRegionMap::Visitor::~Visitor()"},
    {"_ZN5clang4ento12SubRegionMap7VisitorD0Ev", "clang::ento::SubRegionMap::Visitor::~Visitor()"},
    {"_ZNK4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE7isEqualERKS9_", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::isEqual(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>> const&) const"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::destroy()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4StmtENS3_4ento4SValEEEEESaISB_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSB_SD_EERKSB_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>**, std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*>>>, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>* const&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEE13computeDigestEPS9_SA_RKSt4pairIS5_S7_E", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::computeDigest(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, std::pair<clang::Stmt const*, clang::ento::SVal> const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4StmtENS3_4ento4SValEEEEENS_12DenseMapInfoIjEENSC_ISB_EEE16InsertIntoBucketERKjRKSB_PSt4pairIjSB_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4StmtENS3_4ento4SValEEEEENS_12DenseMapInfoIjEENSC_ISB_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>*>>::grow(unsigned int)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4StmtENS2_4ento4SValEEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::Stmt const*, clang::ento::SVal>>::~ImutAVLFactory()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPvS2_EEED2Ev", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<void*, void*>>::~ImutAVLFactory()"},
    {"_ZN5clang4ento26createHTMLDiagnosticClientERKSsRKNS_12PreprocessorE", "clang::ento::createHTMLDiagnosticClient(std::string const&, clang::Preprocessor const&)"},
    {"_ZN12_GLOBAL__N_115HTMLDiagnosticsD1Ev", "(anonymous namespace)::HTMLDiagnostics::~HTMLDiagnostics()"},
    {"_ZN12_GLOBAL__N_115HTMLDiagnosticsD0Ev", "(anonymous namespace)::HTMLDiagnostics::~HTMLDiagnostics()"},
    {"_ZN12_GLOBAL__N_115HTMLDiagnostics16FlushDiagnosticsEPN4llvm15SmallVectorImplISsEE", "(anonymous namespace)::HTMLDiagnostics::FlushDiagnostics(llvm::SmallVectorImpl<std::string>*)"},
    {"_ZNK12_GLOBAL__N_115HTMLDiagnostics7getNameEv", "(anonymous namespace)::HTMLDiagnostics::getName() const"},
    {"_ZN12_GLOBAL__N_115HTMLDiagnostics20HandlePathDiagnosticEPKN5clang4ento14PathDiagnosticE", "(anonymous namespace)::HTMLDiagnostics::HandlePathDiagnostic(clang::ento::PathDiagnostic const*)"},
    {"_ZN12_GLOBAL__N_115HTMLDiagnostics10ReportDiagERKN5clang4ento14PathDiagnosticEPN4llvm15SmallVectorImplISsEE", "(anonymous namespace)::HTMLDiagnostics::ReportDiag(clang::ento::PathDiagnostic const&, llvm::SmallVectorImpl<std::string>*)"},
    {"_ZN12_GLOBAL__N_115HTMLDiagnostics17ProcessMacroPieceERN4llvm11raw_ostreamERKN5clang4ento24PathDiagnosticMacroPieceEj", "(anonymous namespace)::HTMLDiagnostics::ProcessMacroPiece(llvm::raw_ostream&, clang::ento::PathDiagnosticMacroPiece const&, unsigned int)"},
    {"_Z16EmitAlphaCounterRN4llvm11raw_ostreamEj", "EmitAlphaCounter(llvm::raw_ostream&, unsigned int)"},
    {"_ZN5clang4ento9MemRegionD0Ev", "clang::ento::MemRegion::~MemRegion()"},
    {"_ZN5clang4ento9MemRegionD1Ev", "clang::ento::MemRegion::~MemRegion()"},
    {"_ZN5clang4ento9MemRegionD2Ev", "clang::ento::MemRegion::~MemRegion()"},
    {"_ZN5clang4ento16MemRegionManagerD1Ev", "clang::ento::MemRegionManager::~MemRegionManager()"},
    {"_ZN5clang4ento16MemRegionManagerD2Ev", "clang::ento::MemRegionManager::~MemRegionManager()"},
    {"_ZNK5clang4ento9SubRegion13isSubRegionOfEPKNS0_9MemRegionE", "clang::ento::SubRegion::isSubRegionOf(clang::ento::MemRegion const*) const"},
    {"_ZNK5clang4ento9SubRegion19getMemRegionManagerEv", "clang::ento::SubRegion::getMemRegionManager() const"},
    {"_ZNK5clang4ento9VarRegion13getStackFrameEv", "clang::ento::VarRegion::getStackFrame() const"},
    {"_ZNK5clang4ento9MemRegion14getMemorySpaceEv", "clang::ento::MemRegion::getMemorySpace() const"},
    {"_ZNK5clang4ento10DeclRegion9getExtentERNS0_11SValBuilderE", "clang::ento::DeclRegion::getExtent(clang::ento::SValBuilder&) const"},
    {"_ZNK5clang4ento11FieldRegion9getExtentERNS0_11SValBuilderE", "clang::ento::FieldRegion::getExtent(clang::ento::SValBuilder&) const"},
    {"_ZNK5clang4ento12AllocaRegion9getExtentERNS0_11SValBuilderE", "clang::ento::AllocaRegion::getExtent(clang::ento::SValBuilder&) const"},
    {"_ZNK5clang4ento14SymbolicRegion9getExtentERNS0_11SValBuilderE", "clang::ento::SymbolicRegion::getExtent(clang::ento::SValBuilder&) const"},
    {"_ZNK5clang4ento12StringRegion9getExtentERNS0_11SValBuilderE", "clang::ento::StringRegion::getExtent(clang::ento::SValBuilder&) const"},
    {"_ZNK5clang4ento19CXXBaseObjectRegion12getValueTypeEv", "clang::ento::CXXBaseObjectRegion::getValueType() const"},
    {"_ZNK5clang4ento14MemSpaceRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::MemSpaceRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento16StackSpaceRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::StackSpaceRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento23StaticGlobalSpaceRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::StaticGlobalSpaceRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento12StringRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS_13StringLiteralEPKNS0_9MemRegionE", "clang::ento::StringRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::StringLiteral const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento12AllocaRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS_4ExprEjPKNS0_9MemRegionE", "clang::ento::AllocaRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::Expr const*, unsigned int, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento12AllocaRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::AllocaRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento21CompoundLiteralRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::CompoundLiteralRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento21CompoundLiteralRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS_19CompoundLiteralExprEPKNS0_9MemRegionE", "clang::ento::CompoundLiteralRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::CompoundLiteralExpr const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento13CXXThisRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS_11PointerTypeEPKNS0_9MemRegionE", "clang::ento::CXXThisRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::PointerType const*, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento13CXXThisRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::CXXThisRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento10DeclRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS_4DeclEPKNS0_9MemRegionENS8_4KindE", "clang::ento::DeclRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::Decl const*, clang::ento::MemRegion const*, clang::ento::MemRegion::Kind)"},
    {"_ZNK5clang4ento10DeclRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::DeclRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento9VarRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::VarRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento14SymbolicRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS0_10SymbolDataEPKNS0_9MemRegionE", "clang::ento::SymbolicRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::ento::SymbolData const*, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento14SymbolicRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::SymbolicRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento13ElementRegion13ProfileRegionERN4llvm16FoldingSetNodeIDENS_8QualTypeENS0_4SValEPKNS0_9MemRegionE", "clang::ento::ElementRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::QualType, clang::ento::SVal, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento13ElementRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::ElementRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento18FunctionTextRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS_12FunctionDeclEPKNS0_9MemRegionE", "clang::ento::FunctionTextRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::FunctionDecl const*, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento18FunctionTextRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::FunctionTextRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento15BlockTextRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS_9BlockDeclENS_7CanQualINS_4TypeEEEPKNS_15AnalysisContextEPKNS0_9MemRegionE", "clang::ento::BlockTextRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::BlockDecl const*, clang::CanQual<clang::Type>, clang::AnalysisContext const*, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento15BlockTextRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::BlockTextRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento15BlockDataRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS0_15BlockTextRegionEPKNS_15LocationContextEPKNS0_9MemRegionE", "clang::ento::BlockDataRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::ento::BlockTextRegion const*, clang::LocationContext const*, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento15BlockDataRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::BlockDataRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento19CXXTempObjectRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS_4ExprEPKNS0_9MemRegionE", "clang::ento::CXXTempObjectRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::Expr const*, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento19CXXTempObjectRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::CXXTempObjectRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento19CXXBaseObjectRegion13ProfileRegionERN4llvm16FoldingSetNodeIDEPKNS_13CXXRecordDeclEPKNS0_9MemRegionE", "clang::ento::CXXBaseObjectRegion::ProfileRegion(llvm::FoldingSetNodeID&, clang::CXXRecordDecl const*, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento19CXXBaseObjectRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::CXXBaseObjectRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento9MemRegion4dumpEv", "clang::ento::MemRegion::dump() const"},
    {"_ZNK5clang4ento9MemRegion9getStringEv", "clang::ento::MemRegion::getString() const"},
    {"_ZNK5clang4ento9MemRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::MemRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento12AllocaRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::AllocaRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento18FunctionTextRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::FunctionTextRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento15BlockTextRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::BlockTextRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento15BlockDataRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::BlockDataRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento21CompoundLiteralRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::CompoundLiteralRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento19CXXTempObjectRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::CXXTempObjectRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento19CXXBaseObjectRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::CXXBaseObjectRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento13CXXThisRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::CXXThisRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento13ElementRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::ElementRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento11FieldRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::FieldRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento26NonStaticGlobalSpaceRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::NonStaticGlobalSpaceRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento14ObjCIvarRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::ObjCIvarRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento12StringRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::StringRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento14SymbolicRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::SymbolicRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento9VarRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::VarRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento15RegionRawOffset4dumpEv", "clang::ento::RegionRawOffset::dump() const"},
    {"_ZNK5clang4ento15RegionRawOffset12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::RegionRawOffset::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento23StaticGlobalSpaceRegion12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::StaticGlobalSpaceRegion::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZN5clang4ento16MemRegionManager20getStackLocalsRegionEPKNS_17StackFrameContextE", "clang::ento::MemRegionManager::getStackLocalsRegion(clang::StackFrameContext const*)"},
    {"_ZN5clang4ento16MemRegionManager23getStackArgumentsRegionEPKNS_17StackFrameContextE", "clang::ento::MemRegionManager::getStackArgumentsRegion(clang::StackFrameContext const*)"},
    {"_ZN5clang4ento16MemRegionManager16getGlobalsRegionEPKNS0_14CodeTextRegionE", "clang::ento::MemRegionManager::getGlobalsRegion(clang::ento::CodeTextRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager13getHeapRegionEv", "clang::ento::MemRegionManager::getHeapRegion()"},
    {"_ZN5clang4ento16MemRegionManager16getUnknownRegionEv", "clang::ento::MemRegionManager::getUnknownRegion()"},
    {"_ZN5clang4ento16MemRegionManager13getCodeRegionEv", "clang::ento::MemRegionManager::getCodeRegion()"},
    {"_ZN5clang4ento16MemRegionManager15getStringRegionEPKNS_13StringLiteralE", "clang::ento::MemRegionManager::getStringRegion(clang::StringLiteral const*)"},
    {"_ZN5clang4ento16MemRegionManager12getVarRegionEPKNS_7VarDeclEPKNS_15LocationContextE", "clang::ento::MemRegionManager::getVarRegion(clang::VarDecl const*, clang::LocationContext const*)"},
    {"_ZN5clang4ento16MemRegionManager21getFunctionTextRegionEPKNS_12FunctionDeclE", "clang::ento::MemRegionManager::getFunctionTextRegion(clang::FunctionDecl const*)"},
    {"_ZN5clang4ento16MemRegionManager18getBlockTextRegionEPKNS_9BlockDeclENS_7CanQualINS_4TypeEEEPNS_15AnalysisContextE", "clang::ento::MemRegionManager::getBlockTextRegion(clang::BlockDecl const*, clang::CanQual<clang::Type>, clang::AnalysisContext*)"},
    {"_ZN5clang4ento16MemRegionManager12getVarRegionEPKNS_7VarDeclEPKNS0_9MemRegionE", "clang::ento::MemRegionManager::getVarRegion(clang::VarDecl const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager18getBlockDataRegionEPKNS0_15BlockTextRegionEPKNS_15LocationContextE", "clang::ento::MemRegionManager::getBlockDataRegion(clang::ento::BlockTextRegion const*, clang::LocationContext const*)"},
    {"_ZN5clang4ento16MemRegionManager24getCompoundLiteralRegionEPKNS_19CompoundLiteralExprEPKNS_15LocationContextE", "clang::ento::MemRegionManager::getCompoundLiteralRegion(clang::CompoundLiteralExpr const*, clang::LocationContext const*)"},
    {"_ZN5clang4ento16MemRegionManager16getElementRegionENS_8QualTypeENS0_6NonLocEPKNS0_9MemRegionERNS_10ASTContextE", "clang::ento::MemRegionManager::getElementRegion(clang::QualType, clang::ento::NonLoc, clang::ento::MemRegion const*, clang::ASTContext&)"},
    {"_ZN5clang4ento16MemRegionManager17getSymbolicRegionEPKNS0_10SymbolDataE", "clang::ento::MemRegionManager::getSymbolicRegion(clang::ento::SymbolData const*)"},
    {"_ZN5clang4ento16MemRegionManager14getFieldRegionEPKNS_9FieldDeclEPKNS0_9MemRegionE", "clang::ento::MemRegionManager::getFieldRegion(clang::FieldDecl const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager17getObjCIvarRegionEPKNS_12ObjCIvarDeclEPKNS0_9MemRegionE", "clang::ento::MemRegionManager::getObjCIvarRegion(clang::ObjCIvarDecl const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager22getCXXTempObjectRegionEPKNS_4ExprEPKNS_15LocationContextE", "clang::ento::MemRegionManager::getCXXTempObjectRegion(clang::Expr const*, clang::LocationContext const*)"},
    {"_ZN5clang4ento16MemRegionManager22getCXXBaseObjectRegionEPKNS_13CXXRecordDeclEPKNS0_9MemRegionE", "clang::ento::MemRegionManager::getCXXBaseObjectRegion(clang::CXXRecordDecl const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager16getCXXThisRegionENS_8QualTypeEPKNS_15LocationContextE", "clang::ento::MemRegionManager::getCXXThisRegion(clang::QualType, clang::LocationContext const*)"},
    {"_ZN5clang4ento16MemRegionManager15getAllocaRegionEPKNS_4ExprEjPKNS_15LocationContextE", "clang::ento::MemRegionManager::getAllocaRegion(clang::Expr const*, unsigned int, clang::LocationContext const*)"},
    {"_ZNK5clang4ento9MemRegion15hasStackStorageEv", "clang::ento::MemRegion::hasStackStorage() const"},
    {"_ZNK5clang4ento9MemRegion28hasStackNonParametersStorageEv", "clang::ento::MemRegion::hasStackNonParametersStorage() const"},
    {"_ZNK5clang4ento9MemRegion25hasStackParametersStorageEv", "clang::ento::MemRegion::hasStackParametersStorage() const"},
    {"_ZNK5clang4ento9MemRegion29hasGlobalsOrParametersStorageEv", "clang::ento::MemRegion::hasGlobalsOrParametersStorage() const"},
    {"_ZNK5clang4ento9MemRegion13getBaseRegionEv", "clang::ento::MemRegion::getBaseRegion() const"},
    {"_ZNK5clang4ento9MemRegion10StripCastsEv", "clang::ento::MemRegion::StripCasts() const"},
    {"_ZNK5clang4ento13ElementRegion16getAsArrayOffsetEv", "clang::ento::ElementRegion::getAsArrayOffset() const"},
    {"_ZNK5clang4ento9MemRegion11getAsOffsetEv", "clang::ento::MemRegion::getAsOffset() const"},
    {"_ZN5clang4ento15BlockDataRegion28LazyInitializeReferencedVarsEv", "clang::ento::BlockDataRegion::LazyInitializeReferencedVars()"},
    {"_ZNK5clang4ento15BlockDataRegion21referenced_vars_beginEv", "clang::ento::BlockDataRegion::referenced_vars_begin() const"},
    {"_ZNK5clang4ento15BlockDataRegion19referenced_vars_endEv", "clang::ento::BlockDataRegion::referenced_vars_end() const"},
    {"_ZN4llvm10FoldingSetIN5clang4ento9MemRegionEED1Ev", "llvm::FoldingSet<clang::ento::MemRegion>::~FoldingSet()"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_12StringRegionEPKNS_13StringLiteralEEEPT_T0_PKNS0_9MemRegionE", "clang::ento::StringRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::StringRegion, clang::StringLiteral const*>(clang::StringLiteral const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_9VarRegionEPKNS_7VarDeclEEEPT_T0_PKNS0_9MemRegionE", "clang::ento::VarRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::VarRegion, clang::VarDecl const*>(clang::VarDecl const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_15BlockDataRegionEPKNS0_15BlockTextRegionEPKNS_15LocationContextEEEPT_T0_T1_PKNS0_9MemRegionE", "clang::ento::BlockDataRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::BlockDataRegion, clang::ento::BlockTextRegion const*, clang::LocationContext const*>(clang::ento::BlockTextRegion const*, clang::LocationContext const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_21CompoundLiteralRegionEPKNS_19CompoundLiteralExprEEEPT_T0_PKNS0_9MemRegionE", "clang::ento::CompoundLiteralRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::CompoundLiteralRegion, clang::CompoundLiteralExpr const*>(clang::CompoundLiteralExpr const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_18FunctionTextRegionEPKNS_12FunctionDeclEEEPT_T0_PKNS0_9MemRegionE", "clang::ento::FunctionTextRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::FunctionTextRegion, clang::FunctionDecl const*>(clang::FunctionDecl const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_15BlockTextRegionEPKNS_9BlockDeclENS_7CanQualINS_4TypeEEEPNS_15AnalysisContextEEEPT_T0_T1_T2_PKNS0_9MemRegionE", "clang::ento::BlockTextRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::BlockTextRegion, clang::BlockDecl const*, clang::CanQual<clang::Type>, clang::AnalysisContext*>(clang::BlockDecl const*, clang::CanQual<clang::Type>, clang::AnalysisContext*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_14SymbolicRegionEPKNS0_10SymbolDataEEEPT_T0_PKNS0_9MemRegionE", "clang::ento::SymbolicRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::SymbolicRegion, clang::ento::SymbolData const*>(clang::ento::SymbolData const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_11FieldRegionEPKNS_9FieldDeclEEEPT_T0_PKNS0_9MemRegionE", "clang::ento::FieldRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::FieldRegion, clang::FieldDecl const*>(clang::FieldDecl const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_14ObjCIvarRegionEPKNS_12ObjCIvarDeclEEEPT_T0_PKNS0_9MemRegionE", "clang::ento::ObjCIvarRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::ObjCIvarRegion, clang::ObjCIvarDecl const*>(clang::ObjCIvarDecl const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_19CXXTempObjectRegionEPKNS_4ExprEEEPT_T0_PKNS0_9MemRegionE", "clang::ento::CXXTempObjectRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::CXXTempObjectRegion, clang::Expr const*>(clang::Expr const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_19CXXBaseObjectRegionEPKNS_13CXXRecordDeclEEEPT_T0_PKNS0_9MemRegionE", "clang::ento::CXXBaseObjectRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::CXXBaseObjectRegion, clang::CXXRecordDecl const*>(clang::CXXRecordDecl const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_13CXXThisRegionEPKNS_11PointerTypeEEEPT_T0_PKNS0_9MemRegionE", "clang::ento::CXXThisRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::CXXThisRegion, clang::PointerType const*>(clang::PointerType const*, clang::ento::MemRegion const*)"},
    {"_ZN5clang4ento16MemRegionManager12getSubRegionINS0_12AllocaRegionEPKNS_4ExprEjEEPT_T0_T1_PKNS0_9MemRegionE", "clang::ento::AllocaRegion* clang::ento::MemRegionManager::getSubRegion<clang::ento::AllocaRegion, clang::Expr const*, unsigned int>(clang::Expr const*, unsigned int, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento9MemRegion11isBoundableEv", "clang::ento::MemRegion::isBoundable() const"},
    {"_ZN5clang4ento14MemSpaceRegionD1Ev", "clang::ento::MemSpaceRegion::~MemSpaceRegion()"},
    {"_ZN5clang4ento14MemSpaceRegionD0Ev", "clang::ento::MemSpaceRegion::~MemSpaceRegion()"},
    {"_ZNK5clang4ento14MemSpaceRegion19getMemRegionManagerEv", "clang::ento::MemSpaceRegion::getMemRegionManager() const"},
    {"_ZNK5clang4ento14MemSpaceRegion11isBoundableEv", "clang::ento::MemSpaceRegion::isBoundable() const"},
    {"_ZN5clang4ento23StaticGlobalSpaceRegionD1Ev", "clang::ento::StaticGlobalSpaceRegion::~StaticGlobalSpaceRegion()"},
    {"_ZN5clang4ento23StaticGlobalSpaceRegionD0Ev", "clang::ento::StaticGlobalSpaceRegion::~StaticGlobalSpaceRegion()"},
    {"_ZN5clang4ento26NonStaticGlobalSpaceRegionD1Ev", "clang::ento::NonStaticGlobalSpaceRegion::~NonStaticGlobalSpaceRegion()"},
    {"_ZN5clang4ento26NonStaticGlobalSpaceRegionD0Ev", "clang::ento::NonStaticGlobalSpaceRegion::~NonStaticGlobalSpaceRegion()"},
    {"_ZN5clang4ento16StackSpaceRegionD1Ev", "clang::ento::StackSpaceRegion::~StackSpaceRegion()"},
    {"_ZN5clang4ento16StackSpaceRegionD0Ev", "clang::ento::StackSpaceRegion::~StackSpaceRegion()"},
    {"_ZN5clang4ento9SubRegionD1Ev", "clang::ento::SubRegion::~SubRegion()"},
    {"_ZN5clang4ento9SubRegionD0Ev", "clang::ento::SubRegion::~SubRegion()"},
    {"_ZNK5clang4ento9SubRegion9getExtentERNS0_11SValBuilderE", "clang::ento::SubRegion::getExtent(clang::ento::SValBuilder&) const"},
    {"_ZN5clang4ento12AllocaRegionD1Ev", "clang::ento::AllocaRegion::~AllocaRegion()"},
    {"_ZN5clang4ento12AllocaRegionD0Ev", "clang::ento::AllocaRegion::~AllocaRegion()"},
    {"_ZNK5clang4ento12AllocaRegion11isBoundableEv", "clang::ento::AllocaRegion::isBoundable() const"},
    {"_ZN5clang4ento18FunctionTextRegionD1Ev", "clang::ento::FunctionTextRegion::~FunctionTextRegion()"},
    {"_ZN5clang4ento18FunctionTextRegionD0Ev", "clang::ento::FunctionTextRegion::~FunctionTextRegion()"},
    {"_ZNK5clang4ento14CodeTextRegion11isBoundableEv", "clang::ento::CodeTextRegion::isBoundable() const"},
    {"_ZNK5clang4ento14CodeTextRegion12getValueTypeEv", "clang::ento::CodeTextRegion::getValueType() const"},
    {"_ZNK5clang4ento18FunctionTextRegion15getLocationTypeEv", "clang::ento::FunctionTextRegion::getLocationType() const"},
    {"_ZN5clang4ento15BlockTextRegionD1Ev", "clang::ento::BlockTextRegion::~BlockTextRegion()"},
    {"_ZN5clang4ento15BlockTextRegionD0Ev", "clang::ento::BlockTextRegion::~BlockTextRegion()"},
    {"_ZNK5clang4ento15BlockTextRegion15getLocationTypeEv", "clang::ento::BlockTextRegion::getLocationType() const"},
    {"_ZN5clang4ento15BlockDataRegionD1Ev", "clang::ento::BlockDataRegion::~BlockDataRegion()"},
    {"_ZN5clang4ento15BlockDataRegionD0Ev", "clang::ento::BlockDataRegion::~BlockDataRegion()"},
    {"_ZN5clang4ento14SymbolicRegionD1Ev", "clang::ento::SymbolicRegion::~SymbolicRegion()"},
    {"_ZN5clang4ento14SymbolicRegionD0Ev", "clang::ento::SymbolicRegion::~SymbolicRegion()"},
    {"_ZNK5clang4ento14SymbolicRegion11isBoundableEv", "clang::ento::SymbolicRegion::isBoundable() const"},
    {"_ZN5clang4ento12StringRegionD1Ev", "clang::ento::StringRegion::~StringRegion()"},
    {"_ZN5clang4ento12StringRegionD0Ev", "clang::ento::StringRegion::~StringRegion()"},
    {"_ZNK5clang4ento12StringRegion7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::StringRegion::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento12StringRegion11isBoundableEv", "clang::ento::StringRegion::isBoundable() const"},
    {"_ZNK5clang4ento12StringRegion12getValueTypeEv", "clang::ento::StringRegion::getValueType() const"},
    {"_ZNK5clang4ento11TypedRegion15getLocationTypeEv", "clang::ento::TypedRegion::getLocationType() const"},
    {"_ZN5clang4ento21CompoundLiteralRegionD1Ev", "clang::ento::CompoundLiteralRegion::~CompoundLiteralRegion()"},
    {"_ZN5clang4ento21CompoundLiteralRegionD0Ev", "clang::ento::CompoundLiteralRegion::~CompoundLiteralRegion()"},
    {"_ZNK5clang4ento21CompoundLiteralRegion11isBoundableEv", "clang::ento::CompoundLiteralRegion::isBoundable() const"},
    {"_ZNK5clang4ento21CompoundLiteralRegion12getValueTypeEv", "clang::ento::CompoundLiteralRegion::getValueType() const"},
    {"_ZN5clang4ento10DeclRegionD1Ev", "clang::ento::DeclRegion::~DeclRegion()"},
    {"_ZN5clang4ento10DeclRegionD0Ev", "clang::ento::DeclRegion::~DeclRegion()"},
    {"_ZNK5clang4ento11TypedRegion11isBoundableEv", "clang::ento::TypedRegion::isBoundable() const"},
    {"_ZN5clang4ento9VarRegionD1Ev", "clang::ento::VarRegion::~VarRegion()"},
    {"_ZN5clang4ento9VarRegionD0Ev", "clang::ento::VarRegion::~VarRegion()"},
    {"_ZNK5clang4ento9VarRegion12getValueTypeEv", "clang::ento::VarRegion::getValueType() const"},
    {"_ZN5clang4ento13CXXThisRegionD1Ev", "clang::ento::CXXThisRegion::~CXXThisRegion()"},
    {"_ZN5clang4ento13CXXThisRegionD0Ev", "clang::ento::CXXThisRegion::~CXXThisRegion()"},
    {"_ZNK5clang4ento13CXXThisRegion12getValueTypeEv", "clang::ento::CXXThisRegion::getValueType() const"},
    {"_ZN5clang4ento11FieldRegionD1Ev", "clang::ento::FieldRegion::~FieldRegion()"},
    {"_ZN5clang4ento11FieldRegionD0Ev", "clang::ento::FieldRegion::~FieldRegion()"},
    {"_ZNK5clang4ento11FieldRegion12getValueTypeEv", "clang::ento::FieldRegion::getValueType() const"},
    {"_ZN5clang4ento14ObjCIvarRegionD1Ev", "clang::ento::ObjCIvarRegion::~ObjCIvarRegion()"},
    {"_ZN5clang4ento14ObjCIvarRegionD0Ev", "clang::ento::ObjCIvarRegion::~ObjCIvarRegion()"},
    {"_ZNK5clang4ento14ObjCIvarRegion12getValueTypeEv", "clang::ento::ObjCIvarRegion::getValueType() const"},
    {"_ZN5clang4ento13ElementRegionD1Ev", "clang::ento::ElementRegion::~ElementRegion()"},
    {"_ZN5clang4ento13ElementRegionD0Ev", "clang::ento::ElementRegion::~ElementRegion()"},
    {"_ZNK5clang4ento13ElementRegion12getValueTypeEv", "clang::ento::ElementRegion::getValueType() const"},
    {"_ZN5clang4ento19CXXTempObjectRegionD1Ev", "clang::ento::CXXTempObjectRegion::~CXXTempObjectRegion()"},
    {"_ZN5clang4ento19CXXTempObjectRegionD0Ev", "clang::ento::CXXTempObjectRegion::~CXXTempObjectRegion()"},
    {"_ZNK5clang4ento19CXXTempObjectRegion12getValueTypeEv", "clang::ento::CXXTempObjectRegion::getValueType() const"},
    {"_ZN5clang4ento19CXXBaseObjectRegionD1Ev", "clang::ento::CXXBaseObjectRegion::~CXXBaseObjectRegion()"},
    {"_ZN5clang4ento19CXXBaseObjectRegionD0Ev", "clang::ento::CXXBaseObjectRegion::~CXXBaseObjectRegion()"},
    {"_ZN5clang4ento11TypedRegionD1Ev", "clang::ento::TypedRegion::~TypedRegion()"},
    {"_ZN5clang4ento11TypedRegionD0Ev", "clang::ento::TypedRegion::~TypedRegion()"},
    {"_ZN5clang4ento14CodeTextRegionD1Ev", "clang::ento::CodeTextRegion::~CodeTextRegion()"},
    {"_ZN5clang4ento14CodeTextRegionD0Ev", "clang::ento::CodeTextRegion::~CodeTextRegion()"},
    {"_ZN5clang4ento18UnknownSpaceRegionD1Ev", "clang::ento::UnknownSpaceRegion::~UnknownSpaceRegion()"},
    {"_ZN5clang4ento18UnknownSpaceRegionD0Ev", "clang::ento::UnknownSpaceRegion::~UnknownSpaceRegion()"},
    {"_ZN5clang4ento15HeapSpaceRegionD1Ev", "clang::ento::HeapSpaceRegion::~HeapSpaceRegion()"},
    {"_ZN5clang4ento15HeapSpaceRegionD0Ev", "clang::ento::HeapSpaceRegion::~HeapSpaceRegion()"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento14CodeTextRegionEPNS2_23StaticGlobalSpaceRegionENS_12DenseMapInfoIS5_EENS8_IS7_EEE16InsertIntoBucketERKS5_RKS7_PSt4pairIS5_S7_E", "llvm::DenseMap<clang::ento::CodeTextRegion const*, clang::ento::StaticGlobalSpaceRegion*, llvm::DenseMapInfo<clang::ento::CodeTextRegion const*>, llvm::DenseMapInfo<clang::ento::StaticGlobalSpaceRegion*>>::InsertIntoBucket(clang::ento::CodeTextRegion const* const&, clang::ento::StaticGlobalSpaceRegion* const&, std::pair<clang::ento::CodeTextRegion const*, clang::ento::StaticGlobalSpaceRegion*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento14CodeTextRegionEPNS2_23StaticGlobalSpaceRegionENS_12DenseMapInfoIS5_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::ento::CodeTextRegion const*, clang::ento::StaticGlobalSpaceRegion*, llvm::DenseMapInfo<clang::ento::CodeTextRegion const*>, llvm::DenseMapInfo<clang::ento::StaticGlobalSpaceRegion*>>::grow(unsigned int)"},
    {"_ZN5clang4ento18GlobalsSpaceRegionD1Ev", "clang::ento::GlobalsSpaceRegion::~GlobalsSpaceRegion()"},
    {"_ZN5clang4ento18GlobalsSpaceRegionD0Ev", "clang::ento::GlobalsSpaceRegion::~GlobalsSpaceRegion()"},
    {"_ZN4llvm8DenseMapIPKN5clang17StackFrameContextEPNS1_4ento25StackArgumentsSpaceRegionENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::StackFrameContext const*, clang::ento::StackArgumentsSpaceRegion*, llvm::DenseMapInfo<clang::StackFrameContext const*>, llvm::DenseMapInfo<clang::ento::StackArgumentsSpaceRegion*>>::InsertIntoBucket(clang::StackFrameContext const* const&, clang::ento::StackArgumentsSpaceRegion* const&, std::pair<clang::StackFrameContext const*, clang::ento::StackArgumentsSpaceRegion*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang17StackFrameContextEPNS1_4ento25StackArgumentsSpaceRegionENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::StackFrameContext const*, clang::ento::StackArgumentsSpaceRegion*, llvm::DenseMapInfo<clang::StackFrameContext const*>, llvm::DenseMapInfo<clang::ento::StackArgumentsSpaceRegion*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang17StackFrameContextEPNS1_4ento22StackLocalsSpaceRegionENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::StackFrameContext const*, clang::ento::StackLocalsSpaceRegion*, llvm::DenseMapInfo<clang::StackFrameContext const*>, llvm::DenseMapInfo<clang::ento::StackLocalsSpaceRegion*>>::InsertIntoBucket(clang::StackFrameContext const* const&, clang::ento::StackLocalsSpaceRegion* const&, std::pair<clang::StackFrameContext const*, clang::ento::StackLocalsSpaceRegion*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang17StackFrameContextEPNS1_4ento22StackLocalsSpaceRegionENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::StackFrameContext const*, clang::ento::StackLocalsSpaceRegion*, llvm::DenseMapInfo<clang::StackFrameContext const*>, llvm::DenseMapInfo<clang::ento::StackLocalsSpaceRegion*>>::grow(unsigned int)"},
    {"_ZN5clang4ento25StackArgumentsSpaceRegionD1Ev", "clang::ento::StackArgumentsSpaceRegion::~StackArgumentsSpaceRegion()"},
    {"_ZN5clang4ento25StackArgumentsSpaceRegionD0Ev", "clang::ento::StackArgumentsSpaceRegion::~StackArgumentsSpaceRegion()"},
    {"_ZN5clang4ento22StackLocalsSpaceRegionD1Ev", "clang::ento::StackLocalsSpaceRegion::~StackLocalsSpaceRegion()"},
    {"_ZN5clang4ento22StackLocalsSpaceRegionD0Ev", "clang::ento::StackLocalsSpaceRegion::~StackLocalsSpaceRegion()"},
    {"_ZN4llvm10FoldingSetIN5clang4ento9MemRegionEED0Ev", "llvm::FoldingSet<clang::ento::MemRegion>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento9MemRegionEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::MemRegion>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento9MemRegionEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::ento::MemRegion>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento9MemRegionEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::MemRegion>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento11ObjCMessage7getTypeERNS_10ASTContextE", "clang::ento::ObjCMessage::getType(clang::ASTContext&) const"},
    {"_ZNK5clang4ento11ObjCMessage11getSelectorEv", "clang::ento::ObjCMessage::getSelector() const"},
    {"_ZNK5clang4ento11ObjCMessage13getMethodDeclEv", "clang::ento::ObjCMessage::getMethodDecl() const"},
    {"_ZNK5clang4ento11ObjCMessage20getReceiverInterfaceEv", "clang::ento::ObjCMessage::getReceiverInterface() const"},
    {"_ZNK5clang4ento11ObjCMessage10getArgExprEj", "clang::ento::ObjCMessage::getArgExpr(unsigned int) const"},
    {"_ZNK5clang4ento17CallOrObjCMessage13getResultTypeERNS_10ASTContextE", "clang::ento::CallOrObjCMessage::getResultType(clang::ASTContext&) const"},
    {"_ZNK5clang4ento17CallOrObjCMessage23getArgSValAsScalarOrLocEj", "clang::ento::CallOrObjCMessage::getArgSValAsScalarOrLoc(unsigned int) const"},
    {"_ZNK5clang4ento24PathDiagnosticMacroPiece13containsEventEv", "clang::ento::PathDiagnosticMacroPiece::containsEvent() const"},
    {"_ZN5clang4ento19PathDiagnosticPieceC1EN4llvm9StringRefENS1_4KindENS1_11DisplayHintE", "clang::ento::PathDiagnosticPiece::PathDiagnosticPiece(llvm::StringRef, clang::ento::PathDiagnosticPiece::Kind, clang::ento::PathDiagnosticPiece::DisplayHint)"},
    {"_ZN5clang4ento19PathDiagnosticPieceC2EN4llvm9StringRefENS1_4KindENS1_11DisplayHintE", "clang::ento::PathDiagnosticPiece::PathDiagnosticPiece(llvm::StringRef, clang::ento::PathDiagnosticPiece::Kind, clang::ento::PathDiagnosticPiece::DisplayHint)"},
    {"_ZN5clang4ento19PathDiagnosticPieceC1ENS1_4KindENS1_11DisplayHintE", "clang::ento::PathDiagnosticPiece::PathDiagnosticPiece(clang::ento::PathDiagnosticPiece::Kind, clang::ento::PathDiagnosticPiece::DisplayHint)"},
    {"_ZN5clang4ento19PathDiagnosticPieceC2ENS1_4KindENS1_11DisplayHintE", "clang::ento::PathDiagnosticPiece::PathDiagnosticPiece(clang::ento::PathDiagnosticPiece::Kind, clang::ento::PathDiagnosticPiece::DisplayHint)"},
    {"_ZN5clang4ento19PathDiagnosticPieceD0Ev", "clang::ento::PathDiagnosticPiece::~PathDiagnosticPiece()"},
    {"_ZN5clang4ento19PathDiagnosticPieceD1Ev", "clang::ento::PathDiagnosticPiece::~PathDiagnosticPiece()"},
    {"_ZN5clang4ento19PathDiagnosticPieceD2Ev", "clang::ento::PathDiagnosticPiece::~PathDiagnosticPiece()"},
    {"_ZN5clang4ento24PathDiagnosticEventPieceD0Ev", "clang::ento::PathDiagnosticEventPiece::~PathDiagnosticEventPiece()"},
    {"_ZN5clang4ento24PathDiagnosticEventPieceD1Ev", "clang::ento::PathDiagnosticEventPiece::~PathDiagnosticEventPiece()"},
    {"_ZN5clang4ento24PathDiagnosticEventPieceD2Ev", "clang::ento::PathDiagnosticEventPiece::~PathDiagnosticEventPiece()"},
    {"_ZN5clang4ento30PathDiagnosticControlFlowPieceD0Ev", "clang::ento::PathDiagnosticControlFlowPiece::~PathDiagnosticControlFlowPiece()"},
    {"_ZN5clang4ento30PathDiagnosticControlFlowPieceD1Ev", "clang::ento::PathDiagnosticControlFlowPiece::~PathDiagnosticControlFlowPiece()"},
    {"_ZN5clang4ento30PathDiagnosticControlFlowPieceD2Ev", "clang::ento::PathDiagnosticControlFlowPiece::~PathDiagnosticControlFlowPiece()"},
    {"_ZN5clang4ento24PathDiagnosticMacroPieceD0Ev", "clang::ento::PathDiagnosticMacroPiece::~PathDiagnosticMacroPiece()"},
    {"_ZN5clang4ento24PathDiagnosticMacroPieceD1Ev", "clang::ento::PathDiagnosticMacroPiece::~PathDiagnosticMacroPiece()"},
    {"_ZN5clang4ento24PathDiagnosticMacroPieceD2Ev", "clang::ento::PathDiagnosticMacroPiece::~PathDiagnosticMacroPiece()"},
    {"_ZN5clang4ento14PathDiagnosticC1Ev", "clang::ento::PathDiagnostic::PathDiagnostic()"},
    {"_ZN5clang4ento14PathDiagnosticC2Ev", "clang::ento::PathDiagnostic::PathDiagnostic()"},
    {"_ZN5clang4ento14PathDiagnosticD1Ev", "clang::ento::PathDiagnostic::~PathDiagnostic()"},
    {"_ZN5clang4ento14PathDiagnosticD2Ev", "clang::ento::PathDiagnostic::~PathDiagnostic()"},
    {"_ZN5clang4ento14PathDiagnostic9resetPathEb", "clang::ento::PathDiagnostic::resetPath(bool)"},
    {"_ZN5clang4ento14PathDiagnosticC1EN4llvm9StringRefES3_S3_", "clang::ento::PathDiagnostic::PathDiagnostic(llvm::StringRef, llvm::StringRef, llvm::StringRef)"},
    {"_ZN5clang4ento14PathDiagnosticC2EN4llvm9StringRefES3_S3_", "clang::ento::PathDiagnostic::PathDiagnostic(llvm::StringRef, llvm::StringRef, llvm::StringRef)"},
    {"_ZN5clang4ento20PathDiagnosticClient16HandleDiagnosticENS_10Diagnostic5LevelERKNS_14DiagnosticInfoE", "clang::ento::PathDiagnosticClient::HandleDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_ZNK5clang4ento22PathDiagnosticLocation10asLocationEv", "clang::ento::PathDiagnosticLocation::asLocation() const"},
    {"_ZNK5clang4ento22PathDiagnosticLocation7asRangeEv", "clang::ento::PathDiagnosticLocation::asRange() const"},
    {"_ZN5clang4ento22PathDiagnosticLocation7flattenEv", "clang::ento::PathDiagnosticLocation::flatten()"},
    {"_ZNK5clang4ento22PathDiagnosticLocation7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::PathDiagnosticLocation::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento19PathDiagnosticPiece7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::PathDiagnosticPiece::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento23PathDiagnosticSpotPiece7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::PathDiagnosticSpotPiece::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento30PathDiagnosticControlFlowPiece7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::PathDiagnosticControlFlowPiece::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento24PathDiagnosticMacroPiece7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::PathDiagnosticMacroPiece::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4ento14PathDiagnostic7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::PathDiagnostic::Profile(llvm::FoldingSetNodeID&) const"},
    {"_ZNSt11_Deque_baseIPN5clang4ento19PathDiagnosticPieceESaIS3_EE17_M_initialize_mapEm", "std::_Deque_base<clang::ento::PathDiagnosticPiece*, std::allocator<clang::ento::PathDiagnosticPiece*>>::_M_initialize_map(unsigned long)"},
    {"_ZN5clang4ento23PathDiagnosticSpotPieceC2ERKNS0_22PathDiagnosticLocationEN4llvm9StringRefENS0_19PathDiagnosticPiece4KindEb", "clang::ento::PathDiagnosticSpotPiece::PathDiagnosticSpotPiece(clang::ento::PathDiagnosticLocation const&, llvm::StringRef, clang::ento::PathDiagnosticPiece::Kind, bool)"},
    {"_ZN5clang4ento27createPlistDiagnosticClientERKSsRKNS_12PreprocessorEPNS0_20PathDiagnosticClientE", "clang::ento::createPlistDiagnosticClient(std::string const&, clang::Preprocessor const&, clang::ento::PathDiagnosticClient*)"},
    {"_ZN12_GLOBAL__N_116PlistDiagnosticsD1Ev", "(anonymous namespace)::PlistDiagnostics::~PlistDiagnostics()"},
    {"_ZN12_GLOBAL__N_116PlistDiagnosticsD0Ev", "(anonymous namespace)::PlistDiagnostics::~PlistDiagnostics()"},
    {"_ZN12_GLOBAL__N_116PlistDiagnostics16FlushDiagnosticsEPN4llvm15SmallVectorImplISsEE", "(anonymous namespace)::PlistDiagnostics::FlushDiagnostics(llvm::SmallVectorImpl<std::string>*)"},
    {"_ZNK12_GLOBAL__N_116PlistDiagnostics7getNameEv", "(anonymous namespace)::PlistDiagnostics::getName() const"},
    {"_ZN12_GLOBAL__N_116PlistDiagnostics20HandlePathDiagnosticEPKN5clang4ento14PathDiagnosticE", "(anonymous namespace)::PlistDiagnostics::HandlePathDiagnostic(clang::ento::PathDiagnostic const*)"},
    {"_ZNK12_GLOBAL__N_116PlistDiagnostics19getGenerationSchemeEv", "(anonymous namespace)::PlistDiagnostics::getGenerationScheme() const"},
    {"_ZNK12_GLOBAL__N_116PlistDiagnostics28supportsLogicalOpControlFlowEv", "(anonymous namespace)::PlistDiagnostics::supportsLogicalOpControlFlow() const"},
    {"_ZNK12_GLOBAL__N_116PlistDiagnostics21supportsAllBlockEdgesEv", "(anonymous namespace)::PlistDiagnostics::supportsAllBlockEdges() const"},
    {"_ZNK12_GLOBAL__N_116PlistDiagnostics21useVerboseDescriptionEv", "(anonymous namespace)::PlistDiagnostics::useVerboseDescription() const"},
    {"_Z6AddFIDRN4llvm8DenseMapIN5clang6FileIDEjNS_12DenseMapInfoIS2_EENS3_IjEEEERNS_15SmallVectorImplIS2_EEPKNS1_13SourceManagerENS1_14SourceLocationE", "AddFID(llvm::DenseMap<clang::FileID, unsigned int, llvm::DenseMapInfo<clang::FileID>, llvm::DenseMapInfo<unsigned int>>&, llvm::SmallVectorImpl<clang::FileID>&, clang::SourceManager const*, clang::SourceLocation)"},
    {"_Z10EmitStringRN4llvm11raw_ostreamERKSs", "EmitString(llvm::raw_ostream&, std::string const&)"},
    {"_Z12EmitLocationRN4llvm11raw_ostreamERKN5clang13SourceManagerERKNS2_11LangOptionsENS2_14SourceLocationERKNS_8DenseMapINS2_6FileIDEjNS_12DenseMapInfoISB_EENSC_IjEEEEjb", "EmitLocation(llvm::raw_ostream&, clang::SourceManager const&, clang::LangOptions const&, clang::SourceLocation, llvm::DenseMap<clang::FileID, unsigned int, llvm::DenseMapInfo<clang::FileID>, llvm::DenseMapInfo<unsigned int>> const&, unsigned int, bool)"},
    {"_Z11ReportEventRN4llvm11raw_ostreamERKN5clang4ento19PathDiagnosticPieceERKNS_8DenseMapINS2_6FileIDEjNS_12DenseMapInfoIS8_EENS9_IjEEEERKNS2_13SourceManagerERKNS2_11LangOptionsEj", "ReportEvent(llvm::raw_ostream&, clang::ento::PathDiagnosticPiece const&, llvm::DenseMap<clang::FileID, unsigned int, llvm::DenseMapInfo<clang::FileID>, llvm::DenseMapInfo<unsigned int>> const&, clang::SourceManager const&, clang::LangOptions const&, unsigned int)"},
    {"_Z11ReportMacroRN4llvm11raw_ostreamERKN5clang4ento24PathDiagnosticMacroPieceERKNS_8DenseMapINS2_6FileIDEjNS_12DenseMapInfoIS8_EENS9_IjEEEERKNS2_13SourceManagerERKNS2_11LangOptionsEj", "ReportMacro(llvm::raw_ostream&, clang::ento::PathDiagnosticMacroPiece const&, llvm::DenseMap<clang::FileID, unsigned int, llvm::DenseMapInfo<clang::FileID>, llvm::DenseMapInfo<unsigned int>> const&, clang::SourceManager const&, clang::LangOptions const&, unsigned int)"},
    {"_Z9EmitRangeRN4llvm11raw_ostreamERKN5clang13SourceManagerERKNS2_11LangOptionsENS2_4ento19PathDiagnosticRangeERKNS_8DenseMapINS2_6FileIDEjNS_12DenseMapInfoISC_EENSD_IjEEEEj", "EmitRange(llvm::raw_ostream&, clang::SourceManager const&, clang::LangOptions const&, clang::ento::PathDiagnosticRange, llvm::DenseMap<clang::FileID, unsigned int, llvm::DenseMapInfo<clang::FileID>, llvm::DenseMapInfo<unsigned int>> const&, unsigned int)"},
    {"_ZSt16__introsort_loopIN9__gnu_cxx17__normal_iteratorIPPKN5clang4ento14PathDiagnosticESt6vectorIS6_SaIS6_EEEElN12_GLOBAL__N_118CompareDiagnosticsEEvT_SE_T0_T1_", "void std::__introsort_loop<__gnu_cxx::__normal_iterator<clang::ento::PathDiagnostic const**, std::vector<clang::ento::PathDiagnostic const*, std::allocator<clang::ento::PathDiagnostic const*>>>, long, (anonymous namespace)::CompareDiagnostics>(__gnu_cxx::__normal_iterator<clang::ento::PathDiagnostic const**, std::vector<clang::ento::PathDiagnostic const*, std::allocator<clang::ento::PathDiagnostic const*>>>, __gnu_cxx::__normal_iterator<clang::ento::PathDiagnostic const**, std::vector<clang::ento::PathDiagnostic const*, std::allocator<clang::ento::PathDiagnostic const*>>>, long, (anonymous namespace)::CompareDiagnostics)"},
    {"_ZSt16__insertion_sortIN9__gnu_cxx17__normal_iteratorIPPKN5clang4ento14PathDiagnosticESt6vectorIS6_SaIS6_EEEEN12_GLOBAL__N_118CompareDiagnosticsEEvT_SE_T0_", "void std::__insertion_sort<__gnu_cxx::__normal_iterator<clang::ento::PathDiagnostic const**, std::vector<clang::ento::PathDiagnostic const*, std::allocator<clang::ento::PathDiagnostic const*>>>, (anonymous namespace)::CompareDiagnostics>(__gnu_cxx::__normal_iterator<clang::ento::PathDiagnostic const**, std::vector<clang::ento::PathDiagnostic const*, std::allocator<clang::ento::PathDiagnostic const*>>>, __gnu_cxx::__normal_iterator<clang::ento::PathDiagnostic const**, std::vector<clang::ento::PathDiagnostic const*, std::allocator<clang::ento::PathDiagnostic const*>>>, (anonymous namespace)::CompareDiagnostics)"},
    {"_ZNK12_GLOBAL__N_118CompareDiagnosticsclEPKN5clang4ento14PathDiagnosticES5_", "(anonymous namespace)::CompareDiagnostics::operator()(clang::ento::PathDiagnostic const*, clang::ento::PathDiagnostic const*) const"},
    {"_ZSt13__adjust_heapIN9__gnu_cxx17__normal_iteratorIPPKN5clang4ento14PathDiagnosticESt6vectorIS6_SaIS6_EEEElS6_N12_GLOBAL__N_118CompareDiagnosticsEEvT_T0_SF_T1_T2_", "void std::__adjust_heap<__gnu_cxx::__normal_iterator<clang::ento::PathDiagnostic const**, std::vector<clang::ento::PathDiagnostic const*, std::allocator<clang::ento::PathDiagnostic const*>>>, long, clang::ento::PathDiagnostic const*, (anonymous namespace)::CompareDiagnostics>(__gnu_cxx::__normal_iterator<clang::ento::PathDiagnostic const**, std::vector<clang::ento::PathDiagnostic const*, std::allocator<clang::ento::PathDiagnostic const*>>>, long, long, clang::ento::PathDiagnostic const*, (anonymous namespace)::CompareDiagnostics)"},
    {"_ZNSt6vectorIPKN5clang4ento14PathDiagnosticESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<clang::ento::PathDiagnostic const*, std::allocator<clang::ento::PathDiagnostic const*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::ento::PathDiagnostic const**, std::vector<clang::ento::PathDiagnostic const*, std::allocator<clang::ento::PathDiagnostic const*>>>, clang::ento::PathDiagnostic const* const&)"},
    {"_ZN4llvm8DenseMapIN5clang6FileIDEjNS_12DenseMapInfoIS2_EENS3_IjEEE16InsertIntoBucketERKS2_RKjPSt4pairIS2_jE", "llvm::DenseMap<clang::FileID, unsigned int, llvm::DenseMapInfo<clang::FileID>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::FileID const&, unsigned int const&, std::pair<clang::FileID, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIN5clang6FileIDEjNS_12DenseMapInfoIS2_EENS3_IjEEE4growEj", "llvm::DenseMap<clang::FileID, unsigned int, llvm::DenseMapInfo<clang::FileID>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN5clang4ento28CreateRangeConstraintManagerERNS0_14GRStateManagerERNS0_9SubEngineE", "clang::ento::CreateRangeConstraintManager(clang::ento::GRStateManager&, clang::ento::SubEngine&)"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManagerD1Ev", "(anonymous namespace)::RangeConstraintManager::~RangeConstraintManager()"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManagerD0Ev", "(anonymous namespace)::RangeConstraintManager::~RangeConstraintManager()"},
    {"_ZNK12_GLOBAL__N_122RangeConstraintManager9getSymValEPKN5clang4ento7GRStateEPKNS2_10SymbolDataE", "(anonymous namespace)::RangeConstraintManager::getSymVal(clang::ento::GRState const*, clang::ento::SymbolData const*) const"},
    {"_ZNK12_GLOBAL__N_122RangeConstraintManager7isEqualEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntE", "(anonymous namespace)::RangeConstraintManager::isEqual(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&) const"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManager18removeDeadBindingsEPKN5clang4ento7GRStateERNS2_12SymbolReaperE", "(anonymous namespace)::RangeConstraintManager::removeDeadBindings(clang::ento::GRState const*, clang::ento::SymbolReaper&)"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManager5printEPKN5clang4ento7GRStateERN4llvm11raw_ostreamEPKcSA_", "(anonymous namespace)::RangeConstraintManager::print(clang::ento::GRState const*, llvm::raw_ostream&, char const*, char const*)"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManager11assumeSymNEEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::RangeConstraintManager::assumeSymNE(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManager11assumeSymEQEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::RangeConstraintManager::assumeSymEQ(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManager11assumeSymLTEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::RangeConstraintManager::assumeSymLT(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManager11assumeSymGTEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::RangeConstraintManager::assumeSymGT(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManager11assumeSymLEEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::RangeConstraintManager::assumeSymLE(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManager11assumeSymGEEPKN5clang4ento7GRStateEPKNS2_10SymbolDataERKN4llvm6APSIntESC_", "(anonymous namespace)::RangeConstraintManager::assumeSymGE(clang::ento::GRState const*, clang::ento::SymbolData const*, llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_122RangeConstraintManager8GetRangeEPKN5clang4ento7GRStateEPKNS2_10SymbolDataE", "(anonymous namespace)::RangeConstraintManager::GetRange(clang::ento::GRState const*, clang::ento::SymbolData const*)"},
    {"_ZNK12_GLOBAL__N_18RangeSet9IntersectERN5clang4ento17BasicValueFactoryERN4llvm12ImmutableSetINS_5RangeENS_10RangeTraitEE7FactoryERKNS5_6APSIntESE_", "(anonymous namespace)::RangeSet::Intersect(clang::ento::BasicValueFactory&, llvm::ImmutableSet<(anonymous namespace)::Range, (anonymous namespace)::RangeTrait>::Factory&, llvm::APSInt const&, llvm::APSInt const&) const"},
    {"_ZNK5clang4ento7GRState3setIN12_GLOBAL__N_115ConstraintRangeEEEPKS1_NS0_12GRStateTraitIT_E8key_typeENS9_10value_typeE", "clang::ento::GRState const* clang::ento::GRState::set<(anonymous namespace)::ConstraintRange>(clang::ento::GRStateTrait<(anonymous namespace)::ConstraintRange>::key_type, clang::ento::GRStateTrait<(anonymous namespace)::ConstraintRange>::value_type) const"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_18RangeSetENS2_16ImutKeyValueInfoIS6_S8_EEEEE13CreateContextERNS2_16BumpPtrAllocatorE", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>>::CreateContext(llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento19GRStatePartialTraitIN4llvm12ImmutableMapIPKNS0_10SymbolDataEN12_GLOBAL__N_18RangeSetENS2_16ImutKeyValueInfoIS6_S8_EEEEE13DeleteContextEPv", "clang::ento::GRStatePartialTrait<llvm::ImmutableMap<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet, llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>>::DeleteContext(void*)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>::destroy()"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEEENS_12DenseMapInfoIjEENSD_ISC_EEEixERKj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*>>::operator[](unsigned int const&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEEESaISC_EE9push_backERKSC_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*>>::push_back(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>* const&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*)"},
    {"_ZN4llvm26ImutAVLTreeInOrderIteratorINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEEppEv", "llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>::operator++()"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorIN12_GLOBAL__N_110RangeTraitEEppEv", "llvm::ImutAVLTreeGenericIterator<(anonymous namespace)::RangeTrait>::operator++()"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEE12add_internalERKSt4pairIS6_S8_EPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>::add_internal(std::pair<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEE13markImmutableEPNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEE10createNodeEPNS_11ImutAVLTreeIS9_EERKSt4pairIS6_S8_ESD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*, std::pair<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEE11balanceTreeEPNS_11ImutAVLTreeIS9_EERKSt4pairIS6_S8_ESD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*, std::pair<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*)"},
    {"_ZN4llvm11ImutAVLTreeIN12_GLOBAL__N_110RangeTraitEE7destroyEv", "llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>::destroy()"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeIN12_GLOBAL__N_110RangeTraitEEENS_12DenseMapInfoIjEENS6_IS5_EEEixERKj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>*>>::operator[](unsigned int const&)"},
    {"_ZN4llvm11ImutAVLTreeIN12_GLOBAL__N_110RangeTraitEE13computeDigestEv", "llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeIN12_GLOBAL__N_110RangeTraitEEESaIS5_EE9push_backERKS5_", "std::vector<llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>*, std::allocator<llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>*>>::push_back(llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>* const&)"},
    {"_ZNK12_GLOBAL__N_18RangeSet16IntersectInRangeERN5clang4ento17BasicValueFactoryERN4llvm12ImmutableSetINS_5RangeENS_10RangeTraitEE7FactoryERKNS5_6APSIntESE_RS9_RNS9_8iteratorESH_", "(anonymous namespace)::RangeSet::IntersectInRange(clang::ento::BasicValueFactory&, llvm::ImmutableSet<(anonymous namespace)::Range, (anonymous namespace)::RangeTrait>::Factory&, llvm::APSInt const&, llvm::APSInt const&, llvm::ImmutableSet<(anonymous namespace)::Range, (anonymous namespace)::RangeTrait>&, llvm::ImmutableSet<(anonymous namespace)::Range, (anonymous namespace)::RangeTrait>::iterator&, llvm::ImmutableSet<(anonymous namespace)::Range, (anonymous namespace)::RangeTrait>::iterator&) const"},
    {"_ZN4llvm12ImmutableSetIN12_GLOBAL__N_15RangeENS1_10RangeTraitEE7Factory3addES4_RKS2_", "llvm::ImmutableSet<(anonymous namespace)::Range, (anonymous namespace)::RangeTrait>::Factory::add(llvm::ImmutableSet<(anonymous namespace)::Range, (anonymous namespace)::RangeTrait>, (anonymous namespace)::Range const&)"},
    {"_ZN4llvm14ImutAVLFactoryIN12_GLOBAL__N_110RangeTraitEE12add_internalERKNS1_5RangeEPNS_11ImutAVLTreeIS2_EE", "llvm::ImutAVLFactory<(anonymous namespace)::RangeTrait>::add_internal((anonymous namespace)::Range const&, llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>*)"},
    {"_ZN4llvm14ImutAVLFactoryIN12_GLOBAL__N_110RangeTraitEE13markImmutableEPNS_11ImutAVLTreeIS2_EE", "llvm::ImutAVLFactory<(anonymous namespace)::RangeTrait>::markImmutable(llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>*)"},
    {"_ZN4llvm14ImutAVLFactoryIN12_GLOBAL__N_110RangeTraitEE10createNodeEPNS_11ImutAVLTreeIS2_EERKNS1_5RangeES6_", "llvm::ImutAVLFactory<(anonymous namespace)::RangeTrait>::createNode(llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>*, (anonymous namespace)::Range const&, llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>*)"},
    {"_ZN4llvm14ImutAVLFactoryIN12_GLOBAL__N_110RangeTraitEE11balanceTreeEPNS_11ImutAVLTreeIS2_EERKNS1_5RangeES6_", "llvm::ImutAVLFactory<(anonymous namespace)::RangeTrait>::balanceTree(llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>*, (anonymous namespace)::Range const&, llvm::ImutAVLTree<(anonymous namespace)::RangeTrait>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEE15remove_internalERKS6_PNS_11ImutAVLTreeIS9_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>::remove_internal(clang::ento::SymbolData const* const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIPKN5clang4ento10SymbolDataEN12_GLOBAL__N_18RangeSetEEEE16removeMinBindingEPNS_11ImutAVLTreeIS9_EERSD_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>::removeMinBinding(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<clang::ento::SymbolData const*, (anonymous namespace)::RangeSet>>*&)"},
    {"_ZN5clang4ento17ConstraintManager7EndPathEPKNS0_7GRStateE", "clang::ento::ConstraintManager::EndPath(clang::ento::GRState const*)"},
    {"_ZN4llvm6APSInt11getMaxValueEjb", "llvm::APSInt::getMaxValue(unsigned int, bool)"},
    {"_ZN4llvm6APSInt11getMinValueEjb", "llvm::APSInt::getMinValue(unsigned int, bool)"},
    {"_ZN5clang4ento24CreateRegionStoreManagerERNS0_14GRStateManagerE", "clang::ento::CreateRegionStoreManager(clang::ento::GRStateManager&)"},
    {"_ZN5clang4ento34CreateFieldsOnlyRegionStoreManagerERNS0_14GRStateManagerE", "clang::ento::CreateFieldsOnlyRegionStoreManager(clang::ento::GRStateManager&)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManagerD1Ev", "(anonymous namespace)::RegionStoreManager::~RegionStoreManager()"},
    {"_ZN12_GLOBAL__N_118RegionStoreManagerD0Ev", "(anonymous namespace)::RegionStoreManager::~RegionStoreManager()"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager8RetrieveEPKvN5clang4ento3LocENS3_8QualTypeE", "(anonymous namespace)::RegionStoreManager::Retrieve(void const*, clang::ento::Loc, clang::QualType)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager4BindEPKvN5clang4ento3LocENS4_4SValE", "(anonymous namespace)::RegionStoreManager::Bind(void const*, clang::ento::Loc, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager11BindDefaultEPKvPKN5clang4ento9MemRegionENS4_4SValE", "(anonymous namespace)::RegionStoreManager::BindDefault(void const*, clang::ento::MemRegion const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager6RemoveEPKvN5clang4ento3LocE", "(anonymous namespace)::RegionStoreManager::Remove(void const*, clang::ento::Loc)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager19BindCompoundLiteralEPKvPKN5clang19CompoundLiteralExprEPKNS3_15LocationContextENS3_4ento4SValE", "(anonymous namespace)::RegionStoreManager::BindCompoundLiteral(void const*, clang::CompoundLiteralExpr const*, clang::LocationContext const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager15getInitialStoreEPKN5clang15LocationContextE", "(anonymous namespace)::RegionStoreManager::getInitialStore(clang::LocationContext const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager15getSubRegionMapEPKv", "(anonymous namespace)::RegionStoreManager::getSubRegionMap(void const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager17getSizeInElementsEPKN5clang4ento7GRStateEPKNS2_9MemRegionENS1_8QualTypeE", "(anonymous namespace)::RegionStoreManager::getSizeInElements(clang::ento::GRState const*, clang::ento::MemRegion const*, clang::QualType)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager14ArrayToPointerEN5clang4ento3LocE", "(anonymous namespace)::RegionStoreManager::ArrayToPointer(clang::ento::Loc)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager17evalDerivedToBaseEN5clang4ento4SValENS1_8QualTypeE", "(anonymous namespace)::RegionStoreManager::evalDerivedToBase(clang::ento::SVal, clang::QualType)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager18removeDeadBindingsEPKvPKN5clang17StackFrameContextERNS3_4ento12SymbolReaperERN4llvm15SmallVectorImplIPKNS7_9MemRegionEEE", "(anonymous namespace)::RegionStoreManager::removeDeadBindings(void const*, clang::StackFrameContext const*, clang::ento::SymbolReaper&, llvm::SmallVectorImpl<clang::ento::MemRegion const*>&)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager8BindDeclEPKvPKN5clang4ento9VarRegionENS4_4SValE", "(anonymous namespace)::RegionStoreManager::BindDecl(void const*, clang::ento::VarRegion const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager18BindDeclWithNoInitEPKvPKN5clang4ento9VarRegionE", "(anonymous namespace)::RegionStoreManager::BindDeclWithNoInit(void const*, clang::ento::VarRegion const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager17InvalidateRegionsEPKvPKPKN5clang4ento9MemRegionES9_PKNS3_4ExprEjPN4llvm8DenseSetIPKNS4_10SymbolDataENSD_12DenseMapInfoISH_EEEEbPNSD_11SmallVectorIS7_Lj8EEE", "(anonymous namespace)::RegionStoreManager::InvalidateRegions(void const*, clang::ento::MemRegion const* const*, clang::ento::MemRegion const* const*, clang::Expr const*, unsigned int, llvm::DenseSet<clang::ento::SymbolData const*, llvm::DenseMapInfo<clang::ento::SymbolData const*>>*, bool, llvm::SmallVector<clang::ento::MemRegion const*, 8u>*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager15enterStackFrameEPKN5clang4ento7GRStateEPKNS1_17StackFrameContextE", "(anonymous namespace)::RegionStoreManager::enterStackFrame(clang::ento::GRState const*, clang::StackFrameContext const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager5printEPKvRN4llvm11raw_ostreamEPKcS7_", "(anonymous namespace)::RegionStoreManager::print(void const*, llvm::raw_ostream&, char const*, char const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager12iterBindingsEPKvRN5clang4ento12StoreManager15BindingsHandlerE", "(anonymous namespace)::RegionStoreManager::iterBindings(void const*, clang::ento::StoreManager::BindingsHandler&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>::destroy()"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEEENS_12DenseMapInfoIjEENSB_ISA_EEEixERKj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*>>::operator[](unsigned int const&)"},
    {"_ZN4llvm11ImutAVLTreeINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEEESaISA_EE9push_backERKSA_", "std::vector<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*>>::push_back(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>* const&)"},
    {"_ZN4llvm26ImutAVLTreeInOrderIteratorINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEEppEv", "llvm::ImutAVLTreeInOrderIterator<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>::operator++()"},
    {"_ZN12_GLOBAL__N_115ClusterAnalysisINS_23InvalidateRegionsWorkerEE13AddToWorkListEPKN5clang4ento9MemRegionE", "(anonymous namespace)::ClusterAnalysis<(anonymous namespace)::InvalidateRegionsWorker>::AddToWorkList(clang::ento::MemRegion const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager10addBindingEN4llvm12ImmutableMapINS_10BindingKeyEN5clang4ento4SValENS1_16ImutKeyValueInfoIS3_S6_EEEES3_S6_", "(anonymous namespace)::RegionStoreManager::addBinding(llvm::ImmutableMap<(anonymous namespace)::BindingKey, clang::ento::SVal, llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>, (anonymous namespace)::BindingKey, clang::ento::SVal)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEE12add_internalERKSt4pairIS3_S6_EPNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>::add_internal(std::pair<(anonymous namespace)::BindingKey, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEE13markImmutableEPNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>::markImmutable(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEE10createNodeEPNS_11ImutAVLTreeIS7_EERKSt4pairIS3_S6_ESB_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>::createNode(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*, std::pair<(anonymous namespace)::BindingKey, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEE11balanceTreeEPNS_11ImutAVLTreeIS7_EERKSt4pairIS3_S6_ESB_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>::balanceTree(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*, std::pair<(anonymous namespace)::BindingKey, clang::ento::SVal> const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager13removeBindingEN4llvm12ImmutableMapINS_10BindingKeyEN5clang4ento4SValENS1_16ImutKeyValueInfoIS3_S6_EEEES3_", "(anonymous namespace)::RegionStoreManager::removeBinding(llvm::ImmutableMap<(anonymous namespace)::BindingKey, clang::ento::SVal, llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>, (anonymous namespace)::BindingKey)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEE15remove_internalERKS3_PNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>::remove_internal((anonymous namespace)::BindingKey const&, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_16ImutKeyValueInfoIN12_GLOBAL__N_110BindingKeyEN5clang4ento4SValEEEE16removeMinBindingEPNS_11ImutAVLTreeIS7_EERSB_", "llvm::ImutAVLFactory<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>::removeMinBinding(llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*, llvm::ImutAVLTree<llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>*&)"},
    {"_ZN12_GLOBAL__N_123InvalidateRegionsWorker12VisitBindingEN5clang4ento4SValE", "(anonymous namespace)::InvalidateRegionsWorker::VisitBinding(clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_115ClusterAnalysisINS_23InvalidateRegionsWorkerEE10getClusterEPKN5clang4ento9MemRegionE", "(anonymous namespace)::ClusterAnalysis<(anonymous namespace)::InvalidateRegionsWorker>::getCluster(clang::ento::MemRegion const*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento9MemRegionEPNS1_10BumpVectorIN12_GLOBAL__N_110BindingKeyEEENS_12DenseMapInfoIS5_EENSB_ISA_EEEixERKS5_", "llvm::DenseMap<clang::ento::MemRegion const*, clang::BumpVector<(anonymous namespace)::BindingKey>*, llvm::DenseMapInfo<clang::ento::MemRegion const*>, llvm::DenseMapInfo<clang::BumpVector<(anonymous namespace)::BindingKey>*>>::operator[](clang::ento::MemRegion const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang10BumpVectorIN12_GLOBAL__N_110BindingKeyEEEjNS_12DenseMapInfoIS7_EENS8_IjEEEixERKS7_", "llvm::DenseMap<clang::BumpVector<(anonymous namespace)::BindingKey> const*, unsigned int, llvm::DenseMapInfo<clang::BumpVector<(anonymous namespace)::BindingKey> const*>, llvm::DenseMapInfo<unsigned int>>::operator[](clang::BumpVector<(anonymous namespace)::BindingKey> const* const&)"},
    {"_ZN5clang10BumpVectorIN12_GLOBAL__N_110BindingKeyEE9push_backERKS2_RNS_17BumpVectorContextE", "clang::BumpVector<(anonymous namespace)::BindingKey>::push_back((anonymous namespace)::BindingKey const&, clang::BumpVectorContext&)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager9BindArrayEPKvPKN5clang4ento11TypedRegionENS4_4SValE", "(anonymous namespace)::RegionStoreManager::BindArray(void const*, clang::ento::TypedRegion const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager10BindStructEPKvPKN5clang4ento11TypedRegionENS4_4SValE", "(anonymous namespace)::RegionStoreManager::BindStruct(void const*, clang::ento::TypedRegion const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager16CopyLazyBindingsEN5clang4ento6nonloc15LazyCompoundValEPKvPKNS2_11TypedRegionE", "(anonymous namespace)::RegionStoreManager::CopyLazyBindings(clang::ento::nonloc::LazyCompoundVal, void const*, clang::ento::TypedRegion const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager10KillStructEPKvPKN5clang4ento11TypedRegionENS4_4SValE", "(anonymous namespace)::RegionStoreManager::KillStruct(void const*, clang::ento::TypedRegion const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager26getRegionStoreSubRegionMapEPKv", "(anonymous namespace)::RegionStoreManager::getRegionStoreSubRegionMap(void const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager23RemoveSubRegionBindingsERN4llvm12ImmutableMapINS_10BindingKeyEN5clang4ento4SValENS1_16ImutKeyValueInfoIS3_S6_EEEEPKNS5_9MemRegionERNS_23RegionStoreSubRegionMapE", "(anonymous namespace)::RegionStoreManager::RemoveSubRegionBindings(llvm::ImmutableMap<(anonymous namespace)::BindingKey, clang::ento::SVal, llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>&, clang::ento::MemRegion const*, (anonymous namespace)::RegionStoreSubRegionMap&)"},
    {"_ZN12_GLOBAL__N_123RegionStoreSubRegionMap7processERN4llvm15SmallVectorImplIPKN5clang4ento9SubRegionEEES7_", "(anonymous namespace)::RegionStoreSubRegionMap::process(llvm::SmallVectorImpl<clang::ento::SubRegion const*>&, clang::ento::SubRegion const*)"},
    {"_ZN12_GLOBAL__N_123RegionStoreSubRegionMapD1Ev", "(anonymous namespace)::RegionStoreSubRegionMap::~RegionStoreSubRegionMap()"},
    {"_ZN12_GLOBAL__N_123RegionStoreSubRegionMapD0Ev", "(anonymous namespace)::RegionStoreSubRegionMap::~RegionStoreSubRegionMap()"},
    {"_ZNK12_GLOBAL__N_123RegionStoreSubRegionMap14iterSubRegionsEPKN5clang4ento9MemRegionERNS2_12SubRegionMap7VisitorE", "(anonymous namespace)::RegionStoreSubRegionMap::iterSubRegions(clang::ento::MemRegion const*, clang::ento::SubRegionMap::Visitor&) const"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager23setImplicitDefaultValueEPKvPKN5clang4ento9MemRegionENS3_8QualTypeE", "(anonymous namespace)::RegionStoreManager::setImplicitDefaultValue(void const*, clang::ento::MemRegion const*, clang::QualType)"},
    {"_ZN12_GLOBAL__N_115ClusterAnalysisINS_24removeDeadBindingsWorkerEE13AddToWorkListEPKN5clang4ento9MemRegionE", "(anonymous namespace)::ClusterAnalysis<(anonymous namespace)::removeDeadBindingsWorker>::AddToWorkList(clang::ento::MemRegion const*)"},
    {"_ZN12_GLOBAL__N_124removeDeadBindingsWorker12VisitBindingEN5clang4ento4SValE", "(anonymous namespace)::removeDeadBindingsWorker::VisitBinding(clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager13RetrieveFieldEPKvPKN5clang4ento11FieldRegionE", "(anonymous namespace)::RegionStoreManager::RetrieveField(void const*, clang::ento::FieldRegion const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager15RetrieveElementEPKvPKN5clang4ento13ElementRegionE", "(anonymous namespace)::RegionStoreManager::RetrieveElement(void const*, clang::ento::ElementRegion const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager27RetrieveDerivedDefaultValueEN4llvm12ImmutableMapINS_10BindingKeyEN5clang4ento4SValENS1_16ImutKeyValueInfoIS3_S6_EEEEPKNS5_9MemRegionEPKNS5_11TypedRegionENS4_8QualTypeE", "(anonymous namespace)::RegionStoreManager::RetrieveDerivedDefaultValue(llvm::ImmutableMap<(anonymous namespace)::BindingKey, clang::ento::SVal, llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>, clang::ento::MemRegion const*, clang::ento::TypedRegion const*, clang::QualType)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager17getDefaultBindingEN4llvm12ImmutableMapINS_10BindingKeyEN5clang4ento4SValENS1_16ImutKeyValueInfoIS3_S6_EEEEPKNS5_9MemRegionE", "(anonymous namespace)::RegionStoreManager::getDefaultBinding(llvm::ImmutableMap<(anonymous namespace)::BindingKey, clang::ento::SVal, llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>, clang::ento::MemRegion const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager28RetrieveFieldOrElementCommonEPKvPKN5clang4ento11TypedRegionENS3_8QualTypeEPKNS4_9MemRegionE", "(anonymous namespace)::RegionStoreManager::RetrieveFieldOrElementCommon(void const*, clang::ento::TypedRegion const*, clang::QualType, clang::ento::MemRegion const*)"},
    {"_ZN12_GLOBAL__N_118RegionStoreManager14GetLazyBindingEN4llvm12ImmutableMapINS_10BindingKeyEN5clang4ento4SValENS1_16ImutKeyValueInfoIS3_S6_EEEEPKNS5_9MemRegionE", "(anonymous namespace)::RegionStoreManager::GetLazyBinding(llvm::ImmutableMap<(anonymous namespace)::BindingKey, clang::ento::SVal, llvm::ImutKeyValueInfo<(anonymous namespace)::BindingKey, clang::ento::SVal>>, clang::ento::MemRegion const*)"},
    {"_ZN4llvm26ImutAVLTreeGenericIteratorINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEEppEv", "llvm::ImutAVLTreeGenericIterator<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::operator++()"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento9MemRegionENS_12ImmutableSetIS5_NS_17ImutContainerInfoIS5_EEEENS_12DenseMapInfoIS5_EENSA_IS9_EEE6insertERKSt4pairIS5_S9_E", "llvm::DenseMap<clang::ento::MemRegion const*, llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>>, llvm::DenseMapInfo<clang::ento::MemRegion const*>, llvm::DenseMapInfo<llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>>>>::insert(std::pair<clang::ento::MemRegion const*, llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>>> const&)"},
    {"_ZN4llvm11ImutAVLTreeINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE7destroyEv", "llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::destroy()"},
    {"_ZN4llvm11ImutAVLTreeINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE13computeDigestEv", "llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::computeDigest()"},
    {"_ZNSt6vectorIPN4llvm11ImutAVLTreeINS0_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEEESaISA_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSA_SC_EERKSA_", "std::vector<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>**, std::vector<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*, std::allocator<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*>>>, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>* const&)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEEENS_12DenseMapInfoIjEENSB_ISA_EEE16InsertIntoBucketERKjRKSA_PSt4pairIjSA_E", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*>>::InsertIntoBucket(unsigned int const&, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>* const&, std::pair<unsigned int, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*>*)"},
    {"_ZN4llvm8DenseMapIjPNS_11ImutAVLTreeINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEEENS_12DenseMapInfoIjEENSB_ISA_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*>>::grow(unsigned int)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE3addEPNS_11ImutAVLTreeIS7_EES6_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::add(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*, clang::ento::MemRegion const*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE16getCanonicalTreeEPNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::getCanonicalTree(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE22compareTreeWithSectionEPNS_11ImutAVLTreeIS7_EERNS_26ImutAVLTreeInOrderIteratorIS7_EESE_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::compareTreeWithSection(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*, llvm::ImutAVLTreeInOrderIterator<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>&, llvm::ImutAVLTreeInOrderIterator<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>&)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE12add_internalES6_PNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::add_internal(clang::ento::MemRegion const*, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE13markImmutableEPNS_11ImutAVLTreeIS7_EE", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::markImmutable(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE10createNodeEPNS_11ImutAVLTreeIS7_EES6_SB_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::createNode(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*, clang::ento::MemRegion const*, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEE11balanceTreeEPNS_11ImutAVLTreeIS7_EES6_SB_", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::balanceTree(llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*, clang::ento::MemRegion const*, llvm::ImutAVLTree<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento9MemRegionENS_12ImmutableSetIS5_NS_17ImutContainerInfoIS5_EEEENS_12DenseMapInfoIS5_EENSA_IS9_EEE16InsertIntoBucketERKS5_RKS9_PSt4pairIS5_S9_E", "llvm::DenseMap<clang::ento::MemRegion const*, llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>>, llvm::DenseMapInfo<clang::ento::MemRegion const*>, llvm::DenseMapInfo<llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>>>>::InsertIntoBucket(clang::ento::MemRegion const* const&, llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>> const&, std::pair<clang::ento::MemRegion const*, llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4ento9MemRegionENS_12ImmutableSetIS5_NS_17ImutContainerInfoIS5_EEEENS_12DenseMapInfoIS5_EENSA_IS9_EEE4growEj", "llvm::DenseMap<clang::ento::MemRegion const*, llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>>, llvm::DenseMapInfo<clang::ento::MemRegion const*>, llvm::DenseMapInfo<llvm::ImmutableSet<clang::ento::MemRegion const*, llvm::ImutContainerInfo<clang::ento::MemRegion const*>>>>::grow(unsigned int)"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEED2Ev", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::~ImutAVLFactory()"},
    {"_ZN4llvm14ImutAVLFactoryINS_17ImutContainerInfoIPKN5clang4ento9MemRegionEEEEC2Ev", "llvm::ImutAVLFactory<llvm::ImutContainerInfo<clang::ento::MemRegion const*>>::ImutAVLFactory()"},
    {"_ZN5clang4ento11SValBuilder11makeZeroValENS_8QualTypeE", "clang::ento::SValBuilder::makeZeroVal(clang::QualType)"},
    {"_ZN5clang4ento11SValBuilder10makeNonLocEPKNS0_7SymExprENS_18BinaryOperatorKindERKN4llvm6APSIntENS_8QualTypeE", "clang::ento::SValBuilder::makeNonLoc(clang::ento::SymExpr const*, clang::BinaryOperatorKind, llvm::APSInt const&, clang::QualType)"},
    {"_ZN5clang4ento11SValBuilder10makeNonLocEPKNS0_7SymExprENS_18BinaryOperatorKindES4_NS_8QualTypeE", "clang::ento::SValBuilder::makeNonLoc(clang::ento::SymExpr const*, clang::BinaryOperatorKind, clang::ento::SymExpr const*, clang::QualType)"},
    {"_ZN5clang4ento11SValBuilder19convertToArrayIndexENS0_4SValE", "clang::ento::SValBuilder::convertToArrayIndex(clang::ento::SVal)"},
    {"_ZN5clang4ento11SValBuilder23getRegionValueSymbolValEPKNS0_11TypedRegionE", "clang::ento::SValBuilder::getRegionValueSymbolVal(clang::ento::TypedRegion const*)"},
    {"_ZN5clang4ento11SValBuilder20getConjuredSymbolValEPKvPKNS_4ExprEj", "clang::ento::SValBuilder::getConjuredSymbolVal(void const*, clang::Expr const*, unsigned int)"},
    {"_ZN5clang4ento11SValBuilder20getConjuredSymbolValEPKvPKNS_4ExprENS_8QualTypeEj", "clang::ento::SValBuilder::getConjuredSymbolVal(void const*, clang::Expr const*, clang::QualType, unsigned int)"},
    {"_ZN5clang4ento11SValBuilder20getMetadataSymbolValEPKvPKNS0_9MemRegionEPKNS_4ExprENS_8QualTypeEj", "clang::ento::SValBuilder::getMetadataSymbolVal(void const*, clang::ento::MemRegion const*, clang::Expr const*, clang::QualType, unsigned int)"},
    {"_ZN5clang4ento11SValBuilder30getDerivedRegionValueSymbolValEPKNS0_10SymbolDataEPKNS0_11TypedRegionE", "clang::ento::SValBuilder::getDerivedRegionValueSymbolVal(clang::ento::SymbolData const*, clang::ento::TypedRegion const*)"},
    {"_ZN5clang4ento11SValBuilder18getFunctionPointerEPKNS_12FunctionDeclE", "clang::ento::SValBuilder::getFunctionPointer(clang::FunctionDecl const*)"},
    {"_ZN5clang4ento11SValBuilder15getBlockPointerEPKNS_9BlockDeclENS_7CanQualINS_4TypeEEEPKNS_15LocationContextE", "clang::ento::SValBuilder::getBlockPointer(clang::BlockDecl const*, clang::CanQual<clang::Type>, clang::LocationContext const*)"},
    {"_ZN5clang4ento11SValBuilder9evalBinOpEPKNS0_7GRStateENS_18BinaryOperatorKindENS0_4SValES6_NS_8QualTypeE", "clang::ento::SValBuilder::evalBinOp(clang::ento::GRState const*, clang::BinaryOperatorKind, clang::ento::SVal, clang::ento::SVal, clang::QualType)"},
    {"_ZN5clang4ento11SValBuilder6evalEQEPKNS0_7GRStateENS0_20DefinedOrUnknownSValES5_", "clang::ento::SValBuilder::evalEQ(clang::ento::GRState const*, clang::ento::DefinedOrUnknownSVal, clang::ento::DefinedOrUnknownSVal)"},
    {"_ZN5clang4ento11SValBuilder8evalCastENS0_4SValENS_8QualTypeES3_", "clang::ento::SValBuilder::evalCast(clang::ento::SVal, clang::QualType, clang::QualType)"},
    {"_ZNK5clang4ento4SVal17hasConjuredSymbolEv", "clang::ento::SVal::hasConjuredSymbol() const"},
    {"_ZNK5clang4ento4SVal17getAsFunctionDeclEv", "clang::ento::SVal::getAsFunctionDecl() const"},
    {"_ZNK5clang4ento4SVal14getAsLocSymbolEv", "clang::ento::SVal::getAsLocSymbol() const"},
    {"_ZNK5clang4ento3loc12MemRegionVal10StripCastsEv", "clang::ento::loc::MemRegionVal::StripCasts() const"},
    {"_ZNK5clang4ento4SVal18getLocSymbolInBaseEv", "clang::ento::SVal::getLocSymbolInBase() const"},
    {"_ZNK5clang4ento4SVal11getAsSymbolEv", "clang::ento::SVal::getAsSymbol() const"},
    {"_ZNK5clang4ento4SVal23getAsSymbolicExpressionEv", "clang::ento::SVal::getAsSymbolicExpression() const"},
    {"_ZNK5clang4ento4SVal11getAsRegionEv", "clang::ento::SVal::getAsRegion() const"},
    {"_ZNK5clang4ento4SVal15symbol_iteratoreqERKS2_", "clang::ento::SVal::symbol_iterator::operator==(clang::ento::SVal::symbol_iterator const&) const"},
    {"_ZNK5clang4ento4SVal15symbol_iteratorneERKS2_", "clang::ento::SVal::symbol_iterator::operator!=(clang::ento::SVal::symbol_iterator const&) const"},
    {"_ZN5clang4ento4SVal15symbol_iteratorC1EPKNS0_7SymExprE", "clang::ento::SVal::symbol_iterator::symbol_iterator(clang::ento::SymExpr const*)"},
    {"_ZN5clang4ento4SVal15symbol_iteratorC2EPKNS0_7SymExprE", "clang::ento::SVal::symbol_iterator::symbol_iterator(clang::ento::SymExpr const*)"},
    {"_ZN5clang4ento4SVal15symbol_iterator6expandEv", "clang::ento::SVal::symbol_iterator::expand()"},
    {"_ZN5clang4ento4SVal15symbol_iteratorppEv", "clang::ento::SVal::symbol_iterator::operator++()"},
    {"_ZN5clang4ento4SVal15symbol_iteratordeEv", "clang::ento::SVal::symbol_iterator::operator*()"},
    {"_ZNK5clang4ento6nonloc15LazyCompoundVal8getStoreEv", "clang::ento::nonloc::LazyCompoundVal::getStore() const"},
    {"_ZNK5clang4ento6nonloc15LazyCompoundVal9getRegionEv", "clang::ento::nonloc::LazyCompoundVal::getRegion() const"},
    {"_ZNK5clang4ento6nonloc11CompoundVal5beginEv", "clang::ento::nonloc::CompoundVal::begin() const"},
    {"_ZNK5clang4ento6nonloc11CompoundVal3endEv", "clang::ento::nonloc::CompoundVal::end() const"},
    {"_ZNK5clang4ento4SVal10isConstantEv", "clang::ento::SVal::isConstant() const"},
    {"_ZNK5clang4ento4SVal10isConstantEi", "clang::ento::SVal::isConstant(int) const"},
    {"_ZNK5clang4ento4SVal14isZeroConstantEv", "clang::ento::SVal::isZeroConstant() const"},
    {"_ZNK5clang4ento6nonloc11ConcreteInt9evalBinOpERNS0_11SValBuilderENS_18BinaryOperatorKindERKS2_", "clang::ento::nonloc::ConcreteInt::evalBinOp(clang::ento::SValBuilder&, clang::BinaryOperatorKind, clang::ento::nonloc::ConcreteInt const&) const"},
    {"_ZNK5clang4ento6nonloc11ConcreteInt14evalComplementERNS0_11SValBuilderE", "clang::ento::nonloc::ConcreteInt::evalComplement(clang::ento::SValBuilder&) const"},
    {"_ZNK5clang4ento6nonloc11ConcreteInt9evalMinusERNS0_11SValBuilderE", "clang::ento::nonloc::ConcreteInt::evalMinus(clang::ento::SValBuilder&) const"},
    {"_ZNK5clang4ento3loc11ConcreteInt9evalBinOpERNS0_17BasicValueFactoryENS_18BinaryOperatorKindERKS2_", "clang::ento::loc::ConcreteInt::evalBinOp(clang::ento::BasicValueFactory&, clang::BinaryOperatorKind, clang::ento::loc::ConcreteInt const&) const"},
    {"_ZNK5clang4ento4SVal4dumpEv", "clang::ento::SVal::dump() const"},
    {"_ZNK5clang4ento4SVal12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::SVal::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento6NonLoc12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::NonLoc::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento3Loc12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::Loc::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZN5clang4ento23SimpleConstraintManagerD0Ev", "clang::ento::SimpleConstraintManager::~SimpleConstraintManager()"},
    {"_ZN5clang4ento23SimpleConstraintManagerD1Ev", "clang::ento::SimpleConstraintManager::~SimpleConstraintManager()"},
    {"_ZN5clang4ento23SimpleConstraintManagerD2Ev", "clang::ento::SimpleConstraintManager::~SimpleConstraintManager()"},
    {"_ZNK5clang4ento23SimpleConstraintManager14canReasonAboutENS0_4SValE", "clang::ento::SimpleConstraintManager::canReasonAbout(clang::ento::SVal) const"},
    {"_ZN5clang4ento23SimpleConstraintManager6assumeEPKNS0_7GRStateENS0_11DefinedSValEb", "clang::ento::SimpleConstraintManager::assume(clang::ento::GRState const*, clang::ento::DefinedSVal, bool)"},
    {"_ZN5clang4ento23SimpleConstraintManager6assumeEPKNS0_7GRStateENS0_6NonLocEb", "clang::ento::SimpleConstraintManager::assume(clang::ento::GRState const*, clang::ento::NonLoc, bool)"},
    {"_ZN5clang4ento23SimpleConstraintManager6assumeEPKNS0_7GRStateENS0_3LocEb", "clang::ento::SimpleConstraintManager::assume(clang::ento::GRState const*, clang::ento::Loc, bool)"},
    {"_ZN5clang4ento23SimpleConstraintManager9assumeAuxEPKNS0_7GRStateENS0_3LocEb", "clang::ento::SimpleConstraintManager::assumeAux(clang::ento::GRState const*, clang::ento::Loc, bool)"},
    {"_ZN5clang4ento23SimpleConstraintManager9assumeAuxEPKNS0_7GRStateENS0_6NonLocEb", "clang::ento::SimpleConstraintManager::assumeAux(clang::ento::GRState const*, clang::ento::NonLoc, bool)"},
    {"_ZN5clang4ento23SimpleConstraintManager12assumeSymRelEPKNS0_7GRStateEPKNS0_7SymExprENS_18BinaryOperatorKindERKN4llvm6APSIntE", "clang::ento::SimpleConstraintManager::assumeSymRel(clang::ento::GRState const*, clang::ento::SymExpr const*, clang::BinaryOperatorKind, llvm::APSInt const&)"},
    {"_ZN5clang4ento23createSimpleSValBuilderERN4llvm16BumpPtrAllocatorERNS_10ASTContextERNS0_14GRStateManagerE", "clang::ento::createSimpleSValBuilder(llvm::BumpPtrAllocator&, clang::ASTContext&, clang::ento::GRStateManager&)"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilder10evalCastNLEN5clang4ento6NonLocENS1_8QualTypeE", "(anonymous namespace)::SimpleSValBuilder::evalCastNL(clang::ento::NonLoc, clang::QualType)"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilder9evalCastLEN5clang4ento3LocENS1_8QualTypeE", "(anonymous namespace)::SimpleSValBuilder::evalCastL(clang::ento::Loc, clang::QualType)"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilderD1Ev", "(anonymous namespace)::SimpleSValBuilder::~SimpleSValBuilder()"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilderD0Ev", "(anonymous namespace)::SimpleSValBuilder::~SimpleSValBuilder()"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilder9evalMinusEN5clang4ento6NonLocE", "(anonymous namespace)::SimpleSValBuilder::evalMinus(clang::ento::NonLoc)"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilder14evalComplementEN5clang4ento6NonLocE", "(anonymous namespace)::SimpleSValBuilder::evalComplement(clang::ento::NonLoc)"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilder11evalBinOpNNEPKN5clang4ento7GRStateENS1_18BinaryOperatorKindENS2_6NonLocES7_NS1_8QualTypeE", "(anonymous namespace)::SimpleSValBuilder::evalBinOpNN(clang::ento::GRState const*, clang::BinaryOperatorKind, clang::ento::NonLoc, clang::ento::NonLoc, clang::QualType)"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilder11evalBinOpLLEPKN5clang4ento7GRStateENS1_18BinaryOperatorKindENS2_3LocES7_NS1_8QualTypeE", "(anonymous namespace)::SimpleSValBuilder::evalBinOpLL(clang::ento::GRState const*, clang::BinaryOperatorKind, clang::ento::Loc, clang::ento::Loc, clang::QualType)"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilder11evalBinOpLNEPKN5clang4ento7GRStateENS1_18BinaryOperatorKindENS2_3LocENS2_6NonLocENS1_8QualTypeE", "(anonymous namespace)::SimpleSValBuilder::evalBinOpLN(clang::ento::GRState const*, clang::BinaryOperatorKind, clang::ento::Loc, clang::ento::NonLoc, clang::QualType)"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilder13getKnownValueEPKN5clang4ento7GRStateENS2_4SValE", "(anonymous namespace)::SimpleSValBuilder::getKnownValue(clang::ento::GRState const*, clang::ento::SVal)"},
    {"_ZN12_GLOBAL__N_117SimpleSValBuilder13MakeSymIntValEPKN5clang4ento7SymExprENS1_18BinaryOperatorKindERKN4llvm6APSIntENS1_8QualTypeE", "(anonymous namespace)::SimpleSValBuilder::MakeSymIntVal(clang::ento::SymExpr const*, clang::BinaryOperatorKind, llvm::APSInt const&, clang::QualType)"},
    {"_ZN5clang4ento11SValBuilderC2ERN4llvm16BumpPtrAllocatorERNS_10ASTContextERNS0_14GRStateManagerE", "clang::ento::SValBuilder::SValBuilder(llvm::BumpPtrAllocator&, clang::ASTContext&, clang::ento::GRStateManager&)"},
    {"_ZN5clang4ento11SValBuilderD1Ev", "clang::ento::SValBuilder::~SValBuilder()"},
    {"_ZN5clang4ento11SValBuilderD0Ev", "clang::ento::SValBuilder::~SValBuilder()"},
    {"_ZN5clang4ento16MemRegionManagerC2ERNS_10ASTContextERN4llvm16BumpPtrAllocatorE", "clang::ento::MemRegionManager::MemRegionManager(clang::ASTContext&, llvm::BumpPtrAllocator&)"},
    {"_ZN5clang4ento12StoreManagerC1ERNS0_14GRStateManagerE", "clang::ento::StoreManager::StoreManager(clang::ento::GRStateManager&)"},
    {"_ZN5clang4ento12StoreManagerC2ERNS0_14GRStateManagerE", "clang::ento::StoreManager::StoreManager(clang::ento::GRStateManager&)"},
    {"_ZN5clang4ento12StoreManager15enterStackFrameEPKNS0_7GRStateEPKNS_17StackFrameContextE", "clang::ento::StoreManager::enterStackFrame(clang::ento::GRState const*, clang::StackFrameContext const*)"},
    {"_ZN5clang4ento12StoreManager17MakeElementRegionEPKNS0_9MemRegionENS_8QualTypeEy", "clang::ento::StoreManager::MakeElementRegion(clang::ento::MemRegion const*, clang::QualType, unsigned long long)"},
    {"_ZN5clang4ento12StoreManager20GetElementZeroRegionEPKNS0_9MemRegionENS_8QualTypeE", "clang::ento::StoreManager::GetElementZeroRegion(clang::ento::MemRegion const*, clang::QualType)"},
    {"_ZN5clang4ento12StoreManager10CastRegionEPKNS0_9MemRegionENS_8QualTypeE", "clang::ento::StoreManager::CastRegion(clang::ento::MemRegion const*, clang::QualType)"},
    {"_ZN5clang4ento12StoreManager16CastRetrievedValENS0_4SValEPKNS0_11TypedRegionENS_8QualTypeEb", "clang::ento::StoreManager::CastRetrievedVal(clang::ento::SVal, clang::ento::TypedRegion const*, clang::QualType, bool)"},
    {"_ZN5clang4ento12StoreManager20getLValueFieldOrIvarEPKNS_4DeclENS0_4SValE", "clang::ento::StoreManager::getLValueFieldOrIvar(clang::Decl const*, clang::ento::SVal)"},
    {"_ZN5clang4ento12StoreManager16getLValueElementENS_8QualTypeENS0_6NonLocENS0_4SValE", "clang::ento::StoreManager::getLValueElement(clang::QualType, clang::ento::NonLoc, clang::ento::SVal)"},
    {"_ZNK5clang4ento7SymExpr4dumpEv", "clang::ento::SymExpr::dump() const"},
    {"_ZNK5clang4ento10SymIntExpr12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::SymIntExpr::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento10SymSymExpr12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::SymSymExpr::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento14SymbolConjured12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::SymbolConjured::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento13SymbolDerived12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::SymbolDerived::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento12SymbolExtent12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::SymbolExtent::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento14SymbolMetadata12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::SymbolMetadata::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZNK5clang4ento17SymbolRegionValue12dumpToStreamERN4llvm11raw_ostreamE", "clang::ento::SymbolRegionValue::dumpToStream(llvm::raw_ostream&) const"},
    {"_ZN5clang4ento13SymbolManager20getRegionValueSymbolEPKNS0_11TypedRegionE", "clang::ento::SymbolManager::getRegionValueSymbol(clang::ento::TypedRegion const*)"},
    {"_ZN5clang4ento13SymbolManager17getConjuredSymbolEPKNS_4StmtENS_8QualTypeEjPKv", "clang::ento::SymbolManager::getConjuredSymbol(clang::Stmt const*, clang::QualType, unsigned int, void const*)"},
    {"_ZN5clang4ento13SymbolManager16getDerivedSymbolEPKNS0_10SymbolDataEPKNS0_11TypedRegionE", "clang::ento::SymbolManager::getDerivedSymbol(clang::ento::SymbolData const*, clang::ento::TypedRegion const*)"},
    {"_ZN5clang4ento13SymbolManager15getExtentSymbolEPKNS0_9SubRegionE", "clang::ento::SymbolManager::getExtentSymbol(clang::ento::SubRegion const*)"},
    {"_ZN5clang4ento13SymbolManager17getMetadataSymbolEPKNS0_9MemRegionEPKNS_4StmtENS_8QualTypeEjPKv", "clang::ento::SymbolManager::getMetadataSymbol(clang::ento::MemRegion const*, clang::Stmt const*, clang::QualType, unsigned int, void const*)"},
    {"_ZN5clang4ento13SymbolManager13getSymIntExprEPKNS0_7SymExprENS_18BinaryOperatorKindERKN4llvm6APSIntENS_8QualTypeE", "clang::ento::SymbolManager::getSymIntExpr(clang::ento::SymExpr const*, clang::BinaryOperatorKind, llvm::APSInt const&, clang::QualType)"},
    {"_ZN5clang4ento13SymbolManager13getSymSymExprEPKNS0_7SymExprENS_18BinaryOperatorKindES4_NS_8QualTypeE", "clang::ento::SymbolManager::getSymSymExpr(clang::ento::SymExpr const*, clang::BinaryOperatorKind, clang::ento::SymExpr const*, clang::QualType)"},
    {"_ZNK5clang4ento14SymbolConjured7getTypeERNS_10ASTContextE", "clang::ento::SymbolConjured::getType(clang::ASTContext&) const"},
    {"_ZNK5clang4ento13SymbolDerived7getTypeERNS_10ASTContextE", "clang::ento::SymbolDerived::getType(clang::ASTContext&) const"},
    {"_ZNK5clang4ento12SymbolExtent7getTypeERNS_10ASTContextE", "clang::ento::SymbolExtent::getType(clang::ASTContext&) const"},
    {"_ZNK5clang4ento14SymbolMetadata7getTypeERNS_10ASTContextE", "clang::ento::SymbolMetadata::getType(clang::ASTContext&) const"},
    {"_ZNK5clang4ento17SymbolRegionValue7getTypeERNS_10ASTContextE", "clang::ento::SymbolRegionValue::getType(clang::ASTContext&) const"},
    {"_ZN5clang4ento13SymbolManagerD1Ev", "clang::ento::SymbolManager::~SymbolManager()"},
    {"_ZN5clang4ento13SymbolManagerD2Ev", "clang::ento::SymbolManager::~SymbolManager()"},
    {"_ZN5clang4ento13SymbolManager14canSymbolicateENS_8QualTypeE", "clang::ento::SymbolManager::canSymbolicate(clang::QualType)"},
    {"_ZN5clang4ento12SymbolReaper8markLiveEPKNS0_10SymbolDataE", "clang::ento::SymbolReaper::markLive(clang::ento::SymbolData const*)"},
    {"_ZN5clang4ento12SymbolReaper9markInUseEPKNS0_10SymbolDataE", "clang::ento::SymbolReaper::markInUse(clang::ento::SymbolData const*)"},
    {"_ZN5clang4ento12SymbolReaper9maybeDeadEPKNS0_10SymbolDataE", "clang::ento::SymbolReaper::maybeDead(clang::ento::SymbolData const*)"},
    {"_ZN5clang4ento12SymbolReaper6isLiveEPKNS0_10SymbolDataE", "clang::ento::SymbolReaper::isLive(clang::ento::SymbolData const*)"},
    {"_Z12IsLiveRegionRN5clang4ento12SymbolReaperEPKNS0_9MemRegionE", "IsLiveRegion(clang::ento::SymbolReaper&, clang::ento::MemRegion const*)"},
    {"_ZNK5clang4ento12SymbolReaper6isLiveEPKNS_4StmtE", "clang::ento::SymbolReaper::isLive(clang::Stmt const*) const"},
    {"_ZNK5clang4ento12SymbolReaper6isLiveEPKNS0_9VarRegionE", "clang::ento::SymbolReaper::isLive(clang::ento::VarRegion const*) const"},
    {"_ZN5clang4ento13SymbolVisitorD0Ev", "clang::ento::SymbolVisitor::~SymbolVisitor()"},
    {"_ZN5clang4ento13SymbolVisitorD1Ev", "clang::ento::SymbolVisitor::~SymbolVisitor()"},
    {"_ZN5clang4ento13SymbolVisitorD2Ev", "clang::ento::SymbolVisitor::~SymbolVisitor()"},
    {"_ZN4llvm10FoldingSetIN5clang4ento7SymExprEED1Ev", "llvm::FoldingSet<clang::ento::SymExpr>::~FoldingSet()"},
    {"_ZN5clang4ento17SymbolRegionValueD1Ev", "clang::ento::SymbolRegionValue::~SymbolRegionValue()"},
    {"_ZN5clang4ento17SymbolRegionValueD0Ev", "clang::ento::SymbolRegionValue::~SymbolRegionValue()"},
    {"_ZN5clang4ento17SymbolRegionValue7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::SymbolRegionValue::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang4ento14SymbolConjuredD1Ev", "clang::ento::SymbolConjured::~SymbolConjured()"},
    {"_ZN5clang4ento14SymbolConjuredD0Ev", "clang::ento::SymbolConjured::~SymbolConjured()"},
    {"_ZN5clang4ento14SymbolConjured7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::SymbolConjured::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang4ento13SymbolDerivedD1Ev", "clang::ento::SymbolDerived::~SymbolDerived()"},
    {"_ZN5clang4ento13SymbolDerivedD0Ev", "clang::ento::SymbolDerived::~SymbolDerived()"},
    {"_ZN5clang4ento13SymbolDerived7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::SymbolDerived::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang4ento12SymbolExtentD1Ev", "clang::ento::SymbolExtent::~SymbolExtent()"},
    {"_ZN5clang4ento12SymbolExtentD0Ev", "clang::ento::SymbolExtent::~SymbolExtent()"},
    {"_ZN5clang4ento12SymbolExtent7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::SymbolExtent::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang4ento14SymbolMetadataD1Ev", "clang::ento::SymbolMetadata::~SymbolMetadata()"},
    {"_ZN5clang4ento14SymbolMetadataD0Ev", "clang::ento::SymbolMetadata::~SymbolMetadata()"},
    {"_ZN5clang4ento14SymbolMetadata7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::SymbolMetadata::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang4ento10SymIntExprD1Ev", "clang::ento::SymIntExpr::~SymIntExpr()"},
    {"_ZN5clang4ento10SymIntExprD0Ev", "clang::ento::SymIntExpr::~SymIntExpr()"},
    {"_ZNK5clang4ento10SymIntExpr7getTypeERNS_10ASTContextE", "clang::ento::SymIntExpr::getType(clang::ASTContext&) const"},
    {"_ZN5clang4ento10SymIntExpr7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::SymIntExpr::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang4ento10SymSymExprD1Ev", "clang::ento::SymSymExpr::~SymSymExpr()"},
    {"_ZN5clang4ento10SymSymExprD0Ev", "clang::ento::SymSymExpr::~SymSymExpr()"},
    {"_ZNK5clang4ento10SymSymExpr7getTypeERNS_10ASTContextE", "clang::ento::SymSymExpr::getType(clang::ASTContext&) const"},
    {"_ZN5clang4ento10SymSymExpr7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ento::SymSymExpr::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang4ento7SymExprD1Ev", "clang::ento::SymExpr::~SymExpr()"},
    {"_ZN5clang4ento7SymExprD0Ev", "clang::ento::SymExpr::~SymExpr()"},
    {"_ZN5clang4ento10SymbolDataD1Ev", "clang::ento::SymbolData::~SymbolData()"},
    {"_ZN5clang4ento10SymbolDataD0Ev", "clang::ento::SymbolData::~SymbolData()"},
    {"_ZN4llvm10FoldingSetIN5clang4ento7SymExprEED0Ev", "llvm::FoldingSet<clang::ento::SymExpr>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento7SymExprEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::SymExpr>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento7SymExprEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::ento::SymExpr>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang4ento7SymExprEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ento::SymExpr>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang4ento30createTextPathDiagnosticClientERKSsRKNS_12PreprocessorE", "clang::ento::createTextPathDiagnosticClient(std::string const&, clang::Preprocessor const&)"},
    {"_ZN12_GLOBAL__N_119TextPathDiagnosticsD1Ev", "(anonymous namespace)::TextPathDiagnostics::~TextPathDiagnostics()"},
    {"_ZN12_GLOBAL__N_119TextPathDiagnosticsD0Ev", "(anonymous namespace)::TextPathDiagnostics::~TextPathDiagnostics()"},
    {"_ZN12_GLOBAL__N_119TextPathDiagnostics16FlushDiagnosticsEPN4llvm15SmallVectorImplISsEE", "(anonymous namespace)::TextPathDiagnostics::FlushDiagnostics(llvm::SmallVectorImpl<std::string>*)"},
    {"_ZNK12_GLOBAL__N_119TextPathDiagnostics7getNameEv", "(anonymous namespace)::TextPathDiagnostics::getName() const"},
    {"_ZN12_GLOBAL__N_119TextPathDiagnostics20HandlePathDiagnosticEPKN5clang4ento14PathDiagnosticE", "(anonymous namespace)::TextPathDiagnostics::HandlePathDiagnostic(clang::ento::PathDiagnostic const*)"},
    {"_ZNK12_GLOBAL__N_119TextPathDiagnostics19getGenerationSchemeEv", "(anonymous namespace)::TextPathDiagnostics::getGenerationScheme() const"},
    {"_ZNK12_GLOBAL__N_119TextPathDiagnostics28supportsLogicalOpControlFlowEv", "(anonymous namespace)::TextPathDiagnostics::supportsLogicalOpControlFlow() const"},
    {"_ZNK12_GLOBAL__N_119TextPathDiagnostics21supportsAllBlockEdgesEv", "(anonymous namespace)::TextPathDiagnostics::supportsAllBlockEdges() const"},
    {"_ZNK12_GLOBAL__N_119TextPathDiagnostics21useVerboseDescriptionEv", "(anonymous namespace)::TextPathDiagnostics::useVerboseDescription() const"},
    {"_ZN5clang4ento20PathDiagnosticClientD1Ev", "clang::ento::PathDiagnosticClient::~PathDiagnosticClient()"},
    {"_ZN5clang4ento20PathDiagnosticClientD0Ev", "clang::ento::PathDiagnosticClient::~PathDiagnosticClient()"},
    {"_ZNK5clang4ento20PathDiagnosticClient19getGenerationSchemeEv", "clang::ento::PathDiagnosticClient::getGenerationScheme() const"},
    {"_ZNK5clang4ento20PathDiagnosticClient28supportsLogicalOpControlFlowEv", "clang::ento::PathDiagnosticClient::supportsLogicalOpControlFlow() const"},
    {"_ZNK5clang4ento20PathDiagnosticClient21supportsAllBlockEdgesEv", "clang::ento::PathDiagnosticClient::supportsAllBlockEdges() const"},
    {"_ZNK5clang4ento20PathDiagnosticClient21useVerboseDescriptionEv", "clang::ento::PathDiagnosticClient::useVerboseDescription() const"},
    {"_ZN5clang22AnalysisContextManager5clearEv", "clang::AnalysisContextManager::clear()"},
    {"_ZN5clang15AnalysisContextD1Ev", "clang::AnalysisContext::~AnalysisContext()"},
    {"_ZN5clang15AnalysisContext7getBodyEv", "clang::AnalysisContext::getBody()"},
    {"_ZNK5clang15AnalysisContext11getSelfDeclEv", "clang::AnalysisContext::getSelfDecl() const"},
    {"_ZN5clang15AnalysisContext6getCFGEv", "clang::AnalysisContext::getCFG()"},
    {"_ZN5clang15AnalysisContext17getUnoptimizedCFGEv", "clang::AnalysisContext::getUnoptimizedCFG()"},
    {"_ZN5clang15AnalysisContext7dumpCFGEv", "clang::AnalysisContext::dumpCFG()"},
    {"_ZN5clang15AnalysisContext12getParentMapEv", "clang::AnalysisContext::getParentMap()"},
    {"_ZN5clang15AnalysisContext25getPseudoConstantAnalysisEv", "clang::AnalysisContext::getPseudoConstantAnalysis()"},
    {"_ZN5clang15AnalysisContext16getLiveVariablesEv", "clang::AnalysisContext::getLiveVariables()"},
    {"_ZN5clang15AnalysisContext23getRelaxedLiveVariablesEv", "clang::AnalysisContext::getRelaxedLiveVariables()"},
    {"_ZN5clang22AnalysisContextManager10getContextEPKNS_4DeclEPNS_3idx15TranslationUnitE", "clang::AnalysisContextManager::getContext(clang::Decl const*, clang::idx::TranslationUnit*)"},
    {"_ZN5clang15LocationContext13ProfileCommonERN4llvm16FoldingSetNodeIDENS0_11ContextKindEPNS_15AnalysisContextEPKS0_PKv", "clang::LocationContext::ProfileCommon(llvm::FoldingSetNodeID&, clang::LocationContext::ContextKind, clang::AnalysisContext*, clang::LocationContext const*, void const*)"},
    {"_ZN5clang17StackFrameContext7ProfileERN4llvm16FoldingSetNodeIDE", "clang::StackFrameContext::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang12ScopeContext7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ScopeContext::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang22BlockInvocationContext7ProfileERN4llvm16FoldingSetNodeIDE", "clang::BlockInvocationContext::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang22LocationContextManager13getStackFrameEPNS_15AnalysisContextEPKNS_15LocationContextEPKNS_4StmtEPKNS_8CFGBlockEj", "clang::LocationContextManager::getStackFrame(clang::AnalysisContext*, clang::LocationContext const*, clang::Stmt const*, clang::CFGBlock const*, unsigned int)"},
    {"_ZN5clang22LocationContextManager8getScopeEPNS_15AnalysisContextEPKNS_15LocationContextEPKNS_4StmtE", "clang::LocationContextManager::getScope(clang::AnalysisContext*, clang::LocationContext const*, clang::Stmt const*)"},
    {"_ZNK5clang15LocationContext20getCurrentStackFrameEv", "clang::LocationContext::getCurrentStackFrame() const"},
    {"_ZNK5clang15LocationContext27getStackFrameForDeclContextEPKNS_11DeclContextE", "clang::LocationContext::getStackFrameForDeclContext(clang::DeclContext const*) const"},
    {"_ZNK5clang15LocationContext10isParentOfEPKS0_", "clang::LocationContext::isParentOf(clang::LocationContext const*) const"},
    {"_ZN5clang15AnalysisContext22getReferencedBlockVarsEPKNS_9BlockDeclE", "clang::AnalysisContext::getReferencedBlockVars(clang::BlockDecl const*)"},
    {"_ZN5clang15AnalysisContextD2Ev", "clang::AnalysisContext::~AnalysisContext()"},
    {"_ZN5clang22AnalysisContextManagerD1Ev", "clang::AnalysisContextManager::~AnalysisContextManager()"},
    {"_ZN5clang22AnalysisContextManagerD2Ev", "clang::AnalysisContextManager::~AnalysisContextManager()"},
    {"_ZN5clang15LocationContextD0Ev", "clang::LocationContext::~LocationContext()"},
    {"_ZN5clang15LocationContextD1Ev", "clang::LocationContext::~LocationContext()"},
    {"_ZN5clang15LocationContextD2Ev", "clang::LocationContext::~LocationContext()"},
    {"_ZN5clang22LocationContextManagerD1Ev", "clang::LocationContextManager::~LocationContextManager()"},
    {"_ZN5clang22LocationContextManagerD2Ev", "clang::LocationContextManager::~LocationContextManager()"},
    {"_ZN5clang22LocationContextManager5clearEv", "clang::LocationContextManager::clear()"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_125FindBlockDeclRefExprsValsEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::FindBlockDeclRefExprsVals, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_125FindBlockDeclRefExprsVals9VisitStmtEPN5clang4StmtE", "(anonymous namespace)::FindBlockDeclRefExprsVals::VisitStmt(clang::Stmt*)"},
    {"_ZN5clang22LocationContextManager18getLocationContextINS_12ScopeContextENS_4StmtEEEPKT_PNS_15AnalysisContextEPKNS_15LocationContextEPKT0_", "clang::ScopeContext const* clang::LocationContextManager::getLocationContext<clang::ScopeContext, clang::Stmt>(clang::AnalysisContext*, clang::LocationContext const*, clang::Stmt const*)"},
    {"_ZN5clang17StackFrameContextD1Ev", "clang::StackFrameContext::~StackFrameContext()"},
    {"_ZN5clang17StackFrameContextD0Ev", "clang::StackFrameContext::~StackFrameContext()"},
    {"_ZN5clang12ScopeContextD1Ev", "clang::ScopeContext::~ScopeContext()"},
    {"_ZN5clang12ScopeContextD0Ev", "clang::ScopeContext::~ScopeContext()"},
    {"_ZN5clang22BlockInvocationContextD1Ev", "clang::BlockInvocationContext::~BlockInvocationContext()"},
    {"_ZN5clang22BlockInvocationContextD0Ev", "clang::BlockInvocationContext::~BlockInvocationContext()"},
    {"_ZN4llvm8DenseMapIPKN5clang9BlockDeclEPvNS_12DenseMapInfoIS4_EENS6_IS5_EEE16InsertIntoBucketERKS4_RKS5_PSt4pairIS4_S5_E", "llvm::DenseMap<clang::BlockDecl const*, void*, llvm::DenseMapInfo<clang::BlockDecl const*>, llvm::DenseMapInfo<void*>>::InsertIntoBucket(clang::BlockDecl const* const&, void* const&, std::pair<clang::BlockDecl const*, void*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang9BlockDeclEPvNS_12DenseMapInfoIS4_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::BlockDecl const*, void*, llvm::DenseMapInfo<clang::BlockDecl const*>, llvm::DenseMapInfo<void*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclEPNS1_15AnalysisContextENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::Decl const*, clang::AnalysisContext*, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<clang::AnalysisContext*>>::InsertIntoBucket(clang::Decl const* const&, clang::AnalysisContext* const&, std::pair<clang::Decl const*, clang::AnalysisContext*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclEPNS1_15AnalysisContextENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::Decl const*, clang::AnalysisContext*, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<clang::AnalysisContext*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclEPNS1_15AnalysisContextENS_12DenseMapInfoIS4_EENS7_IS6_EEE16shrink_and_clearEv", "llvm::DenseMap<clang::Decl const*, clang::AnalysisContext*, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<clang::AnalysisContext*>>::shrink_and_clear()"},
    {"_ZN5clang14DataflowValuesINS_24LiveVariables_ValueTypesENS_8dataflow21backward_analysis_tagEED2Ev", "clang::DataflowValues<clang::LiveVariables_ValueTypes, clang::dataflow::backward_analysis_tag>::~DataflowValues()"},
    {"_ZN5clang24LiveVariables_ValueTypes14AnalysisDataTyD1Ev", "clang::LiveVariables_ValueTypes::AnalysisDataTy::~AnalysisDataTy()"},
    {"_ZN4llvm8DenseMapIN5clang12ProgramPointENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS2_EENS5_IS4_EEED2Ev", "llvm::DenseMap<clang::ProgramPoint, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::ProgramPoint>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::~DenseMap()"},
    {"_ZN5clang24LiveVariables_ValueTypes14AnalysisDataTyD0Ev", "clang::LiveVariables_ValueTypes::AnalysisDataTy::~AnalysisDataTy()"},
    {"_ZN5clang23StmtDeclBitVector_Types14AnalysisDataTyD1Ev", "clang::StmtDeclBitVector_Types::AnalysisDataTy::~AnalysisDataTy()"},
    {"_ZN5clang23StmtDeclBitVector_Types14AnalysisDataTyD0Ev", "clang::StmtDeclBitVector_Types::AnalysisDataTy::~AnalysisDataTy()"},
    {"_ZN5clang19DeclBitVector_Types14AnalysisDataTyD1Ev", "clang::DeclBitVector_Types::AnalysisDataTy::~AnalysisDataTy()"},
    {"_ZN5clang19DeclBitVector_Types14AnalysisDataTyD0Ev", "clang::DeclBitVector_Types::AnalysisDataTy::~AnalysisDataTy()"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::VarDecl const*, unsigned int, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::VarDecl const* const&, unsigned int const&, std::pair<clang::VarDecl const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::VarDecl const*, unsigned int, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN5clang3CFG11createBlockEv", "clang::CFG::createBlock()"},
    {"_ZN5clang3CFG8buildCFGEPKNS_4DeclEPNS_4StmtEPNS_10ASTContextENS0_12BuildOptionsE", "clang::CFG::buildCFG(clang::Decl const*, clang::Stmt*, clang::ASTContext*, clang::CFG::BuildOptions)"},
    {"_ZN5clang3CFG13getBlkExprNumEPKNS_4StmtE", "clang::CFG::getBlkExprNum(clang::Stmt const*)"},
    {"_Z18PopulateBlkExprMapRN5clang3CFGE", "PopulateBlkExprMap(clang::CFG&)"},
    {"_ZN5clang3CFG14getNumBlkExprsEv", "clang::CFG::getNumBlkExprs()"},
    {"_ZN5clang8CFGBlock10FilterEdgeERKNS0_13FilterOptionsEPKS0_S5_", "clang::CFGBlock::FilterEdge(clang::CFGBlock::FilterOptions const&, clang::CFGBlock const*, clang::CFGBlock const*)"},
    {"_ZN5clang3CFGD1Ev", "clang::CFG::~CFG()"},
    {"_ZN5clang3CFGD2Ev", "clang::CFG::~CFG()"},
    {"_ZNK5clang3CFG4dumpERKNS_11LangOptionsE", "clang::CFG::dump(clang::LangOptions const&) const"},
    {"_ZNK5clang3CFG5printERN4llvm11raw_ostreamERKNS_11LangOptionsE", "clang::CFG::print(llvm::raw_ostream&, clang::LangOptions const&) const"},
    {"_ZN12_GLOBAL__N_117StmtPrinterHelperC1EPKN5clang3CFGERKNS1_11LangOptionsE", "(anonymous namespace)::StmtPrinterHelper::StmtPrinterHelper(clang::CFG const*, clang::LangOptions const&)"},
    {"_Z11print_blockRN4llvm11raw_ostreamEPKN5clang3CFGERKNS2_8CFGBlockEPN12_GLOBAL__N_117StmtPrinterHelperEb", "print_block(llvm::raw_ostream&, clang::CFG const*, clang::CFGBlock const&, (anonymous namespace)::StmtPrinterHelper*, bool)"},
    {"_ZN12_GLOBAL__N_117StmtPrinterHelperD1Ev", "(anonymous namespace)::StmtPrinterHelper::~StmtPrinterHelper()"},
    {"_ZNK5clang8CFGBlock4dumpEPKNS_3CFGERKNS_11LangOptionsE", "clang::CFGBlock::dump(clang::CFG const*, clang::LangOptions const&) const"},
    {"_ZNK5clang8CFGBlock5printERN4llvm11raw_ostreamEPKNS_3CFGERKNS_11LangOptionsE", "clang::CFGBlock::print(llvm::raw_ostream&, clang::CFG const*, clang::LangOptions const&) const"},
    {"_ZNK5clang8CFGBlock15printTerminatorERN4llvm11raw_ostreamERKNS_11LangOptionsE", "clang::CFGBlock::printTerminator(llvm::raw_ostream&, clang::LangOptions const&) const"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_123CFGBlockTerminatorPrintEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::CFGBlockTerminatorPrint, void>::Visit(clang::Stmt*)"},
    {"_ZN5clang8CFGBlock22getTerminatorConditionEv", "clang::CFGBlock::getTerminatorCondition()"},
    {"_ZNK5clang8CFGBlock25hasBinaryBranchTerminatorEv", "clang::CFGBlock::hasBinaryBranchTerminator() const"},
    {"_ZNK5clang3CFG7viewCFGERKNS_11LangOptionsE", "clang::CFG::viewCFG(clang::LangOptions const&) const"},
    {"_ZN12_GLOBAL__N_123CFGBlockTerminatorPrint19VisitBinaryOperatorEPN5clang14BinaryOperatorE", "(anonymous namespace)::CFGBlockTerminatorPrint::VisitBinaryOperator(clang::BinaryOperator*)"},
    {"_ZN12_GLOBAL__N_117StmtPrinterHelperD0Ev", "(anonymous namespace)::StmtPrinterHelper::~StmtPrinterHelper()"},
    {"_ZN12_GLOBAL__N_117StmtPrinterHelper11handledStmtEPN5clang4StmtERN4llvm11raw_ostreamE", "(anonymous namespace)::StmtPrinterHelper::handledStmt(clang::Stmt*, llvm::raw_ostream&)"},
    {"_Z22FindSubExprAssignmentsPN5clang4StmtERN4llvm11SmallPtrSetIPNS_4ExprELj50EEE", "FindSubExprAssignments(clang::Stmt*, llvm::SmallPtrSet<clang::Expr*, 50u>&)"},
    {"_ZN12_GLOBAL__N_110CFGBuilder22VisitForTemporaryDtorsEPN5clang4StmtEb", "(anonymous namespace)::CFGBuilder::VisitForTemporaryDtors(clang::Stmt*, bool)"},
    {"_ZN12_GLOBAL__N_110CFGBuilder5VisitEPN5clang4StmtENS_13AddStmtChoiceE", "(anonymous namespace)::CFGBuilder::Visit(clang::Stmt*, (anonymous namespace)::AddStmtChoice)"},
    {"_ZN12_GLOBAL__N_110CFGBuilder17VisitCompoundStmtEPN5clang12CompoundStmtE", "(anonymous namespace)::CFGBuilder::VisitCompoundStmt(clang::CompoundStmt*)"},
    {"_ZN12_GLOBAL__N_110CFGBuilder17VisitCXXCatchStmtEPN5clang12CXXCatchStmtE", "(anonymous namespace)::CFGBuilder::VisitCXXCatchStmt(clang::CXXCatchStmt*)"},
    {"_ZN12_GLOBAL__N_110CFGBuilder23addLocalScopeForVarDeclEPN5clang7VarDeclEPNS_10LocalScopeE", "(anonymous namespace)::CFGBuilder::addLocalScopeForVarDecl(clang::VarDecl*, (anonymous namespace)::LocalScope*)"},
    {"_ZN12_GLOBAL__N_110CFGBuilder20addAutomaticObjDtorsENS_10LocalScope14const_iteratorES2_PN5clang4StmtE", "(anonymous namespace)::CFGBuilder::addAutomaticObjDtors((anonymous namespace)::LocalScope::const_iterator, (anonymous namespace)::LocalScope::const_iterator, clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_110CFGBuilder20addLocalScopeForStmtEPN5clang4StmtE", "(anonymous namespace)::CFGBuilder::addLocalScopeForStmt(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_110CFGBuilder16VisitDeclSubExprEPN5clang8DeclStmtE", "(anonymous namespace)::CFGBuilder::VisitDeclSubExpr(clang::DeclStmt*)"},
    {"_ZN12_GLOBAL__N_110CFGBuilder13VisitChildrenEPN5clang4StmtE", "(anonymous namespace)::CFGBuilder::VisitChildren(clang::Stmt*)"},
    {"_ZN4llvm14format_object1IjED1Ev", "llvm::format_object1<unsigned int>::~format_object1()"},
    {"_ZNK4llvm14format_object1IjE7snprintEPcj", "llvm::format_object1<unsigned int>::snprint(char*, unsigned int) const"},
    {"_ZN4llvm14format_object1IjED0Ev", "llvm::format_object1<unsigned int>::~format_object1()"},
    {"_ZN4llvm8DenseMapIPN5clang4DeclESt4pairIjjENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PS4_IS3_S5_E", "llvm::DenseMap<clang::Decl*, std::pair<unsigned int, unsigned int>, llvm::DenseMapInfo<clang::Decl*>, llvm::DenseMapInfo<std::pair<unsigned int, unsigned int>>>::InsertIntoBucket(clang::Decl* const&, std::pair<unsigned int, unsigned int> const&, std::pair<clang::Decl*, std::pair<unsigned int, unsigned int>>*)"},
    {"_ZN4llvm8DenseMapIPN5clang4DeclESt4pairIjjENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::Decl*, std::pair<unsigned int, unsigned int>, llvm::DenseMapInfo<clang::Decl*>, llvm::DenseMapInfo<std::pair<unsigned int, unsigned int>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang4StmtESt4pairIjjENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PS4_IS3_S5_E", "llvm::DenseMap<clang::Stmt*, std::pair<unsigned int, unsigned int>, llvm::DenseMapInfo<clang::Stmt*>, llvm::DenseMapInfo<std::pair<unsigned int, unsigned int>>>::InsertIntoBucket(clang::Stmt* const&, std::pair<unsigned int, unsigned int> const&, std::pair<clang::Stmt*, std::pair<unsigned int, unsigned int>>*)"},
    {"_ZN4llvm8DenseMapIPN5clang4StmtESt4pairIjjENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::Stmt*, std::pair<unsigned int, unsigned int>, llvm::DenseMapInfo<clang::Stmt*>, llvm::DenseMapInfo<std::pair<unsigned int, unsigned int>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang4StmtEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::Stmt const*, unsigned int, llvm::DenseMapInfo<clang::Stmt const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::Stmt const* const&, unsigned int const&, std::pair<clang::Stmt const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4StmtEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::Stmt const*, unsigned int, llvm::DenseMapInfo<clang::Stmt const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN4llvm9OwningPtrIN5clang3CFGEED2Ev", "llvm::OwningPtr<clang::CFG>::~OwningPtr()"},
    {"_ZN5clang8CFGBlock12addSuccessorEPS0_RNS_17BumpVectorContextE", "clang::CFGBlock::addSuccessor(clang::CFGBlock*, clang::BumpVectorContext&)"},
    {"_ZN5clang10BumpVectorINS_10CFGElementEE6insertEPS1_mRKS1_RNS_17BumpVectorContextE", "clang::BumpVector<clang::CFGElement>::insert(clang::CFGElement*, unsigned long, clang::CFGElement const&, clang::BumpVectorContext&)"},
    {"_ZN5clang10BumpVectorINS_10CFGElementEE9push_backERKS1_RNS_17BumpVectorContextE", "clang::BumpVector<clang::CFGElement>::push_back(clang::CFGElement const&, clang::BumpVectorContext&)"},
    {"_ZN5clang8CFGBlockC2EjRNS_17BumpVectorContextE", "clang::CFGBlock::CFGBlock(unsigned int, clang::BumpVectorContext&)"},
    {"_ZN5clang10BumpVectorINS_10CFGElementEE7reserveERNS_17BumpVectorContextEj", "clang::BumpVector<clang::CFGElement>::reserve(clang::BumpVectorContext&, unsigned int)"},
    {"_ZN5clang10CFGStmtMapD1Ev", "clang::CFGStmtMap::~CFGStmtMap()"},
    {"_ZN5clang10CFGStmtMapD2Ev", "clang::CFGStmtMap::~CFGStmtMap()"},
    {"_ZN5clang10CFGStmtMap8getBlockEPNS_4StmtE", "clang::CFGStmtMap::getBlock(clang::Stmt*)"},
    {"_ZN5clang10CFGStmtMap5BuildEPNS_3CFGEPNS_9ParentMapE", "clang::CFGStmtMap::Build(clang::CFG*, clang::ParentMap*)"},
    {"_ZN4llvm8DenseMapIPN5clang4StmtEPNS1_8CFGBlockENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::Stmt*, clang::CFGBlock*, llvm::DenseMapInfo<clang::Stmt*>, llvm::DenseMapInfo<clang::CFGBlock*>>::InsertIntoBucket(clang::Stmt* const&, clang::CFGBlock* const&, std::pair<clang::Stmt*, clang::CFGBlock*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang4StmtEPNS1_8CFGBlockENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::Stmt*, clang::CFGBlock*, llvm::DenseMapInfo<clang::Stmt*>, llvm::DenseMapInfo<clang::CFGBlock*>>::grow(unsigned int)"},
    {"_ZN5clang4ento5cocoa22deriveNamingConventionENS_8SelectorEb", "clang::ento::cocoa::deriveNamingConvention(clang::Selector, bool)"},
    {"_Z9parseWordPKc", "parseWord(char const*)"},
    {"_ZN5clang4ento5cocoa9isRefTypeENS_8QualTypeEN4llvm9StringRefES4_", "clang::ento::cocoa::isRefType(clang::QualType, llvm::StringRef, llvm::StringRef)"},
    {"_ZN5clang4ento5cocoa13isCFObjectRefENS_8QualTypeE", "clang::ento::cocoa::isCFObjectRef(clang::QualType)"},
    {"_ZN5clang4ento5cocoa16isCocoaObjectRefENS_8QualTypeE", "clang::ento::cocoa::isCocoaObjectRef(clang::QualType)"},
    {"_ZN5clang21analyze_format_string19FormatStringHandlerD0Ev", "clang::analyze_format_string::FormatStringHandler::~FormatStringHandler()"},
    {"_ZN5clang21analyze_format_string19FormatStringHandlerD1Ev", "clang::analyze_format_string::FormatStringHandler::~FormatStringHandler()"},
    {"_ZN5clang21analyze_format_string19FormatStringHandlerD2Ev", "clang::analyze_format_string::FormatStringHandler::~FormatStringHandler()"},
    {"_ZN5clang21analyze_format_string11ParseAmountERPKcS2_", "clang::analyze_format_string::ParseAmount(char const*&, char const*)"},
    {"_ZN5clang21analyze_format_string22ParseNonPositionAmountERPKcS2_Rj", "clang::analyze_format_string::ParseNonPositionAmount(char const*&, char const*, unsigned int&)"},
    {"_ZN5clang21analyze_format_string19ParsePositionAmountERNS0_19FormatStringHandlerEPKcRS4_S4_NS0_15PositionContextE", "clang::analyze_format_string::ParsePositionAmount(clang::analyze_format_string::FormatStringHandler&, char const*, char const*&, char const*, clang::analyze_format_string::PositionContext)"},
    {"_ZN5clang21analyze_format_string15ParseFieldWidthERNS0_19FormatStringHandlerERNS0_15FormatSpecifierEPKcRS6_S6_Pj", "clang::analyze_format_string::ParseFieldWidth(clang::analyze_format_string::FormatStringHandler&, clang::analyze_format_string::FormatSpecifier&, char const*, char const*&, char const*, unsigned int*)"},
    {"_ZN5clang21analyze_format_string16ParseArgPositionERNS0_19FormatStringHandlerERNS0_15FormatSpecifierEPKcRS6_S6_", "clang::analyze_format_string::ParseArgPosition(clang::analyze_format_string::FormatStringHandler&, clang::analyze_format_string::FormatSpecifier&, char const*, char const*&, char const*)"},
    {"_ZN5clang21analyze_format_string19ParseLengthModifierERNS0_15FormatSpecifierERPKcS4_", "clang::analyze_format_string::ParseLengthModifier(clang::analyze_format_string::FormatSpecifier&, char const*&, char const*)"},
    {"_ZNK5clang21analyze_format_string13ArgTypeResult11matchesTypeERNS_10ASTContextENS_8QualTypeE", "clang::analyze_format_string::ArgTypeResult::matchesType(clang::ASTContext&, clang::QualType) const"},
    {"_ZNK5clang21analyze_format_string13ArgTypeResult21getRepresentativeTypeERNS_10ASTContextE", "clang::analyze_format_string::ArgTypeResult::getRepresentativeType(clang::ASTContext&) const"},
    {"_ZNK5clang21analyze_format_string14OptionalAmount10getArgTypeERNS_10ASTContextE", "clang::analyze_format_string::OptionalAmount::getArgType(clang::ASTContext&) const"},
    {"_ZNK5clang21analyze_format_string14LengthModifier8toStringEv", "clang::analyze_format_string::LengthModifier::toString() const"},
    {"_ZNK5clang21analyze_format_string14OptionalAmount8toStringERN4llvm11raw_ostreamE", "clang::analyze_format_string::OptionalAmount::toString(llvm::raw_ostream&) const"},
    {"_ZNK5clang21analyze_format_string15FormatSpecifier22hasValidLengthModifierEv", "clang::analyze_format_string::FormatSpecifier::hasValidLengthModifier() const"},
    {"_ZN5clang13LiveVariablesC1ERNS_15AnalysisContextEb", "clang::LiveVariables::LiveVariables(clang::AnalysisContext&, bool)"},
    {"_ZN5clang13LiveVariablesC2ERNS_15AnalysisContextEb", "clang::LiveVariables::LiveVariables(clang::AnalysisContext&, bool)"},
    {"_ZN5clang13LiveVariables8runOnCFGERNS_3CFGE", "clang::LiveVariables::runOnCFG(clang::CFG&)"},
    {"_ZN5clang13LiveVariables14runOnAllBlocksERKNS_3CFGEPNS_24LiveVariables_ValueTypes10ObserverTyEb", "clang::LiveVariables::runOnAllBlocks(clang::CFG const&, clang::LiveVariables_ValueTypes::ObserverTy*, bool)"},
    {"_ZNK5clang13LiveVariables6isLiveEPKNS_8CFGBlockEPKNS_7VarDeclE", "clang::LiveVariables::isLive(clang::CFGBlock const*, clang::VarDecl const*) const"},
    {"_ZNK5clang13LiveVariables6isLiveERKNS_23StmtDeclBitVector_Types5ValTyEPKNS_7VarDeclE", "clang::LiveVariables::isLive(clang::StmtDeclBitVector_Types::ValTy const&, clang::VarDecl const*) const"},
    {"_ZNK5clang13LiveVariables6isLiveEPKNS_4StmtES3_", "clang::LiveVariables::isLive(clang::Stmt const*, clang::Stmt const*) const"},
    {"_ZNK5clang13LiveVariables6isLiveEPKNS_4StmtEPKNS_7VarDeclE", "clang::LiveVariables::isLive(clang::Stmt const*, clang::VarDecl const*) const"},
    {"_ZNK5clang13LiveVariables12dumpLivenessERKNS_23StmtDeclBitVector_Types5ValTyERKNS_13SourceManagerE", "clang::LiveVariables::dumpLiveness(clang::StmtDeclBitVector_Types::ValTy const&, clang::SourceManager const&) const"},
    {"_ZNK5clang13LiveVariables17dumpBlockLivenessERKNS_13SourceManagerE", "clang::LiveVariables::dumpBlockLiveness(clang::SourceManager const&) const"},
    {"_ZN5clang14DataflowSolverINS_13LiveVariablesEN12_GLOBAL__N_113TransferFuncsENS_23StmtDeclBitVector_Types5UnionESt8equal_toINS4_5ValTyEEE12ProcessBlockEPKNS_8CFGBlockEbNS_8dataflow21backward_analysis_tagE", "clang::DataflowSolver<clang::LiveVariables, (anonymous namespace)::TransferFuncs, clang::StmtDeclBitVector_Types::Union, std::equal_to<clang::StmtDeclBitVector_Types::ValTy>>::ProcessBlock(clang::CFGBlock const*, bool, clang::dataflow::backward_analysis_tag)"},
    {"_ZN12_GLOBAL__N_113TransferFuncs5VisitEPN5clang4StmtE", "(anonymous namespace)::TransferFuncs::Visit(clang::Stmt*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_113TransferFuncsEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::TransferFuncs, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_113TransferFuncs18VisitUnaryOperatorEPN5clang13UnaryOperatorE", "(anonymous namespace)::TransferFuncs::VisitUnaryOperator(clang::UnaryOperator*)"},
    {"_ZN5clang14CFGStmtVisitorIN12_GLOBAL__N_113TransferFuncsEvE13VisitChildrenEPNS_4StmtE", "clang::CFGStmtVisitor<(anonymous namespace)::TransferFuncs, void>::VisitChildren(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_113TransferFuncs11VisitAssignEPN5clang14BinaryOperatorE", "(anonymous namespace)::TransferFuncs::VisitAssign(clang::BinaryOperator*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_113RegisterDeclsEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::RegisterDecls, void>::Visit(clang::Stmt*)"},
    {"_ZN5clang14CFGStmtVisitorIN12_GLOBAL__N_113RegisterDeclsEvE13VisitChildrenEPNS_4StmtE", "clang::CFGStmtVisitor<(anonymous namespace)::RegisterDecls, void>::VisitChildren(clang::Stmt*)"},
    {"_ZN5clang21CFGRecStmtDeclVisitorIN12_GLOBAL__N_113RegisterDeclsEE9VisitDeclEPNS_4DeclE", "clang::CFGRecStmtDeclVisitor<(anonymous namespace)::RegisterDecls>::VisitDecl(clang::Decl*)"},
    {"_ZN5clang14DataflowValuesINS_24LiveVariables_ValueTypesENS_8dataflow21backward_analysis_tagEEC2Ev", "clang::DataflowValues<clang::LiveVariables_ValueTypes, clang::dataflow::backward_analysis_tag>::DataflowValues()"},
    {"_ZN5clang21analyze_format_string17ParsePrintfStringERNS0_19FormatStringHandlerEPKcS4_", "clang::analyze_format_string::ParsePrintfString(clang::analyze_format_string::FormatStringHandler&, char const*, char const*)"},
    {"_ZNK5clang21analyze_format_string19ConversionSpecifier8toStringEv", "clang::analyze_format_string::ConversionSpecifier::toString() const"},
    {"_ZNK5clang14analyze_printf15PrintfSpecifier10getArgTypeERNS_10ASTContextE", "clang::analyze_printf::PrintfSpecifier::getArgType(clang::ASTContext&) const"},
    {"_ZN5clang14analyze_printf15PrintfSpecifier7fixTypeENS_8QualTypeE", "clang::analyze_printf::PrintfSpecifier::fixType(clang::QualType)"},
    {"_ZNK5clang14analyze_printf15PrintfSpecifier8toStringERN4llvm11raw_ostreamE", "clang::analyze_printf::PrintfSpecifier::toString(llvm::raw_ostream&) const"},
    {"_ZNK5clang14analyze_printf15PrintfSpecifier18hasValidPlusPrefixEv", "clang::analyze_printf::PrintfSpecifier::hasValidPlusPrefix() const"},
    {"_ZNK5clang14analyze_printf15PrintfSpecifier23hasValidAlternativeFormEv", "clang::analyze_printf::PrintfSpecifier::hasValidAlternativeForm() const"},
    {"_ZNK5clang14analyze_printf15PrintfSpecifier20hasValidLeadingZerosEv", "clang::analyze_printf::PrintfSpecifier::hasValidLeadingZeros() const"},
    {"_ZNK5clang14analyze_printf15PrintfSpecifier19hasValidSpacePrefixEv", "clang::analyze_printf::PrintfSpecifier::hasValidSpacePrefix() const"},
    {"_ZNK5clang14analyze_printf15PrintfSpecifier21hasValidLeftJustifiedEv", "clang::analyze_printf::PrintfSpecifier::hasValidLeftJustified() const"},
    {"_ZNK5clang14analyze_printf15PrintfSpecifier31hasValidThousandsGroupingPrefixEv", "clang::analyze_printf::PrintfSpecifier::hasValidThousandsGroupingPrefix() const"},
    {"_ZNK5clang14analyze_printf15PrintfSpecifier17hasValidPrecisionEv", "clang::analyze_printf::PrintfSpecifier::hasValidPrecision() const"},
    {"_ZNK5clang14analyze_printf15PrintfSpecifier18hasValidFieldWidthEv", "clang::analyze_printf::PrintfSpecifier::hasValidFieldWidth() const"},
    {"_ZN5clang22PseudoConstantAnalysisC1EPKNS_4StmtE", "clang::PseudoConstantAnalysis::PseudoConstantAnalysis(clang::Stmt const*)"},
    {"_ZN5clang22PseudoConstantAnalysisC2EPKNS_4StmtE", "clang::PseudoConstantAnalysis::PseudoConstantAnalysis(clang::Stmt const*)"},
    {"_ZN5clang22PseudoConstantAnalysisD1Ev", "clang::PseudoConstantAnalysis::~PseudoConstantAnalysis()"},
    {"_ZN5clang22PseudoConstantAnalysisD2Ev", "clang::PseudoConstantAnalysis::~PseudoConstantAnalysis()"},
    {"_ZN5clang22PseudoConstantAnalysis16isPseudoConstantEPKNS_7VarDeclE", "clang::PseudoConstantAnalysis::isPseudoConstant(clang::VarDecl const*)"},
    {"_ZN5clang22PseudoConstantAnalysis11RunAnalysisEv", "clang::PseudoConstantAnalysis::RunAnalysis()"},
    {"_ZN5clang22PseudoConstantAnalysis13wasReferencedEPKNS_7VarDeclE", "clang::PseudoConstantAnalysis::wasReferenced(clang::VarDecl const*)"},
    {"_ZN5clang14reachable_code22ScanReachableFromBlockERKNS_8CFGBlockERN4llvm9BitVectorE", "clang::reachable_code::ScanReachableFromBlock(clang::CFGBlock const&, llvm::BitVector&)"},
    {"_ZN5clang14reachable_code19FindUnreachableCodeERNS_15AnalysisContextERNS0_8CallbackE", "clang::reachable_code::FindUnreachableCode(clang::AnalysisContext&, clang::reachable_code::Callback&)"},
    {"_Z17GetUnreachableLocRKN5clang8CFGBlockERNS_11SourceRangeES4_", "GetUnreachableLoc(clang::CFGBlock const&, clang::SourceRange&, clang::SourceRange&)"},
    {"_ZN4llvm15SmallVectorImplIN12_GLOBAL__N_16ErrLocEE9push_backERKS2_", "llvm::SmallVectorImpl<(anonymous namespace)::ErrLoc>::push_back((anonymous namespace)::ErrLoc const&)"},
    {"_Z7LineCmpPKvS0_", "LineCmp(void const*, void const*)"},
    {"_ZN5clang21analyze_format_string16ParseScanfStringERNS0_19FormatStringHandlerEPKcS4_", "clang::analyze_format_string::ParseScanfString(clang::analyze_format_string::FormatStringHandler&, char const*, char const*)"},
    {"_ZN5clang19UninitializedValues16InitializeValuesERKNS_3CFGE", "clang::UninitializedValues::InitializeValues(clang::CFG const&)"},
    {"_ZN5clang30UninitializedValues_ValueTypes10ObserverTyD0Ev", "clang::UninitializedValues_ValueTypes::ObserverTy::~ObserverTy()"},
    {"_ZN5clang30UninitializedValues_ValueTypes10ObserverTyD1Ev", "clang::UninitializedValues_ValueTypes::ObserverTy::~ObserverTy()"},
    {"_ZN5clang30UninitializedValues_ValueTypes10ObserverTyD2Ev", "clang::UninitializedValues_ValueTypes::ObserverTy::~ObserverTy()"},
    {"_ZN5clang24CheckUninitializedValuesERNS_3CFGERNS_10ASTContextERNS_10DiagnosticEb", "clang::CheckUninitializedValues(clang::CFG&, clang::ASTContext&, clang::Diagnostic&, bool)"},
    {"_ZN12_GLOBAL__N_126UninitializedValuesCheckerD1Ev", "(anonymous namespace)::UninitializedValuesChecker::~UninitializedValuesChecker()"},
    {"_ZN5clang14DataflowSolverINS_19UninitializedValuesEN12_GLOBAL__N_113TransferFuncsENS_23StmtDeclBitVector_Types5UnionESt8equal_toINS4_5ValTyEEE12ProcessBlockEPKNS_8CFGBlockEbNS_8dataflow20forward_analysis_tagE", "clang::DataflowSolver<clang::UninitializedValues, (anonymous namespace)::TransferFuncs, clang::StmtDeclBitVector_Types::Union, std::equal_to<clang::StmtDeclBitVector_Types::ValTy>>::ProcessBlock(clang::CFGBlock const*, bool, clang::dataflow::forward_analysis_tag)"},
    {"_ZN12_GLOBAL__N_113TransferFuncs19BlockStmt_VisitExprEPN5clang4ExprE", "(anonymous namespace)::TransferFuncs::BlockStmt_VisitExpr(clang::Expr*)"},
    {"_ZN5clang14CFGStmtVisitorIN12_GLOBAL__N_113TransferFuncsEbE5VisitEPNS_4StmtE", "clang::CFGStmtVisitor<(anonymous namespace)::TransferFuncs, bool>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_113TransferFuncs19VisitBinaryOperatorEPN5clang14BinaryOperatorE", "(anonymous namespace)::TransferFuncs::VisitBinaryOperator(clang::BinaryOperator*)"},
    {"_ZN12_GLOBAL__N_113TransferFuncs18VisitUnaryOperatorEPN5clang13UnaryOperatorE", "(anonymous namespace)::TransferFuncs::VisitUnaryOperator(clang::UnaryOperator*)"},
    {"_ZN12_GLOBAL__N_113TransferFuncs9VisitStmtEPN5clang4StmtE", "(anonymous namespace)::TransferFuncs::VisitStmt(clang::Stmt*)"},
    {"_ZN5clang14CFGStmtVisitorIN12_GLOBAL__N_113TransferFuncsEbE13VisitChildrenEPNS_4StmtE", "clang::CFGStmtVisitor<(anonymous namespace)::TransferFuncs, bool>::VisitChildren(clang::Stmt*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_113RegisterDeclsEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::RegisterDecls, void>::Visit(clang::Stmt*)"},
    {"_ZN5clang14CFGStmtVisitorIN12_GLOBAL__N_113RegisterDeclsEvE13VisitChildrenEPNS_4StmtE", "clang::CFGStmtVisitor<(anonymous namespace)::RegisterDecls, void>::VisitChildren(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_126UninitializedValuesCheckerD0Ev", "(anonymous namespace)::UninitializedValuesChecker::~UninitializedValuesChecker()"},
    {"_ZN12_GLOBAL__N_126UninitializedValuesChecker18ObserveDeclRefExprERN5clang23StmtDeclBitVector_Types5ValTyERNS1_30UninitializedValues_ValueTypes14AnalysisDataTyEPNS1_11DeclRefExprEPNS1_7VarDeclE", "(anonymous namespace)::UninitializedValuesChecker::ObserveDeclRefExpr(clang::StmtDeclBitVector_Types::ValTy&, clang::UninitializedValues_ValueTypes::AnalysisDataTy&, clang::DeclRefExpr*, clang::VarDecl*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4StmtENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS4_EENS7_IS6_EEE16FindAndConstructERKS4_", "llvm::DenseMap<clang::Stmt const*, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::Stmt const*>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::FindAndConstruct(clang::Stmt const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang4StmtENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::Stmt const*, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::Stmt const*>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::InsertIntoBucket(clang::Stmt const* const&, clang::StmtDeclBitVector_Types::ValTy const&, std::pair<clang::Stmt const*, clang::StmtDeclBitVector_Types::ValTy>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4StmtENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::Stmt const*, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::Stmt const*>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::grow(unsigned int)"},
    {"_ZN5clang18DataflowWorkListTy7dequeueEv", "clang::DataflowWorkListTy::dequeue()"},
    {"_ZN4llvm8DenseMapIN5clang12ProgramPointENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS2_EENS5_IS4_EEE4findERKS2_", "llvm::DenseMap<clang::ProgramPoint, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::ProgramPoint>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::find(clang::ProgramPoint const&)"},
    {"_ZN5clang18DataflowWorkListTy7enqueueEPKNS_8CFGBlockE", "clang::DataflowWorkListTy::enqueue(clang::CFGBlock const*)"},
    {"_ZN4llvm8DenseMapIPKN5clang8CFGBlockEhNS_12DenseMapInfoIS4_EENS5_IhEEE16InsertIntoBucketERKS4_RKhPSt4pairIS4_hE", "llvm::DenseMap<clang::CFGBlock const*, unsigned char, llvm::DenseMapInfo<clang::CFGBlock const*>, llvm::DenseMapInfo<unsigned char>>::InsertIntoBucket(clang::CFGBlock const* const&, unsigned char const&, std::pair<clang::CFGBlock const*, unsigned char>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang8CFGBlockEhNS_12DenseMapInfoIS4_EENS5_IhEEE4growEj", "llvm::DenseMap<clang::CFGBlock const*, unsigned char, llvm::DenseMapInfo<clang::CFGBlock const*>, llvm::DenseMapInfo<unsigned char>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIN5clang12ProgramPointENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS2_EENS5_IS4_EEE16FindAndConstructERKS2_", "llvm::DenseMap<clang::ProgramPoint, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::ProgramPoint>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::FindAndConstruct(clang::ProgramPoint const&)"},
    {"_ZNK4llvm8DenseMapIN5clang12ProgramPointENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS2_EENS5_IS4_EEE15LookupBucketForERKS2_RPSt4pairIS2_S4_E", "llvm::DenseMap<clang::ProgramPoint, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::ProgramPoint>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::LookupBucketFor(clang::ProgramPoint const&, std::pair<clang::ProgramPoint, clang::StmtDeclBitVector_Types::ValTy>*&) const"},
    {"_ZN4llvm8DenseMapIN5clang12ProgramPointENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS2_EENS5_IS4_EEE16InsertIntoBucketERKS2_RKS4_PSt4pairIS2_S4_E", "llvm::DenseMap<clang::ProgramPoint, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::ProgramPoint>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::InsertIntoBucket(clang::ProgramPoint const&, clang::StmtDeclBitVector_Types::ValTy const&, std::pair<clang::ProgramPoint, clang::StmtDeclBitVector_Types::ValTy>*)"},
    {"_ZN4llvm8DenseMapIN5clang12ProgramPointENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS2_EENS5_IS4_EEE4growEj", "llvm::DenseMap<clang::ProgramPoint, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::ProgramPoint>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::grow(unsigned int)"},
    {"_ZNK5clang12ProgramPoint12getHashValueEv", "clang::ProgramPoint::getHashValue() const"},
    {"_ZN4llvm8DenseMapIPKN5clang8CFGBlockENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS4_EENS7_IS6_EEE6insertERKSt4pairIS4_S6_E", "llvm::DenseMap<clang::CFGBlock const*, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::CFGBlock const*>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::insert(std::pair<clang::CFGBlock const*, clang::StmtDeclBitVector_Types::ValTy> const&)"},
    {"_ZNSt4pairIPKN5clang8CFGBlockENS0_23StmtDeclBitVector_Types5ValTyEEC2ERKS3_RKS5_", "std::pair<clang::CFGBlock const*, clang::StmtDeclBitVector_Types::ValTy>::pair(clang::CFGBlock const* const&, clang::StmtDeclBitVector_Types::ValTy const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang8CFGBlockENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::CFGBlock const*, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::CFGBlock const*>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::InsertIntoBucket(clang::CFGBlock const* const&, clang::StmtDeclBitVector_Types::ValTy const&, std::pair<clang::CFGBlock const*, clang::StmtDeclBitVector_Types::ValTy>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang8CFGBlockENS1_23StmtDeclBitVector_Types5ValTyENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::CFGBlock const*, clang::StmtDeclBitVector_Types::ValTy, llvm::DenseMapInfo<clang::CFGBlock const*>, llvm::DenseMapInfo<clang::StmtDeclBitVector_Types::ValTy>>::grow(unsigned int)"},
    {"_ZN5clang23StmtDeclBitVector_Types5ValTyoRERKS1_", "clang::StmtDeclBitVector_Types::ValTy::operator|=(clang::StmtDeclBitVector_Types::ValTy const&)"},
    {"_ZN5clang19DeclBitVector_Types14AnalysisDataTy8RegisterEPKNS_9NamedDeclE", "clang::DeclBitVector_Types::AnalysisDataTy::Register(clang::NamedDecl const*)"},
    {"_ZN5clang14DataflowValuesINS_30UninitializedValues_ValueTypesENS_8dataflow20forward_analysis_tagEED2Ev", "clang::DataflowValues<clang::UninitializedValues_ValueTypes, clang::dataflow::forward_analysis_tag>::~DataflowValues()"},
    {"_ZN5clang30UninitializedValues_ValueTypes14AnalysisDataTyD1Ev", "clang::UninitializedValues_ValueTypes::AnalysisDataTy::~AnalysisDataTy()"},
    {"_ZN5clang30UninitializedValues_ValueTypes14AnalysisDataTyD0Ev", "clang::UninitializedValues_ValueTypes::AnalysisDataTy::~AnalysisDataTy()"},
    {"_ZN5clang14DataflowValuesINS_30UninitializedValues_ValueTypesENS_8dataflow20forward_analysis_tagEEC2Ev", "clang::DataflowValues<clang::UninitializedValues_ValueTypes, clang::dataflow::forward_analysis_tag>::DataflowValues()"},
    {"_ZN5clang33runUninitializedVariablesAnalysisERKNS_11DeclContextERKNS_3CFGERNS_15AnalysisContextERNS_22UninitVariablesHandlerE", "clang::runUninitializedVariablesAnalysis(clang::DeclContext const&, clang::CFG const&, clang::AnalysisContext&, clang::UninitVariablesHandler&)"},
    {"_Z10runOnBlockPKN5clang8CFGBlockERKNS_3CFGERNS_15AnalysisContextERN12_GLOBAL__N_114CFGBlockValuesEPNS_22UninitVariablesHandlerEb", "runOnBlock(clang::CFGBlock const*, clang::CFG const&, clang::AnalysisContext&, (anonymous namespace)::CFGBlockValues&, clang::UninitVariablesHandler*, bool)"},
    {"_ZN5clang22UninitVariablesHandlerD0Ev", "clang::UninitVariablesHandler::~UninitVariablesHandler()"},
    {"_ZN5clang22UninitVariablesHandlerD1Ev", "clang::UninitVariablesHandler::~UninitVariablesHandler()"},
    {"_ZN5clang22UninitVariablesHandlerD2Ev", "clang::UninitVariablesHandler::~UninitVariablesHandler()"},
    {"_Z25getLogicalOperatorInChainPKN5clang8CFGBlockE", "getLogicalOperatorInChain(clang::CFGBlock const*)"},
    {"_ZN12_GLOBAL__N_114CFGBlockValues12getBitVectorEPKN5clang8CFGBlockES4_", "(anonymous namespace)::CFGBlockValues::getBitVector(clang::CFGBlock const*, clang::CFGBlock const*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_117TransferFunctionsEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::TransferFunctions, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_117TransferFunctions19VisitBinaryOperatorEPN5clang14BinaryOperatorE", "(anonymous namespace)::TransferFunctions::VisitBinaryOperator(clang::BinaryOperator*)"},
    {"_ZN12_GLOBAL__N_117TransferFunctions18VisitUnaryOperatorEPN5clang13UnaryOperatorE", "(anonymous namespace)::TransferFunctions::VisitUnaryOperator(clang::UnaryOperator*)"},
    {"_ZN5clang14CFGStmtVisitorIN12_GLOBAL__N_117TransferFunctionsEvE13VisitChildrenEPNS_4StmtE", "clang::CFGStmtVisitor<(anonymous namespace)::TransferFunctions, void>::VisitChildren(clang::Stmt*)"},
    {"_Z12isTrackedVarPKN5clang7VarDeclEPKNS_11DeclContextE", "isTrackedVar(clang::VarDecl const*, clang::DeclContext const*)"},
    {"_ZN12_GLOBAL__N_117TransferFunctions13VisitCastExprEPN5clang8CastExprE", "(anonymous namespace)::TransferFunctions::VisitCastExpr(clang::CastExpr*)"},
    {"_ZNK4llvm9BitVectoreqERKS0_", "llvm::BitVector::operator==(llvm::BitVector const&) const"},
    {"_ZNK5clang4Decl7getAttrINS_10BlocksAttrEEEPT_v", "clang::BlocksAttr* clang::Decl::getAttr<clang::BlocksAttr>() const"},
    {"_ZN5clang3idx12EntityGetter9getEntityENS0_6EntityENS_15DeclarationNameEjb", "clang::idx::EntityGetter::getEntity(clang::idx::Entity, clang::DeclarationName, unsigned int, bool)"},
    {"_ZN5clang3idx12EntityGetter15getGlobalEntityEN4llvm9StringRefE", "clang::idx::EntityGetter::getGlobalEntity(llvm::StringRef)"},
    {"_ZN5clang3idx12EntityGetter14VisitNamedDeclEPNS_9NamedDeclE", "clang::idx::EntityGetter::VisitNamedDecl(clang::NamedDecl*)"},
    {"_ZN5clang3idx6EntityC1EPNS_4DeclE", "clang::idx::Entity::Entity(clang::Decl*)"},
    {"_ZN5clang3idx12EntityGetter12VisitVarDeclEPNS_7VarDeclE", "clang::idx::EntityGetter::VisitVarDecl(clang::VarDecl*)"},
    {"_ZN5clang3idx12EntityGetter17VisitFunctionDeclEPNS_12FunctionDeclE", "clang::idx::EntityGetter::VisitFunctionDecl(clang::FunctionDecl*)"},
    {"_ZN5clang3idx12EntityGetter14VisitFieldDeclEPNS_9FieldDeclE", "clang::idx::EntityGetter::VisitFieldDecl(clang::FieldDecl*)"},
    {"_ZN5clang3idx12EntityGetter13VisitTypeDeclEPNS_8TypeDeclE", "clang::idx::EntityGetter::VisitTypeDecl(clang::TypeDecl*)"},
    {"_ZN5clang3idx10EntityImpl7getDeclERNS_10ASTContextE", "clang::idx::EntityImpl::getDecl(clang::ASTContext&)"},
    {"_ZNK5clang3idx6Entity7getDeclERNS_10ASTContextE", "clang::idx::Entity::getDecl(clang::ASTContext&) const"},
    {"_ZN5clang3idx10EntityImpl3getEPNS_4DeclERNS0_7ProgramERNS0_11ProgramImplE", "clang::idx::EntityImpl::get(clang::Decl*, clang::idx::Program&, clang::idx::ProgramImpl&)"},
    {"_ZN5clang3idx10EntityImpl3getEN4llvm9StringRefERNS0_7ProgramERNS0_11ProgramImplE", "clang::idx::EntityImpl::get(llvm::StringRef, clang::idx::Program&, clang::idx::ProgramImpl&)"},
    {"_ZN5clang3idx10EntityImpl16getPrintableNameEv", "clang::idx::EntityImpl::getPrintableName()"},
    {"_ZN5clang3idx6EntityC2EPNS_4DeclE", "clang::idx::Entity::Entity(clang::Decl*)"},
    {"_ZNK5clang3idx6Entity16getPrintableNameEv", "clang::idx::Entity::getPrintableName() const"},
    {"_ZN5clang3idx6Entity3getEPNS_4DeclERNS0_7ProgramE", "clang::idx::Entity::get(clang::Decl*, clang::idx::Program&)"},
    {"_ZN5clang3idx6Entity3getEN4llvm9StringRefERNS0_7ProgramE", "clang::idx::Entity::get(llvm::StringRef, clang::idx::Program&)"},
    {"_ZN4llvm12DenseMapInfoIN5clang3idx6EntityEE12getHashValueES3_", "llvm::DenseMapInfo<clang::idx::Entity>::getHashValue(clang::idx::Entity)"},
    {"_ZN5clang11DeclVisitorINS_3idx12EntityGetterENS1_6EntityEE5VisitEPNS_4DeclE", "clang::DeclVisitor<clang::idx::EntityGetter, clang::idx::Entity>::Visit(clang::Decl*)"},
    {"_ZNK5clang3idx14GlobalSelector11getSelectorERNS_10ASTContextE", "clang::idx::GlobalSelector::getSelector(clang::ASTContext&) const"},
    {"_ZNK5clang3idx14GlobalSelector16getPrintableNameEv", "clang::idx::GlobalSelector::getPrintableName() const"},
    {"_ZN5clang3idx14GlobalSelector3getENS_8SelectorERNS0_7ProgramE", "clang::idx::GlobalSelector::get(clang::Selector, clang::idx::Program&)"},
    {"_ZN4llvm12DenseMapInfoIN5clang3idx14GlobalSelectorEE12getHashValueES3_", "llvm::DenseMapInfo<clang::idx::GlobalSelector>::getHashValue(clang::idx::GlobalSelector)"},
    {"_ZN5clang3idx13EntityHandlerD0Ev", "clang::idx::EntityHandler::~EntityHandler()"},
    {"_ZN5clang3idx13EntityHandlerD1Ev", "clang::idx::EntityHandler::~EntityHandler()"},
    {"_ZN5clang3idx13EntityHandlerD2Ev", "clang::idx::EntityHandler::~EntityHandler()"},
    {"_ZN5clang3idx22TranslationUnitHandlerD0Ev", "clang::idx::TranslationUnitHandler::~TranslationUnitHandler()"},
    {"_ZN5clang3idx22TranslationUnitHandlerD1Ev", "clang::idx::TranslationUnitHandler::~TranslationUnitHandler()"},
    {"_ZN5clang3idx22TranslationUnitHandlerD2Ev", "clang::idx::TranslationUnitHandler::~TranslationUnitHandler()"},
    {"_ZN5clang3idx17TULocationHandlerD0Ev", "clang::idx::TULocationHandler::~TULocationHandler()"},
    {"_ZN5clang3idx17TULocationHandlerD1Ev", "clang::idx::TULocationHandler::~TULocationHandler()"},
    {"_ZN5clang3idx17TULocationHandlerD2Ev", "clang::idx::TULocationHandler::~TULocationHandler()"},
    {"_ZN5clang3idx13IndexProviderD0Ev", "clang::idx::IndexProvider::~IndexProvider()"},
    {"_ZN5clang3idx13IndexProviderD1Ev", "clang::idx::IndexProvider::~IndexProvider()"},
    {"_ZN5clang3idx13IndexProviderD2Ev", "clang::idx::IndexProvider::~IndexProvider()"},
    {"_ZN5clang3idx7Indexer8IndexASTEPNS0_15TranslationUnitE", "clang::idx::Indexer::IndexAST(clang::idx::TranslationUnit*)"},
    {"_ZN12_GLOBAL__N_113EntityIndexerD1Ev", "(anonymous namespace)::EntityIndexer::~EntityIndexer()"},
    {"_ZN5clang3idx7Indexer22GetTranslationUnitsForENS0_6EntityERNS0_22TranslationUnitHandlerE", "clang::idx::Indexer::GetTranslationUnitsFor(clang::idx::Entity, clang::idx::TranslationUnitHandler&)"},
    {"_ZN5clang3idx7Indexer22GetTranslationUnitsForENS0_14GlobalSelectorERNS0_22TranslationUnitHandlerE", "clang::idx::Indexer::GetTranslationUnitsFor(clang::idx::GlobalSelector, clang::idx::TranslationUnitHandler&)"},
    {"_ZN5clang3idx7Indexer16getDefinitionForENS0_6EntityE", "clang::idx::Indexer::getDefinitionFor(clang::idx::Entity)"},
    {"_ZN5clang11DeclVisitorIN12_GLOBAL__N_115SelectorIndexerEvE5VisitEPNS_4DeclE", "clang::DeclVisitor<(anonymous namespace)::SelectorIndexer, void>::Visit(clang::Decl*)"},
    {"_ZN5clang11DeclVisitorIN12_GLOBAL__N_115SelectorIndexerEvE14VisitNamedDeclEPNS_9NamedDeclE", "clang::DeclVisitor<(anonymous namespace)::SelectorIndexer, void>::VisitNamedDecl(clang::NamedDecl*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_115SelectorIndexerEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::SelectorIndexer, void>::Visit(clang::Stmt*)"},
    {"_ZN5clang3idx10ASTVisitorIN12_GLOBAL__N_115SelectorIndexerEE9VisitStmtEPNS_4StmtE", "clang::idx::ASTVisitor<(anonymous namespace)::SelectorIndexer>::VisitStmt(clang::Stmt*)"},
    {"_ZN5clang3idx10ASTVisitorIN12_GLOBAL__N_115SelectorIndexerEE19VisitDeclaratorDeclEPNS_14DeclaratorDeclE", "clang::idx::ASTVisitor<(anonymous namespace)::SelectorIndexer>::VisitDeclaratorDecl(clang::DeclaratorDecl*)"},
    {"_ZN5clang14TypeLocVisitorIN12_GLOBAL__N_115SelectorIndexerEvE5VisitENS_7TypeLocE", "clang::TypeLocVisitor<(anonymous namespace)::SelectorIndexer, void>::Visit(clang::TypeLoc)"},
    {"_ZN12_GLOBAL__N_113EntityIndexerD0Ev", "(anonymous namespace)::EntityIndexer::~EntityIndexer()"},
    {"_ZN12_GLOBAL__N_113EntityIndexer6HandleEN5clang3idx6EntityE", "(anonymous namespace)::EntityIndexer::Handle(clang::idx::Entity)"},
    {"_ZN5clang3idx7IndexerD1Ev", "clang::idx::Indexer::~Indexer()"},
    {"_ZN5clang3idx7IndexerD0Ev", "clang::idx::Indexer::~Indexer()"},
    {"_ZNSt3mapIN5clang3idx14GlobalSelectorEN4llvm11SmallPtrSetIPNS1_15TranslationUnitELj4EEESt4lessIS2_ESaISt4pairIKS2_S7_EEEixERSB_", "std::map<clang::idx::GlobalSelector, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>, std::less<clang::idx::GlobalSelector>, std::allocator<std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>>::operator[](clang::idx::GlobalSelector const&)"},
    {"_ZNSt8_Rb_treeIN5clang3idx14GlobalSelectorESt4pairIKS2_N4llvm11SmallPtrSetIPNS1_15TranslationUnitELj4EEEESt10_Select1stISA_ESt4lessIS2_ESaISA_EE16_M_insert_uniqueESt17_Rb_tree_iteratorISA_ERKSA_", "std::_Rb_tree<clang::idx::GlobalSelector, std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>, std::_Select1st<std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>, std::less<clang::idx::GlobalSelector>, std::allocator<std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>, std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>> const&)"},
    {"_ZNSt8_Rb_treeIN5clang3idx14GlobalSelectorESt4pairIKS2_N4llvm11SmallPtrSetIPNS1_15TranslationUnitELj4EEEESt10_Select1stISA_ESt4lessIS2_ESaISA_EE16_M_insert_uniqueERKSA_", "std::_Rb_tree<clang::idx::GlobalSelector, std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>, std::_Select1st<std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>, std::less<clang::idx::GlobalSelector>, std::allocator<std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>>::_M_insert_unique(std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>> const&)"},
    {"_ZN4llvm8DenseMapIPN5clang10ASTContextEPNS1_3idx15TranslationUnitENS_12DenseMapInfoIS3_EENS7_IS6_EEE16InsertIntoBucketERKS3_RKS6_PSt4pairIS3_S6_E", "llvm::DenseMap<clang::ASTContext*, clang::idx::TranslationUnit*, llvm::DenseMapInfo<clang::ASTContext*>, llvm::DenseMapInfo<clang::idx::TranslationUnit*>>::InsertIntoBucket(clang::ASTContext* const&, clang::idx::TranslationUnit* const&, std::pair<clang::ASTContext*, clang::idx::TranslationUnit*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang10ASTContextEPNS1_3idx15TranslationUnitENS_12DenseMapInfoIS3_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::ASTContext*, clang::idx::TranslationUnit*, llvm::DenseMapInfo<clang::ASTContext*>, llvm::DenseMapInfo<clang::idx::TranslationUnit*>>::grow(unsigned int)"},
    {"_ZNSt8_Rb_treeIN5clang3idx6EntityESt4pairIKS2_N4llvm11SmallPtrSetIPNS1_15TranslationUnitELj4EEEESt10_Select1stISA_ESt4lessIS2_ESaISA_EE8_M_eraseEPSt13_Rb_tree_nodeISA_E", "std::_Rb_tree<clang::idx::Entity, std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>, std::_Select1st<std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>, std::less<clang::idx::Entity>, std::allocator<std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>*)"},
    {"_ZNSt8_Rb_treeIN5clang3idx6EntityESt4pairIKS2_S3_IPNS0_12FunctionDeclEPNS1_15TranslationUnitEEESt10_Select1stISA_ESt4lessIS2_ESaISA_EE8_M_eraseEPSt13_Rb_tree_nodeISA_E", "std::_Rb_tree<clang::idx::Entity, std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>, std::_Select1st<std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>>, std::less<clang::idx::Entity>, std::allocator<std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>>*)"},
    {"_ZNSt8_Rb_treeIN5clang3idx14GlobalSelectorESt4pairIKS2_N4llvm11SmallPtrSetIPNS1_15TranslationUnitELj4EEEESt10_Select1stISA_ESt4lessIS2_ESaISA_EE8_M_eraseEPSt13_Rb_tree_nodeISA_E", "std::_Rb_tree<clang::idx::GlobalSelector, std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>, std::_Select1st<std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>, std::less<clang::idx::GlobalSelector>, std::allocator<std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::idx::GlobalSelector const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>*)"},
    {"_ZNSt3mapIN5clang3idx6EntityEN4llvm11SmallPtrSetIPNS1_15TranslationUnitELj4EEESt4lessIS2_ESaISt4pairIKS2_S7_EEEixERSB_", "std::map<clang::idx::Entity, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>, std::less<clang::idx::Entity>, std::allocator<std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>>::operator[](clang::idx::Entity const&)"},
    {"_ZNSt8_Rb_treeIN5clang3idx6EntityESt4pairIKS2_S3_IPNS0_12FunctionDeclEPNS1_15TranslationUnitEEESt10_Select1stISA_ESt4lessIS2_ESaISA_EE16_M_insert_uniqueESt17_Rb_tree_iteratorISA_ERKSA_", "std::_Rb_tree<clang::idx::Entity, std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>, std::_Select1st<std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>>, std::less<clang::idx::Entity>, std::allocator<std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>>, std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>> const&)"},
    {"_ZNSt8_Rb_treeIN5clang3idx6EntityESt4pairIKS2_S3_IPNS0_12FunctionDeclEPNS1_15TranslationUnitEEESt10_Select1stISA_ESt4lessIS2_ESaISA_EE16_M_insert_uniqueERKSA_", "std::_Rb_tree<clang::idx::Entity, std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>, std::_Select1st<std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>>, std::less<clang::idx::Entity>, std::allocator<std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>>>>::_M_insert_unique(std::pair<clang::idx::Entity const, std::pair<clang::FunctionDecl*, clang::idx::TranslationUnit*>> const&)"},
    {"_ZNSt8_Rb_treeIN5clang3idx6EntityESt4pairIKS2_N4llvm11SmallPtrSetIPNS1_15TranslationUnitELj4EEEESt10_Select1stISA_ESt4lessIS2_ESaISA_EE16_M_insert_uniqueESt17_Rb_tree_iteratorISA_ERKSA_", "std::_Rb_tree<clang::idx::Entity, std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>, std::_Select1st<std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>, std::less<clang::idx::Entity>, std::allocator<std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>, std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>> const&)"},
    {"_ZNSt8_Rb_treeIN5clang3idx6EntityESt4pairIKS2_N4llvm11SmallPtrSetIPNS1_15TranslationUnitELj4EEEESt10_Select1stISA_ESt4lessIS2_ESaISA_EE16_M_insert_uniqueERKSA_", "std::_Rb_tree<clang::idx::Entity, std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>, std::_Select1st<std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>, std::less<clang::idx::Entity>, std::allocator<std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>>>>::_M_insert_unique(std::pair<clang::idx::Entity const, llvm::SmallPtrSet<clang::idx::TranslationUnit*, 4u>> const&)"},
    {"_ZN5clang3idx15TranslationUnitD0Ev", "clang::idx::TranslationUnit::~TranslationUnit()"},
    {"_ZN5clang3idx15TranslationUnitD1Ev", "clang::idx::TranslationUnit::~TranslationUnit()"},
    {"_ZN5clang3idx15TranslationUnitD2Ev", "clang::idx::TranslationUnit::~TranslationUnit()"},
    {"_ZN5clang3idx7ProgramC1Ev", "clang::idx::Program::Program()"},
    {"_ZN5clang3idx7ProgramC2Ev", "clang::idx::Program::Program()"},
    {"_ZN5clang3idx7ProgramD1Ev", "clang::idx::Program::~Program()"},
    {"_ZN5clang3idx7ProgramD2Ev", "clang::idx::Program::~Program()"},
    {"_ZN5clang3idx7Program12FindEntitiesERNS_10ASTContextERNS0_13EntityHandlerE", "clang::idx::Program::FindEntities(clang::ASTContext&, clang::idx::EntityHandler&)"},
    {"_Z16FindEntitiesInDCPN5clang11DeclContextERNS_3idx7ProgramERNS2_13EntityHandlerE", "FindEntitiesInDC(clang::DeclContext*, clang::idx::Program&, clang::idx::EntityHandler&)"},
    {"_ZN4llvm10FoldingSetIN5clang3idx10EntityImplEED1Ev", "llvm::FoldingSet<clang::idx::EntityImpl>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang3idx10EntityImplEED0Ev", "llvm::FoldingSet<clang::idx::EntityImpl>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang3idx10EntityImplEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::idx::EntityImpl>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang3idx10EntityImplEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::idx::EntityImpl>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang3idx10EntityImplEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::idx::EntityImpl>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang3idx11ProgramImplC2Ev", "clang::idx::ProgramImpl::ProgramImpl()"},
    {"_ZN5clang9DeltaTreeC1Ev", "clang::DeltaTree::DeltaTree()"},
    {"_ZN5clang9DeltaTreeC2Ev", "clang::DeltaTree::DeltaTree()"},
    {"_ZN5clang9DeltaTreeC1ERKS0_", "clang::DeltaTree::DeltaTree(clang::DeltaTree const&)"},
    {"_ZN5clang9DeltaTreeC2ERKS0_", "clang::DeltaTree::DeltaTree(clang::DeltaTree const&)"},
    {"_ZN5clang9DeltaTreeD1Ev", "clang::DeltaTree::~DeltaTree()"},
    {"_ZN5clang9DeltaTreeD2Ev", "clang::DeltaTree::~DeltaTree()"},
    {"_ZN12_GLOBAL__N_113DeltaTreeNode7DestroyEv", "(anonymous namespace)::DeltaTreeNode::Destroy()"},
    {"_ZNK5clang9DeltaTree10getDeltaAtEj", "clang::DeltaTree::getDeltaAt(unsigned int) const"},
    {"_ZN5clang9DeltaTree8AddDeltaEji", "clang::DeltaTree::AddDelta(unsigned int, int)"},
    {"_ZN12_GLOBAL__N_113DeltaTreeNode11DoInsertionEjiPNS0_12InsertResultE", "(anonymous namespace)::DeltaTreeNode::DoInsertion(unsigned int, int, (anonymous namespace)::DeltaTreeNode::InsertResult*)"},
    {"_ZN12_GLOBAL__N_113DeltaTreeNode7DoSplitERNS0_12InsertResultE", "(anonymous namespace)::DeltaTreeNode::DoSplit((anonymous namespace)::DeltaTreeNode::InsertResult&)"},
    {"_ZN5clang13FixItRewriterC1ERNS_10DiagnosticERNS_13SourceManagerERKNS_11LangOptionsEPNS_12FixItOptionsE", "clang::FixItRewriter::FixItRewriter(clang::Diagnostic&, clang::SourceManager&, clang::LangOptions const&, clang::FixItOptions*)"},
    {"_ZN5clang13FixItRewriterC2ERNS_10DiagnosticERNS_13SourceManagerERKNS_11LangOptionsEPNS_12FixItOptionsE", "clang::FixItRewriter::FixItRewriter(clang::Diagnostic&, clang::SourceManager&, clang::LangOptions const&, clang::FixItOptions*)"},
    {"_ZN5clang13FixItRewriterD0Ev", "clang::FixItRewriter::~FixItRewriter()"},
    {"_ZN5clang13FixItRewriterD1Ev", "clang::FixItRewriter::~FixItRewriter()"},
    {"_ZN5clang13FixItRewriterD2Ev", "clang::FixItRewriter::~FixItRewriter()"},
    {"_ZN5clang13FixItRewriter14WriteFixedFileENS_6FileIDERN4llvm11raw_ostreamE", "clang::FixItRewriter::WriteFixedFile(clang::FileID, llvm::raw_ostream&)"},
    {"_ZN5clang13FixItRewriter15WriteFixedFilesEv", "clang::FixItRewriter::WriteFixedFiles()"},
    {"_ZN5clang13FixItRewriter4DiagENS_14SourceLocationEj", "clang::FixItRewriter::Diag(clang::SourceLocation, unsigned int)"},
    {"_ZNK5clang13FixItRewriter25IncludeInDiagnosticCountsEv", "clang::FixItRewriter::IncludeInDiagnosticCounts() const"},
    {"_ZN5clang13FixItRewriter16HandleDiagnosticENS_10Diagnostic5LevelERKNS_14DiagnosticInfoE", "clang::FixItRewriter::HandleDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_ZN5clang12FixItOptionsD0Ev", "clang::FixItOptions::~FixItOptions()"},
    {"_ZN5clang12FixItOptionsD1Ev", "clang::FixItOptions::~FixItOptions()"},
    {"_ZN5clang12FixItOptionsD2Ev", "clang::FixItOptions::~FixItOptions()"},
    {"_ZN5clang15HTMLPrintAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::HTMLPrintAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang11FixItActionC1Ev", "clang::FixItAction::FixItAction()"},
    {"_ZN5clang11FixItActionC2Ev", "clang::FixItAction::FixItAction()"},
    {"_ZN5clang11FixItActionD0Ev", "clang::FixItAction::~FixItAction()"},
    {"_ZN5clang11FixItActionD1Ev", "clang::FixItAction::~FixItAction()"},
    {"_ZN5clang11FixItActionD2Ev", "clang::FixItAction::~FixItAction()"},
    {"_ZN5clang11FixItAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::FixItAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang11FixItAction21BeginSourceFileActionERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::FixItAction::BeginSourceFileAction(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang11FixItAction19EndSourceFileActionEv", "clang::FixItAction::EndSourceFileAction()"},
    {"_ZN5clang17RewriteObjCAction17CreateASTConsumerERNS_16CompilerInstanceEN4llvm9StringRefE", "clang::RewriteObjCAction::CreateASTConsumer(clang::CompilerInstance&, llvm::StringRef)"},
    {"_ZN5clang19RewriteMacrosAction13ExecuteActionEv", "clang::RewriteMacrosAction::ExecuteAction()"},
    {"_ZN5clang17RewriteTestAction13ExecuteActionEv", "clang::RewriteTestAction::ExecuteAction()"},
    {"_ZN12_GLOBAL__N_119FixItRewriteInPlaceD1Ev", "(anonymous namespace)::FixItRewriteInPlace::~FixItRewriteInPlace()"},
    {"_ZN12_GLOBAL__N_119FixItRewriteInPlaceD0Ev", "(anonymous namespace)::FixItRewriteInPlace::~FixItRewriteInPlace()"},
    {"_ZN12_GLOBAL__N_119FixItRewriteInPlace15RewriteFilenameERKSs", "(anonymous namespace)::FixItRewriteInPlace::RewriteFilename(std::string const&)"},
    {"_ZN12_GLOBAL__N_125FixItActionSuffixInserterD1Ev", "(anonymous namespace)::FixItActionSuffixInserter::~FixItActionSuffixInserter()"},
    {"_ZN12_GLOBAL__N_125FixItActionSuffixInserterD0Ev", "(anonymous namespace)::FixItActionSuffixInserter::~FixItActionSuffixInserter()"},
    {"_ZN12_GLOBAL__N_125FixItActionSuffixInserter15RewriteFilenameERKSs", "(anonymous namespace)::FixItActionSuffixInserter::RewriteFilename(std::string const&)"},
    {"_ZNK5clang11FixItAction17hasASTFileSupportEv", "clang::FixItAction::hasASTFileSupport() const"},
    {"_ZN5clang15HTMLPrintActionD1Ev", "clang::HTMLPrintAction::~HTMLPrintAction()"},
    {"_ZN5clang15HTMLPrintActionD0Ev", "clang::HTMLPrintAction::~HTMLPrintAction()"},
    {"_ZN5clang17RewriteObjCActionD1Ev", "clang::RewriteObjCAction::~RewriteObjCAction()"},
    {"_ZN5clang17RewriteObjCActionD0Ev", "clang::RewriteObjCAction::~RewriteObjCAction()"},
    {"_ZN5clang19RewriteMacrosActionD1Ev", "clang::RewriteMacrosAction::~RewriteMacrosAction()"},
    {"_ZN5clang19RewriteMacrosActionD0Ev", "clang::RewriteMacrosAction::~RewriteMacrosAction()"},
    {"_ZN5clang17RewriteTestActionD1Ev", "clang::RewriteTestAction::~RewriteTestAction()"},
    {"_ZN5clang17RewriteTestActionD0Ev", "clang::RewriteTestAction::~RewriteTestAction()"},
    {"_ZN5clang17CreateHTMLPrinterEPN4llvm11raw_ostreamERNS_12PreprocessorEbb", "clang::CreateHTMLPrinter(llvm::raw_ostream*, clang::Preprocessor&, bool, bool)"},
    {"_ZN12_GLOBAL__N_111HTMLPrinterD1Ev", "(anonymous namespace)::HTMLPrinter::~HTMLPrinter()"},
    {"_ZN12_GLOBAL__N_111HTMLPrinterD0Ev", "(anonymous namespace)::HTMLPrinter::~HTMLPrinter()"},
    {"_ZN12_GLOBAL__N_111HTMLPrinter10InitializeERN5clang10ASTContextE", "(anonymous namespace)::HTMLPrinter::Initialize(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_111HTMLPrinter21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::HTMLPrinter::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN5clang4html14HighlightRangeERNS_8RewriterENS_14SourceLocationES3_PKcS5_", "clang::html::HighlightRange(clang::Rewriter&, clang::SourceLocation, clang::SourceLocation, char const*, char const*)"},
    {"_ZN5clang4html14HighlightRangeERNS_13RewriteBufferEjjPKcS4_S4_", "clang::html::HighlightRange(clang::RewriteBuffer&, unsigned int, unsigned int, char const*, char const*, char const*)"},
    {"_ZN5clang4html10EscapeTextERNS_8RewriterENS_6FileIDEbb", "clang::html::EscapeText(clang::Rewriter&, clang::FileID, bool, bool)"},
    {"_ZN5clang4html10EscapeTextERKSsbb", "clang::html::EscapeText(std::string const&, bool, bool)"},
    {"_ZN5clang4html14AddLineNumbersERNS_8RewriterENS_6FileIDE", "clang::html::AddLineNumbers(clang::Rewriter&, clang::FileID)"},
    {"_ZN5clang4html33AddHeaderFooterInternalBuiltinCSSERNS_8RewriterENS_6FileIDEPKc", "clang::html::AddHeaderFooterInternalBuiltinCSS(clang::Rewriter&, clang::FileID, char const*)"},
    {"_ZN5clang4html15SyntaxHighlightERNS_8RewriterENS_6FileIDERKNS_12PreprocessorE", "clang::html::SyntaxHighlight(clang::Rewriter&, clang::FileID, clang::Preprocessor const&)"},
    {"_ZN5clang4html15HighlightMacrosERNS_8RewriterENS_6FileIDERKNS_12PreprocessorE", "clang::html::HighlightMacros(clang::Rewriter&, clang::FileID, clang::Preprocessor const&)"},
    {"_ZN12_GLOBAL__N_118IgnoringDiagClientD1Ev", "(anonymous namespace)::IgnoringDiagClient::~IgnoringDiagClient()"},
    {"_ZN12_GLOBAL__N_118IgnoringDiagClientD0Ev", "(anonymous namespace)::IgnoringDiagClient::~IgnoringDiagClient()"},
    {"_ZN12_GLOBAL__N_118IgnoringDiagClient16HandleDiagnosticEN5clang10Diagnostic5LevelERKNS1_14DiagnosticInfoE", "(anonymous namespace)::IgnoringDiagClient::HandleDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_ZN5clang20RewriteMacrosInInputERNS_12PreprocessorEPN4llvm11raw_ostreamE", "clang::RewriteMacrosInInput(clang::Preprocessor&, llvm::raw_ostream*)"},
    {"_ZN5clang18CreateObjCRewriterERKSsPN4llvm11raw_ostreamERNS_10DiagnosticERKNS_11LangOptionsEb", "clang::CreateObjCRewriter(std::string const&, llvm::raw_ostream*, clang::Diagnostic&, clang::LangOptions const&, bool)"},
    {"_ZN12_GLOBAL__N_111RewriteObjCD1Ev", "(anonymous namespace)::RewriteObjC::~RewriteObjC()"},
    {"_ZN12_GLOBAL__N_111RewriteObjCD0Ev", "(anonymous namespace)::RewriteObjC::~RewriteObjC()"},
    {"_ZN12_GLOBAL__N_111RewriteObjC10InitializeERN5clang10ASTContextE", "(anonymous namespace)::RewriteObjC::Initialize(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC18HandleTopLevelDeclEN5clang12DeclGroupRefE", "(anonymous namespace)::RewriteObjC::HandleTopLevelDecl(clang::DeclGroupRef)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC21HandleTranslationUnitERN5clang10ASTContextE", "(anonymous namespace)::RewriteObjC::HandleTranslationUnit(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC27RewriteObjCProtocolMetaDataEPN5clang16ObjCProtocolDeclEN4llvm9StringRefES5_RSs", "(anonymous namespace)::RewriteObjC::RewriteObjCProtocolMetaData(clang::ObjCProtocolDecl*, llvm::StringRef, llvm::StringRef, std::string&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC28SynthesizeMetaDataIntoBufferERSs", "(anonymous namespace)::RewriteObjC::SynthesizeMetaDataIntoBuffer(std::string&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC26RewriteObjCMethodsMetaDataIPPN5clang14ObjCMethodDeclEEEvT_S6_bN4llvm9StringRefES8_RSs", "void (anonymous namespace)::RewriteObjC::RewriteObjCMethodsMetaData<clang::ObjCMethodDecl**>(clang::ObjCMethodDecl**, clang::ObjCMethodDecl**, bool, llvm::StringRef, llvm::StringRef, std::string&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC26RewriteObjCMethodsMetaDataIN5clang11DeclContext22filtered_decl_iteratorINS2_14ObjCMethodDeclEXadL_ZNKS5_13isClassMethodEvEEEEEEvT_S7_bN4llvm9StringRefES9_RSs",
     "void (anonymous namespace)::RewriteObjC::RewriteObjCMethodsMetaData<clang::DeclContext::filtered_decl_iterator<clang::ObjCMethodDecl, &clang::ObjCMethodDecl::isClassMethod() const>>(clang::DeclContext::filtered_decl_iterator<clang::ObjCMethodDecl, &clang::ObjCMethodDecl::isClassMethod() const>, clang::DeclContext::filtered_decl_iterator<clang::ObjCMethodDecl, &clang::ObjCMethodDecl::isClassMethod() const>, bool, llvm::StringRef, llvm::StringRef, std::string&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC31RewriteObjCProtocolListMetaDataERKN5clang8ObjCListINS1_16ObjCProtocolDeclEEEN4llvm9StringRefES8_RSs", "(anonymous namespace)::RewriteObjC::RewriteObjCProtocolListMetaData(clang::ObjCList<clang::ObjCProtocolDecl> const&, llvm::StringRef, llvm::StringRef, std::string&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC28SynthesizeObjCInternalStructEPN5clang17ObjCInterfaceDeclERSs", "(anonymous namespace)::RewriteObjC::SynthesizeObjCInternalStruct(clang::ObjCInterfaceDecl*, std::string&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC17QuoteDoublequotesERSsS1_", "(anonymous namespace)::RewriteObjC::QuoteDoublequotes(std::string&, std::string&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC31SynthesizeIvarOffsetComputationEPN5clang12ObjCIvarDeclERSs", "(anonymous namespace)::RewriteObjC::SynthesizeIvarOffsetComputation(clang::ObjCIvarDecl*, std::string&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC25RewriteImplementationDeclEPN5clang4DeclE", "(anonymous namespace)::RewriteObjC::RewriteImplementationDecl(clang::Decl*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC21RewriteObjCMethodDeclEPKN5clang17ObjCInterfaceDeclEPNS1_14ObjCMethodDeclERSs", "(anonymous namespace)::RewriteObjC::RewriteObjCMethodDecl(clang::ObjCInterfaceDecl const*, clang::ObjCMethodDecl*, std::string&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC21RewriteTypeIntoStringEN5clang8QualTypeERSsRPKNS1_12FunctionTypeE", "(anonymous namespace)::RewriteObjC::RewriteTypeIntoString(clang::QualType, std::string&, clang::FunctionType const*&)"},
    {"_Z19getIvarAccessStringPN5clang12ObjCIvarDeclE", "getIvarAccessString(clang::ObjCIvarDecl*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC24HandleTopLevelSingleDeclEPN5clang4DeclE", "(anonymous namespace)::RewriteObjC::HandleTopLevelSingleDecl(clang::Decl*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC32RewriteBlocksInFunctionProtoTypeEN5clang8QualTypeEPNS1_9NamedDeclE", "(anonymous namespace)::RewriteObjC::RewriteBlocksInFunctionProtoType(clang::QualType, clang::NamedDecl*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC22CollectPropertySettersEPN5clang4StmtE", "(anonymous namespace)::RewriteObjC::CollectPropertySetters(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC38RewriteFunctionBodyOrGlobalInitializerEPN5clang4StmtE", "(anonymous namespace)::RewriteObjC::RewriteFunctionBodyOrGlobalInitializer(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC34RewriteObjCQualifiedInterfaceTypesEPN5clang4DeclE", "(anonymous namespace)::RewriteObjC::RewriteObjCQualifiedInterfaceTypes(clang::Decl*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC23RewriteBlockPointerDeclEPN5clang9NamedDeclE", "(anonymous namespace)::RewriteObjC::RewriteBlockPointerDecl(clang::NamedDecl*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC15RewriteCastExprEPN5clang14CStyleCastExprE", "(anonymous namespace)::RewriteObjC::RewriteCastExpr(clang::CStyleCastExpr*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC17RewriteRecordBodyEPN5clang10RecordDeclE", "(anonymous namespace)::RewriteObjC::RewriteRecordBody(clang::RecordDecl*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC23SynthesizeBlockLiteralsEN5clang14SourceLocationEN4llvm9StringRefE", "(anonymous namespace)::RewriteObjC::SynthesizeBlockLiterals(clang::SourceLocation, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC31RewriteBlockLiteralFunctionDeclEPN5clang12FunctionDeclE", "(anonymous namespace)::RewriteObjC::RewriteBlockLiteralFunctionDecl(clang::FunctionDecl*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC23CollectBlockDeclRefInfoEPN5clang9BlockExprE", "(anonymous namespace)::RewriteObjC::CollectBlockDeclRefInfo(clang::BlockExpr*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC18RewriteByRefStringERSsRKSsPN5clang9ValueDeclEb", "(anonymous namespace)::RewriteObjC::RewriteByRefString(std::string&, std::string const&, clang::ValueDecl*, bool)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC23RewriteBlockPointerTypeERSsN5clang8QualTypeE", "(anonymous namespace)::RewriteObjC::RewriteBlockPointerType(std::string&, clang::QualType)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC20GetBlockDeclRefExprsEPN5clang4StmtE", "(anonymous namespace)::RewriteObjC::GetBlockDeclRefExprs(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC33PointerTypeTakesAnyBlockArgumentsEN5clang8QualTypeE", "(anonymous namespace)::RewriteObjC::PointerTypeTakesAnyBlockArguments(clang::QualType)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC23needToScanForQualifiersEN5clang8QualTypeE", "(anonymous namespace)::RewriteObjC::needToScanForQualifiers(clang::QualType)"},
    {"_Z21BuildUniqueMethodNameRSsPN5clang14ObjCMethodDeclE", "BuildUniqueMethodName(std::string&, clang::ObjCMethodDecl*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC28RewriteObjCNestedIvarRefExprEPN5clang4StmtERb", "(anonymous namespace)::RewriteObjC::RewriteObjCNestedIvarRefExpr(clang::Stmt*, bool&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC11ReplaceStmtEPN5clang4StmtES3_", "(anonymous namespace)::RewriteObjC::ReplaceStmt(clang::Stmt*, clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC25GetInnerBlockDeclRefExprsEPN5clang4StmtERN4llvm11SmallVectorIPNS1_16BlockDeclRefExprELj8EEERNS4_11SmallPtrSetIPKNS1_11DeclContextELj8EEE", "(anonymous namespace)::RewriteObjC::GetInnerBlockDeclRefExprs(clang::Stmt*, llvm::SmallVector<clang::BlockDeclRefExpr*, 8u>&, llvm::SmallPtrSet<clang::DeclContext const*, 8u>&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC23RewriteBlockDeclRefExprEPN5clang4ExprE", "(anonymous namespace)::RewriteObjC::RewriteBlockDeclRefExpr(clang::Expr*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC19SynthesizeBlockCallEPN5clang8CallExprEPKNS1_4ExprE", "(anonymous namespace)::RewriteObjC::SynthesizeBlockCall(clang::CallExpr*, clang::Expr const*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC15getProtocolTypeEv", "(anonymous namespace)::RewriteObjC::getProtocolType()"},
    {"_ZN12_GLOBAL__N_111RewriteObjC14HasReturnStmtsEPN5clang4StmtERb", "(anonymous namespace)::RewriteObjC::HasReturnStmts(clang::Stmt*, bool&)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC22RewriteSyncReturnStmtsEPN5clang4StmtESs", "(anonymous namespace)::RewriteObjC::RewriteSyncReturnStmts(clang::Stmt*, std::string)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC24WarnAboutReturnGotoStmtsEPN5clang4StmtE", "(anonymous namespace)::RewriteObjC::WarnAboutReturnGotoStmts(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC21RewriteTryReturnStmtsEPN5clang4StmtE", "(anonymous namespace)::RewriteObjC::RewriteTryReturnStmts(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC16SynthMessageExprEPN5clang15ObjCMessageExprENS1_14SourceLocationES4_", "(anonymous namespace)::RewriteObjC::SynthMessageExpr(clang::ObjCMessageExpr*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC26SynthSelGetUidFunctionDeclEv", "(anonymous namespace)::RewriteObjC::SynthSelGetUidFunctionDecl()"},
    {"_ZN12_GLOBAL__N_111RewriteObjC28SynthesizeCallToFunctionDeclEPN5clang12FunctionDeclEPPNS1_4ExprEjNS1_14SourceLocationES7_", "(anonymous namespace)::RewriteObjC::SynthesizeCallToFunctionDecl(clang::FunctionDecl*, clang::Expr**, unsigned int, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC18getSuperStructTypeEv", "(anonymous namespace)::RewriteObjC::getSuperStructType()"},
    {"_ZN12_GLOBAL__N_111RewriteObjC32SynthSuperContructorFunctionDeclEv", "(anonymous namespace)::RewriteObjC::SynthSuperContructorFunctionDecl()"},
    {"_ZN12_GLOBAL__N_111RewriteObjC26SynthBlockInitFunctionDeclEN4llvm9StringRefE", "(anonymous namespace)::RewriteObjC::SynthBlockInitFunctionDecl(llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_111RewriteObjC24RewriteMethodDeclarationEPN5clang14ObjCMethodDeclE", "(anonymous namespace)::RewriteObjC::RewriteMethodDeclaration(clang::ObjCMethodDecl*)"},
    {"_ZN4llvm8DenseMapIPN5clang14ObjCMethodDeclESsNS_12DenseMapInfoIS3_EENS4_ISsEEE16FindAndConstructERKS3_", "llvm::DenseMap<clang::ObjCMethodDecl*, std::string, llvm::DenseMapInfo<clang::ObjCMethodDecl*>, llvm::DenseMapInfo<std::string>>::FindAndConstruct(clang::ObjCMethodDecl* const&)"},
    {"_ZN4llvm8DenseMapIPN5clang14ObjCMethodDeclESsNS_12DenseMapInfoIS3_EENS4_ISsEEE16InsertIntoBucketERKS3_RKSsPSt4pairIS3_SsE", "llvm::DenseMap<clang::ObjCMethodDecl*, std::string, llvm::DenseMapInfo<clang::ObjCMethodDecl*>, llvm::DenseMapInfo<std::string>>::InsertIntoBucket(clang::ObjCMethodDecl* const&, std::string const&, std::pair<clang::ObjCMethodDecl*, std::string>*)"},
    {"_ZN4llvm8DenseMapIPN5clang14ObjCMethodDeclESsNS_12DenseMapInfoIS3_EENS4_ISsEEE4growEj", "llvm::DenseMap<clang::ObjCMethodDecl*, std::string, llvm::DenseMapInfo<clang::ObjCMethodDecl*>, llvm::DenseMapInfo<std::string>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang14ObjCMethodDeclEE6appendINS1_11DeclContext22filtered_decl_iteratorIS2_XadL_ZNKS2_16isInstanceMethodEvEEEEEEvT_S9_", "void llvm::SmallVectorImpl<clang::ObjCMethodDecl*>::append<clang::DeclContext::filtered_decl_iterator<clang::ObjCMethodDecl, &clang::ObjCMethodDecl::isInstanceMethod() const>>(clang::DeclContext::filtered_decl_iterator<clang::ObjCMethodDecl, &clang::ObjCMethodDecl::isInstanceMethod() const>, clang::DeclContext::filtered_decl_iterator<clang::ObjCMethodDecl, &clang::ObjCMethodDecl::isInstanceMethod() const>)"},
    {"_ZNK5clang17ObjCInterfaceDecl9ivar_sizeEv", "clang::ObjCInterfaceDecl::ivar_size() const"},
    {"_ZNSs12_S_constructIN5clang22RopePieceBTreeIteratorEEEPcT_S3_RKSaIcESt20forward_iterator_tag", "char* std::string::_S_construct<clang::RopePieceBTreeIterator>(clang::RopePieceBTreeIterator, clang::RopePieceBTreeIterator, std::allocator<char> const&, std::forward_iterator_tag)"},
    {"_ZN4llvm8DenseMapIPN5clang9BlockExprESsNS_12DenseMapInfoIS3_EENS4_ISsEEE5clearEv", "llvm::DenseMap<clang::BlockExpr*, std::string, llvm::DenseMapInfo<clang::BlockExpr*>, llvm::DenseMapInfo<std::string>>::clear()"},
    {"_ZN4llvm8DenseMapIPN5clang9BlockExprESsNS_12DenseMapInfoIS3_EENS4_ISsEEE16shrink_and_clearEv", "llvm::DenseMap<clang::BlockExpr*, std::string, llvm::DenseMapInfo<clang::BlockExpr*>, llvm::DenseMapInfo<std::string>>::shrink_and_clear()"},
    {"_ZN4llvm8DenseMapIPN5clang9BlockExprESsNS_12DenseMapInfoIS3_EENS4_ISsEEE16FindAndConstructERKS3_", "llvm::DenseMap<clang::BlockExpr*, std::string, llvm::DenseMapInfo<clang::BlockExpr*>, llvm::DenseMapInfo<std::string>>::FindAndConstruct(clang::BlockExpr* const&)"},
    {"_ZN4llvm8DenseMapIPN5clang9BlockExprESsNS_12DenseMapInfoIS3_EENS4_ISsEEE16InsertIntoBucketERKS3_RKSsPSt4pairIS3_SsE", "llvm::DenseMap<clang::BlockExpr*, std::string, llvm::DenseMapInfo<clang::BlockExpr*>, llvm::DenseMapInfo<std::string>>::InsertIntoBucket(clang::BlockExpr* const&, std::string const&, std::pair<clang::BlockExpr*, std::string>*)"},
    {"_ZN4llvm8DenseMapIPN5clang9BlockExprESsNS_12DenseMapInfoIS3_EENS4_ISsEEE4growEj", "llvm::DenseMap<clang::BlockExpr*, std::string, llvm::DenseMapInfo<clang::BlockExpr*>, llvm::DenseMapInfo<std::string>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang9ValueDeclEjNS_12DenseMapInfoIS3_EENS4_IjEEE16InsertIntoBucketERKS3_RKjPSt4pairIS3_jE", "llvm::DenseMap<clang::ValueDecl*, unsigned int, llvm::DenseMapInfo<clang::ValueDecl*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::ValueDecl* const&, unsigned int const&, std::pair<clang::ValueDecl*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPN5clang9ValueDeclEjNS_12DenseMapInfoIS3_EENS4_IjEEE4growEj", "llvm::DenseMap<clang::ValueDecl*, unsigned int, llvm::DenseMapInfo<clang::ValueDecl*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN5clang19ConditionalOperatorC2EPNS_4ExprENS_14SourceLocationES2_S3_S2_S2_NS_8QualTypeENS_13ExprValueKindENS_14ExprObjectKindE", "clang::ConditionalOperator::ConditionalOperator(clang::Expr*, clang::SourceLocation, clang::Expr*, clang::SourceLocation, clang::Expr*, clang::Expr*, clang::QualType, clang::ExprValueKind, clang::ExprObjectKind)"},
    {"_ZN5clang13UnaryOperatorC2EPNS_4ExprENS_17UnaryOperatorKindENS_8QualTypeENS_13ExprValueKindENS_14ExprObjectKindENS_14SourceLocationE", "clang::UnaryOperator::UnaryOperator(clang::Expr*, clang::UnaryOperatorKind, clang::QualType, clang::ExprValueKind, clang::ExprObjectKind, clang::SourceLocation)"},
    {"_ZN4llvm8DenseMapIycNS_12DenseMapInfoIyEENS1_IcEEE6insertERKSt4pairIycE", "llvm::DenseMap<unsigned long long, char, llvm::DenseMapInfo<unsigned long long>, llvm::DenseMapInfo<char>>::insert(std::pair<unsigned long long, char> const&)"},
    {"_ZN4llvm8DenseMapIycNS_12DenseMapInfoIyEENS1_IcEEE16InsertIntoBucketERKyRKcPSt4pairIycE", "llvm::DenseMap<unsigned long long, char, llvm::DenseMapInfo<unsigned long long>, llvm::DenseMapInfo<char>>::InsertIntoBucket(unsigned long long const&, char const&, std::pair<unsigned long long, char>*)"},
    {"_ZN4llvm8DenseMapIycNS_12DenseMapInfoIyEENS1_IcEEE4growEj", "llvm::DenseMap<unsigned long long, char, llvm::DenseMapInfo<unsigned long long>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZN5clang14BinaryOperatorC2EPNS_4ExprES2_NS_18BinaryOperatorKindENS_8QualTypeENS_13ExprValueKindENS_14ExprObjectKindENS_14SourceLocationE", "clang::BinaryOperator::BinaryOperator(clang::Expr*, clang::Expr*, clang::BinaryOperatorKind, clang::QualType, clang::ExprValueKind, clang::ExprObjectKind, clang::SourceLocation)"},
    {"_ZN4llvm8DenseMapIPN5clang4ExprEPNS1_4StmtENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::Expr*, clang::Stmt*, llvm::DenseMapInfo<clang::Expr*>, llvm::DenseMapInfo<clang::Stmt*>>::InsertIntoBucket(clang::Expr* const&, clang::Stmt* const&, std::pair<clang::Expr*, clang::Stmt*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang4ExprEPNS1_4StmtENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::Expr*, clang::Stmt*, llvm::DenseMapInfo<clang::Expr*>, llvm::DenseMapInfo<clang::Stmt*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang4StmtES3_NS_12DenseMapInfoIS3_EES5_E16InsertIntoBucketERKS3_S8_PSt4pairIS3_S3_E", "llvm::DenseMap<clang::Stmt*, clang::Stmt*, llvm::DenseMapInfo<clang::Stmt*>, llvm::DenseMapInfo<clang::Stmt*>>::InsertIntoBucket(clang::Stmt* const&, clang::Stmt* const&, std::pair<clang::Stmt*, clang::Stmt*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang4StmtES3_NS_12DenseMapInfoIS3_EES5_E4growEj", "llvm::DenseMap<clang::Stmt*, clang::Stmt*, llvm::DenseMapInfo<clang::Stmt*>, llvm::DenseMapInfo<clang::Stmt*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang4ExprEPNS1_14BinaryOperatorENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::Expr*, clang::BinaryOperator*, llvm::DenseMapInfo<clang::Expr*>, llvm::DenseMapInfo<clang::BinaryOperator*>>::InsertIntoBucket(clang::Expr* const&, clang::BinaryOperator* const&, std::pair<clang::Expr*, clang::BinaryOperator*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang4ExprEPNS1_14BinaryOperatorENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::Expr*, clang::BinaryOperator*, llvm::DenseMapInfo<clang::Expr*>, llvm::DenseMapInfo<clang::BinaryOperator*>>::grow(unsigned int)"},
    {"_ZNSt8_Rb_treeIN5clang6FileIDESt4pairIKS1_NS0_13RewriteBufferEESt10_Select1stIS5_ESt4lessIS1_ESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<clang::FileID, std::pair<clang::FileID const, clang::RewriteBuffer>, std::_Select1st<std::pair<clang::FileID const, clang::RewriteBuffer>>, std::less<clang::FileID>, std::allocator<std::pair<clang::FileID const, clang::RewriteBuffer>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::FileID const, clang::RewriteBuffer>>*)"},
    {"_ZN5clang22RopePieceBTreeIteratorC1EPKv", "clang::RopePieceBTreeIterator::RopePieceBTreeIterator(void const*)"},
    {"_ZN5clang22RopePieceBTreeIteratorC2EPKv", "clang::RopePieceBTreeIterator::RopePieceBTreeIterator(void const*)"},
    {"_ZN5clang22RopePieceBTreeIterator15MoveToNextPieceEv", "clang::RopePieceBTreeIterator::MoveToNextPiece()"},
    {"_ZN5clang14RopePieceBTreeC1Ev", "clang::RopePieceBTree::RopePieceBTree()"},
    {"_ZN5clang14RopePieceBTreeC2Ev", "clang::RopePieceBTree::RopePieceBTree()"},
    {"_ZN5clang14RopePieceBTreeC1ERKS0_", "clang::RopePieceBTree::RopePieceBTree(clang::RopePieceBTree const&)"},
    {"_ZN5clang14RopePieceBTreeC2ERKS0_", "clang::RopePieceBTree::RopePieceBTree(clang::RopePieceBTree const&)"},
    {"_ZN5clang14RopePieceBTreeD1Ev", "clang::RopePieceBTree::~RopePieceBTree()"},
    {"_ZN5clang14RopePieceBTreeD2Ev", "clang::RopePieceBTree::~RopePieceBTree()"},
    {"_ZN12_GLOBAL__N_118RopePieceBTreeNode7DestroyEv", "(anonymous namespace)::RopePieceBTreeNode::Destroy()"},
    {"_ZNK5clang14RopePieceBTree4sizeEv", "clang::RopePieceBTree::size() const"},
    {"_ZN5clang14RopePieceBTree5clearEv", "clang::RopePieceBTree::clear()"},
    {"_ZN5clang14RopePieceBTree6insertEjRKNS_9RopePieceE", "clang::RopePieceBTree::insert(unsigned int, clang::RopePiece const&)"},
    {"_ZN12_GLOBAL__N_118RopePieceBTreeNode5splitEj", "(anonymous namespace)::RopePieceBTreeNode::split(unsigned int)"},
    {"_ZN12_GLOBAL__N_118RopePieceBTreeNode6insertEjRKN5clang9RopePieceE", "(anonymous namespace)::RopePieceBTreeNode::insert(unsigned int, clang::RopePiece const&)"},
    {"_ZN5clang14RopePieceBTree5eraseEjj", "clang::RopePieceBTree::erase(unsigned int, unsigned int)"},
    {"_ZN12_GLOBAL__N_118RopePieceBTreeNode5eraseEjj", "(anonymous namespace)::RopePieceBTreeNode::erase(unsigned int, unsigned int)"},
    {"_ZN5clang11RewriteRope14MakeRopeStringEPKcS2_", "clang::RewriteRope::MakeRopeString(char const*, char const*)"},
    {"_ZN12_GLOBAL__N_118RopePieceBTreeLeaf6insertEjRKN5clang9RopePieceE", "(anonymous namespace)::RopePieceBTreeLeaf::insert(unsigned int, clang::RopePiece const&)"},
    {"_ZN12_GLOBAL__N_122RopePieceBTreeInterior16HandleChildPieceEjPNS_18RopePieceBTreeNodeE", "(anonymous namespace)::RopePieceBTreeInterior::HandleChildPiece(unsigned int, (anonymous namespace)::RopePieceBTreeNode*)"},
    {"_ZN5clang13DoRewriteTestERNS_12PreprocessorEPN4llvm11raw_ostreamE", "clang::DoRewriteTest(clang::Preprocessor&, llvm::raw_ostream*)"},
    {"_ZNK5clang13RewriteBuffer5writeERN4llvm11raw_ostreamE", "clang::RewriteBuffer::write(llvm::raw_ostream&) const"},
    {"_ZN5clang13RewriteBuffer10RemoveTextEjj", "clang::RewriteBuffer::RemoveText(unsigned int, unsigned int)"},
    {"_ZN5clang13RewriteBuffer10InsertTextEjN4llvm9StringRefEb", "clang::RewriteBuffer::InsertText(unsigned int, llvm::StringRef, bool)"},
    {"_ZN5clang13RewriteBuffer11ReplaceTextEjjN4llvm9StringRefE", "clang::RewriteBuffer::ReplaceText(unsigned int, unsigned int, llvm::StringRef)"},
    {"_ZNK5clang8Rewriter12getRangeSizeERKNS_15CharSourceRangeE", "clang::Rewriter::getRangeSize(clang::CharSourceRange const&) const"},
    {"_ZNK5clang8Rewriter26getLocationOffsetAndFileIDENS_14SourceLocationERNS_6FileIDE", "clang::Rewriter::getLocationOffsetAndFileID(clang::SourceLocation, clang::FileID&) const"},
    {"_ZNK5clang8Rewriter12getRangeSizeENS_11SourceRangeE", "clang::Rewriter::getRangeSize(clang::SourceRange) const"},
    {"_ZNK5clang8Rewriter16getRewrittenTextENS_11SourceRangeE", "clang::Rewriter::getRewrittenText(clang::SourceRange) const"},
    {"_ZN5clang8Rewriter13getEditBufferENS_6FileIDE", "clang::Rewriter::getEditBuffer(clang::FileID)"},
    {"_ZN5clang8Rewriter10InsertTextENS_14SourceLocationEN4llvm9StringRefEb", "clang::Rewriter::InsertText(clang::SourceLocation, llvm::StringRef, bool)"},
    {"_ZN5clang8Rewriter10RemoveTextENS_14SourceLocationEj", "clang::Rewriter::RemoveText(clang::SourceLocation, unsigned int)"},
    {"_ZN5clang8Rewriter11ReplaceTextENS_14SourceLocationEjN4llvm9StringRefE", "clang::Rewriter::ReplaceText(clang::SourceLocation, unsigned int, llvm::StringRef)"},
    {"_ZN5clang8Rewriter11ReplaceStmtEPNS_4StmtES2_", "clang::Rewriter::ReplaceStmt(clang::Stmt*, clang::Stmt*)"},
    {"_ZNSt8_Rb_treeIN5clang6FileIDESt4pairIKS1_NS0_13RewriteBufferEESt10_Select1stIS5_ESt4lessIS1_ESaIS5_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS5_ERKS5_", "std::_Rb_tree<clang::FileID, std::pair<clang::FileID const, clang::RewriteBuffer>, std::_Select1st<std::pair<clang::FileID const, clang::RewriteBuffer>>, std::less<clang::FileID>, std::allocator<std::pair<clang::FileID const, clang::RewriteBuffer>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::FileID const, clang::RewriteBuffer>>, std::pair<clang::FileID const, clang::RewriteBuffer> const&)"},
    {"_ZNSt8_Rb_treeIN5clang6FileIDESt4pairIKS1_NS0_13RewriteBufferEESt10_Select1stIS5_ESt4lessIS1_ESaIS5_EE9_M_insertEPSt18_Rb_tree_node_baseSD_RKS5_", "std::_Rb_tree<clang::FileID, std::pair<clang::FileID const, clang::RewriteBuffer>, std::_Select1st<std::pair<clang::FileID const, clang::RewriteBuffer>>, std::less<clang::FileID>, std::allocator<std::pair<clang::FileID const, clang::RewriteBuffer>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<clang::FileID const, clang::RewriteBuffer> const&)"},
    {"_ZNSt8_Rb_treeIN5clang6FileIDESt4pairIKS1_NS0_13RewriteBufferEESt10_Select1stIS5_ESt4lessIS1_ESaIS5_EE16_M_insert_uniqueERKS5_", "std::_Rb_tree<clang::FileID, std::pair<clang::FileID const, clang::RewriteBuffer>, std::_Select1st<std::pair<clang::FileID const, clang::RewriteBuffer>>, std::less<clang::FileID>, std::allocator<std::pair<clang::FileID const, clang::RewriteBuffer>>>::_M_insert_unique(std::pair<clang::FileID const, clang::RewriteBuffer> const&)"},
    {"_ZN5clang13TokenRewriterC1ENS_6FileIDERNS_13SourceManagerERKNS_11LangOptionsE", "clang::TokenRewriter::TokenRewriter(clang::FileID, clang::SourceManager&, clang::LangOptions const&)"},
    {"_ZN5clang13TokenRewriterC2ENS_6FileIDERNS_13SourceManagerERKNS_11LangOptionsE", "clang::TokenRewriter::TokenRewriter(clang::FileID, clang::SourceManager&, clang::LangOptions const&)"},
    {"_ZN5clang13TokenRewriter8AddTokenERKNS_5TokenESt14_List_iteratorIS1_E", "clang::TokenRewriter::AddToken(clang::Token const&, std::_List_iterator<clang::Token>)"},
    {"_ZN5clang13TokenRewriterD1Ev", "clang::TokenRewriter::~TokenRewriter()"},
    {"_ZN5clang13TokenRewriterD2Ev", "clang::TokenRewriter::~TokenRewriter()"},
    {"_ZN5clang13TokenRewriter13RemapIteratorESt20_List_const_iteratorINS_5TokenEE", "clang::TokenRewriter::RemapIterator(std::_List_const_iterator<clang::Token>)"},
    {"_ZN5clang13TokenRewriter14AddTokenBeforeESt20_List_const_iteratorINS_5TokenEEPKc", "clang::TokenRewriter::AddTokenBefore(std::_List_const_iterator<clang::Token>, char const*)"},
    {"_ZNSt8_Rb_treeIN5clang14SourceLocationESt4pairIKS1_St14_List_iteratorINS0_5TokenEEESt10_Select1stIS7_ESt4lessIS1_ESaIS7_EE16_M_insert_uniqueERKS7_", "std::_Rb_tree<clang::SourceLocation, std::pair<clang::SourceLocation const, std::_List_iterator<clang::Token>>, std::_Select1st<std::pair<clang::SourceLocation const, std::_List_iterator<clang::Token>>>, std::less<clang::SourceLocation>, std::allocator<std::pair<clang::SourceLocation const, std::_List_iterator<clang::Token>>>>::_M_insert_unique(std::pair<clang::SourceLocation const, std::_List_iterator<clang::Token>> const&)"},
    {"_ZNSt8_Rb_treeIN5clang14SourceLocationESt4pairIKS1_St14_List_iteratorINS0_5TokenEEESt10_Select1stIS7_ESt4lessIS1_ESaIS7_EE8_M_eraseEPSt13_Rb_tree_nodeIS7_E", "std::_Rb_tree<clang::SourceLocation, std::pair<clang::SourceLocation const, std::_List_iterator<clang::Token>>, std::_Select1st<std::pair<clang::SourceLocation const, std::_List_iterator<clang::Token>>>, std::less<clang::SourceLocation>, std::allocator<std::pair<clang::SourceLocation const, std::_List_iterator<clang::Token>>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::SourceLocation const, std::_List_iterator<clang::Token>>>*)"},
    {"_ZN5clang7APValueC1EPNS_4ExprE", "clang::APValue::APValue(clang::Expr*)"},
    {"_ZN5clang7APValueC2EPNS_4ExprE", "clang::APValue::APValue(clang::Expr*)"},
    {"_ZN5clang7APValue10MakeLValueEv", "clang::APValue::MakeLValue()"},
    {"_ZN5clang7APValue9setLValueEPNS_4ExprERKNS_9CharUnitsE", "clang::APValue::setLValue(clang::Expr*, clang::CharUnits const&)"},
    {"_ZN5clang7APValueaSERKS0_", "clang::APValue::operator=(clang::APValue const&)"},
    {"_ZN5clang7APValue10MakeUninitEv", "clang::APValue::MakeUninit()"},
    {"_ZNK5clang7APValue13getLValueBaseEv", "clang::APValue::getLValueBase() const"},
    {"_ZNK5clang7APValue15getLValueOffsetEv", "clang::APValue::getLValueOffset() const"},
    {"_ZNK5clang7APValue4dumpEv", "clang::APValue::dump() const"},
    {"_ZNK5clang7APValue5printERN4llvm11raw_ostreamE", "clang::APValue::print(llvm::raw_ostream&) const"},
    {"_ZN5clang11ASTConsumer18HandleTopLevelDeclENS_12DeclGroupRefE", "clang::ASTConsumer::HandleTopLevelDecl(clang::DeclGroupRef)"},
    {"_ZN5clang11ASTConsumer21HandleInterestingDeclENS_12DeclGroupRefE", "clang::ASTConsumer::HandleInterestingDecl(clang::DeclGroupRef)"},
    {"_ZN5clang10ASTContext29CanonicalTemplateTemplateParm7ProfileERN4llvm16FoldingSetNodeIDEPNS_24TemplateTemplateParmDeclE", "clang::ASTContext::CanonicalTemplateTemplateParm::Profile(llvm::FoldingSetNodeID&, clang::TemplateTemplateParmDecl*)"},
    {"_ZNK5clang10ASTContext36getCanonicalTemplateTemplateParmDeclEPNS_24TemplateTemplateParmDeclE", "clang::ASTContext::getCanonicalTemplateTemplateParmDecl(clang::TemplateTemplateParmDecl*) const"},
    {"_ZNK5clang10ASTContext24getTrivialTypeSourceInfoENS_8QualTypeENS_14SourceLocationE", "clang::ASTContext::getTrivialTypeSourceInfo(clang::QualType, clang::SourceLocation) const"},
    {"_ZN5clang10ASTContext12createCXXABIERKNS_10TargetInfoE", "clang::ASTContext::createCXXABI(clang::TargetInfo const&)"},
    {"_ZN5clang10ASTContextC1ERKNS_11LangOptionsERNS_13SourceManagerERKNS_10TargetInfoERNS_15IdentifierTableERNS_13SelectorTableERNS_7Builtin7ContextEj", "clang::ASTContext::ASTContext(clang::LangOptions const&, clang::SourceManager&, clang::TargetInfo const&, clang::IdentifierTable&, clang::SelectorTable&, clang::Builtin::Context&, unsigned int)"},
    {"_ZN5clang10ASTContextC2ERKNS_11LangOptionsERNS_13SourceManagerERKNS_10TargetInfoERNS_15IdentifierTableERNS_13SelectorTableERNS_7Builtin7ContextEj", "clang::ASTContext::ASTContext(clang::LangOptions const&, clang::SourceManager&, clang::TargetInfo const&, clang::IdentifierTable&, clang::SelectorTable&, clang::Builtin::Context&, unsigned int)"},
    {"_ZN5clang10ASTContext16InitBuiltinTypesEv", "clang::ASTContext::InitBuiltinTypes()"},
    {"_ZN5clang10ASTContextD1Ev", "clang::ASTContext::~ASTContext()"},
    {"_ZN5clang10ASTContextD2Ev", "clang::ASTContext::~ASTContext()"},
    {"_ZN5clang10ASTContext15AddDeallocationEPFvPvES1_", "clang::ASTContext::AddDeallocation(void (*)(void*), void*)"},
    {"_ZN5clang10ASTContext17setExternalSourceERN4llvm9OwningPtrINS_17ExternalASTSourceEEE", "clang::ASTContext::setExternalSource(llvm::OwningPtr<clang::ExternalASTSource>&)"},
    {"_ZNK5clang10ASTContext10PrintStatsEv", "clang::ASTContext::PrintStats() const"},
    {"_ZN5clang10ASTContext15InitBuiltinTypeERNS_7CanQualINS_4TypeEEENS_11BuiltinType4KindE", "clang::ASTContext::InitBuiltinType(clang::CanQual<clang::Type>&, clang::BuiltinType::Kind)"},
    {"_ZNK5clang10ASTContext17getFromTargetTypeEj", "clang::ASTContext::getFromTargetType(unsigned int) const"},
    {"_ZNK5clang10ASTContext14getDiagnosticsEv", "clang::ASTContext::getDiagnostics() const"},
    {"_ZN5clang10ASTContext12getDeclAttrsEPKNS_4DeclE", "clang::ASTContext::getDeclAttrs(clang::Decl const*)"},
    {"_ZN5clang10ASTContext14eraseDeclAttrsEPKNS_4DeclE", "clang::ASTContext::eraseDeclAttrs(clang::Decl const*)"},
    {"_ZN5clang10ASTContext35getInstantiatedFromStaticDataMemberEPKNS_7VarDeclE", "clang::ASTContext::getInstantiatedFromStaticDataMember(clang::VarDecl const*)"},
    {"_ZN5clang10ASTContext35setInstantiatedFromStaticDataMemberEPNS_7VarDeclES2_NS_26TemplateSpecializationKindENS_14SourceLocationE", "clang::ASTContext::setInstantiatedFromStaticDataMember(clang::VarDecl*, clang::VarDecl*, clang::TemplateSpecializationKind, clang::SourceLocation)"},
    {"_ZN5clang10ASTContext28getInstantiatedFromUsingDeclEPNS_9UsingDeclE", "clang::ASTContext::getInstantiatedFromUsingDecl(clang::UsingDecl*)"},
    {"_ZN5clang10ASTContext28setInstantiatedFromUsingDeclEPNS_9UsingDeclEPNS_9NamedDeclE", "clang::ASTContext::setInstantiatedFromUsingDecl(clang::UsingDecl*, clang::NamedDecl*)"},
    {"_ZN5clang10ASTContext34getInstantiatedFromUsingShadowDeclEPNS_15UsingShadowDeclE", "clang::ASTContext::getInstantiatedFromUsingShadowDecl(clang::UsingShadowDecl*)"},
    {"_ZN5clang10ASTContext34setInstantiatedFromUsingShadowDeclEPNS_15UsingShadowDeclES2_", "clang::ASTContext::setInstantiatedFromUsingShadowDecl(clang::UsingShadowDecl*, clang::UsingShadowDecl*)"},
    {"_ZN5clang10ASTContext35getInstantiatedFromUnnamedFieldDeclEPNS_9FieldDeclE", "clang::ASTContext::getInstantiatedFromUnnamedFieldDecl(clang::FieldDecl*)"},
    {"_ZN5clang10ASTContext35setInstantiatedFromUnnamedFieldDeclEPNS_9FieldDeclES2_", "clang::ASTContext::setInstantiatedFromUnnamedFieldDecl(clang::FieldDecl*, clang::FieldDecl*)"},
    {"_ZNK5clang10ASTContext24overridden_methods_beginEPKNS_13CXXMethodDeclE", "clang::ASTContext::overridden_methods_begin(clang::CXXMethodDecl const*) const"},
    {"_ZNK5clang10ASTContext22overridden_methods_endEPKNS_13CXXMethodDeclE", "clang::ASTContext::overridden_methods_end(clang::CXXMethodDecl const*) const"},
    {"_ZNK5clang10ASTContext23overridden_methods_sizeEPKNS_13CXXMethodDeclE", "clang::ASTContext::overridden_methods_size(clang::CXXMethodDecl const*) const"},
    {"_ZN5clang10ASTContext19addOverriddenMethodEPKNS_13CXXMethodDeclES3_", "clang::ASTContext::addOverriddenMethod(clang::CXXMethodDecl const*, clang::CXXMethodDecl const*)"},
    {"_ZNK5clang10ASTContext21getFloatTypeSemanticsENS_8QualTypeE", "clang::ASTContext::getFloatTypeSemantics(clang::QualType) const"},
    {"_ZNK5clang10ASTContext12getDeclAlignEPKNS_4DeclEb", "clang::ASTContext::getDeclAlign(clang::Decl const*, bool) const"},
    {"_ZNK5clang10ASTContext14getPointerTypeENS_8QualTypeE", "clang::ASTContext::getPointerType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext14getAsArrayTypeENS_8QualTypeE", "clang::ASTContext::getAsArrayType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext18getBaseElementTypeEPKNS_9ArrayTypeE", "clang::ASTContext::getBaseElementType(clang::ArrayType const*) const"},
    {"_ZNK5clang10ASTContext21getPreferredTypeAlignEPKNS_4TypeE", "clang::ASTContext::getPreferredTypeAlign(clang::Type const*) const"},
    {"_ZNK5clang10ASTContext19toCharUnitsFromBitsEx", "clang::ASTContext::toCharUnitsFromBits(long long) const"},
    {"_ZN5clang10ASTContext18getTypeInfoInCharsEPKNS_4TypeE", "clang::ASTContext::getTypeInfoInChars(clang::Type const*)"},
    {"_ZNK5clang10ASTContext11getTypeInfoEPKNS_4TypeE", "clang::ASTContext::getTypeInfo(clang::Type const*) const"},
    {"_ZN5clang10ASTContext18getTypeInfoInCharsENS_8QualTypeE", "clang::ASTContext::getTypeInfoInChars(clang::QualType)"},
    {"_ZNK5clang10ASTContext18getPointerDiffTypeEv", "clang::ASTContext::getPointerDiffType() const"},
    {"_ZNK5clang10ASTContext25getASTObjCInterfaceLayoutEPKNS_17ObjCInterfaceDeclE", "clang::ASTContext::getASTObjCInterfaceLayout(clang::ObjCInterfaceDecl const*) const"},
    {"_ZNK5clang10ASTContext18getTypeSizeInCharsENS_8QualTypeE", "clang::ASTContext::getTypeSizeInChars(clang::QualType) const"},
    {"_ZNK5clang10ASTContext18getTypeSizeInCharsEPKNS_4TypeE", "clang::ASTContext::getTypeSizeInChars(clang::Type const*) const"},
    {"_ZNK5clang10ASTContext19getTypeAlignInCharsENS_8QualTypeE", "clang::ASTContext::getTypeAlignInChars(clang::QualType) const"},
    {"_ZNK5clang10ASTContext19getTypeAlignInCharsEPKNS_4TypeE", "clang::ASTContext::getTypeAlignInChars(clang::Type const*) const"},
    {"_ZNK5clang10ASTContext23ShallowCollectObjCIvarsEPKNS_17ObjCInterfaceDeclERN4llvm15SmallVectorImplIPNS_12ObjCIvarDeclEEE", "clang::ASTContext::ShallowCollectObjCIvars(clang::ObjCInterfaceDecl const*, llvm::SmallVectorImpl<clang::ObjCIvarDecl*>&) const"},
    {"_ZNK5clang10ASTContext20DeepCollectObjCIvarsEPKNS_17ObjCInterfaceDeclEbRN4llvm15SmallVectorImplIPNS_12ObjCIvarDeclEEE", "clang::ASTContext::DeepCollectObjCIvars(clang::ObjCInterfaceDecl const*, bool, llvm::SmallVectorImpl<clang::ObjCIvarDecl*>&) const"},
    {"_ZN5clang10ASTContext25CollectInheritedProtocolsEPKNS_4DeclERN4llvm11SmallPtrSetIPNS_16ObjCProtocolDeclELj8EEE", "clang::ASTContext::CollectInheritedProtocols(clang::Decl const*, llvm::SmallPtrSet<clang::ObjCProtocolDecl*, 8u>&)"},
    {"_ZNK5clang10ASTContext18CountNonClassIvarsEPKNS_17ObjCInterfaceDeclE", "clang::ASTContext::CountNonClassIvars(clang::ObjCInterfaceDecl const*) const"},
    {"_ZN5clang10ASTContext21getObjCImplementationEPNS_17ObjCInterfaceDeclE", "clang::ASTContext::getObjCImplementation(clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang10ASTContext21getObjCImplementationEPNS_16ObjCCategoryDeclE", "clang::ASTContext::getObjCImplementation(clang::ObjCCategoryDecl*)"},
    {"_ZN5clang10ASTContext21setObjCImplementationEPNS_17ObjCInterfaceDeclEPNS_22ObjCImplementationDeclE", "clang::ASTContext::setObjCImplementation(clang::ObjCInterfaceDecl*, clang::ObjCImplementationDecl*)"},
    {"_ZN5clang10ASTContext21setObjCImplementationEPNS_16ObjCCategoryDeclEPNS_20ObjCCategoryImplDeclE", "clang::ASTContext::setObjCImplementation(clang::ObjCCategoryDecl*, clang::ObjCCategoryImplDecl*)"},
    {"_ZN5clang10ASTContext20getBlockVarCopyInitsEPKNS_7VarDeclE", "clang::ASTContext::getBlockVarCopyInits(clang::VarDecl const*)"},
    {"_ZN5clang10ASTContext20setBlockVarCopyInitsEPNS_7VarDeclEPNS_4ExprE", "clang::ASTContext::setBlockVarCopyInits(clang::VarDecl*, clang::Expr*)"},
    {"_ZNK5clang10ASTContext20CreateTypeSourceInfoENS_8QualTypeEj", "clang::ASTContext::CreateTypeSourceInfo(clang::QualType, unsigned int) const"},
    {"_ZNK5clang10ASTContext30getASTObjCImplementationLayoutEPKNS_22ObjCImplementationDeclE", "clang::ASTContext::getASTObjCImplementationLayout(clang::ObjCImplementationDecl const*) const"},
    {"_ZNK5clang10ASTContext14getExtQualTypeEPKNS_4TypeENS_10QualifiersE", "clang::ASTContext::getExtQualType(clang::Type const*, clang::Qualifiers) const"},
    {"_ZNK5clang10ASTContext20getAddrSpaceQualTypeENS_8QualTypeEj", "clang::ASTContext::getAddrSpaceQualType(clang::QualType, unsigned int) const"},
    {"_ZNK5clang10ASTContext17getObjCGCQualTypeENS_8QualTypeENS_10Qualifiers2GCE", "clang::ASTContext::getObjCGCQualType(clang::QualType, clang::Qualifiers::GC) const"},
    {"_ZN5clang10ASTContext18adjustFunctionTypeEPKNS_12FunctionTypeENS1_7ExtInfoE", "clang::ASTContext::adjustFunctionType(clang::FunctionType const*, clang::FunctionType::ExtInfo)"},
    {"_ZNK5clang10ASTContext22getFunctionNoProtoTypeENS_8QualTypeERKNS_12FunctionType7ExtInfoE", "clang::ASTContext::getFunctionNoProtoType(clang::QualType, clang::FunctionType::ExtInfo const&) const"},
    {"_ZNK5clang10ASTContext15getFunctionTypeENS_8QualTypeEPKS1_jRKNS_17FunctionProtoType12ExtProtoInfoE", "clang::ASTContext::getFunctionType(clang::QualType, clang::QualType const*, unsigned int, clang::FunctionProtoType::ExtProtoInfo const&) const"},
    {"_ZNK5clang10ASTContext14getComplexTypeENS_8QualTypeE", "clang::ASTContext::getComplexType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext19getBlockPointerTypeENS_8QualTypeE", "clang::ASTContext::getBlockPointerType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext22getLValueReferenceTypeENS_8QualTypeEb", "clang::ASTContext::getLValueReferenceType(clang::QualType, bool) const"},
    {"_ZNK5clang10ASTContext22getRValueReferenceTypeENS_8QualTypeE", "clang::ASTContext::getRValueReferenceType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext20getMemberPointerTypeENS_8QualTypeEPKNS_4TypeE", "clang::ASTContext::getMemberPointerType(clang::QualType, clang::Type const*) const"},
    {"_ZNK5clang10ASTContext20getConstantArrayTypeENS_8QualTypeERKN4llvm5APIntENS_9ArrayType17ArraySizeModifierEj", "clang::ASTContext::getConstantArrayType(clang::QualType, llvm::APInt const&, clang::ArrayType::ArraySizeModifier, unsigned int) const"},
    {"_ZNK5clang10ASTContext27getVariableArrayDecayedTypeENS_8QualTypeE", "clang::ASTContext::getVariableArrayDecayedType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext26getDependentSizedArrayTypeENS_8QualTypeEPNS_4ExprENS_9ArrayType17ArraySizeModifierEjNS_11SourceRangeE", "clang::ASTContext::getDependentSizedArrayType(clang::QualType, clang::Expr*, clang::ArrayType::ArraySizeModifier, unsigned int, clang::SourceRange) const"},
    {"_ZNK5clang10ASTContext20getVariableArrayTypeENS_8QualTypeEPNS_4ExprENS_9ArrayType17ArraySizeModifierEjNS_11SourceRangeE", "clang::ASTContext::getVariableArrayType(clang::QualType, clang::Expr*, clang::ArrayType::ArraySizeModifier, unsigned int, clang::SourceRange) const"},
    {"_ZNK5clang10ASTContext22getIncompleteArrayTypeENS_8QualTypeENS_9ArrayType17ArraySizeModifierEj", "clang::ASTContext::getIncompleteArrayType(clang::QualType, clang::ArrayType::ArraySizeModifier, unsigned int) const"},
    {"_ZNK5clang10ASTContext13getVectorTypeENS_8QualTypeEjNS_10VectorType10VectorKindE", "clang::ASTContext::getVectorType(clang::QualType, unsigned int, clang::VectorType::VectorKind) const"},
    {"_ZNK5clang10ASTContext16getExtVectorTypeENS_8QualTypeEj", "clang::ASTContext::getExtVectorType(clang::QualType, unsigned int) const"},
    {"_ZNK5clang10ASTContext30getDependentSizedExtVectorTypeENS_8QualTypeEPNS_4ExprENS_14SourceLocationE", "clang::ASTContext::getDependentSizedExtVectorType(clang::QualType, clang::Expr*, clang::SourceLocation) const"},
    {"_ZNK5clang10ASTContext21getCanonicalParamTypeENS_8QualTypeE", "clang::ASTContext::getCanonicalParamType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext24getInjectedClassNameTypeEPNS_13CXXRecordDeclENS_8QualTypeE", "clang::ASTContext::getInjectedClassNameType(clang::CXXRecordDecl*, clang::QualType) const"},
    {"_ZNK5clang10ASTContext19getTypeDeclTypeSlowEPKNS_8TypeDeclE", "clang::ASTContext::getTypeDeclTypeSlow(clang::TypeDecl const*) const"},
    {"_ZNK5clang10ASTContext14getTypedefTypeEPKNS_11TypedefDeclENS_8QualTypeE", "clang::ASTContext::getTypedefType(clang::TypedefDecl const*, clang::QualType) const"},
    {"_ZNK5clang10ASTContext13getRecordTypeEPKNS_10RecordDeclE", "clang::ASTContext::getRecordType(clang::RecordDecl const*) const"},
    {"_ZNK5clang10ASTContext11getEnumTypeEPKNS_8EnumDeclE", "clang::ASTContext::getEnumType(clang::EnumDecl const*) const"},
    {"_ZN5clang10ASTContext17getAttributedTypeENS_14AttributedType4KindENS_8QualTypeES3_", "clang::ASTContext::getAttributedType(clang::AttributedType::Kind, clang::QualType, clang::QualType)"},
    {"_ZNK5clang10ASTContext28getSubstTemplateTypeParmTypeEPKNS_20TemplateTypeParmTypeENS_8QualTypeE", "clang::ASTContext::getSubstTemplateTypeParmType(clang::TemplateTypeParmType const*, clang::QualType) const"},
    {"_ZN5clang10ASTContext32getSubstTemplateTypeParmPackTypeEPKNS_20TemplateTypeParmTypeERKNS_16TemplateArgumentE", "clang::ASTContext::getSubstTemplateTypeParmPackType(clang::TemplateTypeParmType const*, clang::TemplateArgument const&)"},
    {"_ZNK5clang10ASTContext23getTemplateTypeParmTypeEjjbPNS_14IdentifierInfoE", "clang::ASTContext::getTemplateTypeParmType(unsigned int, unsigned int, bool, clang::IdentifierInfo*) const"},
    {"_ZNK5clang10ASTContext33getTemplateSpecializationTypeInfoENS_12TemplateNameENS_14SourceLocationERKNS_24TemplateArgumentListInfoENS_8QualTypeE", "clang::ASTContext::getTemplateSpecializationTypeInfo(clang::TemplateName, clang::SourceLocation, clang::TemplateArgumentListInfo const&, clang::QualType) const"},
    {"_ZNK5clang10ASTContext29getTemplateSpecializationTypeENS_12TemplateNameERKNS_24TemplateArgumentListInfoENS_8QualTypeE", "clang::ASTContext::getTemplateSpecializationType(clang::TemplateName, clang::TemplateArgumentListInfo const&, clang::QualType) const"},
    {"_ZNK5clang10ASTContext29getTemplateSpecializationTypeENS_12TemplateNameEPKNS_16TemplateArgumentEjNS_8QualTypeE", "clang::ASTContext::getTemplateSpecializationType(clang::TemplateName, clang::TemplateArgument const*, unsigned int, clang::QualType) const"},
    {"_ZNK5clang10ASTContext38getCanonicalTemplateSpecializationTypeENS_12TemplateNameEPKNS_16TemplateArgumentEj", "clang::ASTContext::getCanonicalTemplateSpecializationType(clang::TemplateName, clang::TemplateArgument const*, unsigned int) const"},
    {"_ZNK5clang10ASTContext24getCanonicalTemplateNameENS_12TemplateNameE", "clang::ASTContext::getCanonicalTemplateName(clang::TemplateName) const"},
    {"_ZNK5clang10ASTContext28getCanonicalTemplateArgumentERKNS_16TemplateArgumentE", "clang::ASTContext::getCanonicalTemplateArgument(clang::TemplateArgument const&) const"},
    {"_ZNK5clang10ASTContext17getElaboratedTypeENS_21ElaboratedTypeKeywordEPNS_19NestedNameSpecifierENS_8QualTypeE", "clang::ASTContext::getElaboratedType(clang::ElaboratedTypeKeyword, clang::NestedNameSpecifier*, clang::QualType) const"},
    {"_ZNK5clang10ASTContext12getParenTypeENS_8QualTypeE", "clang::ASTContext::getParenType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext20getDependentNameTypeENS_21ElaboratedTypeKeywordEPNS_19NestedNameSpecifierEPKNS_14IdentifierInfoENS_8QualTypeE", "clang::ASTContext::getDependentNameType(clang::ElaboratedTypeKeyword, clang::NestedNameSpecifier*, clang::IdentifierInfo const*, clang::QualType) const"},
    {"_ZNK5clang10ASTContext31getCanonicalNestedNameSpecifierEPNS_19NestedNameSpecifierE", "clang::ASTContext::getCanonicalNestedNameSpecifier(clang::NestedNameSpecifier*) const"},
    {"_ZNK5clang10ASTContext38getDependentTemplateSpecializationTypeENS_21ElaboratedTypeKeywordEPNS_19NestedNameSpecifierEPKNS_14IdentifierInfoERKNS_24TemplateArgumentListInfoE", "clang::ASTContext::getDependentTemplateSpecializationType(clang::ElaboratedTypeKeyword, clang::NestedNameSpecifier*, clang::IdentifierInfo const*, clang::TemplateArgumentListInfo const&) const"},
    {"_ZNK5clang10ASTContext38getDependentTemplateSpecializationTypeENS_21ElaboratedTypeKeywordEPNS_19NestedNameSpecifierEPKNS_14IdentifierInfoEjPKNS_16TemplateArgumentE", "clang::ASTContext::getDependentTemplateSpecializationType(clang::ElaboratedTypeKeyword, clang::NestedNameSpecifier*, clang::IdentifierInfo const*, unsigned int, clang::TemplateArgument const*) const"},
    {"_ZN5clang10ASTContext20getPackExpansionTypeENS_8QualTypeEN4llvm8OptionalIjEE", "clang::ASTContext::getPackExpansionType(clang::QualType, llvm::Optional<unsigned int>)"},
    {"_ZNK5clang10ASTContext17getObjCObjectTypeENS_8QualTypeEPKPNS_16ObjCProtocolDeclEj", "clang::ASTContext::getObjCObjectType(clang::QualType, clang::ObjCProtocolDecl* const*, unsigned int) const"},
    {"_ZNK5clang10ASTContext24getObjCObjectPointerTypeENS_8QualTypeE", "clang::ASTContext::getObjCObjectPointerType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext20getObjCInterfaceTypeEPKNS_17ObjCInterfaceDeclE", "clang::ASTContext::getObjCInterfaceType(clang::ObjCInterfaceDecl const*) const"},
    {"_ZNK5clang10ASTContext17getTypeOfExprTypeEPNS_4ExprE", "clang::ASTContext::getTypeOfExprType(clang::Expr*) const"},
    {"_ZNK5clang10ASTContext13getTypeOfTypeENS_8QualTypeE", "clang::ASTContext::getTypeOfType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext15getDecltypeTypeEPNS_4ExprE", "clang::ASTContext::getDecltypeType(clang::Expr*) const"},
    {"_ZNK5clang10ASTContext14getTagDeclTypeEPKNS_7TagDeclE", "clang::ASTContext::getTagDeclType(clang::TagDecl const*) const"},
    {"_ZNK5clang10ASTContext11getSizeTypeEv", "clang::ASTContext::getSizeType() const"},
    {"_ZNK5clang10ASTContext18getSignedWCharTypeEv", "clang::ASTContext::getSignedWCharType() const"},
    {"_ZNK5clang10ASTContext20getUnsignedWCharTypeEv", "clang::ASTContext::getUnsignedWCharType() const"},
    {"_ZNK5clang10ASTContext19getArrayDecayedTypeENS_8QualTypeE", "clang::ASTContext::getArrayDecayedType(clang::QualType) const"},
    {"_ZN5clang10ASTContext23getUnqualifiedArrayTypeENS_8QualTypeERNS_10QualifiersE", "clang::ASTContext::getUnqualifiedArrayType(clang::QualType, clang::Qualifiers&)"},
    {"_ZN5clang10ASTContext25UnwrapSimilarPointerTypesERNS_8QualTypeES2_", "clang::ASTContext::UnwrapSimilarPointerTypes(clang::QualType&, clang::QualType&)"},
    {"_ZNK5clang10ASTContext18getNameForTemplateENS_12TemplateNameENS_14SourceLocationE", "clang::ASTContext::getNameForTemplate(clang::TemplateName, clang::SourceLocation) const"},
    {"_ZNK5clang10ASTContext32getSubstTemplateTemplateParmPackEPNS_24TemplateTemplateParmDeclERKNS_16TemplateArgumentE", "clang::ASTContext::getSubstTemplateTemplateParmPack(clang::TemplateTemplateParmDecl*, clang::TemplateArgument const&) const"},
    {"_ZN5clang10ASTContext19hasSameTemplateNameENS_12TemplateNameES1_", "clang::ASTContext::hasSameTemplateName(clang::TemplateName, clang::TemplateName)"},
    {"_ZNK5clang10ASTContext24getDependentTemplateNameEPNS_19NestedNameSpecifierEPKNS_14IdentifierInfoE", "clang::ASTContext::getDependentTemplateName(clang::NestedNameSpecifier*, clang::IdentifierInfo const*) const"},
    {"_ZNK5clang10ASTContext18getBaseElementTypeENS_8QualTypeE", "clang::ASTContext::getBaseElementType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext28getConstantArrayElementCountEPKNS_17ConstantArrayTypeE", "clang::ASTContext::getConstantArrayElementCount(clang::ConstantArrayType const*) const"},
    {"_ZNK5clang10ASTContext33getFloatingTypeOfSizeWithinDomainENS_8QualTypeES1_", "clang::ASTContext::getFloatingTypeOfSizeWithinDomain(clang::QualType, clang::QualType) const"},
    {"_ZNK5clang10ASTContext20getFloatingTypeOrderENS_8QualTypeES1_", "clang::ASTContext::getFloatingTypeOrder(clang::QualType, clang::QualType) const"},
    {"_ZNK5clang10ASTContext14getIntegerRankEPKNS_4TypeE", "clang::ASTContext::getIntegerRank(clang::Type const*) const"},
    {"_ZNK5clang10ASTContext11getIntWidthENS_8QualTypeE", "clang::ASTContext::getIntWidth(clang::QualType) const"},
    {"_ZNK5clang10ASTContext20isPromotableBitFieldEPNS_4ExprE", "clang::ASTContext::isPromotableBitField(clang::Expr*) const"},
    {"_ZNK5clang10ASTContext22getPromotedIntegerTypeENS_8QualTypeE", "clang::ASTContext::getPromotedIntegerType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext19getIntegerTypeOrderENS_8QualTypeES1_", "clang::ASTContext::getIntegerTypeOrder(clang::QualType, clang::QualType) const"},
    {"_ZNK5clang10ASTContext23getCFConstantStringTypeEv", "clang::ASTContext::getCFConstantStringType() const"},
    {"_ZN5clang10ASTContext23setCFConstantStringTypeENS_8QualTypeE", "clang::ASTContext::setCFConstantStringType(clang::QualType)"},
    {"_ZNK5clang10ASTContext23getNSConstantStringTypeEv", "clang::ASTContext::getNSConstantStringType() const"},
    {"_ZN5clang10ASTContext23setNSConstantStringTypeENS_8QualTypeE", "clang::ASTContext::setNSConstantStringType(clang::QualType)"},
    {"_ZNK5clang10ASTContext31getObjCFastEnumerationStateTypeEv", "clang::ASTContext::getObjCFastEnumerationStateType() const"},
    {"_ZNK5clang10ASTContext22getBlockDescriptorTypeEv", "clang::ASTContext::getBlockDescriptorType() const"},
    {"_ZN5clang10ASTContext22setBlockDescriptorTypeENS_8QualTypeE", "clang::ASTContext::setBlockDescriptorType(clang::QualType)"},
    {"_ZNK5clang10ASTContext30getBlockDescriptorExtendedTypeEv", "clang::ASTContext::getBlockDescriptorExtendedType() const"},
    {"_ZN5clang10ASTContext30setBlockDescriptorExtendedTypeENS_8QualTypeE", "clang::ASTContext::setBlockDescriptorExtendedType(clang::QualType)"},
    {"_ZNK5clang10ASTContext20BlockRequiresCopyingENS_8QualTypeE", "clang::ASTContext::BlockRequiresCopying(clang::QualType) const"},
    {"_ZNK5clang10ASTContext18isObjCNSObjectTypeENS_8QualTypeE", "clang::ASTContext::isObjCNSObjectType(clang::QualType) const"},
    {"_ZNK5clang10ASTContext14BuildByRefTypeEN4llvm9StringRefENS_8QualTypeE", "clang::ASTContext::BuildByRefType(llvm::StringRef, clang::QualType) const"},
    {"_ZNK5clang10ASTContext16getBlockParmTypeEbRN4llvm15SmallVectorImplIPKNS_4ExprEEE", "clang::ASTContext::getBlockParmType(bool, llvm::SmallVectorImpl<clang::Expr const*>&) const"},
    {"_ZN5clang10ASTContext31setObjCFastEnumerationStateTypeENS_8QualTypeE", "clang::ASTContext::setObjCFastEnumerationStateType(clang::QualType)"},
    {"_ZNK5clang10ASTContext23getObjCEncodingTypeSizeENS_8QualTypeE", "clang::ASTContext::getObjCEncodingTypeSize(clang::QualType) const"},
    {"_ZNK5clang10ASTContext23getObjCEncodingForBlockEPKNS_9BlockExprE", "clang::ASTContext::getObjCEncodingForBlock(clang::BlockExpr const*) const"},
    {"_ZNK5clang10ASTContext22getObjCEncodingForTypeENS_8QualTypeERSsPKNS_9FieldDeclE", "clang::ASTContext::getObjCEncodingForType(clang::QualType, std::string&, clang::FieldDecl const*) const"},
    {"_Z17charUnitsToStringRKN5clang9CharUnitsE", "charUnitsToString(clang::CharUnits const&)"},
    {"_ZN5clang10ASTContext30getObjCEncodingForFunctionDeclEPKNS_12FunctionDeclERSs", "clang::ASTContext::getObjCEncodingForFunctionDecl(clang::FunctionDecl const*, std::string&)"},
    {"_ZNK5clang10ASTContext28getObjCEncodingForMethodDeclEPKNS_14ObjCMethodDeclERSs", "clang::ASTContext::getObjCEncodingForMethodDecl(clang::ObjCMethodDecl const*, std::string&) const"},
    {"_ZNK5clang10ASTContext31getObjCEncodingForTypeQualifierENS_4Decl17ObjCDeclQualifierERSs", "clang::ASTContext::getObjCEncodingForTypeQualifier(clang::Decl::ObjCDeclQualifier, std::string&) const"},
    {"_ZNK5clang10ASTContext30getObjCEncodingForPropertyDeclEPKNS_16ObjCPropertyDeclEPKNS_4DeclERSs", "clang::ASTContext::getObjCEncodingForPropertyDecl(clang::ObjCPropertyDecl const*, clang::Decl const*, std::string&) const"},
    {"_ZNK5clang10ASTContext26getObjCEncodingForTypeImplENS_8QualTypeERSsbbPKNS_9FieldDeclEbb", "clang::ASTContext::getObjCEncodingForTypeImpl(clang::QualType, std::string&, bool, bool, clang::FieldDecl const*, bool, bool) const"},
    {"_ZNK5clang10ASTContext29getLegacyIntegralTypeEncodingERNS_8QualTypeE", "clang::ASTContext::getLegacyIntegralTypeEncoding(clang::QualType&) const"},
    {"_Z14EncodeBitFieldPKN5clang10ASTContextERSsNS_8QualTypeEPKNS_9FieldDeclE", "EncodeBitField(clang::ASTContext const*, std::string&, clang::QualType, clang::FieldDecl const*)"},
    {"_Z28ObjCEncodingForPrimitiveKindPKN5clang10ASTContextENS_8QualTypeE", "ObjCEncodingForPrimitiveKind(clang::ASTContext const*, clang::QualType)"},
    {"_ZN5clang10ASTContext20setBuiltinVaListTypeENS_8QualTypeE", "clang::ASTContext::setBuiltinVaListType(clang::QualType)"},
    {"_ZN5clang10ASTContext13setObjCIdTypeENS_8QualTypeE", "clang::ASTContext::setObjCIdType(clang::QualType)"},
    {"_ZN5clang10ASTContext14setObjCSelTypeENS_8QualTypeE", "clang::ASTContext::setObjCSelType(clang::QualType)"},
    {"_ZN5clang10ASTContext16setObjCProtoTypeENS_8QualTypeE", "clang::ASTContext::setObjCProtoType(clang::QualType)"},
    {"_ZN5clang10ASTContext16setObjCClassTypeENS_8QualTypeE", "clang::ASTContext::setObjCClassType(clang::QualType)"},
    {"_ZN5clang10ASTContext30setObjCConstantStringInterfaceEPNS_17ObjCInterfaceDeclE", "clang::ASTContext::setObjCConstantStringInterface(clang::ObjCInterfaceDecl*)"},
    {"_ZNK5clang10ASTContext25getOverloadedTemplateNameENS_21UnresolvedSetIteratorES1_", "clang::ASTContext::getOverloadedTemplateName(clang::UnresolvedSetIterator, clang::UnresolvedSetIterator) const"},
    {"_ZNK5clang10ASTContext24getQualifiedTemplateNameEPNS_19NestedNameSpecifierEbPNS_12TemplateDeclE", "clang::ASTContext::getQualifiedTemplateName(clang::NestedNameSpecifier*, bool, clang::TemplateDecl*) const"},
    {"_ZNK5clang10ASTContext24getDependentTemplateNameEPNS_19NestedNameSpecifierENS_22OverloadedOperatorKindE", "clang::ASTContext::getDependentTemplateName(clang::NestedNameSpecifier*, clang::OverloadedOperatorKind) const"},
    {"_ZNK5clang10ASTContext17getObjCGCAttrKindENS_8QualTypeE", "clang::ASTContext::getObjCGCAttrKind(clang::QualType) const"},
    {"_ZN5clang10ASTContext24areCompatibleVectorTypesENS_8QualTypeES1_", "clang::ASTContext::areCompatibleVectorTypes(clang::QualType, clang::QualType)"},
    {"_ZNK5clang10ASTContext30ProtocolCompatibleWithProtocolEPNS_16ObjCProtocolDeclES2_", "clang::ASTContext::ProtocolCompatibleWithProtocol(clang::ObjCProtocolDecl*, clang::ObjCProtocolDecl*) const"},
    {"_ZN5clang10ASTContext30QualifiedIdConformsQualifiedIdENS_8QualTypeES1_", "clang::ASTContext::QualifiedIdConformsQualifiedId(clang::QualType, clang::QualType)"},
    {"_ZN5clang10ASTContext33ObjCQualifiedIdTypesAreCompatibleENS_8QualTypeES1_b", "clang::ASTContext::ObjCQualifiedIdTypesAreCompatible(clang::QualType, clang::QualType, bool)"},
    {"_ZN5clang10ASTContext36ObjCQualifiedClassTypesAreCompatibleENS_8QualTypeES1_", "clang::ASTContext::ObjCQualifiedClassTypesAreCompatible(clang::QualType, clang::QualType)"},
    {"_ZN5clang10ASTContext23canAssignObjCInterfacesEPKNS_21ObjCObjectPointerTypeES3_", "clang::ASTContext::canAssignObjCInterfaces(clang::ObjCObjectPointerType const*, clang::ObjCObjectPointerType const*)"},
    {"_ZN5clang10ASTContext23canAssignObjCInterfacesEPKNS_14ObjCObjectTypeES3_", "clang::ASTContext::canAssignObjCInterfaces(clang::ObjCObjectType const*, clang::ObjCObjectType const*)"},
    {"_ZN5clang10ASTContext37canAssignObjCInterfacesInBlockPointerEPKNS_21ObjCObjectPointerTypeES3_", "clang::ASTContext::canAssignObjCInterfacesInBlockPointer(clang::ObjCObjectPointerType const*, clang::ObjCObjectPointerType const*)"},
    {"_ZN5clang10ASTContext23areCommonBaseCompatibleEPKNS_21ObjCObjectPointerTypeES3_", "clang::ASTContext::areCommonBaseCompatible(clang::ObjCObjectPointerType const*, clang::ObjCObjectPointerType const*)"},
    {"_ZN5clang10ASTContext29areComparableObjCPointerTypesENS_8QualTypeES1_", "clang::ASTContext::areComparableObjCPointerTypes(clang::QualType, clang::QualType)"},
    {"_ZN5clang10ASTContext21canBindObjCObjectTypeENS_8QualTypeES1_", "clang::ASTContext::canBindObjCObjectType(clang::QualType, clang::QualType)"},
    {"_ZN5clang10ASTContext18typesAreCompatibleENS_8QualTypeES1_b", "clang::ASTContext::typesAreCompatible(clang::QualType, clang::QualType, bool)"},
    {"_ZN5clang10ASTContext10mergeTypesENS_8QualTypeES1_bb", "clang::ASTContext::mergeTypes(clang::QualType, clang::QualType, bool, bool)"},
    {"_ZN5clang10ASTContext30typesAreBlockPointerCompatibleENS_8QualTypeES1_", "clang::ASTContext::typesAreBlockPointerCompatible(clang::QualType, clang::QualType)"},
    {"_ZN5clang10ASTContext25mergeTransparentUnionTypeENS_8QualTypeES1_bb", "clang::ASTContext::mergeTransparentUnionType(clang::QualType, clang::QualType, bool, bool)"},
    {"_ZN5clang10ASTContext26mergeFunctionArgumentTypesENS_8QualTypeES1_bb", "clang::ASTContext::mergeFunctionArgumentTypes(clang::QualType, clang::QualType, bool, bool)"},
    {"_ZN5clang10ASTContext18mergeFunctionTypesENS_8QualTypeES1_bb", "clang::ASTContext::mergeFunctionTypes(clang::QualType, clang::QualType, bool, bool)"},
    {"_ZN5clang10ASTContext21mergeObjCGCQualifiersENS_8QualTypeES1_", "clang::ASTContext::mergeObjCGCQualifiers(clang::QualType, clang::QualType)"},
    {"_ZN5clang10ASTContext28getCorrespondingUnsignedTypeENS_8QualTypeE", "clang::ASTContext::getCorrespondingUnsignedType(clang::QualType)"},
    {"_ZN5clang17ExternalASTSourceD0Ev", "clang::ExternalASTSource::~ExternalASTSource()"},
    {"_ZN5clang17ExternalASTSourceD1Ev", "clang::ExternalASTSource::~ExternalASTSource()"},
    {"_ZN5clang17ExternalASTSourceD2Ev", "clang::ExternalASTSource::~ExternalASTSource()"},
    {"_ZN5clang17ExternalASTSource10PrintStatsEv", "clang::ExternalASTSource::PrintStats()"},
    {"_ZN5clang19ASTMutationListenerD0Ev", "clang::ASTMutationListener::~ASTMutationListener()"},
    {"_ZN5clang19ASTMutationListenerD1Ev", "clang::ASTMutationListener::~ASTMutationListener()"},
    {"_ZN5clang19ASTMutationListenerD2Ev", "clang::ASTMutationListener::~ASTMutationListener()"},
    {"_ZNK5clang10ASTContext14GetBuiltinTypeEjRNS0_19GetBuiltinTypeErrorEPj", "clang::ASTContext::GetBuiltinType(unsigned int, clang::ASTContext::GetBuiltinTypeError&, unsigned int*) const"},
    {"_Z17DecodeTypeFromStrRPKcRKN5clang10ASTContextERNS3_19GetBuiltinTypeErrorERbb", "DecodeTypeFromStr(char const*&, clang::ASTContext const&, clang::ASTContext::GetBuiltinTypeError&, bool&, bool)"},
    {"_ZN5clang10ASTContext24GetGVALinkageForFunctionEPKNS_12FunctionDeclE", "clang::ASTContext::GetGVALinkageForFunction(clang::FunctionDecl const*)"},
    {"_ZN5clang10ASTContext24GetGVALinkageForVariableEPKNS_7VarDeclE", "clang::ASTContext::GetGVALinkageForVariable(clang::VarDecl const*)"},
    {"_ZN5clang10ASTContext17DeclMustBeEmittedEPKNS_4DeclE", "clang::ASTContext::DeclMustBeEmitted(clang::Decl const*)"},
    {"_ZN5clang10ASTContext24getDefaultMethodCallConvEv", "clang::ASTContext::getDefaultMethodCallConv()"},
    {"_ZNK5clang10ASTContext13isNearlyEmptyEPKNS_13CXXRecordDeclE", "clang::ASTContext::isNearlyEmpty(clang::CXXRecordDecl const*) const"},
    {"_ZN5clang10ASTContext19createMangleContextEv", "clang::ASTContext::createMangleContext()"},
    {"_ZN5clang6CXXABID0Ev", "clang::CXXABI::~CXXABI()"},
    {"_ZN5clang6CXXABID1Ev", "clang::CXXABI::~CXXABI()"},
    {"_ZN5clang6CXXABID2Ev", "clang::CXXABI::~CXXABI()"},
    {"_Z16CmpProtocolNamesPKN5clang16ObjCProtocolDeclES2_", "CmpProtocolNames(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*)"},
    {"_ZN4llvm10FoldingSetIN5clang10ASTContext29CanonicalTemplateTemplateParmEED1Ev", "llvm::FoldingSet<clang::ASTContext::CanonicalTemplateTemplateParm>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang19NestedNameSpecifierEED1Ev", "llvm::FoldingSet<clang::NestedNameSpecifier>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang36SubstTemplateTemplateParmPackStorageEED1Ev", "llvm::FoldingSet<clang::SubstTemplateTemplateParmPackStorage>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang21DependentTemplateNameEED1Ev", "llvm::FoldingSet<clang::DependentTemplateName>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang21QualifiedTemplateNameEED1Ev", "llvm::FoldingSet<clang::QualifiedTemplateName>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang14AttributedTypeEED1Ev", "llvm::FoldingSet<clang::AttributedType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang21ObjCObjectPointerTypeEED1Ev", "llvm::FoldingSet<clang::ObjCObjectPointerType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang18ObjCObjectTypeImplEED1Ev", "llvm::FoldingSet<clang::ObjCObjectTypeImpl>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang17PackExpansionTypeEED1Ev", "llvm::FoldingSet<clang::PackExpansionType>::~FoldingSet()"},
    {"_ZN4llvm20ContextualFoldingSetIN5clang35DependentTemplateSpecializationTypeERNS1_10ASTContextEED1Ev", "llvm::ContextualFoldingSet<clang::DependentTemplateSpecializationType, clang::ASTContext&>::~ContextualFoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang17DependentNameTypeEED1Ev", "llvm::FoldingSet<clang::DependentNameType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang14ElaboratedTypeEED1Ev", "llvm::FoldingSet<clang::ElaboratedType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang9ParenTypeEED1Ev", "llvm::FoldingSet<clang::ParenType>::~FoldingSet()"},
    {"_ZN4llvm20ContextualFoldingSetIN5clang26TemplateSpecializationTypeERNS1_10ASTContextEED1Ev", "llvm::ContextualFoldingSet<clang::TemplateSpecializationType, clang::ASTContext&>::~ContextualFoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang29SubstTemplateTypeParmPackTypeEED1Ev", "llvm::FoldingSet<clang::SubstTemplateTypeParmPackType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang25SubstTemplateTypeParmTypeEED1Ev", "llvm::FoldingSet<clang::SubstTemplateTypeParmType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang20TemplateTypeParmTypeEED1Ev", "llvm::FoldingSet<clang::TemplateTypeParmType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang21DependentDecltypeTypeEED1Ev", "llvm::FoldingSet<clang::DependentDecltypeType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang23DependentTypeOfExprTypeEED1Ev", "llvm::FoldingSet<clang::DependentTypeOfExprType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang17FunctionProtoTypeEED1Ev", "llvm::FoldingSet<clang::FunctionProtoType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang19FunctionNoProtoTypeEED1Ev", "llvm::FoldingSet<clang::FunctionNoProtoType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang10VectorTypeEED1Ev", "llvm::FoldingSet<clang::VectorType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang27DependentSizedExtVectorTypeEED1Ev", "llvm::FoldingSet<clang::DependentSizedExtVectorType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang23DependentSizedArrayTypeEED1Ev", "llvm::FoldingSet<clang::DependentSizedArrayType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang19IncompleteArrayTypeEED1Ev", "llvm::FoldingSet<clang::IncompleteArrayType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang17ConstantArrayTypeEED1Ev", "llvm::FoldingSet<clang::ConstantArrayType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang17MemberPointerTypeEED1Ev", "llvm::FoldingSet<clang::MemberPointerType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang19RValueReferenceTypeEED1Ev", "llvm::FoldingSet<clang::RValueReferenceType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang19LValueReferenceTypeEED1Ev", "llvm::FoldingSet<clang::LValueReferenceType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang16BlockPointerTypeEED1Ev", "llvm::FoldingSet<clang::BlockPointerType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang11PointerTypeEED1Ev", "llvm::FoldingSet<clang::PointerType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang11ComplexTypeEED1Ev", "llvm::FoldingSet<clang::ComplexType>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang8ExtQualsEED1Ev", "llvm::FoldingSet<clang::ExtQuals>::~FoldingSet()"},
    {"_ZN5clang20UsuallyTinyPtrVectorIKNS_13CXXMethodDeclEE9push_backEPS2_", "clang::UsuallyTinyPtrVector<clang::CXXMethodDecl const>::push_back(clang::CXXMethodDecl const*)"},
    {"_ZNK5clang4Decl15getMaxAlignmentEv", "clang::Decl::getMaxAlignment() const"},
    {"_ZNK5clang16ObjCCategoryDecl9ivar_sizeEv", "clang::ObjCCategoryDecl::ivar_size() const"},
    {"_ZNK5clang22ObjCImplementationDecl9ivar_sizeEv", "clang::ObjCImplementationDecl::ivar_size() const"},
    {"_ZN4llvm15SmallVectorImplIN5clang16TemplateArgumentEE9push_backERKS2_", "llvm::SmallVectorImpl<clang::TemplateArgument>::push_back(clang::TemplateArgument const&)"},
    {"_ZN5clang16TemplateArgumentaSERKS0_", "clang::TemplateArgument::operator=(clang::TemplateArgument const&)"},
    {"_ZNK5clang4Decl7getAttrINS_16ObjCNSObjectAttrEEEPT_v", "clang::ObjCNSObjectAttr* clang::Decl::getAttr<clang::ObjCNSObjectAttr>() const"},
    {"_ZNK5clang4Type17isObjCBuiltinTypeEv", "clang::Type::isObjCBuiltinType() const"},
    {"_ZN5clang17ExternalASTSource12CompleteTypeEPNS_7TagDeclE", "clang::ExternalASTSource::CompleteType(clang::TagDecl*)"},
    {"_ZN5clang17ExternalASTSource12CompleteTypeEPNS_17ObjCInterfaceDeclE", "clang::ExternalASTSource::CompleteType(clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang17ExternalASTSource20StartedDeserializingEv", "clang::ExternalASTSource::StartedDeserializing()"},
    {"_ZN5clang17ExternalASTSource21FinishedDeserializingEv", "clang::ExternalASTSource::FinishedDeserializing()"},
    {"_ZN5clang17ExternalASTSource20StartTranslationUnitEPNS_11ASTConsumerE", "clang::ExternalASTSource::StartTranslationUnit(clang::ASTConsumer*)"},
    {"_ZN5clang19ASTMutationListener22CompletedTagDefinitionEPKNS_7TagDeclE", "clang::ASTMutationListener::CompletedTagDefinition(clang::TagDecl const*)"},
    {"_ZN5clang19ASTMutationListener16AddedVisibleDeclEPKNS_11DeclContextEPKNS_4DeclE", "clang::ASTMutationListener::AddedVisibleDecl(clang::DeclContext const*, clang::Decl const*)"},
    {"_ZN5clang19ASTMutationListener22AddedCXXImplicitMemberEPKNS_13CXXRecordDeclEPKNS_4DeclE", "clang::ASTMutationListener::AddedCXXImplicitMember(clang::CXXRecordDecl const*, clang::Decl const*)"},
    {"_ZN5clang19ASTMutationListener30AddedCXXTemplateSpecializationEPKNS_17ClassTemplateDeclEPKNS_31ClassTemplateSpecializationDeclE", "clang::ASTMutationListener::AddedCXXTemplateSpecialization(clang::ClassTemplateDecl const*, clang::ClassTemplateSpecializationDecl const*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang16TemplateArgumentELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::TemplateArgument, false>::grow(unsigned long)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang16TemplateArgumentELb0EE18uninitialized_copyIPS2_S5_EEvT_S6_T0_", "void llvm::SmallVectorTemplateBase<clang::TemplateArgument, false>::uninitialized_copy<clang::TemplateArgument*, clang::TemplateArgument*>(clang::TemplateArgument*, clang::TemplateArgument*, clang::TemplateArgument*)"},
    {"_ZNSt6vectorIPN5clang17VariableArrayTypeESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::VariableArrayType*, std::allocator<clang::VariableArrayType*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::VariableArrayType**, std::vector<clang::VariableArrayType*, std::allocator<clang::VariableArrayType*>>>, clang::VariableArrayType* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclEPNS1_4ExprENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::VarDecl const*, clang::Expr*, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<clang::Expr*>>::InsertIntoBucket(clang::VarDecl const* const&, clang::Expr* const&, std::pair<clang::VarDecl const*, clang::Expr*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclEPNS1_4ExprENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::VarDecl const*, clang::Expr*, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<clang::Expr*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang17ObjCContainerDeclEPNS1_12ObjCImplDeclENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::ObjCContainerDecl*, clang::ObjCImplDecl*, llvm::DenseMapInfo<clang::ObjCContainerDecl*>, llvm::DenseMapInfo<clang::ObjCImplDecl*>>::InsertIntoBucket(clang::ObjCContainerDecl* const&, clang::ObjCImplDecl* const&, std::pair<clang::ObjCContainerDecl*, clang::ObjCImplDecl*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang17ObjCContainerDeclEPNS1_12ObjCImplDeclENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::ObjCContainerDecl*, clang::ObjCImplDecl*, llvm::DenseMapInfo<clang::ObjCContainerDecl*>, llvm::DenseMapInfo<clang::ObjCImplDecl*>>::grow(unsigned int)"},
    {"_ZNSt6vectorIPKN5clang13CXXMethodDeclESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<clang::CXXMethodDecl const*, std::allocator<clang::CXXMethodDecl const*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::CXXMethodDecl const**, std::vector<clang::CXXMethodDecl const*, std::allocator<clang::CXXMethodDecl const*>>>, clang::CXXMethodDecl const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclENS1_20UsuallyTinyPtrVectorIS3_EENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::CXXMethodDecl const*, clang::UsuallyTinyPtrVector<clang::CXXMethodDecl const>, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<clang::UsuallyTinyPtrVector<clang::CXXMethodDecl const>>>::InsertIntoBucket(clang::CXXMethodDecl const* const&, clang::UsuallyTinyPtrVector<clang::CXXMethodDecl const> const&, std::pair<clang::CXXMethodDecl const*, clang::UsuallyTinyPtrVector<clang::CXXMethodDecl const>>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclENS1_20UsuallyTinyPtrVectorIS3_EENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::CXXMethodDecl const*, clang::UsuallyTinyPtrVector<clang::CXXMethodDecl const>, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<clang::UsuallyTinyPtrVector<clang::CXXMethodDecl const>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang9FieldDeclES3_NS_12DenseMapInfoIS3_EES5_E16InsertIntoBucketERKS3_S8_PSt4pairIS3_S3_E", "llvm::DenseMap<clang::FieldDecl*, clang::FieldDecl*, llvm::DenseMapInfo<clang::FieldDecl*>, llvm::DenseMapInfo<clang::FieldDecl*>>::InsertIntoBucket(clang::FieldDecl* const&, clang::FieldDecl* const&, std::pair<clang::FieldDecl*, clang::FieldDecl*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang9FieldDeclES3_NS_12DenseMapInfoIS3_EES5_E4growEj", "llvm::DenseMap<clang::FieldDecl*, clang::FieldDecl*, llvm::DenseMapInfo<clang::FieldDecl*>, llvm::DenseMapInfo<clang::FieldDecl*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang15UsingShadowDeclES3_NS_12DenseMapInfoIS3_EES5_E16InsertIntoBucketERKS3_S8_PSt4pairIS3_S3_E", "llvm::DenseMap<clang::UsingShadowDecl*, clang::UsingShadowDecl*, llvm::DenseMapInfo<clang::UsingShadowDecl*>, llvm::DenseMapInfo<clang::UsingShadowDecl*>>::InsertIntoBucket(clang::UsingShadowDecl* const&, clang::UsingShadowDecl* const&, std::pair<clang::UsingShadowDecl*, clang::UsingShadowDecl*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang15UsingShadowDeclES3_NS_12DenseMapInfoIS3_EES5_E4growEj", "llvm::DenseMap<clang::UsingShadowDecl*, clang::UsingShadowDecl*, llvm::DenseMapInfo<clang::UsingShadowDecl*>, llvm::DenseMapInfo<clang::UsingShadowDecl*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang9UsingDeclEPNS1_9NamedDeclENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::UsingDecl*, clang::NamedDecl*, llvm::DenseMapInfo<clang::UsingDecl*>, llvm::DenseMapInfo<clang::NamedDecl*>>::InsertIntoBucket(clang::UsingDecl* const&, clang::NamedDecl* const&, std::pair<clang::UsingDecl*, clang::NamedDecl*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang9UsingDeclEPNS1_9NamedDeclENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::UsingDecl*, clang::NamedDecl*, llvm::DenseMapInfo<clang::UsingDecl*>, llvm::DenseMapInfo<clang::NamedDecl*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclEPNS1_24MemberSpecializationInfoENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::VarDecl const*, clang::MemberSpecializationInfo*, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<clang::MemberSpecializationInfo*>>::InsertIntoBucket(clang::VarDecl const* const&, clang::MemberSpecializationInfo* const&, std::pair<clang::VarDecl const*, clang::MemberSpecializationInfo*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang7VarDeclEPNS1_24MemberSpecializationInfoENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::VarDecl const*, clang::MemberSpecializationInfo*, llvm::DenseMapInfo<clang::VarDecl const*>, llvm::DenseMapInfo<clang::MemberSpecializationInfo*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclEPNS_11SmallVectorIPNS1_4AttrELj2EEENS_12DenseMapInfoIS4_EENSA_IS9_EEE16InsertIntoBucketERKS4_RKS9_PSt4pairIS4_S9_E", "llvm::DenseMap<clang::Decl const*, llvm::SmallVector<clang::Attr*, 2u>*, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::Attr*, 2u>*>>::InsertIntoBucket(clang::Decl const* const&, llvm::SmallVector<clang::Attr*, 2u>* const&, std::pair<clang::Decl const*, llvm::SmallVector<clang::Attr*, 2u>*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4DeclEPNS_11SmallVectorIPNS1_4AttrELj2EEENS_12DenseMapInfoIS4_EENSA_IS9_EEE4growEj", "llvm::DenseMap<clang::Decl const*, llvm::SmallVector<clang::Attr*, 2u>*, llvm::DenseMapInfo<clang::Decl const*>, llvm::DenseMapInfo<llvm::SmallVector<clang::Attr*, 2u>*>>::grow(unsigned int)"},
    {"_ZNSt6vectorIPN5clang4TypeESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::Type*, std::allocator<clang::Type*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::Type**, std::vector<clang::Type*, std::allocator<clang::Type*>>>, clang::Type* const&)"},
    {"_ZN4llvm10FoldingSetIN5clang10ASTContext29CanonicalTemplateTemplateParmEED0Ev", "llvm::FoldingSet<clang::ASTContext::CanonicalTemplateTemplateParm>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang10ASTContext29CanonicalTemplateTemplateParmEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ASTContext::CanonicalTemplateTemplateParm>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang10ASTContext29CanonicalTemplateTemplateParmEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS8_", "llvm::FoldingSet<clang::ASTContext::CanonicalTemplateTemplateParm>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang10ASTContext29CanonicalTemplateTemplateParmEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ASTContext::CanonicalTemplateTemplateParm>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang19NestedNameSpecifierEED0Ev", "llvm::FoldingSet<clang::NestedNameSpecifier>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang19NestedNameSpecifierEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::NestedNameSpecifier>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang19NestedNameSpecifierEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::NestedNameSpecifier>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang19NestedNameSpecifierEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::NestedNameSpecifier>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang36SubstTemplateTemplateParmPackStorageEED0Ev", "llvm::FoldingSet<clang::SubstTemplateTemplateParmPackStorage>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang36SubstTemplateTemplateParmPackStorageEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::SubstTemplateTemplateParmPackStorage>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang36SubstTemplateTemplateParmPackStorageEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::SubstTemplateTemplateParmPackStorage>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang36SubstTemplateTemplateParmPackStorageEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::SubstTemplateTemplateParmPackStorage>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang21DependentTemplateNameEED0Ev", "llvm::FoldingSet<clang::DependentTemplateName>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang21DependentTemplateNameEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentTemplateName>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang21DependentTemplateNameEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::DependentTemplateName>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang21DependentTemplateNameEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentTemplateName>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang21DependentTemplateName7ProfileERN4llvm16FoldingSetNodeIDE", "clang::DependentTemplateName::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN4llvm10FoldingSetIN5clang21QualifiedTemplateNameEED0Ev", "llvm::FoldingSet<clang::QualifiedTemplateName>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang21QualifiedTemplateNameEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::QualifiedTemplateName>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang21QualifiedTemplateNameEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::QualifiedTemplateName>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang21QualifiedTemplateNameEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::QualifiedTemplateName>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang14AttributedTypeEED0Ev", "llvm::FoldingSet<clang::AttributedType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang14AttributedTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::AttributedType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang14AttributedTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::AttributedType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang14AttributedTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::AttributedType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang21ObjCObjectPointerTypeEED0Ev", "llvm::FoldingSet<clang::ObjCObjectPointerType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang21ObjCObjectPointerTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ObjCObjectPointerType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang21ObjCObjectPointerTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::ObjCObjectPointerType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang21ObjCObjectPointerTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ObjCObjectPointerType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang18ObjCObjectTypeImplEED0Ev", "llvm::FoldingSet<clang::ObjCObjectTypeImpl>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang18ObjCObjectTypeImplEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ObjCObjectTypeImpl>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang18ObjCObjectTypeImplEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::ObjCObjectTypeImpl>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang18ObjCObjectTypeImplEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ObjCObjectTypeImpl>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang17PackExpansionTypeEED0Ev", "llvm::FoldingSet<clang::PackExpansionType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang17PackExpansionTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::PackExpansionType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang17PackExpansionTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::PackExpansionType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang17PackExpansionTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::PackExpansionType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang17DependentNameTypeEED0Ev", "llvm::FoldingSet<clang::DependentNameType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang17DependentNameTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentNameType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang17DependentNameTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::DependentNameType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang17DependentNameTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentNameType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang14ElaboratedTypeEED0Ev", "llvm::FoldingSet<clang::ElaboratedType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang14ElaboratedTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ElaboratedType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang14ElaboratedTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::ElaboratedType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang14ElaboratedTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ElaboratedType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang9ParenTypeEED0Ev", "llvm::FoldingSet<clang::ParenType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang9ParenTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ParenType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang9ParenTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::ParenType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang9ParenTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ParenType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang29SubstTemplateTypeParmPackTypeEED0Ev", "llvm::FoldingSet<clang::SubstTemplateTypeParmPackType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang29SubstTemplateTypeParmPackTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::SubstTemplateTypeParmPackType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang29SubstTemplateTypeParmPackTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::SubstTemplateTypeParmPackType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang29SubstTemplateTypeParmPackTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::SubstTemplateTypeParmPackType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang25SubstTemplateTypeParmTypeEED0Ev", "llvm::FoldingSet<clang::SubstTemplateTypeParmType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang25SubstTemplateTypeParmTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::SubstTemplateTypeParmType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang25SubstTemplateTypeParmTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::SubstTemplateTypeParmType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang25SubstTemplateTypeParmTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::SubstTemplateTypeParmType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang20TemplateTypeParmTypeEED0Ev", "llvm::FoldingSet<clang::TemplateTypeParmType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang20TemplateTypeParmTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::TemplateTypeParmType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang20TemplateTypeParmTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::TemplateTypeParmType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang20TemplateTypeParmTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::TemplateTypeParmType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang21DependentDecltypeTypeEED0Ev", "llvm::FoldingSet<clang::DependentDecltypeType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang21DependentDecltypeTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentDecltypeType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang21DependentDecltypeTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::DependentDecltypeType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang21DependentDecltypeTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentDecltypeType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang23DependentTypeOfExprTypeEED0Ev", "llvm::FoldingSet<clang::DependentTypeOfExprType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang23DependentTypeOfExprTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentTypeOfExprType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang23DependentTypeOfExprTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::DependentTypeOfExprType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang23DependentTypeOfExprTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentTypeOfExprType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang17FunctionProtoTypeEED0Ev", "llvm::FoldingSet<clang::FunctionProtoType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang17FunctionProtoTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::FunctionProtoType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang17FunctionProtoTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::FunctionProtoType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang17FunctionProtoTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::FunctionProtoType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang19FunctionNoProtoTypeEED0Ev", "llvm::FoldingSet<clang::FunctionNoProtoType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang19FunctionNoProtoTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::FunctionNoProtoType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang19FunctionNoProtoTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::FunctionNoProtoType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang19FunctionNoProtoTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::FunctionNoProtoType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang10VectorTypeEED0Ev", "llvm::FoldingSet<clang::VectorType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang10VectorTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::VectorType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang10VectorTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::VectorType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang10VectorTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::VectorType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang27DependentSizedExtVectorTypeEED0Ev", "llvm::FoldingSet<clang::DependentSizedExtVectorType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang27DependentSizedExtVectorTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentSizedExtVectorType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang27DependentSizedExtVectorTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::DependentSizedExtVectorType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang27DependentSizedExtVectorTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentSizedExtVectorType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang23DependentSizedArrayTypeEED0Ev", "llvm::FoldingSet<clang::DependentSizedArrayType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang23DependentSizedArrayTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentSizedArrayType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang23DependentSizedArrayTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::DependentSizedArrayType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang23DependentSizedArrayTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::DependentSizedArrayType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang19IncompleteArrayTypeEED0Ev", "llvm::FoldingSet<clang::IncompleteArrayType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang19IncompleteArrayTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::IncompleteArrayType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang19IncompleteArrayTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::IncompleteArrayType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang19IncompleteArrayTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::IncompleteArrayType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang17ConstantArrayTypeEED0Ev", "llvm::FoldingSet<clang::ConstantArrayType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang17ConstantArrayTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ConstantArrayType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang17ConstantArrayTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::ConstantArrayType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang17ConstantArrayTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ConstantArrayType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang17MemberPointerTypeEED0Ev", "llvm::FoldingSet<clang::MemberPointerType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang17MemberPointerTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::MemberPointerType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang17MemberPointerTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::MemberPointerType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang17MemberPointerTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::MemberPointerType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang19RValueReferenceTypeEED0Ev", "llvm::FoldingSet<clang::RValueReferenceType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang19RValueReferenceTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::RValueReferenceType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang19RValueReferenceTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::RValueReferenceType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang19RValueReferenceTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::RValueReferenceType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang19LValueReferenceTypeEED0Ev", "llvm::FoldingSet<clang::LValueReferenceType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang19LValueReferenceTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::LValueReferenceType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang19LValueReferenceTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::LValueReferenceType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang19LValueReferenceTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::LValueReferenceType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang16BlockPointerTypeEED0Ev", "llvm::FoldingSet<clang::BlockPointerType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang16BlockPointerTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::BlockPointerType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang16BlockPointerTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::BlockPointerType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang16BlockPointerTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::BlockPointerType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang11PointerTypeEED0Ev", "llvm::FoldingSet<clang::PointerType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang11PointerTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::PointerType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang11PointerTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::PointerType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang11PointerTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::PointerType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang11ComplexTypeEED0Ev", "llvm::FoldingSet<clang::ComplexType>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang11ComplexTypeEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ComplexType>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang11ComplexTypeEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::ComplexType>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang11ComplexTypeEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ComplexType>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang8ExtQualsEED0Ev", "llvm::FoldingSet<clang::ExtQuals>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang8ExtQualsEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ExtQuals>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang8ExtQualsEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::ExtQuals>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang8ExtQualsEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ExtQuals>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm20ContextualFoldingSetIN5clang35DependentTemplateSpecializationTypeERNS1_10ASTContextEED0Ev", "llvm::ContextualFoldingSet<clang::DependentTemplateSpecializationType, clang::ASTContext&>::~ContextualFoldingSet()"},
    {"_ZNK4llvm20ContextualFoldingSetIN5clang35DependentTemplateSpecializationTypeERNS1_10ASTContextEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::ContextualFoldingSet<clang::DependentTemplateSpecializationType, clang::ASTContext&>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm20ContextualFoldingSetIN5clang35DependentTemplateSpecializationTypeERNS1_10ASTContextEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS9_", "llvm::ContextualFoldingSet<clang::DependentTemplateSpecializationType, clang::ASTContext&>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm20ContextualFoldingSetIN5clang35DependentTemplateSpecializationTypeERNS1_10ASTContextEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::ContextualFoldingSet<clang::DependentTemplateSpecializationType, clang::ASTContext&>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm20ContextualFoldingSetIN5clang26TemplateSpecializationTypeERNS1_10ASTContextEED0Ev", "llvm::ContextualFoldingSet<clang::TemplateSpecializationType, clang::ASTContext&>::~ContextualFoldingSet()"},
    {"_ZNK4llvm20ContextualFoldingSetIN5clang26TemplateSpecializationTypeERNS1_10ASTContextEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::ContextualFoldingSet<clang::TemplateSpecializationType, clang::ASTContext&>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm20ContextualFoldingSetIN5clang26TemplateSpecializationTypeERNS1_10ASTContextEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS9_", "llvm::ContextualFoldingSet<clang::TemplateSpecializationType, clang::ASTContext&>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm20ContextualFoldingSetIN5clang26TemplateSpecializationTypeERNS1_10ASTContextEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::ContextualFoldingSet<clang::TemplateSpecializationType, clang::ASTContext&>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang18getFunctionExtInfoERKNS_4TypeE", "clang::getFunctionExtInfo(clang::Type const&)"},
    {"_ZSt16__introsort_loopIPPN5clang16ObjCProtocolDeclElPFbPKS1_S5_EEvT_S8_T0_T1_", "void std::__introsort_loop<clang::ObjCProtocolDecl**, long, bool (*)(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*)>(clang::ObjCProtocolDecl**, clang::ObjCProtocolDecl**, long, bool (*)(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*))"},
    {"_ZSt22__final_insertion_sortIPPN5clang16ObjCProtocolDeclEPFbPKS1_S5_EEvT_S8_T0_", "void std::__final_insertion_sort<clang::ObjCProtocolDecl**, bool (*)(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*)>(clang::ObjCProtocolDecl**, clang::ObjCProtocolDecl**, bool (*)(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*))"},
    {"_ZSt16__insertion_sortIPPN5clang16ObjCProtocolDeclEPFbPKS1_S5_EEvT_S8_T0_", "void std::__insertion_sort<clang::ObjCProtocolDecl**, bool (*)(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*)>(clang::ObjCProtocolDecl**, clang::ObjCProtocolDecl**, bool (*)(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*))"},
    {"_ZSt13__heap_selectIPPN5clang16ObjCProtocolDeclEPFbPKS1_S5_EEvT_S8_S8_T0_", "void std::__heap_select<clang::ObjCProtocolDecl**, bool (*)(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*)>(clang::ObjCProtocolDecl**, clang::ObjCProtocolDecl**, clang::ObjCProtocolDecl**, bool (*)(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*))"},
    {"_ZSt13__adjust_heapIPPN5clang16ObjCProtocolDeclElS2_PFbPKS1_S5_EEvT_T0_S9_T1_T2_", "void std::__adjust_heap<clang::ObjCProtocolDecl**, long, clang::ObjCProtocolDecl*, bool (*)(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*)>(clang::ObjCProtocolDecl**, long, long, clang::ObjCProtocolDecl*, bool (*)(clang::ObjCProtocolDecl const*, clang::ObjCProtocolDecl const*))"},
    {"_ZN5clang31FormatASTNodeDiagnosticArgumentENS_10Diagnostic12ArgumentKindElPKcjS3_jPKSt4pairIS1_lEjRN4llvm15SmallVectorImplIcEEPv", "clang::FormatASTNodeDiagnosticArgument(clang::Diagnostic::ArgumentKind, long, char const*, unsigned int, char const*, unsigned int, std::pair<clang::Diagnostic::ArgumentKind, long> const*, unsigned int, llvm::SmallVectorImpl<char>&, void*)"},
    {"_Z29ConvertTypeToDiagnosticStringRN5clang10ASTContextENS_8QualTypeEPKSt4pairINS_10Diagnostic12ArgumentKindElEj", "ConvertTypeToDiagnosticString(clang::ASTContext&, clang::QualType, std::pair<clang::Diagnostic::ArgumentKind, long> const*, unsigned int)"},
    {"_Z7DesugarRN5clang10ASTContextENS_8QualTypeERb", "Desugar(clang::ASTContext&, clang::QualType, bool&)"},
    {"_Z14ImportCastPathPN5clang8CastExprERN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEE", "ImportCastPath(clang::CastExpr*, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u>&)"},
    {"_ZN5clang11ASTImporterC1ERNS_10ASTContextERNS_11FileManagerES2_S4_b", "clang::ASTImporter::ASTImporter(clang::ASTContext&, clang::FileManager&, clang::ASTContext&, clang::FileManager&, bool)"},
    {"_ZN5clang11ASTImporterC2ERNS_10ASTContextERNS_11FileManagerES2_S4_b", "clang::ASTImporter::ASTImporter(clang::ASTContext&, clang::FileManager&, clang::ASTContext&, clang::FileManager&, bool)"},
    {"_ZN5clang11ASTImporterD0Ev", "clang::ASTImporter::~ASTImporter()"},
    {"_ZN5clang11ASTImporterD1Ev", "clang::ASTImporter::~ASTImporter()"},
    {"_ZN5clang11ASTImporterD2Ev", "clang::ASTImporter::~ASTImporter()"},
    {"_ZN5clang11ASTImporter6ImportENS_8QualTypeE", "clang::ASTImporter::Import(clang::QualType)"},
    {"_ZN5clang11ASTImporter6ImportEPNS_14TypeSourceInfoE", "clang::ASTImporter::Import(clang::TypeSourceInfo*)"},
    {"_ZN5clang11ASTImporter6ImportEPNS_4DeclE", "clang::ASTImporter::Import(clang::Decl*)"},
    {"_ZN5clang11ASTImporter13ImportContextEPNS_11DeclContextE", "clang::ASTImporter::ImportContext(clang::DeclContext*)"},
    {"_ZN5clang11ASTImporter6ImportEPNS_4ExprE", "clang::ASTImporter::Import(clang::Expr*)"},
    {"_ZN5clang11ASTImporter6ImportEPNS_4StmtE", "clang::ASTImporter::Import(clang::Stmt*)"},
    {"_ZN5clang11ASTImporter6ImportEPNS_19NestedNameSpecifierE", "clang::ASTImporter::Import(clang::NestedNameSpecifier*)"},
    {"_ZN5clang11ASTImporter6ImportENS_12TemplateNameE", "clang::ASTImporter::Import(clang::TemplateName)"},
    {"_ZN5clang11ASTImporter6ImportEPKNS_14IdentifierInfoE", "clang::ASTImporter::Import(clang::IdentifierInfo const*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter22ImportTemplateArgumentERKN5clang16TemplateArgumentE", "(anonymous namespace)::ASTNodeImporter::ImportTemplateArgument(clang::TemplateArgument const&)"},
    {"_ZN5clang11ASTImporter6ImportENS_14SourceLocationE", "clang::ASTImporter::Import(clang::SourceLocation)"},
    {"_ZN5clang11ASTImporter6ImportENS_6FileIDE", "clang::ASTImporter::Import(clang::FileID)"},
    {"_ZN5clang11ASTImporter6ImportENS_11SourceRangeE", "clang::ASTImporter::Import(clang::SourceRange)"},
    {"_ZN5clang11ASTImporter16ImportDefinitionEPNS_4DeclE", "clang::ASTImporter::ImportDefinition(clang::Decl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter17ImportDeclContextEPN5clang11DeclContextEb", "(anonymous namespace)::ASTNodeImporter::ImportDeclContext(clang::DeclContext*, bool)"},
    {"_ZN5clang11ASTImporter6ImportENS_15DeclarationNameE", "clang::ASTImporter::Import(clang::DeclarationName)"},
    {"_ZN5clang11ASTImporter6ImportENS_8SelectorE", "clang::ASTImporter::Import(clang::Selector)"},
    {"_ZN5clang11ASTImporter18HandleNameConflictENS_15DeclarationNameEPNS_11DeclContextEjPPNS_9NamedDeclEj", "clang::ASTImporter::HandleNameConflict(clang::DeclarationName, clang::DeclContext*, unsigned int, clang::NamedDecl**, unsigned int)"},
    {"_ZN5clang11ASTImporter6ToDiagENS_14SourceLocationEj", "clang::ASTImporter::ToDiag(clang::SourceLocation, unsigned int)"},
    {"_ZN5clang11ASTImporter8FromDiagENS_14SourceLocationEj", "clang::ASTImporter::FromDiag(clang::SourceLocation, unsigned int)"},
    {"_ZN5clang11ASTImporter8ImportedEPNS_4DeclES2_", "clang::ASTImporter::Imported(clang::Decl*, clang::Decl*)"},
    {"_ZN5clang11ASTImporter24IsStructurallyEquivalentENS_8QualTypeES1_", "clang::ASTImporter::IsStructurallyEquivalent(clang::QualType, clang::QualType)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter19VisitBinaryOperatorEPN5clang14BinaryOperatorE", "(anonymous namespace)::ASTNodeImporter::VisitBinaryOperator(clang::BinaryOperator*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter27VisitCompoundAssignOperatorEPN5clang22CompoundAssignOperatorE", "(anonymous namespace)::ASTNodeImporter::VisitCompoundAssignOperator(clang::CompoundAssignOperator*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter18VisitUnaryOperatorEPN5clang13UnaryOperatorE", "(anonymous namespace)::ASTNodeImporter::VisitUnaryOperator(clang::UnaryOperator*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter9VisitStmtEPN5clang4StmtE", "(anonymous namespace)::ASTNodeImporter::VisitStmt(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter9VisitExprEPN5clang4ExprE", "(anonymous namespace)::ASTNodeImporter::VisitExpr(clang::Expr*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter18VisitNamespaceDeclEPN5clang13NamespaceDeclE", "(anonymous namespace)::ASTNodeImporter::VisitNamespaceDecl(clang::NamespaceDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter21VisitObjCCategoryDeclEPN5clang16ObjCCategoryDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCCategoryDecl(clang::ObjCCategoryDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter25VisitObjCCategoryImplDeclEPN5clang20ObjCCategoryImplDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCCategoryImplDecl(clang::ObjCCategoryImplDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter27VisitObjCImplementationDeclEPN5clang22ObjCImplementationDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCImplementationDecl(clang::ObjCImplementationDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter22VisitObjCInterfaceDeclEPN5clang17ObjCInterfaceDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCInterfaceDecl(clang::ObjCInterfaceDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter21VisitObjCProtocolDeclEPN5clang16ObjCProtocolDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCProtocolDecl(clang::ObjCProtocolDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter19VisitObjCMethodDeclEPN5clang14ObjCMethodDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCMethodDecl(clang::ObjCMethodDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter21VisitObjCPropertyDeclEPN5clang16ObjCPropertyDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCPropertyDecl(clang::ObjCPropertyDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter22VisitClassTemplateDeclEPN5clang17ClassTemplateDeclE", "(anonymous namespace)::ASTNodeImporter::VisitClassTemplateDecl(clang::ClassTemplateDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter29VisitTemplateTemplateParmDeclEPN5clang24TemplateTemplateParmDeclE", "(anonymous namespace)::ASTNodeImporter::VisitTemplateTemplateParmDecl(clang::TemplateTemplateParmDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter13VisitEnumDeclEPN5clang8EnumDeclE", "(anonymous namespace)::ASTNodeImporter::VisitEnumDecl(clang::EnumDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter15VisitRecordDeclEPN5clang10RecordDeclE", "(anonymous namespace)::ASTNodeImporter::VisitRecordDecl(clang::RecordDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter36VisitClassTemplateSpecializationDeclEPN5clang31ClassTemplateSpecializationDeclE", "(anonymous namespace)::ASTNodeImporter::VisitClassTemplateSpecializationDecl(clang::ClassTemplateSpecializationDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter16VisitTypedefDeclEPN5clang11TypedefDeclE", "(anonymous namespace)::ASTNodeImporter::VisitTypedefDecl(clang::TypedefDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter14VisitFieldDeclEPN5clang9FieldDeclE", "(anonymous namespace)::ASTNodeImporter::VisitFieldDecl(clang::FieldDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter17VisitObjCIvarDeclEPN5clang12ObjCIvarDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCIvarDecl(clang::ObjCIvarDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter17VisitFunctionDeclEPN5clang12FunctionDeclE", "(anonymous namespace)::ASTNodeImporter::VisitFunctionDecl(clang::FunctionDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter28VisitNonTypeTemplateParmDeclEPN5clang23NonTypeTemplateParmDeclE", "(anonymous namespace)::ASTNodeImporter::VisitNonTypeTemplateParmDecl(clang::NonTypeTemplateParmDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter12VisitVarDeclEPN5clang7VarDeclE", "(anonymous namespace)::ASTNodeImporter::VisitVarDecl(clang::VarDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter22VisitImplicitParamDeclEPN5clang17ImplicitParamDeclE", "(anonymous namespace)::ASTNodeImporter::VisitImplicitParamDecl(clang::ImplicitParamDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter16VisitParmVarDeclEPN5clang11ParmVarDeclE", "(anonymous namespace)::ASTNodeImporter::VisitParmVarDecl(clang::ParmVarDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter21VisitEnumConstantDeclEPN5clang16EnumConstantDeclE", "(anonymous namespace)::ASTNodeImporter::VisitEnumConstantDecl(clang::EnumConstantDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter22VisitIndirectFieldDeclEPN5clang17IndirectFieldDeclE", "(anonymous namespace)::ASTNodeImporter::VisitIndirectFieldDecl(clang::IndirectFieldDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter18VisitObjCClassDeclEPN5clang13ObjCClassDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCClassDecl(clang::ObjCClassDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter28VisitObjCForwardProtocolDeclEPN5clang23ObjCForwardProtocolDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCForwardProtocolDecl(clang::ObjCForwardProtocolDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter25VisitObjCPropertyImplDeclEPN5clang20ObjCPropertyImplDeclE", "(anonymous namespace)::ASTNodeImporter::VisitObjCPropertyImplDecl(clang::ObjCPropertyImplDecl*)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter15ImportDeclPartsEPN5clang9NamedDeclERPNS1_11DeclContextES6_RNS1_15DeclarationNameERNS1_14SourceLocationE", "(anonymous namespace)::ASTNodeImporter::ImportDeclParts(clang::NamedDecl*, clang::DeclContext*&, clang::DeclContext*&, clang::DeclarationName&, clang::SourceLocation&)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter16ImportDefinitionEPN5clang10RecordDeclES3_", "(anonymous namespace)::ASTNodeImporter::ImportDefinition(clang::RecordDecl*, clang::RecordDecl*)"},
    {"_Z24IsStructurallyEquivalentRN12_GLOBAL__N_128StructuralEquivalenceContextEPN5clang4DeclES4_", "IsStructurallyEquivalent((anonymous namespace)::StructuralEquivalenceContext&, clang::Decl*, clang::Decl*)"},
    {"_ZN12_GLOBAL__N_128StructuralEquivalenceContext6FinishEv", "(anonymous namespace)::StructuralEquivalenceContext::Finish()"},
    {"_Z24IsStructurallyEquivalentRN12_GLOBAL__N_128StructuralEquivalenceContextEN5clang8QualTypeES3_", "IsStructurallyEquivalent((anonymous namespace)::StructuralEquivalenceContext&, clang::QualType, clang::QualType)"},
    {"_Z24IsStructurallyEquivalentRN12_GLOBAL__N_128StructuralEquivalenceContextEPN5clang21TemplateParameterListES4_", "IsStructurallyEquivalent((anonymous namespace)::StructuralEquivalenceContext&, clang::TemplateParameterList*, clang::TemplateParameterList*)"},
    {"_Z24IsStructurallyEquivalentRN12_GLOBAL__N_128StructuralEquivalenceContextERKN5clang16TemplateArgumentES5_", "IsStructurallyEquivalent((anonymous namespace)::StructuralEquivalenceContext&, clang::TemplateArgument const&, clang::TemplateArgument const&)"},
    {"_Z11IsSameValueRKN4llvm6APSIntES2_", "IsSameValue(llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_115ASTNodeImporter27ImportTemplateParameterListEPN5clang21TemplateParameterListE", "(anonymous namespace)::ASTNodeImporter::ImportTemplateParameterList(clang::TemplateParameterList*)"},
    {"_ZN4llvm8DenseMapIN5clang6FileIDES2_NS_12DenseMapInfoIS2_EES4_E16InsertIntoBucketERKS2_S7_PSt4pairIS2_S2_E", "llvm::DenseMap<clang::FileID, clang::FileID, llvm::DenseMapInfo<clang::FileID>, llvm::DenseMapInfo<clang::FileID>>::InsertIntoBucket(clang::FileID const&, clang::FileID const&, std::pair<clang::FileID, clang::FileID>*)"},
    {"_ZN4llvm8DenseMapIN5clang6FileIDES2_NS_12DenseMapInfoIS2_EES4_E4growEj", "llvm::DenseMap<clang::FileID, clang::FileID, llvm::DenseMapInfo<clang::FileID>, llvm::DenseMapInfo<clang::FileID>>::grow(unsigned int)"},
    {"_ZN5clang14BinaryOperatorC2EPNS_4ExprES2_NS_18BinaryOperatorKindENS_8QualTypeENS_13ExprValueKindENS_14ExprObjectKindENS_14SourceLocationEb", "clang::BinaryOperator::BinaryOperator(clang::Expr*, clang::Expr*, clang::BinaryOperatorKind, clang::QualType, clang::ExprValueKind, clang::ExprObjectKind, clang::SourceLocation, bool)"},
    {"_ZN4llvm8DenseMapISt4pairIPN5clang4DeclES4_EcNS_12DenseMapInfoIS5_EENS6_IcEEE6insertERKS1_IS5_cE", "llvm::DenseMap<std::pair<clang::Decl*, clang::Decl*>, char, llvm::DenseMapInfo<std::pair<clang::Decl*, clang::Decl*>>, llvm::DenseMapInfo<char>>::insert(std::pair<std::pair<clang::Decl*, clang::Decl*>, char> const&)"},
    {"_ZNK4llvm8DenseMapISt4pairIPN5clang4DeclES4_EcNS_12DenseMapInfoIS5_EENS6_IcEEE15LookupBucketForERKS5_RPS1_IS5_cE", "llvm::DenseMap<std::pair<clang::Decl*, clang::Decl*>, char, llvm::DenseMapInfo<std::pair<clang::Decl*, clang::Decl*>>, llvm::DenseMapInfo<char>>::LookupBucketFor(std::pair<clang::Decl*, clang::Decl*> const&, std::pair<std::pair<clang::Decl*, clang::Decl*>, char>*&) const"},
    {"_ZN4llvm8DenseMapISt4pairIPN5clang4DeclES4_EcNS_12DenseMapInfoIS5_EENS6_IcEEE16InsertIntoBucketERKS5_RKcPS1_IS5_cE", "llvm::DenseMap<std::pair<clang::Decl*, clang::Decl*>, char, llvm::DenseMapInfo<std::pair<clang::Decl*, clang::Decl*>>, llvm::DenseMapInfo<char>>::InsertIntoBucket(std::pair<clang::Decl*, clang::Decl*> const&, char const&, std::pair<std::pair<clang::Decl*, clang::Decl*>, char>*)"},
    {"_ZN4llvm8DenseMapISt4pairIPN5clang4DeclES4_EcNS_12DenseMapInfoIS5_EENS6_IcEEE4growEj", "llvm::DenseMap<std::pair<clang::Decl*, clang::Decl*>, char, llvm::DenseMapInfo<std::pair<clang::Decl*, clang::Decl*>>, llvm::DenseMapInfo<char>>::grow(unsigned int)"},
    {"_ZNSt5dequeIPN5clang4DeclESaIS2_EE9push_backERKS2_", "std::deque<clang::Decl*, std::allocator<clang::Decl*>>::push_back(clang::Decl* const&)"},
    {"_ZNSt5dequeIPN5clang4DeclESaIS2_EE17_M_reallocate_mapEmb", "std::deque<clang::Decl*, std::allocator<clang::Decl*>>::_M_reallocate_map(unsigned long, bool)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeES4_NS_12DenseMapInfoIS4_EES6_E16InsertIntoBucketERKS4_S9_PSt4pairIS4_S4_E", "llvm::DenseMap<clang::Type const*, clang::Type const*, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<clang::Type const*>>::InsertIntoBucket(clang::Type const* const&, clang::Type const* const&, std::pair<clang::Type const*, clang::Type const*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang4TypeES4_NS_12DenseMapInfoIS4_EES6_E4growEj", "llvm::DenseMap<clang::Type const*, clang::Type const*, llvm::DenseMapInfo<clang::Type const*>, llvm::DenseMapInfo<clang::Type const*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPN5clang4DeclES3_NS_12DenseMapInfoIS3_EES5_E16InsertIntoBucketERKS3_S8_PSt4pairIS3_S3_E", "llvm::DenseMap<clang::Decl*, clang::Decl*, llvm::DenseMapInfo<clang::Decl*>, llvm::DenseMapInfo<clang::Decl*>>::InsertIntoBucket(clang::Decl* const&, clang::Decl* const&, std::pair<clang::Decl*, clang::Decl*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang4DeclES3_NS_12DenseMapInfoIS3_EES5_E4growEj", "llvm::DenseMap<clang::Decl*, clang::Decl*, llvm::DenseMapInfo<clang::Decl*>, llvm::DenseMapInfo<clang::Decl*>>::grow(unsigned int)"},
    {"_ZN5clang4AttrD0Ev", "clang::Attr::~Attr()"},
    {"_ZN5clang4AttrD1Ev", "clang::Attr::~Attr()"},
    {"_ZN5clang4AttrD2Ev", "clang::Attr::~Attr()"},
    {"_ZNK5clang9AliasAttr5cloneERNS_10ASTContextE", "clang::AliasAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang15AlignMac68kAttr5cloneERNS_10ASTContextE", "clang::AlignMac68kAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang11AlignedAttr20isAlignmentDependentEv", "clang::AlignedAttr::isAlignmentDependent() const"},
    {"_ZNK5clang11AlignedAttr12getAlignmentERNS_10ASTContextE", "clang::AlignedAttr::getAlignment(clang::ASTContext&) const"},
    {"_ZNK5clang11AlignedAttr5cloneERNS_10ASTContextE", "clang::AlignedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang16AlwaysInlineAttr5cloneERNS_10ASTContextE", "clang::AlwaysInlineAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang20AnalyzerNoReturnAttr5cloneERNS_10ASTContextE", "clang::AnalyzerNoReturnAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12AnnotateAttr5cloneERNS_10ASTContextE", "clang::AnnotateAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12AsmLabelAttr5cloneERNS_10ASTContextE", "clang::AsmLabelAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang10BlocksAttr5cloneERNS_10ASTContextE", "clang::BlocksAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang9CDeclAttr5cloneERNS_10ASTContextE", "clang::CDeclAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang14CFConsumedAttr5cloneERNS_10ASTContextE", "clang::CFConsumedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang24CFReturnsNotRetainedAttr5cloneERNS_10ASTContextE", "clang::CFReturnsNotRetainedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang21CFReturnsRetainedAttr5cloneERNS_10ASTContextE", "clang::CFReturnsRetainedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang16CUDAConstantAttr5cloneERNS_10ASTContextE", "clang::CUDAConstantAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang14CUDADeviceAttr5cloneERNS_10ASTContextE", "clang::CUDADeviceAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang14CUDAGlobalAttr5cloneERNS_10ASTContextE", "clang::CUDAGlobalAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12CUDAHostAttr5cloneERNS_10ASTContextE", "clang::CUDAHostAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang20CUDALaunchBoundsAttr5cloneERNS_10ASTContextE", "clang::CUDALaunchBoundsAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang14CUDASharedAttr5cloneERNS_10ASTContextE", "clang::CUDASharedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang21CarriesDependencyAttr5cloneERNS_10ASTContextE", "clang::CarriesDependencyAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang11CleanupAttr5cloneERNS_10ASTContextE", "clang::CleanupAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang10CommonAttr5cloneERNS_10ASTContextE", "clang::CommonAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang9ConstAttr5cloneERNS_10ASTContextE", "clang::ConstAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang15ConstructorAttr5cloneERNS_10ASTContextE", "clang::ConstructorAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang13DLLExportAttr5cloneERNS_10ASTContextE", "clang::DLLExportAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang13DLLImportAttr5cloneERNS_10ASTContextE", "clang::DLLImportAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang14DeprecatedAttr5cloneERNS_10ASTContextE", "clang::DeprecatedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang14DestructorAttr5cloneERNS_10ASTContextE", "clang::DestructorAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12ExplicitAttr5cloneERNS_10ASTContextE", "clang::ExplicitAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12FastCallAttr5cloneERNS_10ASTContextE", "clang::FastCallAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang9FinalAttr5cloneERNS_10ASTContextE", "clang::FinalAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang10FormatAttr5cloneERNS_10ASTContextE", "clang::FormatAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang13FormatArgAttr5cloneERNS_10ASTContextE", "clang::FormatArgAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang13GNUInlineAttr5cloneERNS_10ASTContextE", "clang::GNUInlineAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12IBActionAttr5cloneERNS_10ASTContextE", "clang::IBActionAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12IBOutletAttr5cloneERNS_10ASTContextE", "clang::IBOutletAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang22IBOutletCollectionAttr5cloneERNS_10ASTContextE", "clang::IBOutletCollectionAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang16InitPriorityAttr5cloneERNS_10ASTContextE", "clang::InitPriorityAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang26MBlazeInterruptHandlerAttr5cloneERNS_10ASTContextE", "clang::MBlazeInterruptHandlerAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang23MBlazeSaveVolatilesAttr5cloneERNS_10ASTContextE", "clang::MBlazeSaveVolatilesAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang19MSP430InterruptAttr5cloneERNS_10ASTContextE", "clang::MSP430InterruptAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang10MallocAttr5cloneERNS_10ASTContextE", "clang::MallocAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang21MaxFieldAlignmentAttr5cloneERNS_10ASTContextE", "clang::MaxFieldAlignmentAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12MayAliasAttr5cloneERNS_10ASTContextE", "clang::MayAliasAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang14NSConsumedAttr5cloneERNS_10ASTContextE", "clang::NSConsumedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang18NSConsumesSelfAttr5cloneERNS_10ASTContextE", "clang::NSConsumesSelfAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang25NSReturnsAutoreleasedAttr5cloneERNS_10ASTContextE", "clang::NSReturnsAutoreleasedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang24NSReturnsNotRetainedAttr5cloneERNS_10ASTContextE", "clang::NSReturnsNotRetainedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang21NSReturnsRetainedAttr5cloneERNS_10ASTContextE", "clang::NSReturnsRetainedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang9NakedAttr5cloneERNS_10ASTContextE", "clang::NakedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12NoCommonAttr5cloneERNS_10ASTContextE", "clang::NoCommonAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang11NoDebugAttr5cloneERNS_10ASTContextE", "clang::NoDebugAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12NoInlineAttr5cloneERNS_10ASTContextE", "clang::NoInlineAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang24NoInstrumentFunctionAttr5cloneERNS_10ASTContextE", "clang::NoInstrumentFunctionAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12NoReturnAttr5cloneERNS_10ASTContextE", "clang::NoReturnAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang11NoThrowAttr5cloneERNS_10ASTContextE", "clang::NoThrowAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang11NonNullAttr5cloneERNS_10ASTContextE", "clang::NonNullAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang17ObjCExceptionAttr5cloneERNS_10ASTContextE", "clang::ObjCExceptionAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang16ObjCNSObjectAttr5cloneERNS_10ASTContextE", "clang::ObjCNSObjectAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang16OverloadableAttr5cloneERNS_10ASTContextE", "clang::OverloadableAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12OverrideAttr5cloneERNS_10ASTContextE", "clang::OverrideAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang13OwnershipAttr5cloneERNS_10ASTContextE", "clang::OwnershipAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang10PackedAttr5cloneERNS_10ASTContextE", "clang::PackedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang10PascalAttr5cloneERNS_10ASTContextE", "clang::PascalAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang8PureAttr5cloneERNS_10ASTContextE", "clang::PureAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang11RegparmAttr5cloneERNS_10ASTContextE", "clang::RegparmAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang21ReqdWorkGroupSizeAttr5cloneERNS_10ASTContextE", "clang::ReqdWorkGroupSizeAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang11SectionAttr5cloneERNS_10ASTContextE", "clang::SectionAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12SentinelAttr5cloneERNS_10ASTContextE", "clang::SentinelAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang11StdCallAttr5cloneERNS_10ASTContextE", "clang::StdCallAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang12ThisCallAttr5cloneERNS_10ASTContextE", "clang::ThisCallAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang20TransparentUnionAttr5cloneERNS_10ASTContextE", "clang::TransparentUnionAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang15UnavailableAttr5cloneERNS_10ASTContextE", "clang::UnavailableAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang10UnusedAttr5cloneERNS_10ASTContextE", "clang::UnusedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang8UsedAttr5cloneERNS_10ASTContextE", "clang::UsedAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang8UuidAttr5cloneERNS_10ASTContextE", "clang::UuidAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang13VecReturnAttr5cloneERNS_10ASTContextE", "clang::VecReturnAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang14VisibilityAttr5cloneERNS_10ASTContextE", "clang::VisibilityAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang20WarnUnusedResultAttr5cloneERNS_10ASTContextE", "clang::WarnUnusedResultAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang8WeakAttr5cloneERNS_10ASTContextE", "clang::WeakAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang14WeakImportAttr5cloneERNS_10ASTContextE", "clang::WeakImportAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang11WeakRefAttr5cloneERNS_10ASTContextE", "clang::WeakRefAttr::clone(clang::ASTContext&) const"},
    {"_ZNK5clang27X86ForceAlignArgPointerAttr5cloneERNS_10ASTContextE", "clang::X86ForceAlignArgPointerAttr::clone(clang::ASTContext&) const"},
    {"_ZN5clang9AliasAttrD1Ev", "clang::AliasAttr::~AliasAttr()"},
    {"_ZN5clang9AliasAttrD0Ev", "clang::AliasAttr::~AliasAttr()"},
    {"_ZN5clang15AlignMac68kAttrD1Ev", "clang::AlignMac68kAttr::~AlignMac68kAttr()"},
    {"_ZN5clang15AlignMac68kAttrD0Ev", "clang::AlignMac68kAttr::~AlignMac68kAttr()"},
    {"_ZN5clang11AlignedAttrD1Ev", "clang::AlignedAttr::~AlignedAttr()"},
    {"_ZN5clang11AlignedAttrD0Ev", "clang::AlignedAttr::~AlignedAttr()"},
    {"_ZN5clang16AlwaysInlineAttrD1Ev", "clang::AlwaysInlineAttr::~AlwaysInlineAttr()"},
    {"_ZN5clang16AlwaysInlineAttrD0Ev", "clang::AlwaysInlineAttr::~AlwaysInlineAttr()"},
    {"_ZN5clang20AnalyzerNoReturnAttrD1Ev", "clang::AnalyzerNoReturnAttr::~AnalyzerNoReturnAttr()"},
    {"_ZN5clang20AnalyzerNoReturnAttrD0Ev", "clang::AnalyzerNoReturnAttr::~AnalyzerNoReturnAttr()"},
    {"_ZN5clang12AnnotateAttrD1Ev", "clang::AnnotateAttr::~AnnotateAttr()"},
    {"_ZN5clang12AnnotateAttrD0Ev", "clang::AnnotateAttr::~AnnotateAttr()"},
    {"_ZN5clang12AsmLabelAttrD1Ev", "clang::AsmLabelAttr::~AsmLabelAttr()"},
    {"_ZN5clang12AsmLabelAttrD0Ev", "clang::AsmLabelAttr::~AsmLabelAttr()"},
    {"_ZN5clang10BlocksAttrD1Ev", "clang::BlocksAttr::~BlocksAttr()"},
    {"_ZN5clang10BlocksAttrD0Ev", "clang::BlocksAttr::~BlocksAttr()"},
    {"_ZN5clang9CDeclAttrD1Ev", "clang::CDeclAttr::~CDeclAttr()"},
    {"_ZN5clang9CDeclAttrD0Ev", "clang::CDeclAttr::~CDeclAttr()"},
    {"_ZN5clang14CFConsumedAttrD1Ev", "clang::CFConsumedAttr::~CFConsumedAttr()"},
    {"_ZN5clang14CFConsumedAttrD0Ev", "clang::CFConsumedAttr::~CFConsumedAttr()"},
    {"_ZN5clang24CFReturnsNotRetainedAttrD1Ev", "clang::CFReturnsNotRetainedAttr::~CFReturnsNotRetainedAttr()"},
    {"_ZN5clang24CFReturnsNotRetainedAttrD0Ev", "clang::CFReturnsNotRetainedAttr::~CFReturnsNotRetainedAttr()"},
    {"_ZN5clang21CFReturnsRetainedAttrD1Ev", "clang::CFReturnsRetainedAttr::~CFReturnsRetainedAttr()"},
    {"_ZN5clang21CFReturnsRetainedAttrD0Ev", "clang::CFReturnsRetainedAttr::~CFReturnsRetainedAttr()"},
    {"_ZN5clang16CUDAConstantAttrD1Ev", "clang::CUDAConstantAttr::~CUDAConstantAttr()"},
    {"_ZN5clang16CUDAConstantAttrD0Ev", "clang::CUDAConstantAttr::~CUDAConstantAttr()"},
    {"_ZN5clang14CUDADeviceAttrD1Ev", "clang::CUDADeviceAttr::~CUDADeviceAttr()"},
    {"_ZN5clang14CUDADeviceAttrD0Ev", "clang::CUDADeviceAttr::~CUDADeviceAttr()"},
    {"_ZN5clang14CUDAGlobalAttrD1Ev", "clang::CUDAGlobalAttr::~CUDAGlobalAttr()"},
    {"_ZN5clang14CUDAGlobalAttrD0Ev", "clang::CUDAGlobalAttr::~CUDAGlobalAttr()"},
    {"_ZN5clang12CUDAHostAttrD1Ev", "clang::CUDAHostAttr::~CUDAHostAttr()"},
    {"_ZN5clang12CUDAHostAttrD0Ev", "clang::CUDAHostAttr::~CUDAHostAttr()"},
    {"_ZN5clang20CUDALaunchBoundsAttrD1Ev", "clang::CUDALaunchBoundsAttr::~CUDALaunchBoundsAttr()"},
    {"_ZN5clang20CUDALaunchBoundsAttrD0Ev", "clang::CUDALaunchBoundsAttr::~CUDALaunchBoundsAttr()"},
    {"_ZN5clang14CUDASharedAttrD1Ev", "clang::CUDASharedAttr::~CUDASharedAttr()"},
    {"_ZN5clang14CUDASharedAttrD0Ev", "clang::CUDASharedAttr::~CUDASharedAttr()"},
    {"_ZN5clang21CarriesDependencyAttrD1Ev", "clang::CarriesDependencyAttr::~CarriesDependencyAttr()"},
    {"_ZN5clang21CarriesDependencyAttrD0Ev", "clang::CarriesDependencyAttr::~CarriesDependencyAttr()"},
    {"_ZN5clang11CleanupAttrD1Ev", "clang::CleanupAttr::~CleanupAttr()"},
    {"_ZN5clang11CleanupAttrD0Ev", "clang::CleanupAttr::~CleanupAttr()"},
    {"_ZN5clang10CommonAttrD1Ev", "clang::CommonAttr::~CommonAttr()"},
    {"_ZN5clang10CommonAttrD0Ev", "clang::CommonAttr::~CommonAttr()"},
    {"_ZN5clang9ConstAttrD1Ev", "clang::ConstAttr::~ConstAttr()"},
    {"_ZN5clang9ConstAttrD0Ev", "clang::ConstAttr::~ConstAttr()"},
    {"_ZN5clang15ConstructorAttrD1Ev", "clang::ConstructorAttr::~ConstructorAttr()"},
    {"_ZN5clang15ConstructorAttrD0Ev", "clang::ConstructorAttr::~ConstructorAttr()"},
    {"_ZN5clang13DLLExportAttrD1Ev", "clang::DLLExportAttr::~DLLExportAttr()"},
    {"_ZN5clang13DLLExportAttrD0Ev", "clang::DLLExportAttr::~DLLExportAttr()"},
    {"_ZN5clang13DLLImportAttrD1Ev", "clang::DLLImportAttr::~DLLImportAttr()"},
    {"_ZN5clang13DLLImportAttrD0Ev", "clang::DLLImportAttr::~DLLImportAttr()"},
    {"_ZN5clang14DeprecatedAttrD1Ev", "clang::DeprecatedAttr::~DeprecatedAttr()"},
    {"_ZN5clang14DeprecatedAttrD0Ev", "clang::DeprecatedAttr::~DeprecatedAttr()"},
    {"_ZN5clang14DestructorAttrD1Ev", "clang::DestructorAttr::~DestructorAttr()"},
    {"_ZN5clang14DestructorAttrD0Ev", "clang::DestructorAttr::~DestructorAttr()"},
    {"_ZN5clang12ExplicitAttrD1Ev", "clang::ExplicitAttr::~ExplicitAttr()"},
    {"_ZN5clang12ExplicitAttrD0Ev", "clang::ExplicitAttr::~ExplicitAttr()"},
    {"_ZN5clang12FastCallAttrD1Ev", "clang::FastCallAttr::~FastCallAttr()"},
    {"_ZN5clang12FastCallAttrD0Ev", "clang::FastCallAttr::~FastCallAttr()"},
    {"_ZN5clang9FinalAttrD1Ev", "clang::FinalAttr::~FinalAttr()"},
    {"_ZN5clang9FinalAttrD0Ev", "clang::FinalAttr::~FinalAttr()"},
    {"_ZN5clang10FormatAttrD1Ev", "clang::FormatAttr::~FormatAttr()"},
    {"_ZN5clang10FormatAttrD0Ev", "clang::FormatAttr::~FormatAttr()"},
    {"_ZN5clang13FormatArgAttrD1Ev", "clang::FormatArgAttr::~FormatArgAttr()"},
    {"_ZN5clang13FormatArgAttrD0Ev", "clang::FormatArgAttr::~FormatArgAttr()"},
    {"_ZN5clang13GNUInlineAttrD1Ev", "clang::GNUInlineAttr::~GNUInlineAttr()"},
    {"_ZN5clang13GNUInlineAttrD0Ev", "clang::GNUInlineAttr::~GNUInlineAttr()"},
    {"_ZN5clang12IBActionAttrD1Ev", "clang::IBActionAttr::~IBActionAttr()"},
    {"_ZN5clang12IBActionAttrD0Ev", "clang::IBActionAttr::~IBActionAttr()"},
    {"_ZN5clang12IBOutletAttrD1Ev", "clang::IBOutletAttr::~IBOutletAttr()"},
    {"_ZN5clang12IBOutletAttrD0Ev", "clang::IBOutletAttr::~IBOutletAttr()"},
    {"_ZN5clang22IBOutletCollectionAttrD1Ev", "clang::IBOutletCollectionAttr::~IBOutletCollectionAttr()"},
    {"_ZN5clang22IBOutletCollectionAttrD0Ev", "clang::IBOutletCollectionAttr::~IBOutletCollectionAttr()"},
    {"_ZN5clang16InitPriorityAttrD1Ev", "clang::InitPriorityAttr::~InitPriorityAttr()"},
    {"_ZN5clang16InitPriorityAttrD0Ev", "clang::InitPriorityAttr::~InitPriorityAttr()"},
    {"_ZN5clang26MBlazeInterruptHandlerAttrD1Ev", "clang::MBlazeInterruptHandlerAttr::~MBlazeInterruptHandlerAttr()"},
    {"_ZN5clang26MBlazeInterruptHandlerAttrD0Ev", "clang::MBlazeInterruptHandlerAttr::~MBlazeInterruptHandlerAttr()"},
    {"_ZN5clang23MBlazeSaveVolatilesAttrD1Ev", "clang::MBlazeSaveVolatilesAttr::~MBlazeSaveVolatilesAttr()"},
    {"_ZN5clang23MBlazeSaveVolatilesAttrD0Ev", "clang::MBlazeSaveVolatilesAttr::~MBlazeSaveVolatilesAttr()"},
    {"_ZN5clang19MSP430InterruptAttrD1Ev", "clang::MSP430InterruptAttr::~MSP430InterruptAttr()"},
    {"_ZN5clang19MSP430InterruptAttrD0Ev", "clang::MSP430InterruptAttr::~MSP430InterruptAttr()"},
    {"_ZN5clang10MallocAttrD1Ev", "clang::MallocAttr::~MallocAttr()"},
    {"_ZN5clang10MallocAttrD0Ev", "clang::MallocAttr::~MallocAttr()"},
    {"_ZN5clang21MaxFieldAlignmentAttrD1Ev", "clang::MaxFieldAlignmentAttr::~MaxFieldAlignmentAttr()"},
    {"_ZN5clang21MaxFieldAlignmentAttrD0Ev", "clang::MaxFieldAlignmentAttr::~MaxFieldAlignmentAttr()"},
    {"_ZN5clang12MayAliasAttrD1Ev", "clang::MayAliasAttr::~MayAliasAttr()"},
    {"_ZN5clang12MayAliasAttrD0Ev", "clang::MayAliasAttr::~MayAliasAttr()"},
    {"_ZN5clang14NSConsumedAttrD1Ev", "clang::NSConsumedAttr::~NSConsumedAttr()"},
    {"_ZN5clang14NSConsumedAttrD0Ev", "clang::NSConsumedAttr::~NSConsumedAttr()"},
    {"_ZN5clang18NSConsumesSelfAttrD1Ev", "clang::NSConsumesSelfAttr::~NSConsumesSelfAttr()"},
    {"_ZN5clang18NSConsumesSelfAttrD0Ev", "clang::NSConsumesSelfAttr::~NSConsumesSelfAttr()"},
    {"_ZN5clang25NSReturnsAutoreleasedAttrD1Ev", "clang::NSReturnsAutoreleasedAttr::~NSReturnsAutoreleasedAttr()"},
    {"_ZN5clang25NSReturnsAutoreleasedAttrD0Ev", "clang::NSReturnsAutoreleasedAttr::~NSReturnsAutoreleasedAttr()"},
    {"_ZN5clang24NSReturnsNotRetainedAttrD1Ev", "clang::NSReturnsNotRetainedAttr::~NSReturnsNotRetainedAttr()"},
    {"_ZN5clang24NSReturnsNotRetainedAttrD0Ev", "clang::NSReturnsNotRetainedAttr::~NSReturnsNotRetainedAttr()"},
    {"_ZN5clang21NSReturnsRetainedAttrD1Ev", "clang::NSReturnsRetainedAttr::~NSReturnsRetainedAttr()"},
    {"_ZN5clang21NSReturnsRetainedAttrD0Ev", "clang::NSReturnsRetainedAttr::~NSReturnsRetainedAttr()"},
    {"_ZN5clang9NakedAttrD1Ev", "clang::NakedAttr::~NakedAttr()"},
    {"_ZN5clang9NakedAttrD0Ev", "clang::NakedAttr::~NakedAttr()"},
    {"_ZN5clang12NoCommonAttrD1Ev", "clang::NoCommonAttr::~NoCommonAttr()"},
    {"_ZN5clang12NoCommonAttrD0Ev", "clang::NoCommonAttr::~NoCommonAttr()"},
    {"_ZN5clang11NoDebugAttrD1Ev", "clang::NoDebugAttr::~NoDebugAttr()"},
    {"_ZN5clang11NoDebugAttrD0Ev", "clang::NoDebugAttr::~NoDebugAttr()"},
    {"_ZN5clang12NoInlineAttrD1Ev", "clang::NoInlineAttr::~NoInlineAttr()"},
    {"_ZN5clang12NoInlineAttrD0Ev", "clang::NoInlineAttr::~NoInlineAttr()"},
    {"_ZN5clang24NoInstrumentFunctionAttrD1Ev", "clang::NoInstrumentFunctionAttr::~NoInstrumentFunctionAttr()"},
    {"_ZN5clang24NoInstrumentFunctionAttrD0Ev", "clang::NoInstrumentFunctionAttr::~NoInstrumentFunctionAttr()"},
    {"_ZN5clang12NoReturnAttrD1Ev", "clang::NoReturnAttr::~NoReturnAttr()"},
    {"_ZN5clang12NoReturnAttrD0Ev", "clang::NoReturnAttr::~NoReturnAttr()"},
    {"_ZN5clang11NoThrowAttrD1Ev", "clang::NoThrowAttr::~NoThrowAttr()"},
    {"_ZN5clang11NoThrowAttrD0Ev", "clang::NoThrowAttr::~NoThrowAttr()"},
    {"_ZN5clang11NonNullAttrD1Ev", "clang::NonNullAttr::~NonNullAttr()"},
    {"_ZN5clang11NonNullAttrD0Ev", "clang::NonNullAttr::~NonNullAttr()"},
    {"_ZN5clang17ObjCExceptionAttrD1Ev", "clang::ObjCExceptionAttr::~ObjCExceptionAttr()"},
    {"_ZN5clang17ObjCExceptionAttrD0Ev", "clang::ObjCExceptionAttr::~ObjCExceptionAttr()"},
    {"_ZN5clang16ObjCNSObjectAttrD1Ev", "clang::ObjCNSObjectAttr::~ObjCNSObjectAttr()"},
    {"_ZN5clang16ObjCNSObjectAttrD0Ev", "clang::ObjCNSObjectAttr::~ObjCNSObjectAttr()"},
    {"_ZN5clang16OverloadableAttrD1Ev", "clang::OverloadableAttr::~OverloadableAttr()"},
    {"_ZN5clang16OverloadableAttrD0Ev", "clang::OverloadableAttr::~OverloadableAttr()"},
    {"_ZN5clang12OverrideAttrD1Ev", "clang::OverrideAttr::~OverrideAttr()"},
    {"_ZN5clang12OverrideAttrD0Ev", "clang::OverrideAttr::~OverrideAttr()"},
    {"_ZN5clang13OwnershipAttrD1Ev", "clang::OwnershipAttr::~OwnershipAttr()"},
    {"_ZN5clang13OwnershipAttrD0Ev", "clang::OwnershipAttr::~OwnershipAttr()"},
    {"_ZN5clang10PackedAttrD1Ev", "clang::PackedAttr::~PackedAttr()"},
    {"_ZN5clang10PackedAttrD0Ev", "clang::PackedAttr::~PackedAttr()"},
    {"_ZN5clang10PascalAttrD1Ev", "clang::PascalAttr::~PascalAttr()"},
    {"_ZN5clang10PascalAttrD0Ev", "clang::PascalAttr::~PascalAttr()"},
    {"_ZN5clang8PureAttrD1Ev", "clang::PureAttr::~PureAttr()"},
    {"_ZN5clang8PureAttrD0Ev", "clang::PureAttr::~PureAttr()"},
    {"_ZN5clang11RegparmAttrD1Ev", "clang::RegparmAttr::~RegparmAttr()"},
    {"_ZN5clang11RegparmAttrD0Ev", "clang::RegparmAttr::~RegparmAttr()"},
    {"_ZN5clang21ReqdWorkGroupSizeAttrD1Ev", "clang::ReqdWorkGroupSizeAttr::~ReqdWorkGroupSizeAttr()"},
    {"_ZN5clang21ReqdWorkGroupSizeAttrD0Ev", "clang::ReqdWorkGroupSizeAttr::~ReqdWorkGroupSizeAttr()"},
    {"_ZN5clang11SectionAttrD1Ev", "clang::SectionAttr::~SectionAttr()"},
    {"_ZN5clang11SectionAttrD0Ev", "clang::SectionAttr::~SectionAttr()"},
    {"_ZN5clang12SentinelAttrD1Ev", "clang::SentinelAttr::~SentinelAttr()"},
    {"_ZN5clang12SentinelAttrD0Ev", "clang::SentinelAttr::~SentinelAttr()"},
    {"_ZN5clang11StdCallAttrD1Ev", "clang::StdCallAttr::~StdCallAttr()"},
    {"_ZN5clang11StdCallAttrD0Ev", "clang::StdCallAttr::~StdCallAttr()"},
    {"_ZN5clang12ThisCallAttrD1Ev", "clang::ThisCallAttr::~ThisCallAttr()"},
    {"_ZN5clang12ThisCallAttrD0Ev", "clang::ThisCallAttr::~ThisCallAttr()"},
    {"_ZN5clang20TransparentUnionAttrD1Ev", "clang::TransparentUnionAttr::~TransparentUnionAttr()"},
    {"_ZN5clang20TransparentUnionAttrD0Ev", "clang::TransparentUnionAttr::~TransparentUnionAttr()"},
    {"_ZN5clang15UnavailableAttrD1Ev", "clang::UnavailableAttr::~UnavailableAttr()"},
    {"_ZN5clang15UnavailableAttrD0Ev", "clang::UnavailableAttr::~UnavailableAttr()"},
    {"_ZN5clang10UnusedAttrD1Ev", "clang::UnusedAttr::~UnusedAttr()"},
    {"_ZN5clang10UnusedAttrD0Ev", "clang::UnusedAttr::~UnusedAttr()"},
    {"_ZN5clang8UsedAttrD1Ev", "clang::UsedAttr::~UsedAttr()"},
    {"_ZN5clang8UsedAttrD0Ev", "clang::UsedAttr::~UsedAttr()"},
    {"_ZN5clang8UuidAttrD1Ev", "clang::UuidAttr::~UuidAttr()"},
    {"_ZN5clang8UuidAttrD0Ev", "clang::UuidAttr::~UuidAttr()"},
    {"_ZN5clang13VecReturnAttrD1Ev", "clang::VecReturnAttr::~VecReturnAttr()"},
    {"_ZN5clang13VecReturnAttrD0Ev", "clang::VecReturnAttr::~VecReturnAttr()"},
    {"_ZN5clang14VisibilityAttrD1Ev", "clang::VisibilityAttr::~VisibilityAttr()"},
    {"_ZN5clang14VisibilityAttrD0Ev", "clang::VisibilityAttr::~VisibilityAttr()"},
    {"_ZN5clang20WarnUnusedResultAttrD1Ev", "clang::WarnUnusedResultAttr::~WarnUnusedResultAttr()"},
    {"_ZN5clang20WarnUnusedResultAttrD0Ev", "clang::WarnUnusedResultAttr::~WarnUnusedResultAttr()"},
    {"_ZN5clang8WeakAttrD1Ev", "clang::WeakAttr::~WeakAttr()"},
    {"_ZN5clang8WeakAttrD0Ev", "clang::WeakAttr::~WeakAttr()"},
    {"_ZN5clang14WeakImportAttrD1Ev", "clang::WeakImportAttr::~WeakImportAttr()"},
    {"_ZN5clang14WeakImportAttrD0Ev", "clang::WeakImportAttr::~WeakImportAttr()"},
    {"_ZN5clang11WeakRefAttrD1Ev", "clang::WeakRefAttr::~WeakRefAttr()"},
    {"_ZN5clang11WeakRefAttrD0Ev", "clang::WeakRefAttr::~WeakRefAttr()"},
    {"_ZN5clang27X86ForceAlignArgPointerAttrD1Ev", "clang::X86ForceAlignArgPointerAttr::~X86ForceAlignArgPointerAttr()"},
    {"_ZN5clang27X86ForceAlignArgPointerAttrD0Ev", "clang::X86ForceAlignArgPointerAttr::~X86ForceAlignArgPointerAttr()"},
    {"_ZN5clang12CXXBasePaths17ComputeDeclsFoundEv", "clang::CXXBasePaths::ComputeDeclsFound()"},
    {"_ZN5clang12CXXBasePaths17found_decls_beginEv", "clang::CXXBasePaths::found_decls_begin()"},
    {"_ZN5clang12CXXBasePaths15found_decls_endEv", "clang::CXXBasePaths::found_decls_end()"},
    {"_ZN5clang12CXXBasePaths11isAmbiguousENS_7CanQualINS_4TypeEEE", "clang::CXXBasePaths::isAmbiguous(clang::CanQual<clang::Type>)"},
    {"_ZN5clang12CXXBasePaths5clearEv", "clang::CXXBasePaths::clear()"},
    {"_ZN5clang12CXXBasePaths4swapERS0_", "clang::CXXBasePaths::swap(clang::CXXBasePaths&)"},
    {"_ZNK5clang13CXXRecordDecl13isDerivedFromEPKS0_", "clang::CXXRecordDecl::isDerivedFrom(clang::CXXRecordDecl const*) const"},
    {"_ZNK5clang13CXXRecordDecl13isDerivedFromEPKS0_RNS_12CXXBasePathsE", "clang::CXXRecordDecl::isDerivedFrom(clang::CXXRecordDecl const*, clang::CXXBasePaths&) const"},
    {"_ZNK5clang13CXXRecordDecl13lookupInBasesEPFbPKNS_16CXXBaseSpecifierERNS_11CXXBasePathEPvES6_RNS_12CXXBasePathsE", "clang::CXXRecordDecl::lookupInBases(bool (*)(clang::CXXBaseSpecifier const*, clang::CXXBasePath&, void*), void*, clang::CXXBasePaths&) const"},
    {"_ZN5clang13CXXRecordDecl13FindBaseClassEPKNS_16CXXBaseSpecifierERNS_11CXXBasePathEPv", "clang::CXXRecordDecl::FindBaseClass(clang::CXXBaseSpecifier const*, clang::CXXBasePath&, void*)"},
    {"_ZNK5clang13CXXRecordDecl22isVirtuallyDerivedFromEPS0_", "clang::CXXRecordDecl::isVirtuallyDerivedFrom(clang::CXXRecordDecl*) const"},
    {"_ZN5clang13CXXRecordDecl20FindVirtualBaseClassEPKNS_16CXXBaseSpecifierERNS_11CXXBasePathEPv", "clang::CXXRecordDecl::FindVirtualBaseClass(clang::CXXBaseSpecifier const*, clang::CXXBasePath&, void*)"},
    {"_ZNK5clang13CXXRecordDecl24isProvablyNotDerivedFromEPKS0_", "clang::CXXRecordDecl::isProvablyNotDerivedFrom(clang::CXXRecordDecl const*) const"},
    {"_ZNK5clang13CXXRecordDecl11forallBasesEPFbPKS0_PvES3_b", "clang::CXXRecordDecl::forallBases(bool (*)(clang::CXXRecordDecl const*, void*), void*, bool) const"},
    {"_Z9BaseIsNotPKN5clang13CXXRecordDeclEPv", "BaseIsNot(clang::CXXRecordDecl const*, void*)"},
    {"_ZN5clang12CXXBasePaths13lookupInBasesERNS_10ASTContextEPKNS_13CXXRecordDeclEPFbPKNS_16CXXBaseSpecifierERNS_11CXXBasePathEPvESB_", "clang::CXXBasePaths::lookupInBases(clang::ASTContext&, clang::CXXRecordDecl const*, bool (*)(clang::CXXBaseSpecifier const*, clang::CXXBasePath&, void*), void*)"},
    {"_ZN5clang13CXXRecordDecl13FindTagMemberEPKNS_16CXXBaseSpecifierERNS_11CXXBasePathEPv", "clang::CXXRecordDecl::FindTagMember(clang::CXXBaseSpecifier const*, clang::CXXBasePath&, void*)"},
    {"_ZN5clang13CXXRecordDecl18FindOrdinaryMemberEPKNS_16CXXBaseSpecifierERNS_11CXXBasePathEPv", "clang::CXXRecordDecl::FindOrdinaryMember(clang::CXXBaseSpecifier const*, clang::CXXBasePath&, void*)"},
    {"_ZN5clang13CXXRecordDecl29FindNestedNameSpecifierMemberEPKNS_16CXXBaseSpecifierERNS_11CXXBasePathEPv", "clang::CXXRecordDecl::FindNestedNameSpecifierMember(clang::CXXBaseSpecifier const*, clang::CXXBasePath&, void*)"},
    {"_ZN5clang17OverridingMethods3addEjNS_19UniqueVirtualMethodE", "clang::OverridingMethods::add(unsigned int, clang::UniqueVirtualMethod)"},
    {"_ZN5clang17OverridingMethods3addERKS0_", "clang::OverridingMethods::add(clang::OverridingMethods const&)"},
    {"_ZN5clang17OverridingMethods10replaceAllENS_19UniqueVirtualMethodE", "clang::OverridingMethods::replaceAll(clang::UniqueVirtualMethod)"},
    {"_ZNK5clang13CXXRecordDecl18getFinalOverridersERNS_20CXXFinalOverriderMapE", "clang::CXXRecordDecl::getFinalOverriders(clang::CXXFinalOverriderMap&) const"},
    {"_ZN12_GLOBAL__N_123FinalOverriderCollector7CollectEPKN5clang13CXXRecordDeclEbS4_RNS1_20CXXFinalOverriderMapE", "(anonymous namespace)::FinalOverriderCollector::Collect(clang::CXXRecordDecl const*, bool, clang::CXXRecordDecl const*, clang::CXXFinalOverriderMap&)"},
    {"_ZNK5clang13CXXRecordDecl23getIndirectPrimaryBasesERNS_25CXXIndirectPrimaryBaseSetE", "clang::CXXRecordDecl::getIndirectPrimaryBases(clang::CXXIndirectPrimaryBaseSet&) const"},
    {"_Z23AddIndirectPrimaryBasesPKN5clang13CXXRecordDeclERNS_10ASTContextERNS_25CXXIndirectPrimaryBaseSetE", "AddIndirectPrimaryBases(clang::CXXRecordDecl const*, clang::ASTContext&, clang::CXXIndirectPrimaryBaseSet&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang19UniqueVirtualMethodELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::UniqueVirtualMethod, false>::grow(unsigned long)"},
    {"_ZSt6__findIPN5clang19UniqueVirtualMethodES1_ET_S3_S3_RKT0_St26random_access_iterator_tag", "clang::UniqueVirtualMethod* std::__find<clang::UniqueVirtualMethod*, clang::UniqueVirtualMethod>(clang::UniqueVirtualMethod*, clang::UniqueVirtualMethod*, clang::UniqueVirtualMethod const&, std::random_access_iterator_tag)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIN5clang19UniqueVirtualMethodELj4EEENS_12DenseMapInfoIjEENS5_IS4_EEE16FindAndConstructERKj", "llvm::DenseMap<unsigned int, llvm::SmallVector<clang::UniqueVirtualMethod, 4u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<clang::UniqueVirtualMethod, 4u>>>::FindAndConstruct(unsigned int const&)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIN5clang19UniqueVirtualMethodELj4EEENS_12DenseMapInfoIjEENS5_IS4_EEE16InsertIntoBucketERKjRKS4_PSt4pairIjS4_E", "llvm::DenseMap<unsigned int, llvm::SmallVector<clang::UniqueVirtualMethod, 4u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<clang::UniqueVirtualMethod, 4u>>>::InsertIntoBucket(unsigned int const&, llvm::SmallVector<clang::UniqueVirtualMethod, 4u> const&, std::pair<unsigned int, llvm::SmallVector<clang::UniqueVirtualMethod, 4u>>*)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIN5clang19UniqueVirtualMethodELj4EEENS_12DenseMapInfoIjEENS5_IS4_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::SmallVector<clang::UniqueVirtualMethod, 4u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<clang::UniqueVirtualMethod, 4u>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIN5clang19UniqueVirtualMethodEEaSERKS3_", "llvm::SmallVectorImpl<clang::UniqueVirtualMethod>::operator=(llvm::SmallVectorImpl<clang::UniqueVirtualMethod> const&)"},
    {"_ZN4llvm15SmallVectorImplIN5clang18CXXBasePathElementEEaSERKS3_", "llvm::SmallVectorImpl<clang::CXXBasePathElement>::operator=(llvm::SmallVectorImpl<clang::CXXBasePathElement> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang18CXXBasePathElementELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::CXXBasePathElement, false>::grow(unsigned long)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_S2_IbjEESt10_Select1stIS5_ENS0_16QualTypeOrderingESaIS5_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS5_ERKS5_", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, std::pair<bool, unsigned int>>, std::_Select1st<std::pair<clang::QualType const, std::pair<bool, unsigned int>>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, std::pair<bool, unsigned int>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::QualType const, std::pair<bool, unsigned int>>>, std::pair<clang::QualType const, std::pair<bool, unsigned int>> const&)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_S2_IbjEESt10_Select1stIS5_ENS0_16QualTypeOrderingESaIS5_EE16_M_insert_uniqueERKS5_", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, std::pair<bool, unsigned int>>, std::_Select1st<std::pair<clang::QualType const, std::pair<bool, unsigned int>>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, std::pair<bool, unsigned int>>>>::_M_insert_unique(std::pair<clang::QualType const, std::pair<bool, unsigned int>> const&)"},
    {"_ZNSt8_Rb_treeIPN5clang9NamedDeclES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE16_M_insert_uniqueERKS2_", "std::_Rb_tree<clang::NamedDecl*, clang::NamedDecl*, std::_Identity<clang::NamedDecl*>, std::less<clang::NamedDecl*>, std::allocator<clang::NamedDecl*>>::_M_insert_unique(clang::NamedDecl* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclENS1_17OverridingMethodsENS_12DenseMapInfoIS4_EENS6_IS5_EEE16FindAndConstructERKS4_", "llvm::DenseMap<clang::CXXMethodDecl const*, clang::OverridingMethods, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<clang::OverridingMethods>>::FindAndConstruct(clang::CXXMethodDecl const* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclENS1_17OverridingMethodsENS_12DenseMapInfoIS4_EENS6_IS5_EEE16InsertIntoBucketERKS4_RKS5_PSt4pairIS4_S5_E", "llvm::DenseMap<clang::CXXMethodDecl const*, clang::OverridingMethods, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<clang::OverridingMethods>>::InsertIntoBucket(clang::CXXMethodDecl const* const&, clang::OverridingMethods const&, std::pair<clang::CXXMethodDecl const*, clang::OverridingMethods>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclENS1_17OverridingMethodsENS_12DenseMapInfoIS4_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::CXXMethodDecl const*, clang::OverridingMethods, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<clang::OverridingMethods>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIN5clang19UniqueVirtualMethodELj4EEENS_12DenseMapInfoIjEENS5_IS4_EEE8CopyFromERKS8_", "llvm::DenseMap<unsigned int, llvm::SmallVector<clang::UniqueVirtualMethod, 4u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<clang::UniqueVirtualMethod, 4u>>>::CopyFrom(llvm::DenseMap<unsigned int, llvm::SmallVector<clang::UniqueVirtualMethod, 4u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<clang::UniqueVirtualMethod, 4u>>> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEPNS1_20CXXFinalOverriderMapENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::CXXRecordDecl const*, clang::CXXFinalOverriderMap*, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CXXFinalOverriderMap*>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, clang::CXXFinalOverriderMap* const&, std::pair<clang::CXXRecordDecl const*, clang::CXXFinalOverriderMap*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEPNS1_20CXXFinalOverriderMapENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, clang::CXXFinalOverriderMap*, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CXXFinalOverriderMap*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::CXXRecordDecl const*, unsigned int, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, unsigned int const&, std::pair<clang::CXXRecordDecl const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, unsigned int, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZNSt8_Rb_treeIPN5clang9NamedDeclES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE8_M_eraseEPSt13_Rb_tree_nodeIS2_E", "std::_Rb_tree<clang::NamedDecl*, clang::NamedDecl*, std::_Identity<clang::NamedDecl*>, std::less<clang::NamedDecl*>, std::allocator<clang::NamedDecl*>>::_M_erase(std::_Rb_tree_node<clang::NamedDecl*>*)"},
    {"_ZN5clang9NamedDecl17ClearLinkageCacheEv", "clang::NamedDecl::ClearLinkageCache()"},
    {"_ZNK5clang9NamedDecl10getLinkageEv", "clang::NamedDecl::getLinkage() const"},
    {"_Z12getLVForDeclPKN5clang9NamedDeclEN12_GLOBAL__N_17LVFlagsE", "getLVForDecl(clang::NamedDecl const*, (anonymous namespace)::LVFlags)"},
    {"_ZNK5clang9NamedDecl23getLinkageAndVisibilityEv", "clang::NamedDecl::getLinkageAndVisibility() const"},
    {"_ZNK5clang9NamedDecl24getQualifiedNameAsStringEv", "clang::NamedDecl::getQualifiedNameAsString() const"},
    {"_ZNK5clang9NamedDecl24getQualifiedNameAsStringERKNS_14PrintingPolicyE", "clang::NamedDecl::getQualifiedNameAsString(clang::PrintingPolicy const&) const"},
    {"_ZNK5clang12FunctionDecl12getNumParamsEv", "clang::FunctionDecl::getNumParams() const"},
    {"_ZNK5clang9NamedDecl19declarationReplacesEPS0_", "clang::NamedDecl::declarationReplaces(clang::NamedDecl*) const"},
    {"_ZNK5clang9NamedDecl10hasLinkageEv", "clang::NamedDecl::hasLinkage() const"},
    {"_ZN5clang9NamedDecl17getUnderlyingDeclEv", "clang::NamedDecl::getUnderlyingDecl()"},
    {"_ZNK5clang9NamedDecl19isCXXInstanceMemberEv", "clang::NamedDecl::isCXXInstanceMember() const"},
    {"_ZNK5clang14DeclaratorDecl19getTypeSpecStartLocEv", "clang::DeclaratorDecl::getTypeSpecStartLoc() const"},
    {"_ZN5clang14DeclaratorDecl16setQualifierInfoEPNS_19NestedNameSpecifierENS_11SourceRangeE", "clang::DeclaratorDecl::setQualifierInfo(clang::NestedNameSpecifier*, clang::SourceRange)"},
    {"_ZNK5clang14DeclaratorDecl16getOuterLocStartEv", "clang::DeclaratorDecl::getOuterLocStart() const"},
    {"_ZN5clang13QualifierInfo29setTemplateParameterListsInfoERNS_10ASTContextEjPPNS_21TemplateParameterListE", "clang::QualifierInfo::setTemplateParameterListsInfo(clang::ASTContext&, unsigned int, clang::TemplateParameterList**)"},
    {"_ZN5clang7VarDecl30getStorageClassSpecifierStringENS_12StorageClassE", "clang::VarDecl::getStorageClassSpecifierString(clang::StorageClass)"},
    {"_ZN5clang7VarDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPNS_14TypeSourceInfoENS_12StorageClassESB_", "clang::VarDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::TypeSourceInfo*, clang::StorageClass, clang::StorageClass)"},
    {"_ZN5clang7VarDecl15setStorageClassENS_12StorageClassE", "clang::VarDecl::setStorageClass(clang::StorageClass)"},
    {"_ZNK5clang7VarDecl16getInnerLocStartEv", "clang::VarDecl::getInnerLocStart() const"},
    {"_ZNK5clang7VarDecl14getSourceRangeEv", "clang::VarDecl::getSourceRange() const"},
    {"_ZNK5clang7VarDecl9isExternCEv", "clang::VarDecl::isExternC() const"},
    {"_ZN5clang7VarDecl16getCanonicalDeclEv", "clang::VarDecl::getCanonicalDecl()"},
    {"_ZNK5clang7VarDecl28isThisDeclarationADefinitionEv", "clang::VarDecl::isThisDeclarationADefinition() const"},
    {"_ZNK5clang7VarDecl29getTemplateSpecializationKindEv", "clang::VarDecl::getTemplateSpecializationKind() const"},
    {"_ZN5clang7VarDecl19getActingDefinitionEv", "clang::VarDecl::getActingDefinition()"},
    {"_ZNK5clang7VarDecl24isTentativeDefinitionNowEv", "clang::VarDecl::isTentativeDefinitionNow() const"},
    {"_ZN5clang7VarDecl13getDefinitionEv", "clang::VarDecl::getDefinition()"},
    {"_ZNK5clang7VarDecl13hasDefinitionEv", "clang::VarDecl::hasDefinition() const"},
    {"_ZNK5clang7VarDecl17getAnyInitializerERPKS0_", "clang::VarDecl::getAnyInitializer(clang::VarDecl const*&) const"},
    {"_ZNK5clang7VarDecl11isOutOfLineEv", "clang::VarDecl::isOutOfLine() const"},
    {"_ZNK5clang7VarDecl35getInstantiatedFromStaticDataMemberEv", "clang::VarDecl::getInstantiatedFromStaticDataMember() const"},
    {"_ZN5clang7VarDecl22getOutOfLineDefinitionEv", "clang::VarDecl::getOutOfLineDefinition()"},
    {"_ZN5clang7VarDecl7setInitEPNS_4ExprE", "clang::VarDecl::setInit(clang::Expr*)"},
    {"_ZNK5clang7VarDecl27getMemberSpecializationInfoEv", "clang::VarDecl::getMemberSpecializationInfo() const"},
    {"_ZN5clang7VarDecl29setTemplateSpecializationKindENS_26TemplateSpecializationKindENS_14SourceLocationE", "clang::VarDecl::setTemplateSpecializationKind(clang::TemplateSpecializationKind, clang::SourceLocation)"},
    {"_ZN5clang11ParmVarDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPNS_14TypeSourceInfoENS_12StorageClassESB_PNS_4ExprE", "clang::ParmVarDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::TypeSourceInfo*, clang::StorageClass, clang::StorageClass, clang::Expr*)"},
    {"_ZN5clang11ParmVarDecl13getDefaultArgEv", "clang::ParmVarDecl::getDefaultArg()"},
    {"_ZNK5clang11ParmVarDecl27getNumDefaultArgTemporariesEv", "clang::ParmVarDecl::getNumDefaultArgTemporaries() const"},
    {"_ZN5clang11ParmVarDecl22getDefaultArgTemporaryEj", "clang::ParmVarDecl::getDefaultArgTemporary(unsigned int)"},
    {"_ZNK5clang11ParmVarDecl18getDefaultArgRangeEv", "clang::ParmVarDecl::getDefaultArgRange() const"},
    {"_ZNK5clang11ParmVarDecl15isParameterPackEv", "clang::ParmVarDecl::isParameterPack() const"},
    {"_ZNK5clang12FunctionDecl20getNameForDiagnosticERSsRKNS_14PrintingPolicyEb", "clang::FunctionDecl::getNameForDiagnostic(std::string&, clang::PrintingPolicy const&, bool) const"},
    {"_ZNK5clang12FunctionDecl29getTemplateSpecializationArgsEv", "clang::FunctionDecl::getTemplateSpecializationArgs() const"},
    {"_ZNK5clang12FunctionDecl10isVariadicEv", "clang::FunctionDecl::isVariadic() const"},
    {"_ZNK5clang12FunctionDecl7hasBodyERPKS0_", "clang::FunctionDecl::hasBody(clang::FunctionDecl const*&) const"},
    {"_ZNK5clang12FunctionDecl7getBodyERPKS0_", "clang::FunctionDecl::getBody(clang::FunctionDecl const*&) const"},
    {"_ZN5clang12FunctionDecl7setBodyEPNS_4StmtE", "clang::FunctionDecl::setBody(clang::Stmt*)"},
    {"_ZN5clang12FunctionDecl7setPureEb", "clang::FunctionDecl::setPure(bool)"},
    {"_ZNK5clang12FunctionDecl6isMainEv", "clang::FunctionDecl::isMain() const"},
    {"_ZNK5clang12FunctionDecl9isExternCEv", "clang::FunctionDecl::isExternC() const"},
    {"_ZNK5clang12FunctionDecl8isGlobalEv", "clang::FunctionDecl::isGlobal() const"},
    {"_ZN5clang12FunctionDecl22setPreviousDeclarationEPS0_", "clang::FunctionDecl::setPreviousDeclaration(clang::FunctionDecl*)"},
    {"_ZNK5clang12FunctionDecl16getCanonicalDeclEv", "clang::FunctionDecl::getCanonicalDecl() const"},
    {"_ZN5clang12FunctionDecl16getCanonicalDeclEv", "clang::FunctionDecl::getCanonicalDecl()"},
    {"_ZN5clang12FunctionDecl15setStorageClassENS_12StorageClassE", "clang::FunctionDecl::setStorageClass(clang::StorageClass)"},
    {"_ZNK5clang12FunctionDecl12getBuiltinIDEv", "clang::FunctionDecl::getBuiltinID() const"},
    {"_ZN5clang12FunctionDecl9setParamsERNS_10ASTContextEPPNS_11ParmVarDeclEj", "clang::FunctionDecl::setParams(clang::ASTContext&, clang::ParmVarDecl**, unsigned int)"},
    {"_ZNK5clang12FunctionDecl23getMinRequiredArgumentsEv", "clang::FunctionDecl::getMinRequiredArguments() const"},
    {"_ZNK5clang12FunctionDecl9isInlinedEv", "clang::FunctionDecl::isInlined() const"},
    {"_ZNK5clang12FunctionDecl29getTemplateSpecializationKindEv", "clang::FunctionDecl::getTemplateSpecializationKind() const"},
    {"_ZNK5clang12FunctionDecl31getTemplateInstantiationPatternEv", "clang::FunctionDecl::getTemplateInstantiationPattern() const"},
    {"_ZNK5clang12FunctionDecl35isInlineDefinitionExternallyVisibleEv", "clang::FunctionDecl::isInlineDefinitionExternallyVisible() const"},
    {"_ZNK5clang12FunctionDecl21getOverloadedOperatorEv", "clang::FunctionDecl::getOverloadedOperator() const"},
    {"_ZNK5clang12FunctionDecl20getLiteralIdentifierEv", "clang::FunctionDecl::getLiteralIdentifier() const"},
    {"_ZNK5clang12FunctionDecl16getTemplatedKindEv", "clang::FunctionDecl::getTemplatedKind() const"},
    {"_ZNK5clang12FunctionDecl33getInstantiatedFromMemberFunctionEv", "clang::FunctionDecl::getInstantiatedFromMemberFunction() const"},
    {"_ZNK5clang12FunctionDecl27getMemberSpecializationInfoEv", "clang::FunctionDecl::getMemberSpecializationInfo() const"},
    {"_ZN5clang12FunctionDecl32setInstantiationOfMemberFunctionERNS_10ASTContextEPS0_NS_26TemplateSpecializationKindE", "clang::FunctionDecl::setInstantiationOfMemberFunction(clang::ASTContext&, clang::FunctionDecl*, clang::TemplateSpecializationKind)"},
    {"_ZNK5clang12FunctionDecl24isImplicitlyInstantiableEv", "clang::FunctionDecl::isImplicitlyInstantiable() const"},
    {"_ZNK5clang12FunctionDecl18getPrimaryTemplateEv", "clang::FunctionDecl::getPrimaryTemplate() const"},
    {"_ZNK5clang12FunctionDecl38getTemplateSpecializationArgsAsWrittenEv", "clang::FunctionDecl::getTemplateSpecializationArgsAsWritten() const"},
    {"_ZN5clang12FunctionDecl33setFunctionTemplateSpecializationERNS_10ASTContextEPNS_20FunctionTemplateDeclEPKNS_20TemplateArgumentListEPvNS_26TemplateSpecializationKindEPKNS_24TemplateArgumentListInfoENS_14SourceLocationE", "clang::FunctionDecl::setFunctionTemplateSpecialization(clang::ASTContext&, clang::FunctionTemplateDecl*, clang::TemplateArgumentList const*, void*, clang::TemplateSpecializationKind, clang::TemplateArgumentListInfo const*, clang::SourceLocation)"},
    {"_ZN5clang12FunctionDecl34setDependentTemplateSpecializationERNS_10ASTContextERKNS_17UnresolvedSetImplERKNS_24TemplateArgumentListInfoE", "clang::FunctionDecl::setDependentTemplateSpecialization(clang::ASTContext&, clang::UnresolvedSetImpl const&, clang::TemplateArgumentListInfo const&)"},
    {"_ZN5clang43DependentFunctionTemplateSpecializationInfoC1ERKNS_17UnresolvedSetImplERKNS_24TemplateArgumentListInfoE", "clang::DependentFunctionTemplateSpecializationInfo::DependentFunctionTemplateSpecializationInfo(clang::UnresolvedSetImpl const&, clang::TemplateArgumentListInfo const&)"},
    {"_ZN5clang43DependentFunctionTemplateSpecializationInfoC2ERKNS_17UnresolvedSetImplERKNS_24TemplateArgumentListInfoE", "clang::DependentFunctionTemplateSpecializationInfo::DependentFunctionTemplateSpecializationInfo(clang::UnresolvedSetImpl const&, clang::TemplateArgumentListInfo const&)"},
    {"_ZN5clang12FunctionDecl29setTemplateSpecializationKindENS_26TemplateSpecializationKindENS_14SourceLocationE", "clang::FunctionDecl::setTemplateSpecializationKind(clang::TemplateSpecializationKind, clang::SourceLocation)"},
    {"_ZNK5clang12FunctionDecl23getPointOfInstantiationEv", "clang::FunctionDecl::getPointOfInstantiation() const"},
    {"_ZNK5clang12FunctionDecl11isOutOfLineEv", "clang::FunctionDecl::isOutOfLine() const"},
    {"_ZN5clang9FieldDecl6CreateERKNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPNS_14TypeSourceInfoEPNS_4ExprEb", "clang::FieldDecl::Create(clang::ASTContext const&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::TypeSourceInfo*, clang::Expr*, bool)"},
    {"_ZNK5clang9FieldDecl24isAnonymousStructOrUnionEv", "clang::FieldDecl::isAnonymousStructOrUnion() const"},
    {"_ZNK5clang9FieldDecl13getFieldIndexEv", "clang::FieldDecl::getFieldIndex() const"},
    {"_ZNK5clang10RecordDecl11field_beginEv", "clang::RecordDecl::field_begin() const"},
    {"_ZNK5clang7TagDecl16getOuterLocStartEv", "clang::TagDecl::getOuterLocStart() const"},
    {"_ZNK5clang7TagDecl14getSourceRangeEv", "clang::TagDecl::getSourceRange() const"},
    {"_ZN5clang7TagDecl16getCanonicalDeclEv", "clang::TagDecl::getCanonicalDecl()"},
    {"_ZN5clang7TagDecl21setTypedefForAnonDeclEPNS_11TypedefDeclE", "clang::TagDecl::setTypedefForAnonDecl(clang::TypedefDecl*)"},
    {"_ZN5clang7TagDecl15startDefinitionEv", "clang::TagDecl::startDefinition()"},
    {"_ZN5clang7TagDecl18completeDefinitionEv", "clang::TagDecl::completeDefinition()"},
    {"_ZNK5clang7TagDecl13getDefinitionEv", "clang::TagDecl::getDefinition() const"},
    {"_ZN5clang7TagDecl16setQualifierInfoEPNS_19NestedNameSpecifierENS_11SourceRangeE", "clang::TagDecl::setQualifierInfo(clang::NestedNameSpecifier*, clang::SourceRange)"},
    {"_ZN5clang8EnumDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoES5_PS0_bbb", "clang::EnumDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::EnumDecl*, bool, bool, bool)"},
    {"_ZN5clang8EnumDecl6CreateERNS_10ASTContextENS_4Decl10EmptyShellE", "clang::EnumDecl::Create(clang::ASTContext&, clang::Decl::EmptyShell)"},
    {"_ZN5clang8EnumDecl18completeDefinitionENS_8QualTypeES1_jj", "clang::EnumDecl::completeDefinition(clang::QualType, clang::QualType, unsigned int, unsigned int)"},
    {"_ZN5clang10RecordDeclC1ENS_4Decl4KindENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoEPS0_S6_", "clang::RecordDecl::RecordDecl(clang::Decl::Kind, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::RecordDecl*, clang::SourceLocation)"},
    {"_ZN5clang10RecordDeclC2ENS_4Decl4KindENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoEPS0_S6_", "clang::RecordDecl::RecordDecl(clang::Decl::Kind, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::RecordDecl*, clang::SourceLocation)"},
    {"_ZN5clang10RecordDecl6CreateERKNS_10ASTContextENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoES7_PS0_", "clang::RecordDecl::Create(clang::ASTContext const&, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::RecordDecl*)"},
    {"_ZN5clang10RecordDecl6CreateERKNS_10ASTContextENS_4Decl10EmptyShellE", "clang::RecordDecl::Create(clang::ASTContext const&, clang::Decl::EmptyShell)"},
    {"_ZNK5clang10RecordDecl19isInjectedClassNameEv", "clang::RecordDecl::isInjectedClassName() const"},
    {"_ZNK5clang10RecordDecl29LoadFieldsFromExternalStorageEv", "clang::RecordDecl::LoadFieldsFromExternalStorage() const"},
    {"_ZN5clang10RecordDecl18completeDefinitionEv", "clang::RecordDecl::completeDefinition()"},
    {"_ZN5clang9BlockDecl9setParamsEPPNS_11ParmVarDeclEj", "clang::BlockDecl::setParams(clang::ParmVarDecl**, unsigned int)"},
    {"_ZN5clang9BlockDecl11setCapturesERNS_10ASTContextEPKNS0_7CaptureES5_b", "clang::BlockDecl::setCaptures(clang::ASTContext&, clang::BlockDecl::Capture const*, clang::BlockDecl::Capture const*, bool)"},
    {"_ZNK5clang9BlockDecl14getSourceRangeEv", "clang::BlockDecl::getSourceRange() const"},
    {"_ZN5clang19TranslationUnitDecl6CreateERNS_10ASTContextE", "clang::TranslationUnitDecl::Create(clang::ASTContext&)"},
    {"_ZN5clang13NamespaceDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoE", "clang::NamespaceDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*)"},
    {"_ZN5clang13NamespaceDecl16getNextNamespaceEv", "clang::NamespaceDecl::getNextNamespace()"},
    {"_ZN5clang17ImplicitParamDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeE", "clang::ImplicitParamDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType)"},
    {"_ZN5clang12FunctionDecl6CreateERNS_10ASTContextEPNS_11DeclContextERKNS_19DeclarationNameInfoENS_8QualTypeEPNS_14TypeSourceInfoENS_12StorageClassESB_bb", "clang::FunctionDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::DeclarationNameInfo const&, clang::QualType, clang::TypeSourceInfo*, clang::StorageClass, clang::StorageClass, bool, bool)"},
    {"_ZN5clang9BlockDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationE", "clang::BlockDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation)"},
    {"_ZN5clang16EnumConstantDecl6CreateERNS_10ASTContextEPNS_8EnumDeclENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPNS_4ExprERKN4llvm6APSIntE", "clang::EnumConstantDecl::Create(clang::ASTContext&, clang::EnumDecl*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::Expr*, llvm::APSInt const&)"},
    {"_ZN5clang17IndirectFieldDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPPNS_9NamedDeclEj", "clang::IndirectFieldDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::NamedDecl**, unsigned int)"},
    {"_ZNK5clang16EnumConstantDecl14getSourceRangeEv", "clang::EnumConstantDecl::getSourceRange() const"},
    {"_ZN5clang11TypedefDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoEPNS_14TypeSourceInfoE", "clang::TypedefDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::TypeSourceInfo*)"},
    {"_ZN5clang16FileScopeAsmDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_13StringLiteralE", "clang::FileScopeAsmDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::StringLiteral*)"},
    {"_Z21GetExplicitVisibilityPKN5clang4DeclE", "GetExplicitVisibility(clang::Decl const*)"},
    {"_Z29getLVForTemplateParameterListPKN5clang21TemplateParameterListE", "getLVForTemplateParameterList(clang::TemplateParameterList const*)"},
    {"_Z28getLVForTemplateArgumentListPKN5clang16TemplateArgumentEjRN12_GLOBAL__N_17LVFlagsE", "getLVForTemplateArgumentList(clang::TemplateArgument const*, unsigned int, (anonymous namespace)::LVFlags&)"},
    {"_ZNK5clang4Decl11isOutOfLineEv", "clang::Decl::isOutOfLine() const"},
    {"_ZNK5clang9NamedDecl20getNameForDiagnosticERSsRKNS_14PrintingPolicyEb", "clang::NamedDecl::getNameForDiagnostic(std::string&, clang::PrintingPolicy const&, bool) const"},
    {"_ZNK5clang4Decl7getAttrINS_16OverloadableAttrEEEPT_v", "clang::OverloadableAttr* clang::Decl::getAttr<clang::OverloadableAttr>() const"},
    {"_ZN5clang12RedeclarableINS_12FunctionDeclEE22setPreviousDeclarationEPS1_", "clang::Redeclarable<clang::FunctionDecl>::setPreviousDeclaration(clang::FunctionDecl*)"},
    {"_ZN5clang7TagDeclC2ENS_4Decl4KindENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoEPS0_S6_", "clang::TagDecl::TagDecl(clang::Decl::Kind, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::TagDecl*, clang::SourceLocation)"},
    {"_ZN5clang7VarDeclD1Ev", "clang::VarDecl::~VarDecl()"},
    {"_ZN5clang7VarDeclD0Ev", "clang::VarDecl::~VarDecl()"},
    {"_ZN5clang7VarDecl20getNextRedeclarationEv", "clang::VarDecl::getNextRedeclaration()"},
    {"_ZNK5clang4Decl7getBodyEv", "clang::Decl::getBody() const"},
    {"_ZNK5clang4Decl7hasBodyEv", "clang::Decl::hasBody() const"},
    {"_ZN5clang12FunctionDeclD1Ev", "clang::FunctionDecl::~FunctionDecl()"},
    {"_ZN5clang12FunctionDeclD0Ev", "clang::FunctionDecl::~FunctionDecl()"},
    {"_ZNK5clang12FunctionDecl14getSourceRangeEv", "clang::FunctionDecl::getSourceRange() const"},
    {"_ZN5clang12FunctionDecl20getNextRedeclarationEv", "clang::FunctionDecl::getNextRedeclaration()"},
    {"_ZNK5clang12FunctionDecl7getBodyEv", "clang::FunctionDecl::getBody() const"},
    {"_ZNK5clang12FunctionDecl7hasBodyEv", "clang::FunctionDecl::hasBody() const"},
    {"_ZNK5clang14DeclaratorDecl16getInnerLocStartEv", "clang::DeclaratorDecl::getInnerLocStart() const"},
    {"_ZN5clang16EnumConstantDeclD1Ev", "clang::EnumConstantDecl::~EnumConstantDecl()"},
    {"_ZN5clang16EnumConstantDeclD0Ev", "clang::EnumConstantDecl::~EnumConstantDecl()"},
    {"_ZN5clang4Decl16getCanonicalDeclEv", "clang::Decl::getCanonicalDecl()"},
    {"_ZN5clang4Decl20getNextRedeclarationEv", "clang::Decl::getNextRedeclaration()"},
    {"_ZN5clang7TagDeclD1Ev", "clang::TagDecl::~TagDecl()"},
    {"_ZN5clang7TagDeclD0Ev", "clang::TagDecl::~TagDecl()"},
    {"_ZN5clang7TagDecl20getNextRedeclarationEv", "clang::TagDecl::getNextRedeclaration()"},
    {"_ZNK5clang7TagDecl16getInnerLocStartEv", "clang::TagDecl::getInnerLocStart() const"},
    {"_ZN5clang9BlockDeclD1Ev", "clang::BlockDecl::~BlockDecl()"},
    {"_ZN5clang9BlockDeclD0Ev", "clang::BlockDecl::~BlockDecl()"},
    {"_ZNK5clang9BlockDecl7getBodyEv", "clang::BlockDecl::getBody() const"},
    {"_ZN5clang10RecordDeclD1Ev", "clang::RecordDecl::~RecordDecl()"},
    {"_ZN5clang10RecordDeclD0Ev", "clang::RecordDecl::~RecordDecl()"},
    {"_ZN5clang9FieldDecl11classofKindENS_4Decl4KindE", "clang::FieldDecl::classofKind(clang::Decl::Kind)"},
    {"_ZN5clang8TypeDeclD1Ev", "clang::TypeDecl::~TypeDecl()"},
    {"_ZN5clang8TypeDeclD0Ev", "clang::TypeDecl::~TypeDecl()"},
    {"_ZNK5clang4Decl14getSourceRangeEv", "clang::Decl::getSourceRange() const"},
    {"_ZN5clang9NamedDeclD1Ev", "clang::NamedDecl::~NamedDecl()"},
    {"_ZN5clang9NamedDeclD0Ev", "clang::NamedDecl::~NamedDecl()"},
    {"_ZN5clang9ValueDeclD1Ev", "clang::ValueDecl::~ValueDecl()"},
    {"_ZN5clang9ValueDeclD0Ev", "clang::ValueDecl::~ValueDecl()"},
    {"_ZN5clang14DeclaratorDeclD1Ev", "clang::DeclaratorDecl::~DeclaratorDecl()"},
    {"_ZN5clang14DeclaratorDeclD0Ev", "clang::DeclaratorDecl::~DeclaratorDecl()"},
    {"_ZNK5clang14DeclaratorDecl14getSourceRangeEv", "clang::DeclaratorDecl::getSourceRange() const"},
    {"_ZN5clang16FileScopeAsmDeclD1Ev", "clang::FileScopeAsmDecl::~FileScopeAsmDecl()"},
    {"_ZN5clang16FileScopeAsmDeclD0Ev", "clang::FileScopeAsmDecl::~FileScopeAsmDecl()"},
    {"_ZN5clang11TypedefDeclD1Ev", "clang::TypedefDecl::~TypedefDecl()"},
    {"_ZN5clang11TypedefDeclD0Ev", "clang::TypedefDecl::~TypedefDecl()"},
    {"_ZN5clang11TypedefDecl16getCanonicalDeclEv", "clang::TypedefDecl::getCanonicalDecl()"},
    {"_ZN5clang11TypedefDecl20getNextRedeclarationEv", "clang::TypedefDecl::getNextRedeclaration()"},
    {"_ZN5clang17IndirectFieldDeclD1Ev", "clang::IndirectFieldDecl::~IndirectFieldDecl()"},
    {"_ZN5clang17IndirectFieldDeclD0Ev", "clang::IndirectFieldDecl::~IndirectFieldDecl()"},
    {"_ZN5clang16EnumConstantDeclC2EPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPNS_4ExprERKN4llvm6APSIntE", "clang::EnumConstantDecl::EnumConstantDecl(clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::Expr*, llvm::APSInt const&)"},
    {"_ZN5clang9BlockDeclC2EPNS_11DeclContextENS_14SourceLocationE", "clang::BlockDecl::BlockDecl(clang::DeclContext*, clang::SourceLocation)"},
    {"_ZN5clang12FunctionDeclC2ENS_4Decl4KindEPNS_11DeclContextERKNS_19DeclarationNameInfoENS_8QualTypeEPNS_14TypeSourceInfoENS_12StorageClassESB_b", "clang::FunctionDecl::FunctionDecl(clang::Decl::Kind, clang::DeclContext*, clang::DeclarationNameInfo const&, clang::QualType, clang::TypeSourceInfo*, clang::StorageClass, clang::StorageClass, bool)"},
    {"_ZN5clang7VarDeclC2ENS_4Decl4KindEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPNS_14TypeSourceInfoENS_12StorageClassESB_", "clang::VarDecl::VarDecl(clang::Decl::Kind, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::TypeSourceInfo*, clang::StorageClass, clang::StorageClass)"},
    {"_ZN5clang17ImplicitParamDeclD1Ev", "clang::ImplicitParamDecl::~ImplicitParamDecl()"},
    {"_ZN5clang17ImplicitParamDeclD0Ev", "clang::ImplicitParamDecl::~ImplicitParamDecl()"},
    {"_ZN5clang13NamespaceDeclC2EPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoE", "clang::NamespaceDecl::NamespaceDecl(clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*)"},
    {"_ZN5clang13NamespaceDeclD1Ev", "clang::NamespaceDecl::~NamespaceDecl()"},
    {"_ZN5clang13NamespaceDeclD0Ev", "clang::NamespaceDecl::~NamespaceDecl()"},
    {"_ZNK5clang13NamespaceDecl14getSourceRangeEv", "clang::NamespaceDecl::getSourceRange() const"},
    {"_ZN5clang13NamespaceDecl16getCanonicalDeclEv", "clang::NamespaceDecl::getCanonicalDecl()"},
    {"_ZN5clang19TranslationUnitDeclC2ERNS_10ASTContextE", "clang::TranslationUnitDecl::TranslationUnitDecl(clang::ASTContext&)"},
    {"_ZN5clang19TranslationUnitDeclD1Ev", "clang::TranslationUnitDecl::~TranslationUnitDecl()"},
    {"_ZN5clang19TranslationUnitDeclD0Ev", "clang::TranslationUnitDecl::~TranslationUnitDecl()"},
    {"_ZN5clang12RedeclarableINS_7TagDeclEE22setPreviousDeclarationEPS1_", "clang::Redeclarable<clang::TagDecl>::setPreviousDeclaration(clang::TagDecl*)"},
    {"_ZN5clang8EnumDeclD1Ev", "clang::EnumDecl::~EnumDecl()"},
    {"_ZN5clang8EnumDeclD0Ev", "clang::EnumDecl::~EnumDecl()"},
    {"_ZN5clang8EnumDecl16getCanonicalDeclEv", "clang::EnumDecl::getCanonicalDecl()"},
    {"_ZN5clang9FieldDeclC2ENS_4Decl4KindEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPNS_14TypeSourceInfoEPNS_4ExprEb", "clang::FieldDecl::FieldDecl(clang::Decl::Kind, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::TypeSourceInfo*, clang::Expr*, bool)"},
    {"_ZN5clang9FieldDeclD1Ev", "clang::FieldDecl::~FieldDecl()"},
    {"_ZN5clang9FieldDeclD0Ev", "clang::FieldDecl::~FieldDecl()"},
    {"_ZN5clang11ParmVarDeclD1Ev", "clang::ParmVarDecl::~ParmVarDecl()"},
    {"_ZN5clang11ParmVarDeclD0Ev", "clang::ParmVarDecl::~ParmVarDecl()"},
    {"_ZNK5clang4Decl7getAttrINS_14VisibilityAttrEEEPT_v", "clang::VisibilityAttr* clang::Decl::getAttr<clang::VisibilityAttr>() const"},
    {"_ZNK5clang4Decl15getDeclKindNameEv", "clang::Decl::getDeclKindName() const"},
    {"_ZN5clang4Decl14setInvalidDeclEb", "clang::Decl::setInvalidDecl(bool)"},
    {"_ZNK5clang11DeclContext15getDeclKindNameEv", "clang::DeclContext::getDeclKindName() const"},
    {"_ZN5clang4Decl15CollectingStatsEb", "clang::Decl::CollectingStats(bool)"},
    {"_ZN5clang4Decl10PrintStatsEv", "clang::Decl::PrintStats()"},
    {"_ZN5clang4Decl3addENS0_4KindE", "clang::Decl::add(clang::Decl::Kind)"},
    {"_ZNK5clang4Decl23isTemplateParameterPackEv", "clang::Decl::isTemplateParameterPack() const"},
    {"_ZNK5clang4Decl15isParameterPackEv", "clang::Decl::isParameterPack() const"},
    {"_ZNK5clang4Decl28isFunctionOrFunctionTemplateEv", "clang::Decl::isFunctionOrFunctionTemplate() const"},
    {"_ZNK5clang4Decl32isDefinedOutsideFunctionOrMethodEv", "clang::Decl::isDefinedOutsideFunctionOrMethod() const"},
    {"_ZNK5clang20PrettyStackTraceDecl5printERN4llvm11raw_ostreamE", "clang::PrettyStackTraceDecl::print(llvm::raw_ostream&) const"},
    {"_ZN5clang4DeclD0Ev", "clang::Decl::~Decl()"},
    {"_ZN5clang4DeclD1Ev", "clang::Decl::~Decl()"},
    {"_ZN5clang4DeclD2Ev", "clang::Decl::~Decl()"},
    {"_ZN5clang4Decl14setDeclContextEPNS_11DeclContextE", "clang::Decl::setDeclContext(clang::DeclContext*)"},
    {"_ZN5clang4Decl21setLexicalDeclContextEPNS_11DeclContextE", "clang::Decl::setLexicalDeclContext(clang::DeclContext*)"},
    {"_ZNK5clang4Decl13getASTContextEv", "clang::Decl::getASTContext() const"},
    {"_ZNK5clang4Decl22isInAnonymousNamespaceEv", "clang::Decl::isInAnonymousNamespace() const"},
    {"_ZN5clang4Decl22getTranslationUnitDeclEv", "clang::Decl::getTranslationUnitDecl()"},
    {"_ZNK5clang4Decl22getASTMutationListenerEv", "clang::Decl::getASTMutationListener() const"},
    {"_ZNK5clang4Decl6isUsedEb", "clang::Decl::isUsed(bool) const"},
    {"_ZN5clang4Decl29getIdentifierNamespaceForKindENS0_4KindE", "clang::Decl::getIdentifierNamespaceForKind(clang::Decl::Kind)"},
    {"_ZN5clang4Decl8setAttrsERKN4llvm11SmallVectorIPNS_4AttrELj2EEE", "clang::Decl::setAttrs(llvm::SmallVector<clang::Attr*, 2u> const&)"},
    {"_ZN5clang4Decl9dropAttrsEv", "clang::Decl::dropAttrs()"},
    {"_ZNK5clang4Decl8getAttrsEv", "clang::Decl::getAttrs() const"},
    {"_ZN5clang4Decl9swapAttrsEPS0_", "clang::Decl::swapAttrs(clang::Decl*)"},
    {"_ZN5clang4Decl19castFromDeclContextEPKNS_11DeclContextE", "clang::Decl::castFromDeclContext(clang::DeclContext const*)"},
    {"_ZN5clang4Decl17castToDeclContextEPKS0_", "clang::Decl::castToDeclContext(clang::Decl const*)"},
    {"_ZNK5clang4Decl13getBodyRBraceEv", "clang::Decl::getBodyRBrace() const"},
    {"_ZNK5clang4Decl22CheckAccessDeclContextEv", "clang::Decl::CheckAccessDeclContext() const"},
    {"_ZN5clang11DeclContext7classofEPKNS_4DeclE", "clang::DeclContext::classof(clang::Decl const*)"},
    {"_ZN5clang11DeclContextD1Ev", "clang::DeclContext::~DeclContext()"},
    {"_ZN5clang11DeclContextD2Ev", "clang::DeclContext::~DeclContext()"},
    {"_ZN5clang11DeclContext15getLookupParentEv", "clang::DeclContext::getLookupParent()"},
    {"_ZN5clang11DeclContext16getRedeclContextEv", "clang::DeclContext::getRedeclContext()"},
    {"_ZNK5clang11DeclContext17isInlineNamespaceEv", "clang::DeclContext::isInlineNamespace() const"},
    {"_ZNK5clang11DeclContext18isDependentContextEv", "clang::DeclContext::isDependentContext() const"},
    {"_ZNK5clang11DeclContext20isTransparentContextEv", "clang::DeclContext::isTransparentContext() const"},
    {"_ZNK5clang11DeclContext16isExternCContextEv", "clang::DeclContext::isExternCContext() const"},
    {"_ZNK5clang11DeclContext8EnclosesEPKS0_", "clang::DeclContext::Encloses(clang::DeclContext const*) const"},
    {"_ZN5clang11DeclContext17getPrimaryContextEv", "clang::DeclContext::getPrimaryContext()"},
    {"_ZN5clang11DeclContext14getNextContextEv", "clang::DeclContext::getNextContext()"},
    {"_ZN5clang11DeclContext14BuildDeclChainERKN4llvm15SmallVectorImplIPNS_4DeclEEE", "clang::DeclContext::BuildDeclChain(llvm::SmallVectorImpl<clang::Decl*> const&)"},
    {"_ZNK5clang11DeclContext35LoadLexicalDeclsFromExternalStorageEv", "clang::DeclContext::LoadLexicalDeclsFromExternalStorage() const"},
    {"_ZN5clang17ExternalASTSource32SetNoExternalVisibleDeclsForNameEPKNS_11DeclContextENS_15DeclarationNameE", "clang::ExternalASTSource::SetNoExternalVisibleDeclsForName(clang::DeclContext const*, clang::DeclarationName)"},
    {"_ZNK5clang11DeclContext20CreateStoredDeclsMapERNS_10ASTContextE", "clang::DeclContext::CreateStoredDeclsMap(clang::ASTContext&) const"},
    {"_ZN5clang17ExternalASTSource30SetExternalVisibleDeclsForNameEPKNS_11DeclContextENS_15DeclarationNameERN4llvm15SmallVectorImplIPNS_9NamedDeclEEE", "clang::ExternalASTSource::SetExternalVisibleDeclsForName(clang::DeclContext const*, clang::DeclarationName, llvm::SmallVectorImpl<clang::NamedDecl*>&)"},
    {"_ZN5clang17ExternalASTSource30MaterializeVisibleDeclsForNameEPKNS_11DeclContextENS_15DeclarationNameERN4llvm15SmallVectorImplIPNS_9NamedDeclEEE", "clang::ExternalASTSource::MaterializeVisibleDeclsForName(clang::DeclContext const*, clang::DeclarationName, llvm::SmallVectorImpl<clang::NamedDecl*>&)"},
    {"_ZNK5clang11DeclContext18noload_decls_beginEv", "clang::DeclContext::noload_decls_begin() const"},
    {"_ZNK5clang11DeclContext16noload_decls_endEv", "clang::DeclContext::noload_decls_end() const"},
    {"_ZNK5clang11DeclContext11decls_beginEv", "clang::DeclContext::decls_begin() const"},
    {"_ZNK5clang11DeclContext9decls_endEv", "clang::DeclContext::decls_end() const"},
    {"_ZNK5clang11DeclContext11decls_emptyEv", "clang::DeclContext::decls_empty() const"},
    {"_ZN5clang11DeclContext10removeDeclEPNS_4DeclE", "clang::DeclContext::removeDecl(clang::Decl*)"},
    {"_ZN5clang11DeclContext13addHiddenDeclEPNS_4DeclE", "clang::DeclContext::addHiddenDecl(clang::Decl*)"},
    {"_ZN5clang11DeclContext7addDeclEPNS_4DeclE", "clang::DeclContext::addDecl(clang::Decl*)"},
    {"_ZN5clang11DeclContext24makeDeclVisibleInContextEPNS_9NamedDeclEb", "clang::DeclContext::makeDeclVisibleInContext(clang::NamedDecl*, bool)"},
    {"_ZN5clang11DeclContext11buildLookupEPS0_", "clang::DeclContext::buildLookup(clang::DeclContext*)"},
    {"_ZN5clang11DeclContext28makeDeclVisibleInContextImplEPNS_9NamedDeclE", "clang::DeclContext::makeDeclVisibleInContextImpl(clang::NamedDecl*)"},
    {"_ZN5clang11DeclContext6lookupENS_15DeclarationNameE", "clang::DeclContext::lookup(clang::DeclarationName)"},
    {"_ZNK5clang11DeclContext6lookupENS_15DeclarationNameE", "clang::DeclContext::lookup(clang::DeclarationName) const"},
    {"_ZN5clang11DeclContext28getEnclosingNamespaceContextEv", "clang::DeclContext::getEnclosingNamespaceContext()"},
    {"_ZNK5clang11DeclContext25InEnclosingNamespaceSetOfEPKS0_", "clang::DeclContext::InEnclosingNamespaceSetOf(clang::DeclContext const*) const"},
    {"_ZN5clang11DeclContext42MaterializeVisibleDeclsFromExternalStorageEv", "clang::DeclContext::MaterializeVisibleDeclsFromExternalStorage()"},
    {"_ZNK5clang11DeclContext18getUsingDirectivesEv", "clang::DeclContext::getUsingDirectives() const"},
    {"_ZN5clang10ASTContext22ReleaseDeclContextMapsEv", "clang::ASTContext::ReleaseDeclContextMaps()"},
    {"_ZN5clang14StoredDeclsMap10DestroyAllEPS0_b", "clang::StoredDeclsMap::DestroyAll(clang::StoredDeclsMap*, bool)"},
    {"_ZN5clang19DependentDiagnostic6CreateERNS_10ASTContextEPNS_11DeclContextERKNS_17PartialDiagnosticE", "clang::DependentDiagnostic::Create(clang::ASTContext&, clang::DeclContext*, clang::PartialDiagnostic const&)"},
    {"_ZNK5clang4Decl7hasAttrINS_8UsedAttrEEEbv", "bool clang::Decl::hasAttr<clang::UsedAttr>() const"},
    {"_ZN5clang15StoredDeclsList17AddSubsequentDeclEPNS_9NamedDeclE", "clang::StoredDeclsList::AddSubsequentDecl(clang::NamedDecl*)"},
    {"_ZN5clang15StoredDeclsList6removeEPNS_9NamedDeclE", "clang::StoredDeclsList::remove(clang::NamedDecl*)"},
    {"_ZN5clang15StoredDeclsList19HandleRedeclarationEPNS_9NamedDeclE", "clang::StoredDeclsList::HandleRedeclaration(clang::NamedDecl*)"},
    {"_ZN4llvm8DenseMapIN5clang15DeclarationNameENS1_15StoredDeclsListENS_12DenseMapInfoIS2_EENS4_IS3_EEE16FindAndConstructERKS2_", "llvm::DenseMap<clang::DeclarationName, clang::StoredDeclsList, llvm::DenseMapInfo<clang::DeclarationName>, llvm::DenseMapInfo<clang::StoredDeclsList>>::FindAndConstruct(clang::DeclarationName const&)"},
    {"_ZN4llvm8DenseMapIN5clang15DeclarationNameENS1_15StoredDeclsListENS_12DenseMapInfoIS2_EENS4_IS3_EEE16InsertIntoBucketERKS2_RKS3_PSt4pairIS2_S3_E", "llvm::DenseMap<clang::DeclarationName, clang::StoredDeclsList, llvm::DenseMapInfo<clang::DeclarationName>, llvm::DenseMapInfo<clang::StoredDeclsList>>::InsertIntoBucket(clang::DeclarationName const&, clang::StoredDeclsList const&, std::pair<clang::DeclarationName, clang::StoredDeclsList>*)"},
    {"_ZN4llvm8DenseMapIN5clang15DeclarationNameENS1_15StoredDeclsListENS_12DenseMapInfoIS2_EENS4_IS3_EEE4growEj", "llvm::DenseMap<clang::DeclarationName, clang::StoredDeclsList, llvm::DenseMapInfo<clang::DeclarationName>, llvm::DenseMapInfo<clang::StoredDeclsList>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang9NamedDeclEEaSERKS4_", "llvm::SmallVectorImpl<clang::NamedDecl*>::operator=(llvm::SmallVectorImpl<clang::NamedDecl*> const&)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang4AttrEE4swapERS4_", "llvm::SmallVectorImpl<clang::Attr*>::swap(llvm::SmallVectorImpl<clang::Attr*>&)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang4AttrEEaSERKS4_", "llvm::SmallVectorImpl<clang::Attr*>::operator=(llvm::SmallVectorImpl<clang::Attr*> const&)"},
    {"_ZN4llvm8DenseMapIN5clang15DeclarationNameENS1_15StoredDeclsListENS_12DenseMapInfoIS2_EENS4_IS3_EEED2Ev", "llvm::DenseMap<clang::DeclarationName, clang::StoredDeclsList, llvm::DenseMapInfo<clang::DeclarationName>, llvm::DenseMapInfo<clang::StoredDeclsList>>::~DenseMap()"},
    {"_ZSt6__findIPPN5clang9NamedDeclES2_ET_S4_S4_RKT0_St26random_access_iterator_tag", "clang::NamedDecl** std::__find<clang::NamedDecl**, clang::NamedDecl*>(clang::NamedDecl**, clang::NamedDecl**, clang::NamedDecl* const&, std::random_access_iterator_tag)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang9NamedDeclEE6insertEPS3_RKS3_", "llvm::SmallVectorImpl<clang::NamedDecl*>::insert(clang::NamedDecl**, clang::NamedDecl* const&)"},
    {"_ZN5clang13CXXRecordDecl14DefinitionDataC1EPS0_", "clang::CXXRecordDecl::DefinitionData::DefinitionData(clang::CXXRecordDecl*)"},
    {"_ZN5clang13CXXRecordDecl14DefinitionDataC2EPS0_", "clang::CXXRecordDecl::DefinitionData::DefinitionData(clang::CXXRecordDecl*)"},
    {"_ZN5clang13CXXRecordDeclC1ENS_4Decl4KindENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoEPS0_S6_", "clang::CXXRecordDecl::CXXRecordDecl(clang::Decl::Kind, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::CXXRecordDecl*, clang::SourceLocation)"},
    {"_ZN5clang13CXXRecordDeclC2ENS_4Decl4KindENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoEPS0_S6_", "clang::CXXRecordDecl::CXXRecordDecl(clang::Decl::Kind, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::CXXRecordDecl*, clang::SourceLocation)"},
    {"_ZN5clang13CXXRecordDecl6CreateERKNS_10ASTContextENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoES7_PS0_b", "clang::CXXRecordDecl::Create(clang::ASTContext const&, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::CXXRecordDecl*, bool)"},
    {"_ZN5clang13CXXRecordDecl6CreateERKNS_10ASTContextENS_4Decl10EmptyShellE", "clang::CXXRecordDecl::Create(clang::ASTContext const&, clang::Decl::EmptyShell)"},
    {"_ZN5clang13CXXRecordDecl8setBasesEPKPKNS_16CXXBaseSpecifierEj", "clang::CXXRecordDecl::setBases(clang::CXXBaseSpecifier const* const*, unsigned int)"},
    {"_ZNK5clang13CXXRecordDecl20hasAnyDependentBasesEv", "clang::CXXRecordDecl::hasAnyDependentBases() const"},
    {"_Z7SawBasePKN5clang13CXXRecordDeclEPv", "SawBase(clang::CXXRecordDecl const*, void*)"},
    {"_ZNK5clang13CXXRecordDecl23hasConstCopyConstructorERKNS_10ASTContextE", "clang::CXXRecordDecl::hasConstCopyConstructor(clang::ASTContext const&) const"},
    {"_ZNK5clang13CXXRecordDecl18getCopyConstructorERKNS_10ASTContextEj", "clang::CXXRecordDecl::getCopyConstructor(clang::ASTContext const&, unsigned int) const"},
    {"_ZNK5clang18CXXConstructorDecl17isCopyConstructorERj", "clang::CXXConstructorDecl::isCopyConstructor(unsigned int&) const"},
    {"_Z30GetBestOverloadCandidateSimpleRKN4llvm15SmallVectorImplISt4pairIPN5clang13CXXMethodDeclENS2_10QualifiersEEEE", "GetBestOverloadCandidateSimple(llvm::SmallVectorImpl<std::pair<clang::CXXMethodDecl*, clang::Qualifiers>> const&)"},
    {"_ZNK5clang13CXXRecordDecl25getCopyAssignmentOperatorEb", "clang::CXXRecordDecl::getCopyAssignmentOperator(bool) const"},
    {"_ZN5clang13CXXRecordDecl25markedVirtualFunctionPureEv", "clang::CXXRecordDecl::markedVirtualFunctionPure()"},
    {"_ZN5clang13CXXRecordDecl11addedMemberEPNS_4DeclE", "clang::CXXRecordDecl::addedMember(clang::Decl*)"},
    {"_ZNK5clang18CXXConstructorDecl20isDefaultConstructorEv", "clang::CXXConstructorDecl::isDefaultConstructor() const"},
    {"_ZN5clang13CXXRecordDecl29getVisibleConversionFunctionsEv", "clang::CXXRecordDecl::getVisibleConversionFunctions()"},
    {"_ZN5clang13CXXRecordDecl16removeConversionEPKNS_9NamedDeclE", "clang::CXXRecordDecl::removeConversion(clang::NamedDecl const*)"},
    {"_ZNK5clang13CXXRecordDecl30getInstantiatedFromMemberClassEv", "clang::CXXRecordDecl::getInstantiatedFromMemberClass() const"},
    {"_ZNK5clang13CXXRecordDecl27getMemberSpecializationInfoEv", "clang::CXXRecordDecl::getMemberSpecializationInfo() const"},
    {"_ZN5clang13CXXRecordDecl29setInstantiationOfMemberClassEPS0_NS_26TemplateSpecializationKindE", "clang::CXXRecordDecl::setInstantiationOfMemberClass(clang::CXXRecordDecl*, clang::TemplateSpecializationKind)"},
    {"_ZNK5clang13CXXRecordDecl29getTemplateSpecializationKindEv", "clang::CXXRecordDecl::getTemplateSpecializationKind() const"},
    {"_ZN5clang13CXXRecordDecl29setTemplateSpecializationKindENS_26TemplateSpecializationKindE", "clang::CXXRecordDecl::setTemplateSpecializationKind(clang::TemplateSpecializationKind)"},
    {"_ZNK5clang13CXXRecordDecl13getDestructorEv", "clang::CXXRecordDecl::getDestructor() const"},
    {"_ZN5clang13CXXRecordDecl18completeDefinitionEv", "clang::CXXRecordDecl::completeDefinition()"},
    {"_ZN5clang13CXXRecordDecl18completeDefinitionEPNS_20CXXFinalOverriderMapE", "clang::CXXRecordDecl::completeDefinition(clang::CXXFinalOverriderMap*)"},
    {"_ZNK5clang13CXXRecordDecl13mayBeAbstractEv", "clang::CXXRecordDecl::mayBeAbstract() const"},
    {"_ZN5clang13CXXMethodDecl6CreateERNS_10ASTContextEPNS_13CXXRecordDeclERKNS_19DeclarationNameInfoENS_8QualTypeEPNS_14TypeSourceInfoEbNS_12StorageClassEb", "clang::CXXMethodDecl::Create(clang::ASTContext&, clang::CXXRecordDecl*, clang::DeclarationNameInfo const&, clang::QualType, clang::TypeSourceInfo*, bool, clang::StorageClass, bool)"},
    {"_ZNK5clang13CXXMethodDecl27isUsualDeallocationFunctionEv", "clang::CXXMethodDecl::isUsualDeallocationFunction() const"},
    {"_ZNK5clang13CXXMethodDecl24isCopyAssignmentOperatorEv", "clang::CXXMethodDecl::isCopyAssignmentOperator() const"},
    {"_ZN5clang13CXXMethodDecl19addOverriddenMethodEPKS0_", "clang::CXXMethodDecl::addOverriddenMethod(clang::CXXMethodDecl const*)"},
    {"_ZNK5clang13CXXMethodDecl24begin_overridden_methodsEv", "clang::CXXMethodDecl::begin_overridden_methods() const"},
    {"_ZNK5clang13CXXMethodDecl22end_overridden_methodsEv", "clang::CXXMethodDecl::end_overridden_methods() const"},
    {"_ZNK5clang13CXXMethodDecl23size_overridden_methodsEv", "clang::CXXMethodDecl::size_overridden_methods() const"},
    {"_ZNK5clang13CXXMethodDecl11getThisTypeERNS_10ASTContextE", "clang::CXXMethodDecl::getThisType(clang::ASTContext&) const"},
    {"_ZNK5clang13CXXMethodDecl13hasInlineBodyEv", "clang::CXXMethodDecl::hasInlineBody() const"},
    {"_ZN5clang18CXXCtorInitializerC1ERNS_10ASTContextEPNS_14TypeSourceInfoEbNS_14SourceLocationEPNS_4ExprES5_S5_", "clang::CXXCtorInitializer::CXXCtorInitializer(clang::ASTContext&, clang::TypeSourceInfo*, bool, clang::SourceLocation, clang::Expr*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang18CXXCtorInitializerC2ERNS_10ASTContextEPNS_14TypeSourceInfoEbNS_14SourceLocationEPNS_4ExprES5_S5_", "clang::CXXCtorInitializer::CXXCtorInitializer(clang::ASTContext&, clang::TypeSourceInfo*, bool, clang::SourceLocation, clang::Expr*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang18CXXCtorInitializerC1ERNS_10ASTContextEPNS_9FieldDeclENS_14SourceLocationES5_PNS_4ExprES5_", "clang::CXXCtorInitializer::CXXCtorInitializer(clang::ASTContext&, clang::FieldDecl*, clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang18CXXCtorInitializerC2ERNS_10ASTContextEPNS_9FieldDeclENS_14SourceLocationES5_PNS_4ExprES5_", "clang::CXXCtorInitializer::CXXCtorInitializer(clang::ASTContext&, clang::FieldDecl*, clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang18CXXCtorInitializerC1ERNS_10ASTContextEPNS_17IndirectFieldDeclENS_14SourceLocationES5_PNS_4ExprES5_", "clang::CXXCtorInitializer::CXXCtorInitializer(clang::ASTContext&, clang::IndirectFieldDecl*, clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang18CXXCtorInitializerC2ERNS_10ASTContextEPNS_17IndirectFieldDeclENS_14SourceLocationES5_PNS_4ExprES5_", "clang::CXXCtorInitializer::CXXCtorInitializer(clang::ASTContext&, clang::IndirectFieldDecl*, clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang18CXXCtorInitializerC1ERNS_10ASTContextEPNS_9FieldDeclENS_14SourceLocationES5_PNS_4ExprES5_PPNS_7VarDeclEj", "clang::CXXCtorInitializer::CXXCtorInitializer(clang::ASTContext&, clang::FieldDecl*, clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::SourceLocation, clang::VarDecl**, unsigned int)"},
    {"_ZN5clang18CXXCtorInitializerC2ERNS_10ASTContextEPNS_9FieldDeclENS_14SourceLocationES5_PNS_4ExprES5_PPNS_7VarDeclEj", "clang::CXXCtorInitializer::CXXCtorInitializer(clang::ASTContext&, clang::FieldDecl*, clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::SourceLocation, clang::VarDecl**, unsigned int)"},
    {"_ZN5clang18CXXCtorInitializer6CreateERNS_10ASTContextEPNS_9FieldDeclENS_14SourceLocationES5_PNS_4ExprES5_PPNS_7VarDeclEj", "clang::CXXCtorInitializer::Create(clang::ASTContext&, clang::FieldDecl*, clang::SourceLocation, clang::SourceLocation, clang::Expr*, clang::SourceLocation, clang::VarDecl**, unsigned int)"},
    {"_ZNK5clang18CXXCtorInitializer15getBaseClassLocEv", "clang::CXXCtorInitializer::getBaseClassLoc() const"},
    {"_ZNK5clang18CXXCtorInitializer12getBaseClassEv", "clang::CXXCtorInitializer::getBaseClass() const"},
    {"_ZNK5clang18CXXCtorInitializer17getSourceLocationEv", "clang::CXXCtorInitializer::getSourceLocation() const"},
    {"_ZNK5clang18CXXCtorInitializer14getSourceRangeEv", "clang::CXXCtorInitializer::getSourceRange() const"},
    {"_ZN5clang18CXXConstructorDecl6CreateERNS_10ASTContextENS_4Decl10EmptyShellE", "clang::CXXConstructorDecl::Create(clang::ASTContext&, clang::Decl::EmptyShell)"},
    {"_ZN5clang18CXXConstructorDecl6CreateERNS_10ASTContextEPNS_13CXXRecordDeclERKNS_19DeclarationNameInfoENS_8QualTypeEPNS_14TypeSourceInfoEbbb", "clang::CXXConstructorDecl::Create(clang::ASTContext&, clang::CXXRecordDecl*, clang::DeclarationNameInfo const&, clang::QualType, clang::TypeSourceInfo*, bool, bool, bool)"},
    {"_ZNK5clang18CXXConstructorDecl23isCopyOrMoveConstructorERj", "clang::CXXConstructorDecl::isCopyOrMoveConstructor(unsigned int&) const"},
    {"_ZNK5clang18CXXConstructorDecl17isMoveConstructorERj", "clang::CXXConstructorDecl::isMoveConstructor(unsigned int&) const"},
    {"_ZNK5clang18CXXConstructorDecl23isConvertingConstructorEb", "clang::CXXConstructorDecl::isConvertingConstructor(bool) const"},
    {"_ZNK5clang18CXXConstructorDecl29isSpecializationCopyingObjectEv", "clang::CXXConstructorDecl::isSpecializationCopyingObject() const"},
    {"_ZNK5clang18CXXConstructorDecl23getInheritedConstructorEv", "clang::CXXConstructorDecl::getInheritedConstructor() const"},
    {"_ZN5clang18CXXConstructorDecl23setInheritedConstructorEPKS0_", "clang::CXXConstructorDecl::setInheritedConstructor(clang::CXXConstructorDecl const*)"},
    {"_ZN5clang17CXXDestructorDecl6CreateERNS_10ASTContextENS_4Decl10EmptyShellE", "clang::CXXDestructorDecl::Create(clang::ASTContext&, clang::Decl::EmptyShell)"},
    {"_ZN5clang17CXXDestructorDecl6CreateERNS_10ASTContextEPNS_13CXXRecordDeclERKNS_19DeclarationNameInfoENS_8QualTypeEPNS_14TypeSourceInfoEbb", "clang::CXXDestructorDecl::Create(clang::ASTContext&, clang::CXXRecordDecl*, clang::DeclarationNameInfo const&, clang::QualType, clang::TypeSourceInfo*, bool, bool)"},
    {"_ZN5clang17CXXConversionDecl6CreateERNS_10ASTContextENS_4Decl10EmptyShellE", "clang::CXXConversionDecl::Create(clang::ASTContext&, clang::Decl::EmptyShell)"},
    {"_ZN5clang17CXXConversionDecl6CreateERNS_10ASTContextEPNS_13CXXRecordDeclERKNS_19DeclarationNameInfoENS_8QualTypeEPNS_14TypeSourceInfoEbb", "clang::CXXConversionDecl::Create(clang::ASTContext&, clang::CXXRecordDecl*, clang::DeclarationNameInfo const&, clang::QualType, clang::TypeSourceInfo*, bool, bool)"},
    {"_ZN5clang15LinkageSpecDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationENS0_11LanguageIDsEb", "clang::LinkageSpecDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::LinkageSpecDecl::LanguageIDs, bool)"},
    {"_ZN5clang18UsingDirectiveDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationES5_NS_11SourceRangeEPNS_19NestedNameSpecifierES5_PNS_9NamedDeclES4_", "clang::UsingDirectiveDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::SourceLocation, clang::SourceRange, clang::NestedNameSpecifier*, clang::SourceLocation, clang::NamedDecl*, clang::DeclContext*)"},
    {"_ZN5clang18UsingDirectiveDecl21getNominatedNamespaceEv", "clang::UsingDirectiveDecl::getNominatedNamespace()"},
    {"_ZN5clang18NamespaceAliasDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationES5_PNS_14IdentifierInfoENS_11SourceRangeEPNS_19NestedNameSpecifierES5_PNS_9NamedDeclE", "clang::NamespaceAliasDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceRange, clang::NestedNameSpecifier*, clang::SourceLocation, clang::NamedDecl*)"},
    {"_ZNK5clang15UsingShadowDecl12getUsingDeclEv", "clang::UsingShadowDecl::getUsingDecl() const"},
    {"_ZN5clang9UsingDecl13addShadowDeclEPNS_15UsingShadowDeclE", "clang::UsingDecl::addShadowDecl(clang::UsingShadowDecl*)"},
    {"_ZN5clang9UsingDecl16removeShadowDeclEPNS_15UsingShadowDeclE", "clang::UsingDecl::removeShadowDecl(clang::UsingShadowDecl*)"},
    {"_ZN5clang9UsingDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_11SourceRangeENS_14SourceLocationEPNS_19NestedNameSpecifierERKNS_19DeclarationNameInfoEb", "clang::UsingDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceRange, clang::SourceLocation, clang::NestedNameSpecifier*, clang::DeclarationNameInfo const&, bool)"},
    {"_ZN5clang24UnresolvedUsingValueDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationENS_11SourceRangeEPNS_19NestedNameSpecifierERKNS_19DeclarationNameInfoE", "clang::UnresolvedUsingValueDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::SourceRange, clang::NestedNameSpecifier*, clang::DeclarationNameInfo const&)"},
    {"_ZN5clang27UnresolvedUsingTypenameDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationES5_NS_11SourceRangeEPNS_19NestedNameSpecifierES5_NS_15DeclarationNameE", "clang::UnresolvedUsingTypenameDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::SourceLocation, clang::SourceRange, clang::NestedNameSpecifier*, clang::SourceLocation, clang::DeclarationName)"},
    {"_ZN5clang16StaticAssertDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_4ExprEPNS_13StringLiteralE", "clang::StaticAssertDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::Expr*, clang::StringLiteral*)"},
    {"_ZN5clanglsERKNS_17DiagnosticBuilderENS_15AccessSpecifierE", "clang::operator<<(clang::DiagnosticBuilder const&, clang::AccessSpecifier)"},
    {"_Z17GetConversionTypeRN5clang10ASTContextEPNS_9NamedDeclE", "GetConversionType(clang::ASTContext&, clang::NamedDecl*)"},
    {"_Z25CollectVisibleConversionsRN5clang10ASTContextEPNS_13CXXRecordDeclEbNS_15AccessSpecifierERKN4llvm11SmallPtrSetINS_7CanQualINS_4TypeEEELj8EEERNS_17UnresolvedSetImplESE_RNS6_IPNS_9NamedDeclELj8EEE", "CollectVisibleConversions(clang::ASTContext&, clang::CXXRecordDecl*, bool, clang::AccessSpecifier, llvm::SmallPtrSet<clang::CanQual<clang::Type>, 8u> const&, clang::UnresolvedSetImpl&, clang::UnresolvedSetImpl&, llvm::SmallPtrSet<clang::NamedDecl*, 8u>&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairIPN5clang13CXXMethodDeclENS2_10QualifiersEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<clang::CXXMethodDecl*, clang::Qualifiers>, false>::grow(unsigned long)"},
    {"_ZN5clang16StaticAssertDeclD1Ev", "clang::StaticAssertDecl::~StaticAssertDecl()"},
    {"_ZN5clang16StaticAssertDeclD0Ev", "clang::StaticAssertDecl::~StaticAssertDecl()"},
    {"_ZN5clang27UnresolvedUsingTypenameDeclD1Ev", "clang::UnresolvedUsingTypenameDecl::~UnresolvedUsingTypenameDecl()"},
    {"_ZN5clang27UnresolvedUsingTypenameDeclD0Ev", "clang::UnresolvedUsingTypenameDecl::~UnresolvedUsingTypenameDecl()"},
    {"_ZNK5clang27UnresolvedUsingTypenameDecl14getSourceRangeEv", "clang::UnresolvedUsingTypenameDecl::getSourceRange() const"},
    {"_ZN5clang24UnresolvedUsingValueDeclD1Ev", "clang::UnresolvedUsingValueDecl::~UnresolvedUsingValueDecl()"},
    {"_ZN5clang24UnresolvedUsingValueDeclD0Ev", "clang::UnresolvedUsingValueDecl::~UnresolvedUsingValueDecl()"},
    {"_ZNK5clang24UnresolvedUsingValueDecl14getSourceRangeEv", "clang::UnresolvedUsingValueDecl::getSourceRange() const"},
    {"_ZN5clang9UsingDeclD1Ev", "clang::UsingDecl::~UsingDecl()"},
    {"_ZN5clang9UsingDeclD0Ev", "clang::UsingDecl::~UsingDecl()"},
    {"_ZNK5clang9UsingDecl14getSourceRangeEv", "clang::UsingDecl::getSourceRange() const"},
    {"_ZN5clang18NamespaceAliasDeclD1Ev", "clang::NamespaceAliasDecl::~NamespaceAliasDecl()"},
    {"_ZN5clang18NamespaceAliasDeclD0Ev", "clang::NamespaceAliasDecl::~NamespaceAliasDecl()"},
    {"_ZNK5clang18NamespaceAliasDecl14getSourceRangeEv", "clang::NamespaceAliasDecl::getSourceRange() const"},
    {"_ZN5clang18UsingDirectiveDeclD1Ev", "clang::UsingDirectiveDecl::~UsingDirectiveDecl()"},
    {"_ZN5clang18UsingDirectiveDeclD0Ev", "clang::UsingDirectiveDecl::~UsingDirectiveDecl()"},
    {"_ZNK5clang18UsingDirectiveDecl14getSourceRangeEv", "clang::UsingDirectiveDecl::getSourceRange() const"},
    {"_ZN5clang15LinkageSpecDeclC2EPNS_11DeclContextENS_14SourceLocationENS0_11LanguageIDsEb", "clang::LinkageSpecDecl::LinkageSpecDecl(clang::DeclContext*, clang::SourceLocation, clang::LinkageSpecDecl::LanguageIDs, bool)"},
    {"_ZN5clang15LinkageSpecDeclD1Ev", "clang::LinkageSpecDecl::~LinkageSpecDecl()"},
    {"_ZN5clang15LinkageSpecDeclD0Ev", "clang::LinkageSpecDecl::~LinkageSpecDecl()"},
    {"_ZN5clang17CXXConversionDeclD1Ev", "clang::CXXConversionDecl::~CXXConversionDecl()"},
    {"_ZN5clang17CXXConversionDeclD0Ev", "clang::CXXConversionDecl::~CXXConversionDecl()"},
    {"_ZN5clang13CXXMethodDecl16getCanonicalDeclEv", "clang::CXXMethodDecl::getCanonicalDecl()"},
    {"_ZNK5clang13CXXMethodDecl16getCanonicalDeclEv", "clang::CXXMethodDecl::getCanonicalDecl() const"},
    {"_ZN5clang13CXXMethodDeclD1Ev", "clang::CXXMethodDecl::~CXXMethodDecl()"},
    {"_ZN5clang13CXXMethodDeclD0Ev", "clang::CXXMethodDecl::~CXXMethodDecl()"},
    {"_ZN5clang17CXXDestructorDeclD1Ev", "clang::CXXDestructorDecl::~CXXDestructorDecl()"},
    {"_ZN5clang17CXXDestructorDeclD0Ev", "clang::CXXDestructorDecl::~CXXDestructorDecl()"},
    {"_ZN5clang18CXXConstructorDeclD1Ev", "clang::CXXConstructorDecl::~CXXConstructorDecl()"},
    {"_ZN5clang18CXXConstructorDeclD0Ev", "clang::CXXConstructorDecl::~CXXConstructorDecl()"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXMethodDeclENS1_17OverridingMethodsENS_12DenseMapInfoIS4_EENS6_IS5_EEED2Ev", "llvm::DenseMap<clang::CXXMethodDecl const*, clang::OverridingMethods, llvm::DenseMapInfo<clang::CXXMethodDecl const*>, llvm::DenseMapInfo<clang::OverridingMethods>>::~DenseMap()"},
    {"_ZN5clang10FriendDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEN4llvm12PointerUnionIPNS_9NamedDeclEPNS_14TypeSourceInfoEEES5_", "clang::FriendDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, llvm::PointerUnion<clang::NamedDecl*, clang::TypeSourceInfo*>, clang::SourceLocation)"},
    {"_ZN5clang10FriendDecl6CreateERNS_10ASTContextENS_4Decl10EmptyShellE", "clang::FriendDecl::Create(clang::ASTContext&, clang::Decl::EmptyShell)"},
    {"_ZN5clang10FriendDeclD1Ev", "clang::FriendDecl::~FriendDecl()"},
    {"_ZN5clang10FriendDeclD0Ev", "clang::FriendDecl::~FriendDecl()"},
    {"_ZN5clang9DeclGroup6CreateERNS_10ASTContextEPPNS_4DeclEj", "clang::DeclGroup::Create(clang::ASTContext&, clang::Decl**, unsigned int)"},
    {"_ZN5clang9DeclGroupC1EjPPNS_4DeclE", "clang::DeclGroup::DeclGroup(unsigned int, clang::Decl**)"},
    {"_ZN5clang9DeclGroupC2EjPPNS_4DeclE", "clang::DeclGroup::DeclGroup(unsigned int, clang::Decl**)"},
    {"_ZN5clang12ObjCListBase3setEPKPvjRNS_10ASTContextE", "clang::ObjCListBase::set(void* const*, unsigned int, clang::ASTContext&)"},
    {"_ZN5clang16ObjCProtocolList3setEPKPNS_16ObjCProtocolDeclEjPKNS_14SourceLocationERNS_10ASTContextE", "clang::ObjCProtocolList::set(clang::ObjCProtocolDecl* const*, unsigned int, clang::SourceLocation const*, clang::ASTContext&)"},
    {"_ZNK5clang17ObjCContainerDecl11getIvarDeclEPNS_14IdentifierInfoE", "clang::ObjCContainerDecl::getIvarDecl(clang::IdentifierInfo*) const"},
    {"_ZNK5clang17ObjCContainerDecl9getMethodENS_8SelectorEb", "clang::ObjCContainerDecl::getMethod(clang::Selector, bool) const"},
    {"_ZN5clang16ObjCPropertyDecl16findPropertyDeclEPKNS_11DeclContextEPNS_14IdentifierInfoE", "clang::ObjCPropertyDecl::findPropertyDecl(clang::DeclContext const*, clang::IdentifierInfo*)"},
    {"_ZNK5clang17ObjCContainerDecl23FindPropertyDeclarationEPNS_14IdentifierInfoE", "clang::ObjCContainerDecl::FindPropertyDeclaration(clang::IdentifierInfo*) const"},
    {"_ZNK5clang17ObjCInterfaceDecl33FindPropertyVisibleInPrimaryClassEPNS_14IdentifierInfoE", "clang::ObjCInterfaceDecl::FindPropertyVisibleInPrimaryClass(clang::IdentifierInfo*) const"},
    {"_ZNK5clang17ObjCInterfaceDecl22LoadExternalDefinitionEv", "clang::ObjCInterfaceDecl::LoadExternalDefinition() const"},
    {"_ZN5clang17ObjCInterfaceDecl31mergeClassExtensionProtocolListEPKPNS_16ObjCProtocolDeclEjRNS_10ASTContextE", "clang::ObjCInterfaceDecl::mergeClassExtensionProtocolList(clang::ObjCProtocolDecl* const*, unsigned int, clang::ASTContext&)"},
    {"_ZNK5clang17ObjCInterfaceDecl22getFirstClassExtensionEv", "clang::ObjCInterfaceDecl::getFirstClassExtension() const"},
    {"_ZNK5clang16ObjCCategoryDecl21getNextClassExtensionEv", "clang::ObjCCategoryDecl::getNextClassExtension() const"},
    {"_ZN5clang17ObjCInterfaceDecl22lookupInstanceVariableEPNS_14IdentifierInfoERPS0_", "clang::ObjCInterfaceDecl::lookupInstanceVariable(clang::IdentifierInfo*, clang::ObjCInterfaceDecl*&)"},
    {"_ZN5clang17ObjCInterfaceDecl20lookupInheritedClassEPKNS_14IdentifierInfoE", "clang::ObjCInterfaceDecl::lookupInheritedClass(clang::IdentifierInfo const*)"},
    {"_ZNK5clang17ObjCInterfaceDecl12lookupMethodENS_8SelectorEb", "clang::ObjCInterfaceDecl::lookupMethod(clang::Selector, bool) const"},
    {"_ZNK5clang16ObjCProtocolDecl12lookupMethodENS_8SelectorEb", "clang::ObjCProtocolDecl::lookupMethod(clang::Selector, bool) const"},
    {"_ZN5clang17ObjCInterfaceDecl19lookupPrivateMethodERKNS_8SelectorEb", "clang::ObjCInterfaceDecl::lookupPrivateMethod(clang::Selector const&, bool)"},
    {"_ZNK5clang17ObjCInterfaceDecl17getImplementationEv", "clang::ObjCInterfaceDecl::getImplementation() const"},
    {"_ZN5clang14ObjCMethodDecl6CreateERNS_10ASTContextENS_14SourceLocationES3_NS_8SelectorENS_8QualTypeEPNS_14TypeSourceInfoEPNS_11DeclContextEbbbbNS0_21ImplementationControlEj", "clang::ObjCMethodDecl::Create(clang::ASTContext&, clang::SourceLocation, clang::SourceLocation, clang::Selector, clang::QualType, clang::TypeSourceInfo*, clang::DeclContext*, bool, bool, bool, bool, clang::ObjCMethodDecl::ImplementationControl, unsigned int)"},
    {"_ZN5clang14ObjCMethodDecl20getNextRedeclarationEv", "clang::ObjCMethodDecl::getNextRedeclaration()"},
    {"_ZNK5clang20ObjCCategoryImplDecl15getCategoryDeclEv", "clang::ObjCCategoryImplDecl::getCategoryDecl() const"},
    {"_ZN5clang14ObjCMethodDecl16getCanonicalDeclEv", "clang::ObjCMethodDecl::getCanonicalDecl()"},
    {"_ZN5clang14ObjCMethodDecl20createImplicitParamsERNS_10ASTContextEPKNS_17ObjCInterfaceDeclE", "clang::ObjCMethodDecl::createImplicitParams(clang::ASTContext&, clang::ObjCInterfaceDecl const*)"},
    {"_ZN5clang14ObjCMethodDecl17getClassInterfaceEv", "clang::ObjCMethodDecl::getClassInterface()"},
    {"_ZN5clang17ObjCInterfaceDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoES5_bb", "clang::ObjCInterfaceDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, bool, bool)"},
    {"_ZN5clang17ObjCInterfaceDeclC1EPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoES3_bb", "clang::ObjCInterfaceDecl::ObjCInterfaceDecl(clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, bool, bool)"},
    {"_ZN5clang17ObjCInterfaceDeclC2EPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoES3_bb", "clang::ObjCInterfaceDecl::ObjCInterfaceDecl(clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, bool, bool)"},
    {"_ZN5clang17ObjCInterfaceDecl22setExternallyCompletedEv", "clang::ObjCInterfaceDecl::setExternallyCompleted()"},
    {"_ZN5clang17ObjCInterfaceDecl17setImplementationEPNS_22ObjCImplementationDeclE", "clang::ObjCInterfaceDecl::setImplementation(clang::ObjCImplementationDecl*)"},
    {"_ZN5clang17ObjCInterfaceDecl23all_declared_ivar_beginEv", "clang::ObjCInterfaceDecl::all_declared_ivar_begin()"},
    {"_ZNK5clang17ObjCInterfaceDecl23FindCategoryDeclarationEPNS_14IdentifierInfoE", "clang::ObjCInterfaceDecl::FindCategoryDeclaration(clang::IdentifierInfo*) const"},
    {"_ZNK5clang17ObjCInterfaceDecl25getCategoryInstanceMethodENS_8SelectorE", "clang::ObjCInterfaceDecl::getCategoryInstanceMethod(clang::Selector) const"},
    {"_ZNK5clang16ObjCCategoryDecl17getImplementationEv", "clang::ObjCCategoryDecl::getImplementation() const"},
    {"_ZNK5clang17ObjCInterfaceDecl22getCategoryClassMethodENS_8SelectorE", "clang::ObjCInterfaceDecl::getCategoryClassMethod(clang::Selector) const"},
    {"_ZN5clang17ObjCInterfaceDecl23ClassImplementsProtocolEPNS_16ObjCProtocolDeclEbb", "clang::ObjCInterfaceDecl::ClassImplementsProtocol(clang::ObjCProtocolDecl*, bool, bool)"},
    {"_ZN5clang12ObjCIvarDecl6CreateERNS_10ASTContextEPNS_17ObjCContainerDeclENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPNS_14TypeSourceInfoENS0_13AccessControlEPNS_4ExprEb", "clang::ObjCIvarDecl::Create(clang::ASTContext&, clang::ObjCContainerDecl*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::TypeSourceInfo*, clang::ObjCIvarDecl::AccessControl, clang::Expr*, bool)"},
    {"_ZNK5clang12ObjCIvarDecl22getContainingInterfaceEv", "clang::ObjCIvarDecl::getContainingInterface() const"},
    {"_ZN5clang19ObjCAtDefsFieldDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPNS_4ExprE", "clang::ObjCAtDefsFieldDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::Expr*)"},
    {"_ZN5clang16ObjCProtocolDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoE", "clang::ObjCProtocolDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*)"},
    {"_ZN5clang16ObjCProtocolDecl19lookupProtocolNamedEPNS_14IdentifierInfoE", "clang::ObjCProtocolDecl::lookupProtocolNamed(clang::IdentifierInfo*)"},
    {"_ZN5clang13ObjCClassDeclC1EPNS_11DeclContextENS_14SourceLocationEPKPNS_17ObjCInterfaceDeclEPKS3_jRNS_10ASTContextE", "clang::ObjCClassDecl::ObjCClassDecl(clang::DeclContext*, clang::SourceLocation, clang::ObjCInterfaceDecl* const*, clang::SourceLocation const*, unsigned int, clang::ASTContext&)"},
    {"_ZN5clang13ObjCClassDeclC2EPNS_11DeclContextENS_14SourceLocationEPKPNS_17ObjCInterfaceDeclEPKS3_jRNS_10ASTContextE", "clang::ObjCClassDecl::ObjCClassDecl(clang::DeclContext*, clang::SourceLocation, clang::ObjCInterfaceDecl* const*, clang::SourceLocation const*, unsigned int, clang::ASTContext&)"},
    {"_ZN5clang13ObjCClassDecl12setClassListERNS_10ASTContextEPKPNS_17ObjCInterfaceDeclEPKNS_14SourceLocationEj", "clang::ObjCClassDecl::setClassList(clang::ASTContext&, clang::ObjCInterfaceDecl* const*, clang::SourceLocation const*, unsigned int)"},
    {"_ZN5clang13ObjCClassDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPKPNS_17ObjCInterfaceDeclEPKS5_j", "clang::ObjCClassDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::ObjCInterfaceDecl* const*, clang::SourceLocation const*, unsigned int)"},
    {"_ZNK5clang13ObjCClassDecl14getSourceRangeEv", "clang::ObjCClassDecl::getSourceRange() const"},
    {"_ZN5clang23ObjCForwardProtocolDeclC1EPNS_11DeclContextENS_14SourceLocationEPKPNS_16ObjCProtocolDeclEjPKS3_RNS_10ASTContextE", "clang::ObjCForwardProtocolDecl::ObjCForwardProtocolDecl(clang::DeclContext*, clang::SourceLocation, clang::ObjCProtocolDecl* const*, unsigned int, clang::SourceLocation const*, clang::ASTContext&)"},
    {"_ZN5clang23ObjCForwardProtocolDeclC2EPNS_11DeclContextENS_14SourceLocationEPKPNS_16ObjCProtocolDeclEjPKS3_RNS_10ASTContextE", "clang::ObjCForwardProtocolDecl::ObjCForwardProtocolDecl(clang::DeclContext*, clang::SourceLocation, clang::ObjCProtocolDecl* const*, unsigned int, clang::SourceLocation const*, clang::ASTContext&)"},
    {"_ZN5clang23ObjCForwardProtocolDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPKPNS_16ObjCProtocolDeclEjPKS5_", "clang::ObjCForwardProtocolDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::ObjCProtocolDecl* const*, unsigned int, clang::SourceLocation const*)"},
    {"_ZN5clang16ObjCCategoryDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationES5_S5_PNS_14IdentifierInfoE", "clang::ObjCCategoryDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::IdentifierInfo*)"},
    {"_ZN5clang16ObjCCategoryDecl17setImplementationEPNS_20ObjCCategoryImplDeclE", "clang::ObjCCategoryDecl::setImplementation(clang::ObjCCategoryImplDecl*)"},
    {"_ZN5clang20ObjCCategoryImplDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoEPNS_17ObjCInterfaceDeclE", "clang::ObjCCategoryImplDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang12ObjCImplDecl25addPropertyImplementationEPNS_20ObjCPropertyImplDeclE", "clang::ObjCImplDecl::addPropertyImplementation(clang::ObjCPropertyImplDecl*)"},
    {"_ZN5clang12ObjCImplDecl17setClassInterfaceEPNS_17ObjCInterfaceDeclE", "clang::ObjCImplDecl::setClassInterface(clang::ObjCInterfaceDecl*)"},
    {"_ZNK5clang12ObjCImplDecl24FindPropertyImplIvarDeclEPNS_14IdentifierInfoE", "clang::ObjCImplDecl::FindPropertyImplIvarDecl(clang::IdentifierInfo*) const"},
    {"_ZNK5clang12ObjCImplDecl20FindPropertyImplDeclEPNS_14IdentifierInfoE", "clang::ObjCImplDecl::FindPropertyImplDecl(clang::IdentifierInfo*) const"},
    {"_ZN5clanglsERN4llvm11raw_ostreamEPKNS_20ObjCCategoryImplDeclE", "clang::operator<<(llvm::raw_ostream&, clang::ObjCCategoryImplDecl const*)"},
    {"_ZN5clang22ObjCImplementationDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_17ObjCInterfaceDeclES7_", "clang::ObjCImplementationDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::ObjCInterfaceDecl*, clang::ObjCInterfaceDecl*)"},
    {"_ZN5clanglsERN4llvm11raw_ostreamEPKNS_22ObjCImplementationDeclE", "clang::operator<<(llvm::raw_ostream&, clang::ObjCImplementationDecl const*)"},
    {"_ZN5clang23ObjCCompatibleAliasDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoEPNS_17ObjCInterfaceDeclE", "clang::ObjCCompatibleAliasDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::ObjCInterfaceDecl*)"},
    {"_ZN5clang16ObjCPropertyDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoES5_PNS_14TypeSourceInfoENS0_15PropertyControlE", "clang::ObjCPropertyDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, clang::SourceLocation, clang::TypeSourceInfo*, clang::ObjCPropertyDecl::PropertyControl)"},
    {"_ZN5clang20ObjCPropertyImplDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationES5_PNS_16ObjCPropertyDeclENS0_4KindEPNS_12ObjCIvarDeclES5_", "clang::ObjCPropertyImplDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::SourceLocation, clang::ObjCPropertyDecl*, clang::ObjCPropertyImplDecl::Kind, clang::ObjCIvarDecl*, clang::SourceLocation)"},
    {"_ZNK5clang20ObjCPropertyImplDecl14getSourceRangeEv", "clang::ObjCPropertyImplDecl::getSourceRange() const"},
    {"_ZNK5clang17ObjCInterfaceDecl29all_referenced_protocol_beginEv", "clang::ObjCInterfaceDecl::all_referenced_protocol_begin() const"},
    {"_ZNK5clang17ObjCInterfaceDecl27all_referenced_protocol_endEv", "clang::ObjCInterfaceDecl::all_referenced_protocol_end() const"},
    {"_ZN5clang17ObjCContainerDeclC2ENS_4Decl4KindEPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoE", "clang::ObjCContainerDecl::ObjCContainerDecl(clang::Decl::Kind, clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*)"},
    {"_ZN5clang14ObjCMethodDeclD1Ev", "clang::ObjCMethodDecl::~ObjCMethodDecl()"},
    {"_ZN5clang14ObjCMethodDeclD0Ev", "clang::ObjCMethodDecl::~ObjCMethodDecl()"},
    {"_ZNK5clang14ObjCMethodDecl14getSourceRangeEv", "clang::ObjCMethodDecl::getSourceRange() const"},
    {"_ZNK5clang14ObjCMethodDecl7getBodyEv", "clang::ObjCMethodDecl::getBody() const"},
    {"_ZN5clang20ObjCPropertyImplDeclD1Ev", "clang::ObjCPropertyImplDecl::~ObjCPropertyImplDecl()"},
    {"_ZN5clang20ObjCPropertyImplDeclD0Ev", "clang::ObjCPropertyImplDecl::~ObjCPropertyImplDecl()"},
    {"_ZN5clang13ObjCClassDeclD1Ev", "clang::ObjCClassDecl::~ObjCClassDecl()"},
    {"_ZN5clang13ObjCClassDeclD0Ev", "clang::ObjCClassDecl::~ObjCClassDecl()"},
    {"_ZN5clang23ObjCForwardProtocolDeclD1Ev", "clang::ObjCForwardProtocolDecl::~ObjCForwardProtocolDecl()"},
    {"_ZN5clang23ObjCForwardProtocolDeclD0Ev", "clang::ObjCForwardProtocolDecl::~ObjCForwardProtocolDecl()"},
    {"_ZN5clang17ObjCInterfaceDeclD1Ev", "clang::ObjCInterfaceDecl::~ObjCInterfaceDecl()"},
    {"_ZN5clang17ObjCInterfaceDeclD0Ev", "clang::ObjCInterfaceDecl::~ObjCInterfaceDecl()"},
    {"_ZNK5clang17ObjCContainerDecl14getSourceRangeEv", "clang::ObjCContainerDecl::getSourceRange() const"},
    {"_ZN5clang17ObjCContainerDeclD1Ev", "clang::ObjCContainerDecl::~ObjCContainerDecl()"},
    {"_ZN5clang17ObjCContainerDeclD0Ev", "clang::ObjCContainerDecl::~ObjCContainerDecl()"},
    {"_ZN5clang16ObjCPropertyDeclD1Ev", "clang::ObjCPropertyDecl::~ObjCPropertyDecl()"},
    {"_ZN5clang16ObjCPropertyDeclD0Ev", "clang::ObjCPropertyDecl::~ObjCPropertyDecl()"},
    {"_ZNK5clang16ObjCPropertyDecl14getSourceRangeEv", "clang::ObjCPropertyDecl::getSourceRange() const"},
    {"_ZN5clang23ObjCCompatibleAliasDeclD1Ev", "clang::ObjCCompatibleAliasDecl::~ObjCCompatibleAliasDecl()"},
    {"_ZN5clang23ObjCCompatibleAliasDeclD0Ev", "clang::ObjCCompatibleAliasDecl::~ObjCCompatibleAliasDecl()"},
    {"_ZN5clang22ObjCImplementationDeclD1Ev", "clang::ObjCImplementationDecl::~ObjCImplementationDecl()"},
    {"_ZN5clang22ObjCImplementationDeclD0Ev", "clang::ObjCImplementationDecl::~ObjCImplementationDecl()"},
    {"_ZN5clang12ObjCImplDeclD1Ev", "clang::ObjCImplDecl::~ObjCImplDecl()"},
    {"_ZN5clang12ObjCImplDeclD0Ev", "clang::ObjCImplDecl::~ObjCImplDecl()"},
    {"_ZN5clang20ObjCCategoryImplDeclD1Ev", "clang::ObjCCategoryImplDecl::~ObjCCategoryImplDecl()"},
    {"_ZN5clang20ObjCCategoryImplDeclD0Ev", "clang::ObjCCategoryImplDecl::~ObjCCategoryImplDecl()"},
    {"_ZN5clang16ObjCCategoryDeclD1Ev", "clang::ObjCCategoryDecl::~ObjCCategoryDecl()"},
    {"_ZN5clang16ObjCCategoryDeclD0Ev", "clang::ObjCCategoryDecl::~ObjCCategoryDecl()"},
    {"_ZNK5clang16ObjCCategoryDecl14getSourceRangeEv", "clang::ObjCCategoryDecl::getSourceRange() const"},
    {"_ZN5clang16ObjCProtocolDeclD1Ev", "clang::ObjCProtocolDecl::~ObjCProtocolDecl()"},
    {"_ZN5clang16ObjCProtocolDeclD0Ev", "clang::ObjCProtocolDecl::~ObjCProtocolDecl()"},
    {"_ZN5clang19ObjCAtDefsFieldDeclD1Ev", "clang::ObjCAtDefsFieldDecl::~ObjCAtDefsFieldDecl()"},
    {"_ZN5clang19ObjCAtDefsFieldDeclD0Ev", "clang::ObjCAtDefsFieldDecl::~ObjCAtDefsFieldDecl()"},
    {"_ZN5clang12ObjCIvarDeclC2EPNS_17ObjCContainerDeclENS_14SourceLocationEPNS_14IdentifierInfoENS_8QualTypeEPNS_14TypeSourceInfoENS0_13AccessControlEPNS_4ExprEb", "clang::ObjCIvarDecl::ObjCIvarDecl(clang::ObjCContainerDecl*, clang::SourceLocation, clang::IdentifierInfo*, clang::QualType, clang::TypeSourceInfo*, clang::ObjCIvarDecl::AccessControl, clang::Expr*, bool)"},
    {"_ZN5clang12ObjCIvarDeclD1Ev", "clang::ObjCIvarDecl::~ObjCIvarDecl()"},
    {"_ZN5clang12ObjCIvarDeclD0Ev", "clang::ObjCIvarDecl::~ObjCIvarDecl()"},
    {"_ZN5clang14ObjCMethodDeclC2ENS_14SourceLocationES1_NS_8SelectorENS_8QualTypeEPNS_14TypeSourceInfoEPNS_11DeclContextEbbbbNS0_21ImplementationControlEj", "clang::ObjCMethodDecl::ObjCMethodDecl(clang::SourceLocation, clang::SourceLocation, clang::Selector, clang::QualType, clang::TypeSourceInfo*, clang::DeclContext*, bool, bool, bool, bool, clang::ObjCMethodDecl::ImplementationControl, unsigned int)"},
    {"_ZNK5clang4Decl5printERN4llvm11raw_ostreamEj", "clang::Decl::print(llvm::raw_ostream&, unsigned int) const"},
    {"_ZNK5clang4Decl5printERN4llvm11raw_ostreamERKNS_14PrintingPolicyEj", "clang::Decl::print(llvm::raw_ostream&, clang::PrintingPolicy const&, unsigned int) const"},
    {"_ZN5clang11DeclVisitorIN12_GLOBAL__N_111DeclPrinterEvE5VisitEPNS_4DeclE", "clang::DeclVisitor<(anonymous namespace)::DeclPrinter, void>::Visit(clang::Decl*)"},
    {"_ZN5clang4Decl10printGroupEPPS0_jRN4llvm11raw_ostreamERKNS_14PrintingPolicyEj", "clang::Decl::printGroup(clang::Decl**, unsigned int, llvm::raw_ostream&, clang::PrintingPolicy const&, unsigned int)"},
    {"_ZNK5clang11DeclContext15dumpDeclContextEv", "clang::DeclContext::dumpDeclContext() const"},
    {"_ZN12_GLOBAL__N_111DeclPrinter16VisitDeclContextEPN5clang11DeclContextEb", "(anonymous namespace)::DeclPrinter::VisitDeclContext(clang::DeclContext*, bool)"},
    {"_ZNK5clang4Decl4dumpEv", "clang::Decl::dump() const"},
    {"_ZN12_GLOBAL__N_111DeclPrinter18VisitCXXRecordDeclEPN5clang13CXXRecordDeclE", "(anonymous namespace)::DeclPrinter::VisitCXXRecordDecl(clang::CXXRecordDecl*)"},
    {"_ZN12_GLOBAL__N_111DeclPrinter14VisitFieldDeclEPN5clang9FieldDeclE", "(anonymous namespace)::DeclPrinter::VisitFieldDecl(clang::FieldDecl*)"},
    {"_ZN12_GLOBAL__N_111DeclPrinter17VisitFunctionDeclEPN5clang12FunctionDeclE", "(anonymous namespace)::DeclPrinter::VisitFunctionDecl(clang::FunctionDecl*)"},
    {"_ZN12_GLOBAL__N_111DeclPrinter12VisitVarDeclEPN5clang7VarDeclE", "(anonymous namespace)::DeclPrinter::VisitVarDecl(clang::VarDecl*)"},
    {"_ZN12_GLOBAL__N_111DeclPrinter17VisitTemplateDeclEPN5clang12TemplateDeclE", "(anonymous namespace)::DeclPrinter::VisitTemplateDecl(clang::TemplateDecl*)"},
    {"_ZN12_GLOBAL__N_111DeclPrinter16ProcessDeclGroupERN4llvm15SmallVectorImplIPN5clang4DeclEEE", "(anonymous namespace)::DeclPrinter::ProcessDeclGroup(llvm::SmallVectorImpl<clang::Decl*>&)"},
    {"_ZN5clang21TemplateParameterListC1ENS_14SourceLocationES1_PPNS_9NamedDeclEjS1_", "clang::TemplateParameterList::TemplateParameterList(clang::SourceLocation, clang::SourceLocation, clang::NamedDecl**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang21TemplateParameterListC2ENS_14SourceLocationES1_PPNS_9NamedDeclEjS1_", "clang::TemplateParameterList::TemplateParameterList(clang::SourceLocation, clang::SourceLocation, clang::NamedDecl**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang21TemplateParameterList6CreateERKNS_10ASTContextENS_14SourceLocationES4_PPNS_9NamedDeclEjS4_", "clang::TemplateParameterList::Create(clang::ASTContext const&, clang::SourceLocation, clang::SourceLocation, clang::NamedDecl**, unsigned int, clang::SourceLocation)"},
    {"_ZNK5clang21TemplateParameterList23getMinRequiredArgumentsEv", "clang::TemplateParameterList::getMinRequiredArguments() const"},
    {"_ZNK5clang21TemplateParameterList8getDepthEv", "clang::TemplateParameterList::getDepth() const"},
    {"_ZNK5clang20TemplateTypeParmDecl8getDepthEv", "clang::TemplateTypeParmDecl::getDepth() const"},
    {"_ZN5clang24RedeclarableTemplateDecl12getCommonPtrEv", "clang::RedeclarableTemplateDecl::getCommonPtr()"},
    {"_ZN5clang24RedeclarableTemplateDecl20getCanonicalDeclImplEv", "clang::RedeclarableTemplateDecl::getCanonicalDeclImpl()"},
    {"_ZN5clang24RedeclarableTemplateDecl26setPreviousDeclarationImplEPS0_", "clang::RedeclarableTemplateDecl::setPreviousDeclarationImpl(clang::RedeclarableTemplateDecl*)"},
    {"_ZN5clang24RedeclarableTemplateDecl20getNextRedeclarationEv", "clang::RedeclarableTemplateDecl::getNextRedeclaration()"},
    {"_ZN5clang20FunctionTemplateDecl16DeallocateCommonEPv", "clang::FunctionTemplateDecl::DeallocateCommon(void*)"},
    {"_ZN5clang20FunctionTemplateDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationENS_15DeclarationNameEPNS_21TemplateParameterListEPNS_9NamedDeclE", "clang::FunctionTemplateDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::DeclarationName, clang::TemplateParameterList*, clang::NamedDecl*)"},
    {"_ZN5clang20FunctionTemplateDecl9newCommonERNS_10ASTContextE", "clang::FunctionTemplateDecl::newCommon(clang::ASTContext&)"},
    {"_ZN5clang20FunctionTemplateDecl18findSpecializationEPKNS_16TemplateArgumentEjRPv", "clang::FunctionTemplateDecl::findSpecialization(clang::TemplateArgument const*, unsigned int, void*&)"},
    {"_ZN5clang17ClassTemplateDecl16DeallocateCommonEPv", "clang::ClassTemplateDecl::DeallocateCommon(void*)"},
    {"_ZN5clang17ClassTemplateDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationENS_15DeclarationNameEPNS_21TemplateParameterListEPNS_9NamedDeclEPS0_", "clang::ClassTemplateDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, clang::DeclarationName, clang::TemplateParameterList*, clang::NamedDecl*, clang::ClassTemplateDecl*)"},
    {"_ZN5clang17ClassTemplateDecl23LoadLazySpecializationsEv", "clang::ClassTemplateDecl::LoadLazySpecializations()"},
    {"_ZN5clang17ClassTemplateDecl18getSpecializationsEv", "clang::ClassTemplateDecl::getSpecializations()"},
    {"_ZN5clang17ClassTemplateDecl25getPartialSpecializationsEv", "clang::ClassTemplateDecl::getPartialSpecializations()"},
    {"_ZN5clang17ClassTemplateDecl9newCommonERNS_10ASTContextE", "clang::ClassTemplateDecl::newCommon(clang::ASTContext&)"},
    {"_ZN5clang17ClassTemplateDecl18findSpecializationEPKNS_16TemplateArgumentEjRPv", "clang::ClassTemplateDecl::findSpecialization(clang::TemplateArgument const*, unsigned int, void*&)"},
    {"_ZN5clang17ClassTemplateDecl17AddSpecializationEPNS_31ClassTemplateSpecializationDeclEPv", "clang::ClassTemplateDecl::AddSpecialization(clang::ClassTemplateSpecializationDecl*, void*)"},
    {"_ZN5clang17ClassTemplateDecl25findPartialSpecializationEPKNS_16TemplateArgumentEjRPv", "clang::ClassTemplateDecl::findPartialSpecialization(clang::TemplateArgument const*, unsigned int, void*&)"},
    {"_ZN5clang17ClassTemplateDecl24AddPartialSpecializationEPNS_38ClassTemplatePartialSpecializationDeclEPv", "clang::ClassTemplateDecl::AddPartialSpecialization(clang::ClassTemplatePartialSpecializationDecl*, void*)"},
    {"_ZN5clang17ClassTemplateDecl25getPartialSpecializationsERN4llvm15SmallVectorImplIPNS_38ClassTemplatePartialSpecializationDeclEEE", "clang::ClassTemplateDecl::getPartialSpecializations(llvm::SmallVectorImpl<clang::ClassTemplatePartialSpecializationDecl*>&)"},
    {"_ZN5clang17ClassTemplateDecl25findPartialSpecializationENS_8QualTypeE", "clang::ClassTemplateDecl::findPartialSpecialization(clang::QualType)"},
    {"_ZN5clang17ClassTemplateDecl37findPartialSpecInstantiatedFromMemberEPNS_38ClassTemplatePartialSpecializationDeclE", "clang::ClassTemplateDecl::findPartialSpecInstantiatedFromMember(clang::ClassTemplatePartialSpecializationDecl*)"},
    {"_ZN5clang17ClassTemplateDecl34getInjectedClassNameSpecializationEv", "clang::ClassTemplateDecl::getInjectedClassNameSpecialization()"},
    {"_ZN5clang20TemplateTypeParmDecl6CreateERKNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEjjPNS_14IdentifierInfoEbb", "clang::TemplateTypeParmDecl::Create(clang::ASTContext const&, clang::DeclContext*, clang::SourceLocation, unsigned int, unsigned int, clang::IdentifierInfo*, bool, bool)"},
    {"_ZN5clang20TemplateTypeParmDecl6CreateERKNS_10ASTContextENS_4Decl10EmptyShellE", "clang::TemplateTypeParmDecl::Create(clang::ASTContext const&, clang::Decl::EmptyShell)"},
    {"_ZNK5clang20TemplateTypeParmDecl21getDefaultArgumentLocEv", "clang::TemplateTypeParmDecl::getDefaultArgumentLoc() const"},
    {"_ZNK5clang20TemplateTypeParmDecl8getIndexEv", "clang::TemplateTypeParmDecl::getIndex() const"},
    {"_ZN5clang23NonTypeTemplateParmDeclC1EPNS_11DeclContextENS_14SourceLocationEjjPNS_14IdentifierInfoENS_8QualTypeEPNS_14TypeSourceInfoEPKS6_jPS8_", "clang::NonTypeTemplateParmDecl::NonTypeTemplateParmDecl(clang::DeclContext*, clang::SourceLocation, unsigned int, unsigned int, clang::IdentifierInfo*, clang::QualType, clang::TypeSourceInfo*, clang::QualType const*, unsigned int, clang::TypeSourceInfo**)"},
    {"_ZN5clang23NonTypeTemplateParmDeclC2EPNS_11DeclContextENS_14SourceLocationEjjPNS_14IdentifierInfoENS_8QualTypeEPNS_14TypeSourceInfoEPKS6_jPS8_", "clang::NonTypeTemplateParmDecl::NonTypeTemplateParmDecl(clang::DeclContext*, clang::SourceLocation, unsigned int, unsigned int, clang::IdentifierInfo*, clang::QualType, clang::TypeSourceInfo*, clang::QualType const*, unsigned int, clang::TypeSourceInfo**)"},
    {"_ZN5clang23NonTypeTemplateParmDecl6CreateERKNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEjjPNS_14IdentifierInfoENS_8QualTypeEbPNS_14TypeSourceInfoE", "clang::NonTypeTemplateParmDecl::Create(clang::ASTContext const&, clang::DeclContext*, clang::SourceLocation, unsigned int, unsigned int, clang::IdentifierInfo*, clang::QualType, bool, clang::TypeSourceInfo*)"},
    {"_ZN5clang23NonTypeTemplateParmDecl6CreateERKNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEjjPNS_14IdentifierInfoENS_8QualTypeEPNS_14TypeSourceInfoEPKS9_jPSB_", "clang::NonTypeTemplateParmDecl::Create(clang::ASTContext const&, clang::DeclContext*, clang::SourceLocation, unsigned int, unsigned int, clang::IdentifierInfo*, clang::QualType, clang::TypeSourceInfo*, clang::QualType const*, unsigned int, clang::TypeSourceInfo**)"},
    {"_ZNK5clang23NonTypeTemplateParmDecl16getInnerLocStartEv", "clang::NonTypeTemplateParmDecl::getInnerLocStart() const"},
    {"_ZNK5clang23NonTypeTemplateParmDecl14getSourceRangeEv", "clang::NonTypeTemplateParmDecl::getSourceRange() const"},
    {"_ZNK5clang23NonTypeTemplateParmDecl21getDefaultArgumentLocEv", "clang::NonTypeTemplateParmDecl::getDefaultArgumentLoc() const"},
    {"_ZN5clang24TemplateTemplateParmDecl6CreateERKNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEjjbPNS_14IdentifierInfoEPNS_21TemplateParameterListE", "clang::TemplateTemplateParmDecl::Create(clang::ASTContext const&, clang::DeclContext*, clang::SourceLocation, unsigned int, unsigned int, bool, clang::IdentifierInfo*, clang::TemplateParameterList*)"},
    {"_ZN5clang20TemplateArgumentList10CreateCopyERNS_10ASTContextEPKNS_16TemplateArgumentEj", "clang::TemplateArgumentList::CreateCopy(clang::ASTContext&, clang::TemplateArgument const*, unsigned int)"},
    {"_ZN5clang31ClassTemplateSpecializationDeclC1ERNS_10ASTContextENS_4Decl4KindENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_17ClassTemplateDeclEPKNS_16TemplateArgumentEjPS0_", "clang::ClassTemplateSpecializationDecl::ClassTemplateSpecializationDecl(clang::ASTContext&, clang::Decl::Kind, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::ClassTemplateDecl*, clang::TemplateArgument const*, unsigned int, clang::ClassTemplateSpecializationDecl*)"},
    {"_ZN5clang31ClassTemplateSpecializationDeclC2ERNS_10ASTContextENS_4Decl4KindENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_17ClassTemplateDeclEPKNS_16TemplateArgumentEjPS0_", "clang::ClassTemplateSpecializationDecl::ClassTemplateSpecializationDecl(clang::ASTContext&, clang::Decl::Kind, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::ClassTemplateDecl*, clang::TemplateArgument const*, unsigned int, clang::ClassTemplateSpecializationDecl*)"},
    {"_ZN5clang31ClassTemplateSpecializationDeclC1ENS_4Decl4KindE", "clang::ClassTemplateSpecializationDecl::ClassTemplateSpecializationDecl(clang::Decl::Kind)"},
    {"_ZN5clang31ClassTemplateSpecializationDeclC2ENS_4Decl4KindE", "clang::ClassTemplateSpecializationDecl::ClassTemplateSpecializationDecl(clang::Decl::Kind)"},
    {"_ZN5clang31ClassTemplateSpecializationDecl6CreateERNS_10ASTContextENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_17ClassTemplateDeclEPKNS_16TemplateArgumentEjPS0_", "clang::ClassTemplateSpecializationDecl::Create(clang::ASTContext&, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::ClassTemplateDecl*, clang::TemplateArgument const*, unsigned int, clang::ClassTemplateSpecializationDecl*)"},
    {"_ZN5clang31ClassTemplateSpecializationDecl6CreateERNS_10ASTContextENS_4Decl10EmptyShellE", "clang::ClassTemplateSpecializationDecl::Create(clang::ASTContext&, clang::Decl::EmptyShell)"},
    {"_ZNK5clang31ClassTemplateSpecializationDecl20getNameForDiagnosticERSsRKNS_14PrintingPolicyEb", "clang::ClassTemplateSpecializationDecl::getNameForDiagnostic(std::string&, clang::PrintingPolicy const&, bool) const"},
    {"_ZNK5clang31ClassTemplateSpecializationDecl22getSpecializedTemplateEv", "clang::ClassTemplateSpecializationDecl::getSpecializedTemplate() const"},
    {"_ZN5clang38ClassTemplatePartialSpecializationDecl6CreateERNS_10ASTContextENS_11TagTypeKindEPNS_11DeclContextENS_14SourceLocationEPNS_21TemplateParameterListEPNS_17ClassTemplateDeclEPKNS_16TemplateArgumentEjRKNS_24TemplateArgumentListInfoENS_8QualTypeEPS0_j", "clang::ClassTemplatePartialSpecializationDecl::Create(clang::ASTContext&, clang::TagTypeKind, clang::DeclContext*, clang::SourceLocation, clang::TemplateParameterList*, clang::ClassTemplateDecl*, clang::TemplateArgument const*, unsigned int, clang::TemplateArgumentListInfo const&, clang::QualType, clang::ClassTemplatePartialSpecializationDecl*, unsigned int)"},
    {"_ZN5clang38ClassTemplatePartialSpecializationDecl6CreateERNS_10ASTContextENS_4Decl10EmptyShellE", "clang::ClassTemplatePartialSpecializationDecl::Create(clang::ASTContext&, clang::Decl::EmptyShell)"},
    {"_ZN5clang18FriendTemplateDecl6CreateERNS_10ASTContextEPNS_11DeclContextENS_14SourceLocationEjPPNS_21TemplateParameterListEN4llvm12PointerUnionIPNS_9NamedDeclEPNS_14TypeSourceInfoEEES5_", "clang::FriendTemplateDecl::Create(clang::ASTContext&, clang::DeclContext*, clang::SourceLocation, unsigned int, clang::TemplateParameterList**, llvm::PointerUnion<clang::NamedDecl*, clang::TypeSourceInfo*>, clang::SourceLocation)"},
    {"_ZN5clang18FriendTemplateDecl6CreateERNS_10ASTContextENS_4Decl10EmptyShellE", "clang::FriendTemplateDecl::Create(clang::ASTContext&, clang::Decl::EmptyShell)"},
    {"_ZN5clang24RedeclarableTemplateDecl22findSpecializationImplINS_34FunctionTemplateSpecializationInfoEEEPNS0_15SpecEntryTraitsIT_E8DeclTypeERN4llvm10FoldingSetIS4_EEPKNS_16TemplateArgumentEjRPv", "clang::RedeclarableTemplateDecl::SpecEntryTraits<clang::FunctionTemplateSpecializationInfo>::DeclType* clang::RedeclarableTemplateDecl::findSpecializationImpl<clang::FunctionTemplateSpecializationInfo>(llvm::FoldingSet<clang::FunctionTemplateSpecializationInfo>&, clang::TemplateArgument const*, unsigned int, void*&)"},
    {"_ZN5clang24RedeclarableTemplateDecl22findSpecializationImplINS_31ClassTemplateSpecializationDeclEEEPNS0_15SpecEntryTraitsIT_E8DeclTypeERN4llvm10FoldingSetIS4_EEPKNS_16TemplateArgumentEjRPv", "clang::RedeclarableTemplateDecl::SpecEntryTraits<clang::ClassTemplateSpecializationDecl>::DeclType* clang::RedeclarableTemplateDecl::findSpecializationImpl<clang::ClassTemplateSpecializationDecl>(llvm::FoldingSet<clang::ClassTemplateSpecializationDecl>&, clang::TemplateArgument const*, unsigned int, void*&)"},
    {"_ZN5clang24RedeclarableTemplateDecl22findSpecializationImplINS_38ClassTemplatePartialSpecializationDeclEEEPNS0_15SpecEntryTraitsIT_E8DeclTypeERN4llvm10FoldingSetIS4_EEPKNS_16TemplateArgumentEjRPv", "clang::RedeclarableTemplateDecl::SpecEntryTraits<clang::ClassTemplatePartialSpecializationDecl>::DeclType* clang::RedeclarableTemplateDecl::findSpecializationImpl<clang::ClassTemplatePartialSpecializationDecl>(llvm::FoldingSet<clang::ClassTemplatePartialSpecializationDecl>&, clang::TemplateArgument const*, unsigned int, void*&)"},
    {"_ZN4llvm15SmallVectorImplIPN5clang38ClassTemplatePartialSpecializationDeclEE6resizeEj", "llvm::SmallVectorImpl<clang::ClassTemplatePartialSpecializationDecl*>::resize(unsigned int)"},
    {"_ZN5clang24RedeclarableTemplateDeclD1Ev", "clang::RedeclarableTemplateDecl::~RedeclarableTemplateDecl()"},
    {"_ZN5clang24RedeclarableTemplateDeclD0Ev", "clang::RedeclarableTemplateDecl::~RedeclarableTemplateDecl()"},
    {"_ZNK5clang12TemplateDecl14getSourceRangeEv", "clang::TemplateDecl::getSourceRange() const"},
    {"_ZN5clang24RedeclarableTemplateDecl16getCanonicalDeclEv", "clang::RedeclarableTemplateDecl::getCanonicalDecl()"},
    {"_ZN5clang20FunctionTemplateDeclD1Ev", "clang::FunctionTemplateDecl::~FunctionTemplateDecl()"},
    {"_ZN5clang20FunctionTemplateDeclD0Ev", "clang::FunctionTemplateDecl::~FunctionTemplateDecl()"},
    {"_ZN5clang20FunctionTemplateDecl16getCanonicalDeclEv", "clang::FunctionTemplateDecl::getCanonicalDecl()"},
    {"_ZN5clang23NonTypeTemplateParmDeclD1Ev", "clang::NonTypeTemplateParmDecl::~NonTypeTemplateParmDecl()"},
    {"_ZN5clang23NonTypeTemplateParmDeclD0Ev", "clang::NonTypeTemplateParmDecl::~NonTypeTemplateParmDecl()"},
    {"_ZN5clang31ClassTemplateSpecializationDeclD1Ev", "clang::ClassTemplateSpecializationDecl::~ClassTemplateSpecializationDecl()"},
    {"_ZN5clang31ClassTemplateSpecializationDeclD0Ev", "clang::ClassTemplateSpecializationDecl::~ClassTemplateSpecializationDecl()"},
    {"_ZN5clang13CXXRecordDecl16getCanonicalDeclEv", "clang::CXXRecordDecl::getCanonicalDecl()"},
    {"_ZNK5clang31ClassTemplateSpecializationDecl16getInnerLocStartEv", "clang::ClassTemplateSpecializationDecl::getInnerLocStart() const"},
    {"_ZNK5clang13CXXRecordDecl16getCanonicalDeclEv", "clang::CXXRecordDecl::getCanonicalDecl() const"},
    {"_ZN5clang17ClassTemplateDeclD1Ev", "clang::ClassTemplateDecl::~ClassTemplateDecl()"},
    {"_ZN5clang17ClassTemplateDeclD0Ev", "clang::ClassTemplateDecl::~ClassTemplateDecl()"},
    {"_ZN5clang17ClassTemplateDecl16getCanonicalDeclEv", "clang::ClassTemplateDecl::getCanonicalDecl()"},
    {"_ZN5clang12TemplateDeclD1Ev", "clang::TemplateDecl::~TemplateDecl()"},
    {"_ZN5clang12TemplateDeclD0Ev", "clang::TemplateDecl::~TemplateDecl()"},
    {"_ZN5clang13CXXRecordDeclD1Ev", "clang::CXXRecordDecl::~CXXRecordDecl()"},
    {"_ZN5clang13CXXRecordDeclD0Ev", "clang::CXXRecordDecl::~CXXRecordDecl()"},
    {"_ZN5clang18FriendTemplateDeclD1Ev", "clang::FriendTemplateDecl::~FriendTemplateDecl()"},
    {"_ZN5clang18FriendTemplateDeclD0Ev", "clang::FriendTemplateDecl::~FriendTemplateDecl()"},
    {"_ZN5clang38ClassTemplatePartialSpecializationDeclD1Ev", "clang::ClassTemplatePartialSpecializationDecl::~ClassTemplatePartialSpecializationDecl()"},
    {"_ZN5clang38ClassTemplatePartialSpecializationDeclD0Ev", "clang::ClassTemplatePartialSpecializationDecl::~ClassTemplatePartialSpecializationDecl()"},
    {"_ZN5clang24TemplateTemplateParmDeclC2EPNS_11DeclContextENS_14SourceLocationEjjbPNS_14IdentifierInfoEPNS_21TemplateParameterListE", "clang::TemplateTemplateParmDecl::TemplateTemplateParmDecl(clang::DeclContext*, clang::SourceLocation, unsigned int, unsigned int, bool, clang::IdentifierInfo*, clang::TemplateParameterList*)"},
    {"_ZN5clang24TemplateTemplateParmDeclD1Ev", "clang::TemplateTemplateParmDecl::~TemplateTemplateParmDecl()"},
    {"_ZN5clang24TemplateTemplateParmDeclD0Ev", "clang::TemplateTemplateParmDecl::~TemplateTemplateParmDecl()"},
    {"_ZNK5clang24TemplateTemplateParmDecl14getSourceRangeEv", "clang::TemplateTemplateParmDecl::getSourceRange() const"},
    {"_ZN5clang20TemplateTypeParmDeclC2EPNS_11DeclContextENS_14SourceLocationEPNS_14IdentifierInfoEbNS_8QualTypeEb", "clang::TemplateTypeParmDecl::TemplateTypeParmDecl(clang::DeclContext*, clang::SourceLocation, clang::IdentifierInfo*, bool, clang::QualType, bool)"},
    {"_ZN5clang20TemplateTypeParmDeclD1Ev", "clang::TemplateTypeParmDecl::~TemplateTypeParmDecl()"},
    {"_ZN5clang20TemplateTypeParmDeclD0Ev", "clang::TemplateTypeParmDecl::~TemplateTypeParmDecl()"},
    {"_ZN4llvm10FoldingSetIN5clang38ClassTemplatePartialSpecializationDeclEED1Ev", "llvm::FoldingSet<clang::ClassTemplatePartialSpecializationDecl>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang38ClassTemplatePartialSpecializationDeclEED0Ev", "llvm::FoldingSet<clang::ClassTemplatePartialSpecializationDecl>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang38ClassTemplatePartialSpecializationDeclEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ClassTemplatePartialSpecializationDecl>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang38ClassTemplatePartialSpecializationDeclEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::ClassTemplatePartialSpecializationDecl>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang38ClassTemplatePartialSpecializationDeclEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ClassTemplatePartialSpecializationDecl>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang31ClassTemplateSpecializationDeclEED1Ev", "llvm::FoldingSet<clang::ClassTemplateSpecializationDecl>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang31ClassTemplateSpecializationDeclEED0Ev", "llvm::FoldingSet<clang::ClassTemplateSpecializationDecl>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang31ClassTemplateSpecializationDeclEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ClassTemplateSpecializationDecl>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang31ClassTemplateSpecializationDeclEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::ClassTemplateSpecializationDecl>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang31ClassTemplateSpecializationDeclEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::ClassTemplateSpecializationDecl>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang34FunctionTemplateSpecializationInfoEED1Ev", "llvm::FoldingSet<clang::FunctionTemplateSpecializationInfo>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang34FunctionTemplateSpecializationInfoEED0Ev", "llvm::FoldingSet<clang::FunctionTemplateSpecializationInfo>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang34FunctionTemplateSpecializationInfoEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::FunctionTemplateSpecializationInfo>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang34FunctionTemplateSpecializationInfoEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::FunctionTemplateSpecializationInfo>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang34FunctionTemplateSpecializationInfoEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::FunctionTemplateSpecializationInfo>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN5clang15DeclarationName7compareES0_S0_", "clang::DeclarationName::compare(clang::DeclarationName, clang::DeclarationName)"},
    {"_ZNK5clang15DeclarationName11getNameKindEv", "clang::DeclarationName::getNameKind() const"},
    {"_ZNK5clang15DeclarationName15getObjCSelectorEv", "clang::DeclarationName::getObjCSelector() const"},
    {"_ZNK5clang15DeclarationName14getCXXNameTypeEv", "clang::DeclarationName::getCXXNameType() const"},
    {"_ZNK5clang15DeclarationName24getCXXOverloadedOperatorEv", "clang::DeclarationName::getCXXOverloadedOperator() const"},
    {"_ZNK5clang15DeclarationName23getCXXLiteralIdentifierEv", "clang::DeclarationName::getCXXLiteralIdentifier() const"},
    {"_ZN5clang15DeclarationNameC1ENS_8SelectorE", "clang::DeclarationName::DeclarationName(clang::Selector)"},
    {"_ZN5clang15DeclarationNameC2ENS_8SelectorE", "clang::DeclarationName::DeclarationName(clang::Selector)"},
    {"_ZNK5clang15DeclarationName15isDependentNameEv", "clang::DeclarationName::isDependentName() const"},
    {"_ZNK5clang15DeclarationName11getAsStringEv", "clang::DeclarationName::getAsString() const"},
    {"_ZNK5clang15DeclarationName9printNameERN4llvm11raw_ostreamE", "clang::DeclarationName::printName(llvm::raw_ostream&) const"},
    {"_ZNK5clang15DeclarationName20getFETokenInfoAsVoidEv", "clang::DeclarationName::getFETokenInfoAsVoid() const"},
    {"_ZN5clang15DeclarationName14setFETokenInfoEPv", "clang::DeclarationName::setFETokenInfo(void*)"},
    {"_ZN5clang15DeclarationName21getUsingDirectiveNameEv", "clang::DeclarationName::getUsingDirectiveName()"},
    {"_ZNK5clang15DeclarationName4dumpEv", "clang::DeclarationName::dump() const"},
    {"_ZN5clang20DeclarationNameTableC1ERKNS_10ASTContextE", "clang::DeclarationNameTable::DeclarationNameTable(clang::ASTContext const&)"},
    {"_ZN5clang20DeclarationNameTableC2ERKNS_10ASTContextE", "clang::DeclarationNameTable::DeclarationNameTable(clang::ASTContext const&)"},
    {"_ZN5clang20DeclarationNameTableD1Ev", "clang::DeclarationNameTable::~DeclarationNameTable()"},
    {"_ZN5clang20DeclarationNameTableD2Ev", "clang::DeclarationNameTable::~DeclarationNameTable()"},
    {"_ZN5clang20DeclarationNameTable17getCXXSpecialNameENS_15DeclarationName8NameKindENS_7CanQualINS_4TypeEEE", "clang::DeclarationNameTable::getCXXSpecialName(clang::DeclarationName::NameKind, clang::CanQual<clang::Type>)"},
    {"_ZN5clang20DeclarationNameTable18getCXXOperatorNameENS_22OverloadedOperatorKindE", "clang::DeclarationNameTable::getCXXOperatorName(clang::OverloadedOperatorKind)"},
    {"_ZN5clang20DeclarationNameTable25getCXXLiteralOperatorNameEPNS_14IdentifierInfoE", "clang::DeclarationNameTable::getCXXLiteralOperatorName(clang::IdentifierInfo*)"},
    {"_ZN4llvm12DenseMapInfoIN5clang15DeclarationNameEE12getHashValueES2_", "llvm::DenseMapInfo<clang::DeclarationName>::getHashValue(clang::DeclarationName)"},
    {"_ZN5clang18DeclarationNameLocC1ENS_15DeclarationNameE", "clang::DeclarationNameLoc::DeclarationNameLoc(clang::DeclarationName)"},
    {"_ZN5clang18DeclarationNameLocC2ENS_15DeclarationNameE", "clang::DeclarationNameLoc::DeclarationNameLoc(clang::DeclarationName)"},
    {"_ZNK5clang19DeclarationNameInfo31containsUnexpandedParameterPackEv", "clang::DeclarationNameInfo::containsUnexpandedParameterPack() const"},
    {"_ZNK5clang19DeclarationNameInfo11getAsStringEv", "clang::DeclarationNameInfo::getAsString() const"},
    {"_ZNK5clang19DeclarationNameInfo9printNameERN4llvm11raw_ostreamE", "clang::DeclarationNameInfo::printName(llvm::raw_ostream&) const"},
    {"_ZNK5clang19DeclarationNameInfo9getEndLocEv", "clang::DeclarationNameInfo::getEndLoc() const"},
    {"_ZN4llvm10FoldingSetIN5clang24CXXLiteralOperatorIdNameEED1Ev", "llvm::FoldingSet<clang::CXXLiteralOperatorIdName>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang24CXXLiteralOperatorIdNameEED0Ev", "llvm::FoldingSet<clang::CXXLiteralOperatorIdName>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang24CXXLiteralOperatorIdNameEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::CXXLiteralOperatorIdName>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang24CXXLiteralOperatorIdNameEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::CXXLiteralOperatorIdName>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang24CXXLiteralOperatorIdNameEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::CXXLiteralOperatorIdName>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZN4llvm10FoldingSetIN5clang14CXXSpecialNameEED1Ev", "llvm::FoldingSet<clang::CXXSpecialName>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang14CXXSpecialNameEED0Ev", "llvm::FoldingSet<clang::CXXSpecialName>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang14CXXSpecialNameEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::CXXSpecialName>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang14CXXSpecialNameEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::CXXSpecialName>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang14CXXSpecialNameEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::CXXSpecialName>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang4Decl7dumpXMLEv", "clang::Decl::dumpXML() const"},
    {"_ZNK5clang4Decl7dumpXMLERN4llvm11raw_ostreamE", "clang::Decl::dumpXML(llvm::raw_ostream&) const"},
    {"_ZNK5clang4Expr25isKnownToHaveBooleanValueEv", "clang::Expr::isKnownToHaveBooleanValue() const"},
    {"_ZNK5clang4Expr10getExprLocEv", "clang::Expr::getExprLoc() const"},
    {"_ZN5clang28ExplicitTemplateArgumentList14initializeFromERKNS_24TemplateArgumentListInfoE", "clang::ExplicitTemplateArgumentList::initializeFrom(clang::TemplateArgumentListInfo const&)"},
    {"_ZN5clang28ExplicitTemplateArgumentList14initializeFromERKNS_24TemplateArgumentListInfoERbS4_", "clang::ExplicitTemplateArgumentList::initializeFrom(clang::TemplateArgumentListInfo const&, bool&, bool&)"},
    {"_ZNK5clang28ExplicitTemplateArgumentList8copyIntoERNS_24TemplateArgumentListInfoE", "clang::ExplicitTemplateArgumentList::copyInto(clang::TemplateArgumentListInfo&) const"},
    {"_ZN5clang28ExplicitTemplateArgumentList7sizeForEj", "clang::ExplicitTemplateArgumentList::sizeFor(unsigned int)"},
    {"_ZN5clang28ExplicitTemplateArgumentList7sizeForERKNS_24TemplateArgumentListInfoE", "clang::ExplicitTemplateArgumentList::sizeFor(clang::TemplateArgumentListInfo const&)"},
    {"_ZN5clang11DeclRefExpr17computeDependenceEv", "clang::DeclRefExpr::computeDependence()"},
    {"_Z24computeDeclRefDependencePN5clang9NamedDeclENS_8QualTypeERbS3_", "computeDeclRefDependence(clang::NamedDecl*, clang::QualType, bool&, bool&)"},
    {"_ZN5clang11DeclRefExprC1EPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9ValueDeclENS_14SourceLocationEPKNS_24TemplateArgumentListInfoENS_8QualTypeENS_13ExprValueKindE", "clang::DeclRefExpr::DeclRefExpr(clang::NestedNameSpecifier*, clang::SourceRange, clang::ValueDecl*, clang::SourceLocation, clang::TemplateArgumentListInfo const*, clang::QualType, clang::ExprValueKind)"},
    {"_ZN5clang11DeclRefExprC2EPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9ValueDeclENS_14SourceLocationEPKNS_24TemplateArgumentListInfoENS_8QualTypeENS_13ExprValueKindE", "clang::DeclRefExpr::DeclRefExpr(clang::NestedNameSpecifier*, clang::SourceRange, clang::ValueDecl*, clang::SourceLocation, clang::TemplateArgumentListInfo const*, clang::QualType, clang::ExprValueKind)"},
    {"_ZN5clang11DeclRefExprC1EPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9ValueDeclERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoENS_8QualTypeENS_13ExprValueKindE", "clang::DeclRefExpr::DeclRefExpr(clang::NestedNameSpecifier*, clang::SourceRange, clang::ValueDecl*, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*, clang::QualType, clang::ExprValueKind)"},
    {"_ZN5clang11DeclRefExprC2EPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9ValueDeclERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoENS_8QualTypeENS_13ExprValueKindE", "clang::DeclRefExpr::DeclRefExpr(clang::NestedNameSpecifier*, clang::SourceRange, clang::ValueDecl*, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*, clang::QualType, clang::ExprValueKind)"},
    {"_ZN5clang11DeclRefExpr6CreateERNS_10ASTContextEPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9ValueDeclENS_14SourceLocationENS_8QualTypeENS_13ExprValueKindEPKNS_24TemplateArgumentListInfoE", "clang::DeclRefExpr::Create(clang::ASTContext&, clang::NestedNameSpecifier*, clang::SourceRange, clang::ValueDecl*, clang::SourceLocation, clang::QualType, clang::ExprValueKind, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang11DeclRefExpr6CreateERNS_10ASTContextEPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9ValueDeclERKNS_19DeclarationNameInfoENS_8QualTypeENS_13ExprValueKindEPKNS_24TemplateArgumentListInfoE", "clang::DeclRefExpr::Create(clang::ASTContext&, clang::NestedNameSpecifier*, clang::SourceRange, clang::ValueDecl*, clang::DeclarationNameInfo const&, clang::QualType, clang::ExprValueKind, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang11DeclRefExpr11CreateEmptyERNS_10ASTContextEbbj", "clang::DeclRefExpr::CreateEmpty(clang::ASTContext&, bool, bool, unsigned int)"},
    {"_ZNK5clang11DeclRefExpr14getSourceRangeEv", "clang::DeclRefExpr::getSourceRange() const"},
    {"_ZN5clang14PredefinedExpr11ComputeNameENS0_9IdentTypeEPKNS_4DeclE", "clang::PredefinedExpr::ComputeName(clang::PredefinedExpr::IdentType, clang::Decl const*)"},
    {"_ZN5clang16APNumericStorage11setIntValueERNS_10ASTContextERKN4llvm5APIntE", "clang::APNumericStorage::setIntValue(clang::ASTContext&, llvm::APInt const&)"},
    {"_ZN5clang14IntegerLiteral6CreateERNS_10ASTContextERKN4llvm5APIntENS_8QualTypeENS_14SourceLocationE", "clang::IntegerLiteral::Create(clang::ASTContext&, llvm::APInt const&, clang::QualType, clang::SourceLocation)"},
    {"_ZN5clang14IntegerLiteral6CreateERNS_10ASTContextENS_4Stmt10EmptyShellE", "clang::IntegerLiteral::Create(clang::ASTContext&, clang::Stmt::EmptyShell)"},
    {"_ZN5clang15FloatingLiteral6CreateERNS_10ASTContextERKN4llvm7APFloatEbNS_8QualTypeENS_14SourceLocationE", "clang::FloatingLiteral::Create(clang::ASTContext&, llvm::APFloat const&, bool, clang::QualType, clang::SourceLocation)"},
    {"_ZN5clang15FloatingLiteral6CreateERNS_10ASTContextENS_4Stmt10EmptyShellE", "clang::FloatingLiteral::Create(clang::ASTContext&, clang::Stmt::EmptyShell)"},
    {"_ZNK5clang15FloatingLiteral27getValueAsApproximateDoubleEv", "clang::FloatingLiteral::getValueAsApproximateDouble() const"},
    {"_ZN5clang13StringLiteral6CreateERNS_10ASTContextEPKcjbNS_8QualTypeEPKNS_14SourceLocationEj", "clang::StringLiteral::Create(clang::ASTContext&, char const*, unsigned int, bool, clang::QualType, clang::SourceLocation const*, unsigned int)"},
    {"_ZN5clang13StringLiteral11CreateEmptyERNS_10ASTContextEj", "clang::StringLiteral::CreateEmpty(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang13StringLiteral9setStringERNS_10ASTContextEN4llvm9StringRefE", "clang::StringLiteral::setString(clang::ASTContext&, llvm::StringRef)"},
    {"_ZNK5clang13StringLiteral17getLocationOfByteEjRKNS_13SourceManagerERKNS_11LangOptionsERKNS_10TargetInfoE", "clang::StringLiteral::getLocationOfByte(unsigned int, clang::SourceManager const&, clang::LangOptions const&, clang::TargetInfo const&) const"},
    {"_ZN5clang13UnaryOperator12getOpcodeStrENS_17UnaryOperatorKindE", "clang::UnaryOperator::getOpcodeStr(clang::UnaryOperatorKind)"},
    {"_ZN5clang13UnaryOperator19getOverloadedOpcodeENS_22OverloadedOperatorKindEb", "clang::UnaryOperator::getOverloadedOpcode(clang::OverloadedOperatorKind, bool)"},
    {"_ZN5clang13UnaryOperator21getOverloadedOperatorENS_17UnaryOperatorKindE", "clang::UnaryOperator::getOverloadedOperator(clang::UnaryOperatorKind)"},
    {"_ZN5clang8CallExprC1ERNS_10ASTContextENS_4Stmt9StmtClassEPNS_4ExprEjPS6_jNS_8QualTypeENS_13ExprValueKindENS_14SourceLocationE", "clang::CallExpr::CallExpr(clang::ASTContext&, clang::Stmt::StmtClass, clang::Expr*, unsigned int, clang::Expr**, unsigned int, clang::QualType, clang::ExprValueKind, clang::SourceLocation)"},
    {"_ZN5clang8CallExprC2ERNS_10ASTContextENS_4Stmt9StmtClassEPNS_4ExprEjPS6_jNS_8QualTypeENS_13ExprValueKindENS_14SourceLocationE", "clang::CallExpr::CallExpr(clang::ASTContext&, clang::Stmt::StmtClass, clang::Expr*, unsigned int, clang::Expr**, unsigned int, clang::QualType, clang::ExprValueKind, clang::SourceLocation)"},
    {"_ZN5clang8CallExprC1ERNS_10ASTContextEPNS_4ExprEPS4_jNS_8QualTypeENS_13ExprValueKindENS_14SourceLocationE", "clang::CallExpr::CallExpr(clang::ASTContext&, clang::Expr*, clang::Expr**, unsigned int, clang::QualType, clang::ExprValueKind, clang::SourceLocation)"},
    {"_ZN5clang8CallExprC2ERNS_10ASTContextEPNS_4ExprEPS4_jNS_8QualTypeENS_13ExprValueKindENS_14SourceLocationE", "clang::CallExpr::CallExpr(clang::ASTContext&, clang::Expr*, clang::Expr**, unsigned int, clang::QualType, clang::ExprValueKind, clang::SourceLocation)"},
    {"_ZN5clang8CallExprC1ERNS_10ASTContextENS_4Stmt9StmtClassENS3_10EmptyShellE", "clang::CallExpr::CallExpr(clang::ASTContext&, clang::Stmt::StmtClass, clang::Stmt::EmptyShell)"},
    {"_ZN5clang8CallExprC2ERNS_10ASTContextENS_4Stmt9StmtClassENS3_10EmptyShellE", "clang::CallExpr::CallExpr(clang::ASTContext&, clang::Stmt::StmtClass, clang::Stmt::EmptyShell)"},
    {"_ZN5clang8CallExprC1ERNS_10ASTContextENS_4Stmt9StmtClassEjNS3_10EmptyShellE", "clang::CallExpr::CallExpr(clang::ASTContext&, clang::Stmt::StmtClass, unsigned int, clang::Stmt::EmptyShell)"},
    {"_ZN5clang8CallExprC2ERNS_10ASTContextENS_4Stmt9StmtClassEjNS3_10EmptyShellE", "clang::CallExpr::CallExpr(clang::ASTContext&, clang::Stmt::StmtClass, unsigned int, clang::Stmt::EmptyShell)"},
    {"_ZN5clang8CallExpr13getCalleeDeclEv", "clang::CallExpr::getCalleeDecl()"},
    {"_ZN5clang4Expr16IgnoreParenCastsEv", "clang::Expr::IgnoreParenCasts()"},
    {"_ZN5clang8CallExpr15getDirectCalleeEv", "clang::CallExpr::getDirectCallee()"},
    {"_ZN5clang8CallExpr10setNumArgsERNS_10ASTContextEj", "clang::CallExpr::setNumArgs(clang::ASTContext&, unsigned int)"},
    {"_ZNK5clang8CallExpr13isBuiltinCallERKNS_10ASTContextE", "clang::CallExpr::isBuiltinCall(clang::ASTContext const&) const"},
    {"_ZNK5clang8CallExpr17getCallReturnTypeEv", "clang::CallExpr::getCallReturnType() const"},
    {"_ZN5clang12OffsetOfExpr6CreateERNS_10ASTContextENS_8QualTypeENS_14SourceLocationEPNS_14TypeSourceInfoEPNS0_12OffsetOfNodeEjPPNS_4ExprEjS4_", "clang::OffsetOfExpr::Create(clang::ASTContext&, clang::QualType, clang::SourceLocation, clang::TypeSourceInfo*, clang::OffsetOfExpr::OffsetOfNode*, unsigned int, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang12OffsetOfExprC1ERNS_10ASTContextENS_8QualTypeENS_14SourceLocationEPNS_14TypeSourceInfoEPNS0_12OffsetOfNodeEjPPNS_4ExprEjS4_", "clang::OffsetOfExpr::OffsetOfExpr(clang::ASTContext&, clang::QualType, clang::SourceLocation, clang::TypeSourceInfo*, clang::OffsetOfExpr::OffsetOfNode*, unsigned int, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang12OffsetOfExpr11CreateEmptyERNS_10ASTContextEjj", "clang::OffsetOfExpr::CreateEmpty(clang::ASTContext&, unsigned int, unsigned int)"},
    {"_ZN5clang12OffsetOfExprC2ERNS_10ASTContextENS_8QualTypeENS_14SourceLocationEPNS_14TypeSourceInfoEPNS0_12OffsetOfNodeEjPPNS_4ExprEjS4_", "clang::OffsetOfExpr::OffsetOfExpr(clang::ASTContext&, clang::QualType, clang::SourceLocation, clang::TypeSourceInfo*, clang::OffsetOfExpr::OffsetOfNode*, unsigned int, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZNK5clang12OffsetOfExpr12OffsetOfNode12getFieldNameEv", "clang::OffsetOfExpr::OffsetOfNode::getFieldName() const"},
    {"_ZN5clang10MemberExpr6CreateERNS_10ASTContextEPNS_4ExprEbPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9ValueDeclENS_14DeclAccessPairENS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoENS_8QualTypeENS_13ExprValueKindENS_14ExprObjectKindE", "clang::MemberExpr::Create(clang::ASTContext&, clang::Expr*, bool, clang::NestedNameSpecifier*, clang::SourceRange, clang::ValueDecl*, clang::DeclAccessPair, clang::DeclarationNameInfo, clang::TemplateArgumentListInfo const*, clang::QualType, clang::ExprValueKind, clang::ExprObjectKind)"},
    {"_ZNK5clang8CastExpr15getCastKindNameEv", "clang::CastExpr::getCastKindName() const"},
    {"_ZN5clang8CastExpr19getSubExprAsWrittenEv", "clang::CastExpr::getSubExprAsWritten()"},
    {"_ZN5clang8CastExpr11path_bufferEv", "clang::CastExpr::path_buffer()"},
    {"_ZN5clang8CastExpr11setCastPathERKN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEE", "clang::CastExpr::setCastPath(llvm::SmallVector<clang::CXXBaseSpecifier*, 4u> const&)"},
    {"_ZN5clang16ImplicitCastExpr6CreateERNS_10ASTContextENS_8QualTypeENS_8CastKindEPNS_4ExprEPKN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEENS_13ExprValueKindE", "clang::ImplicitCastExpr::Create(clang::ASTContext&, clang::QualType, clang::CastKind, clang::Expr*, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u> const*, clang::ExprValueKind)"},
    {"_ZN5clang16ImplicitCastExpr11CreateEmptyERNS_10ASTContextEj", "clang::ImplicitCastExpr::CreateEmpty(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang14CStyleCastExpr6CreateERNS_10ASTContextENS_8QualTypeENS_13ExprValueKindENS_8CastKindEPNS_4ExprEPKN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEEPNS_14TypeSourceInfoENS_14SourceLocationESH_", "clang::CStyleCastExpr::Create(clang::ASTContext&, clang::QualType, clang::ExprValueKind, clang::CastKind, clang::Expr*, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u> const*, clang::TypeSourceInfo*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang14CStyleCastExpr11CreateEmptyERNS_10ASTContextEj", "clang::CStyleCastExpr::CreateEmpty(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang14BinaryOperator12getOpcodeStrENS_18BinaryOperatorKindE", "clang::BinaryOperator::getOpcodeStr(clang::BinaryOperatorKind)"},
    {"_ZN5clang14BinaryOperator19getOverloadedOpcodeENS_22OverloadedOperatorKindE", "clang::BinaryOperator::getOverloadedOpcode(clang::OverloadedOperatorKind)"},
    {"_ZN5clang14BinaryOperator21getOverloadedOperatorENS_18BinaryOperatorKindE", "clang::BinaryOperator::getOverloadedOperator(clang::BinaryOperatorKind)"},
    {"_ZN5clang12InitListExprC1ERNS_10ASTContextENS_14SourceLocationEPPNS_4ExprEjS3_", "clang::InitListExpr::InitListExpr(clang::ASTContext&, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang12InitListExprC2ERNS_10ASTContextENS_14SourceLocationEPPNS_4ExprEjS3_", "clang::InitListExpr::InitListExpr(clang::ASTContext&, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang12InitListExpr12reserveInitsERNS_10ASTContextEj", "clang::InitListExpr::reserveInits(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang12InitListExpr11resizeInitsERNS_10ASTContextEj", "clang::InitListExpr::resizeInits(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang12InitListExpr10updateInitERNS_10ASTContextEjPNS_4ExprE", "clang::InitListExpr::updateInit(clang::ASTContext&, unsigned int, clang::Expr*)"},
    {"_ZNK5clang12InitListExpr14getSourceRangeEv", "clang::InitListExpr::getSourceRange() const"},
    {"_ZNK5clang9BlockExpr15getFunctionTypeEv", "clang::BlockExpr::getFunctionType() const"},
    {"_ZNK5clang9BlockExpr16getCaretLocationEv", "clang::BlockExpr::getCaretLocation() const"},
    {"_ZNK5clang9BlockExpr7getBodyEv", "clang::BlockExpr::getBody() const"},
    {"_ZN5clang9BlockExpr7getBodyEv", "clang::BlockExpr::getBody()"},
    {"_ZNK5clang4Expr22isUnusedResultAWarningERNS_14SourceLocationERNS_11SourceRangeES4_RNS_10ASTContextE", "clang::Expr::isUnusedResultAWarning(clang::SourceLocation&, clang::SourceRange&, clang::SourceRange&, clang::ASTContext&) const"},
    {"_ZN5clang4Expr12IgnoreParensEv", "clang::Expr::IgnoreParens()"},
    {"_ZNK5clang4Expr17isOBJCGCCandidateERNS_10ASTContextE", "clang::Expr::isOBJCGCCandidate(clang::ASTContext&) const"},
    {"_ZNK5clang4Expr21isBoundMemberFunctionERNS_10ASTContextE", "clang::Expr::isBoundMemberFunction(clang::ASTContext&) const"},
    {"_ZNK5clang4Expr8CanThrowERNS_10ASTContextE", "clang::Expr::CanThrow(clang::ASTContext&) const"},
    {"_Z16CanSubExprsThrowRN5clang10ASTContextEPKNS_4ExprE", "CanSubExprsThrow(clang::ASTContext&, clang::Expr const*)"},
    {"_Z14CanCalleeThrowPKN5clang4DeclEb", "CanCalleeThrow(clang::Decl const*, bool)"},
    {"_ZN5clang4Expr22IgnoreParenLValueCastsEv", "clang::Expr::IgnoreParenLValueCasts()"},
    {"_ZN5clang4Expr19IgnoreParenImpCastsEv", "clang::Expr::IgnoreParenImpCasts()"},
    {"_ZN5clang4Expr20IgnoreParenNoopCastsERNS_10ASTContextE", "clang::Expr::IgnoreParenNoopCasts(clang::ASTContext&)"},
    {"_ZNK5clang4Expr17isDefaultArgumentEv", "clang::Expr::isDefaultArgument() const"},
    {"_ZNK5clang4Expr17isTemporaryObjectERNS_10ASTContextEPKNS_13CXXRecordDeclE", "clang::Expr::isTemporaryObject(clang::ASTContext&, clang::CXXRecordDecl const*) const"},
    {"_ZN5clang4Expr28hasAnyTypeDependentArgumentsEPPS0_j", "clang::Expr::hasAnyTypeDependentArguments(clang::Expr**, unsigned int)"},
    {"_ZN5clang4Expr29hasAnyValueDependentArgumentsEPPS0_j", "clang::Expr::hasAnyValueDependentArguments(clang::Expr**, unsigned int)"},
    {"_ZNK5clang4Expr21isConstantInitializerERNS_10ASTContextEb", "clang::Expr::isConstantInitializer(clang::ASTContext&, bool) const"},
    {"_ZNK5clang4Expr21isNullPointerConstantERNS_10ASTContextENS0_34NullPointerConstantValueDependenceE", "clang::Expr::isNullPointerConstant(clang::ASTContext&, clang::Expr::NullPointerConstantValueDependence) const"},
    {"_ZNK5clang4Expr15getObjCPropertyEv", "clang::Expr::getObjCProperty() const"},
    {"_ZN5clang4Expr11getBitFieldEv", "clang::Expr::getBitField()"},
    {"_ZNK5clang4Expr21refersToVectorElementEv", "clang::Expr::refersToVectorElement() const"},
    {"_ZNK5clang20ExtVectorElementExpr7isArrowEv", "clang::ExtVectorElementExpr::isArrow() const"},
    {"_ZNK5clang20ExtVectorElementExpr14getNumElementsEv", "clang::ExtVectorElementExpr::getNumElements() const"},
    {"_ZNK5clang20ExtVectorElementExpr25containsDuplicateElementsEv", "clang::ExtVectorElementExpr::containsDuplicateElements() const"},
    {"_ZNK5clang20ExtVectorElementExpr23getEncodedElementAccessERN4llvm15SmallVectorImplIjEE", "clang::ExtVectorElementExpr::getEncodedElementAccess(llvm::SmallVectorImpl<unsigned int>&) const"},
    {"_ZN5clang15ObjCMessageExprC1ENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationES3_bS1_NS_8SelectorES3_PNS_14ObjCMethodDeclEPPNS_4ExprEjS3_", "clang::ObjCMessageExpr::ObjCMessageExpr(clang::QualType, clang::ExprValueKind, clang::SourceLocation, clang::SourceLocation, bool, clang::QualType, clang::Selector, clang::SourceLocation, clang::ObjCMethodDecl*, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang15ObjCMessageExprC2ENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationES3_bS1_NS_8SelectorES3_PNS_14ObjCMethodDeclEPPNS_4ExprEjS3_", "clang::ObjCMessageExpr::ObjCMessageExpr(clang::QualType, clang::ExprValueKind, clang::SourceLocation, clang::SourceLocation, bool, clang::QualType, clang::Selector, clang::SourceLocation, clang::ObjCMethodDecl*, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang15ObjCMessageExprC1ENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationEPNS_14TypeSourceInfoENS_8SelectorES3_PNS_14ObjCMethodDeclEPPNS_4ExprEjS3_", "clang::ObjCMessageExpr::ObjCMessageExpr(clang::QualType, clang::ExprValueKind, clang::SourceLocation, clang::TypeSourceInfo*, clang::Selector, clang::SourceLocation, clang::ObjCMethodDecl*, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang15ObjCMessageExprC2ENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationEPNS_14TypeSourceInfoENS_8SelectorES3_PNS_14ObjCMethodDeclEPPNS_4ExprEjS3_", "clang::ObjCMessageExpr::ObjCMessageExpr(clang::QualType, clang::ExprValueKind, clang::SourceLocation, clang::TypeSourceInfo*, clang::Selector, clang::SourceLocation, clang::ObjCMethodDecl*, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang15ObjCMessageExprC1ENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationEPNS_4ExprENS_8SelectorES3_PNS_14ObjCMethodDeclEPS5_jS3_", "clang::ObjCMessageExpr::ObjCMessageExpr(clang::QualType, clang::ExprValueKind, clang::SourceLocation, clang::Expr*, clang::Selector, clang::SourceLocation, clang::ObjCMethodDecl*, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang15ObjCMessageExprC2ENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationEPNS_4ExprENS_8SelectorES3_PNS_14ObjCMethodDeclEPS5_jS3_", "clang::ObjCMessageExpr::ObjCMessageExpr(clang::QualType, clang::ExprValueKind, clang::SourceLocation, clang::Expr*, clang::Selector, clang::SourceLocation, clang::ObjCMethodDecl*, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang15ObjCMessageExpr6CreateERNS_10ASTContextENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationES5_bS3_NS_8SelectorES5_PNS_14ObjCMethodDeclEPPNS_4ExprEjS5_", "clang::ObjCMessageExpr::Create(clang::ASTContext&, clang::QualType, clang::ExprValueKind, clang::SourceLocation, clang::SourceLocation, bool, clang::QualType, clang::Selector, clang::SourceLocation, clang::ObjCMethodDecl*, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang15ObjCMessageExpr6CreateERNS_10ASTContextENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationEPNS_14TypeSourceInfoENS_8SelectorES5_PNS_14ObjCMethodDeclEPPNS_4ExprEjS5_", "clang::ObjCMessageExpr::Create(clang::ASTContext&, clang::QualType, clang::ExprValueKind, clang::SourceLocation, clang::TypeSourceInfo*, clang::Selector, clang::SourceLocation, clang::ObjCMethodDecl*, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang15ObjCMessageExpr6CreateERNS_10ASTContextENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationEPNS_4ExprENS_8SelectorES5_PNS_14ObjCMethodDeclEPS7_jS5_", "clang::ObjCMessageExpr::Create(clang::ASTContext&, clang::QualType, clang::ExprValueKind, clang::SourceLocation, clang::Expr*, clang::Selector, clang::SourceLocation, clang::ObjCMethodDecl*, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang15ObjCMessageExpr11CreateEmptyERNS_10ASTContextEj", "clang::ObjCMessageExpr::CreateEmpty(clang::ASTContext&, unsigned int)"},
    {"_ZNK5clang15ObjCMessageExpr16getReceiverRangeEv", "clang::ObjCMessageExpr::getReceiverRange() const"},
    {"_ZNK5clang15ObjCMessageExpr11getSelectorEv", "clang::ObjCMessageExpr::getSelector() const"},
    {"_ZNK5clang15ObjCMessageExpr20getReceiverInterfaceEv", "clang::ObjCMessageExpr::getReceiverInterface() const"},
    {"_ZNK5clang10ChooseExpr15isConditionTrueERKNS_10ASTContextE", "clang::ChooseExpr::isConditionTrue(clang::ASTContext const&) const"},
    {"_ZN5clang17ShuffleVectorExprC1ERNS_10ASTContextEPPNS_4ExprEjNS_8QualTypeENS_14SourceLocationES7_", "clang::ShuffleVectorExpr::ShuffleVectorExpr(clang::ASTContext&, clang::Expr**, unsigned int, clang::QualType, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang17ShuffleVectorExprC2ERNS_10ASTContextEPPNS_4ExprEjNS_8QualTypeENS_14SourceLocationES7_", "clang::ShuffleVectorExpr::ShuffleVectorExpr(clang::ASTContext&, clang::Expr**, unsigned int, clang::QualType, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang17ShuffleVectorExpr8setExprsERNS_10ASTContextEPPNS_4ExprEj", "clang::ShuffleVectorExpr::setExprs(clang::ASTContext&, clang::Expr**, unsigned int)"},
    {"_ZN5clang18DesignatedInitExpr10Designator12getFieldNameEv", "clang::DesignatedInitExpr::Designator::getFieldName()"},
    {"_ZN5clang18DesignatedInitExprC1ERNS_10ASTContextENS_8QualTypeEjPKNS0_10DesignatorENS_14SourceLocationEbPPNS_4ExprEjS9_", "clang::DesignatedInitExpr::DesignatedInitExpr(clang::ASTContext&, clang::QualType, unsigned int, clang::DesignatedInitExpr::Designator const*, clang::SourceLocation, bool, clang::Expr**, unsigned int, clang::Expr*)"},
    {"_ZN5clang18DesignatedInitExprC2ERNS_10ASTContextENS_8QualTypeEjPKNS0_10DesignatorENS_14SourceLocationEbPPNS_4ExprEjS9_", "clang::DesignatedInitExpr::DesignatedInitExpr(clang::ASTContext&, clang::QualType, unsigned int, clang::DesignatedInitExpr::Designator const*, clang::SourceLocation, bool, clang::Expr**, unsigned int, clang::Expr*)"},
    {"_ZN5clang18DesignatedInitExpr6CreateERNS_10ASTContextEPNS0_10DesignatorEjPPNS_4ExprEjNS_14SourceLocationEbS6_", "clang::DesignatedInitExpr::Create(clang::ASTContext&, clang::DesignatedInitExpr::Designator*, unsigned int, clang::Expr**, unsigned int, clang::SourceLocation, bool, clang::Expr*)"},
    {"_ZN5clang18DesignatedInitExpr11CreateEmptyERNS_10ASTContextEj", "clang::DesignatedInitExpr::CreateEmpty(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang18DesignatedInitExpr14setDesignatorsERNS_10ASTContextEPKNS0_10DesignatorEj", "clang::DesignatedInitExpr::setDesignators(clang::ASTContext&, clang::DesignatedInitExpr::Designator const*, unsigned int)"},
    {"_ZNK5clang18DesignatedInitExpr14getSourceRangeEv", "clang::DesignatedInitExpr::getSourceRange() const"},
    {"_ZN5clang18DesignatedInitExpr13getArrayIndexERKNS0_10DesignatorE", "clang::DesignatedInitExpr::getArrayIndex(clang::DesignatedInitExpr::Designator const&)"},
    {"_ZN5clang18DesignatedInitExpr18getArrayRangeStartERKNS0_10DesignatorE", "clang::DesignatedInitExpr::getArrayRangeStart(clang::DesignatedInitExpr::Designator const&)"},
    {"_ZN5clang18DesignatedInitExpr16getArrayRangeEndERKNS0_10DesignatorE", "clang::DesignatedInitExpr::getArrayRangeEnd(clang::DesignatedInitExpr::Designator const&)"},
    {"_ZN5clang18DesignatedInitExpr16ExpandDesignatorERNS_10ASTContextEjPKNS0_10DesignatorES5_", "clang::DesignatedInitExpr::ExpandDesignator(clang::ASTContext&, unsigned int, clang::DesignatedInitExpr::Designator const*, clang::DesignatedInitExpr::Designator const*)"},
    {"_ZN5clang13ParenListExprC1ERNS_10ASTContextENS_14SourceLocationEPPNS_4ExprEjS3_", "clang::ParenListExpr::ParenListExpr(clang::ASTContext&, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang13ParenListExprC2ERNS_10ASTContextENS_14SourceLocationEPPNS_4ExprEjS3_", "clang::ParenListExpr::ParenListExpr(clang::ASTContext&, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang12ExprIteratorixEm", "clang::ExprIterator::operator[](unsigned long)"},
    {"_ZNK5clang12ExprIteratordeEv", "clang::ExprIterator::operator*() const"},
    {"_ZNK5clang12ExprIteratorptEv", "clang::ExprIterator::operator->() const"},
    {"_ZNK5clang17ConstExprIteratorixEm", "clang::ConstExprIterator::operator[](unsigned long) const"},
    {"_ZNK5clang17ConstExprIteratordeEv", "clang::ConstExprIterator::operator*() const"},
    {"_ZNK5clang17ConstExprIteratorptEv", "clang::ConstExprIterator::operator->() const"},
    {"_ZN5clang17SizeOfAlignOfExpr8childrenEv", "clang::SizeOfAlignOfExpr::children()"},
    {"_ZN5clang15ObjCMessageExpr8childrenEv", "clang::ObjCMessageExpr::children()"},
    {"_ZN5clang16BlockDeclRefExprC1EPNS_7VarDeclENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationEbb", "clang::BlockDeclRefExpr::BlockDeclRefExpr(clang::VarDecl*, clang::QualType, clang::ExprValueKind, clang::SourceLocation, bool, bool)"},
    {"_ZN5clang16BlockDeclRefExprC2EPNS_7VarDeclENS_8QualTypeENS_13ExprValueKindENS_14SourceLocationEbb", "clang::BlockDeclRefExpr::BlockDeclRefExpr(clang::VarDecl*, clang::QualType, clang::ExprValueKind, clang::SourceLocation, bool, bool)"},
    {"_ZN5clang9ASTVectorIPNS_4StmtEE6insertIPPNS_4ExprEEEPS2_RNS_10ASTContextES8_T_SB_", "clang::Stmt** clang::ASTVector<clang::Stmt*>::insert<clang::Expr**>(clang::ASTContext&, clang::Stmt**, clang::Expr**, clang::Expr**)"},
    {"_ZN5clang9ASTVectorIPNS_4StmtEE6resizeERNS_10ASTContextEjRKS2_", "clang::ASTVector<clang::Stmt*>::resize(clang::ASTContext&, unsigned int, clang::Stmt* const&)"},
    {"_ZN5clang9ASTVectorIPNS_4StmtEE6insertERNS_10ASTContextEPS2_mRKS2_", "clang::ASTVector<clang::Stmt*>::insert(clang::ASTContext&, clang::Stmt**, unsigned long, clang::Stmt* const&)"},
    {"_ZNK5clang4Decl7getAttrINS_20WarnUnusedResultAttrEEEPT_v", "clang::WarnUnusedResultAttr* clang::Decl::getAttr<clang::WarnUnusedResultAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_8PureAttrEEEPT_v", "clang::PureAttr* clang::Decl::getAttr<clang::PureAttr>() const"},
    {"_ZNK5clang4Decl7getAttrINS_9ConstAttrEEEPT_v", "clang::ConstAttr* clang::Decl::getAttr<clang::ConstAttr>() const"},
    {"_ZNK5clang7VarDecl16hasGlobalStorageEv", "clang::VarDecl::hasGlobalStorage() const"},
    {"_ZN5clang9ASTVectorIPNS_4StmtEE6appendERNS_10ASTContextEmRKS2_", "clang::ASTVector<clang::Stmt*>::append(clang::ASTContext&, unsigned long, clang::Stmt* const&)"},
    {"_ZN5clang9ASTVectorIPNS_4StmtEE6appendIPS2_EEvRNS_10ASTContextET_S8_", "void clang::ASTVector<clang::Stmt*>::append<clang::Stmt**>(clang::ASTContext&, clang::Stmt**, clang::Stmt**)"},
    {"_ZN5clang9ASTVectorIPNS_4StmtEE6appendIPPNS_4ExprEEEvRNS_10ASTContextET_SA_", "void clang::ASTVector<clang::Stmt*>::append<clang::Expr**>(clang::ASTContext&, clang::Expr**, clang::Expr**)"},
    {"_ZNK5clang16APNumericStorage11getIntValueEv", "clang::APNumericStorage::getIntValue() const"},
    {"_ZN5clang8CastExprC2ENS_4Stmt9StmtClassENS_8QualTypeENS_13ExprValueKindENS_8CastKindEPNS_4ExprEj", "clang::CastExpr::CastExpr(clang::Stmt::StmtClass, clang::QualType, clang::ExprValueKind, clang::CastKind, clang::Expr*, unsigned int)"},
    {"_ZN5clang14APFloatStorage8setValueERNS_10ASTContextERKN4llvm7APFloatE", "clang::APFloatStorage::setValue(clang::ASTContext&, llvm::APFloat const&)"},
    {"_ZN5clang14IntegerLiteralC2ERNS_10ASTContextERKN4llvm5APIntENS_8QualTypeENS_14SourceLocationE", "clang::IntegerLiteral::IntegerLiteral(clang::ASTContext&, llvm::APInt const&, clang::QualType, clang::SourceLocation)"},
    {"_ZNK5clang13CXXTypeidExpr14getTypeOperandEv", "clang::CXXTypeidExpr::getTypeOperand() const"},
    {"_ZNK5clang13CXXUuidofExpr14getTypeOperandEv", "clang::CXXUuidofExpr::getTypeOperand() const"},
    {"_ZNK5clang22CXXScalarValueInitExpr14getSourceRangeEv", "clang::CXXScalarValueInitExpr::getSourceRange() const"},
    {"_ZN5clang10CXXNewExprC1ERNS_10ASTContextEbPNS_12FunctionDeclEPPNS_4ExprEjNS_11SourceRangeES6_PNS_18CXXConstructorDeclEbS7_jS4_bNS_8QualTypeEPNS_14TypeSourceInfoENS_14SourceLocationESE_SE_SE_", "clang::CXXNewExpr::CXXNewExpr(clang::ASTContext&, bool, clang::FunctionDecl*, clang::Expr**, unsigned int, clang::SourceRange, clang::Expr*, clang::CXXConstructorDecl*, bool, clang::Expr**, unsigned int, clang::FunctionDecl*, bool, clang::QualType, clang::TypeSourceInfo*, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang10CXXNewExprC2ERNS_10ASTContextEbPNS_12FunctionDeclEPPNS_4ExprEjNS_11SourceRangeES6_PNS_18CXXConstructorDeclEbS7_jS4_bNS_8QualTypeEPNS_14TypeSourceInfoENS_14SourceLocationESE_SE_SE_", "clang::CXXNewExpr::CXXNewExpr(clang::ASTContext&, bool, clang::FunctionDecl*, clang::Expr**, unsigned int, clang::SourceRange, clang::Expr*, clang::CXXConstructorDecl*, bool, clang::Expr**, unsigned int, clang::FunctionDecl*, bool, clang::QualType, clang::TypeSourceInfo*, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang10CXXNewExpr17AllocateArgsArrayERNS_10ASTContextEbjj", "clang::CXXNewExpr::AllocateArgsArray(clang::ASTContext&, bool, unsigned int, unsigned int)"},
    {"_ZNK5clang13CXXDeleteExpr16getDestroyedTypeEv", "clang::CXXDeleteExpr::getDestroyedType() const"},
    {"_ZN5clang27PseudoDestructorTypeStorageC1EPNS_14TypeSourceInfoE", "clang::PseudoDestructorTypeStorage::PseudoDestructorTypeStorage(clang::TypeSourceInfo*)"},
    {"_ZN5clang27PseudoDestructorTypeStorageC2EPNS_14TypeSourceInfoE", "clang::PseudoDestructorTypeStorage::PseudoDestructorTypeStorage(clang::TypeSourceInfo*)"},
    {"_ZN5clang23CXXPseudoDestructorExprC1ERNS_10ASTContextEPNS_4ExprEbNS_14SourceLocationEPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_14TypeSourceInfoES5_S5_NS_27PseudoDestructorTypeStorageE", "clang::CXXPseudoDestructorExpr::CXXPseudoDestructorExpr(clang::ASTContext&, clang::Expr*, bool, clang::SourceLocation, clang::NestedNameSpecifier*, clang::SourceRange, clang::TypeSourceInfo*, clang::SourceLocation, clang::SourceLocation, clang::PseudoDestructorTypeStorage)"},
    {"_ZN5clang23CXXPseudoDestructorExprC2ERNS_10ASTContextEPNS_4ExprEbNS_14SourceLocationEPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_14TypeSourceInfoES5_S5_NS_27PseudoDestructorTypeStorageE", "clang::CXXPseudoDestructorExpr::CXXPseudoDestructorExpr(clang::ASTContext&, clang::Expr*, bool, clang::SourceLocation, clang::NestedNameSpecifier*, clang::SourceRange, clang::TypeSourceInfo*, clang::SourceLocation, clang::SourceLocation, clang::PseudoDestructorTypeStorage)"},
    {"_ZNK5clang23CXXPseudoDestructorExpr16getDestroyedTypeEv", "clang::CXXPseudoDestructorExpr::getDestroyedType() const"},
    {"_ZNK5clang23CXXPseudoDestructorExpr14getSourceRangeEv", "clang::CXXPseudoDestructorExpr::getSourceRange() const"},
    {"_ZN5clang20UnresolvedLookupExpr6CreateERNS_10ASTContextEPNS_13CXXRecordDeclEPNS_19NestedNameSpecifierENS_11SourceRangeERKNS_19DeclarationNameInfoEbRKNS_24TemplateArgumentListInfoENS_21UnresolvedSetIteratorESE_", "clang::UnresolvedLookupExpr::Create(clang::ASTContext&, clang::CXXRecordDecl*, clang::NestedNameSpecifier*, clang::SourceRange, clang::DeclarationNameInfo const&, bool, clang::TemplateArgumentListInfo const&, clang::UnresolvedSetIterator, clang::UnresolvedSetIterator)"},
    {"_ZN5clang20UnresolvedLookupExpr11CreateEmptyERNS_10ASTContextEbj", "clang::UnresolvedLookupExpr::CreateEmpty(clang::ASTContext&, bool, unsigned int)"},
    {"_ZN5clang12OverloadExprC1ENS_4Stmt9StmtClassERNS_10ASTContextEPNS_19NestedNameSpecifierENS_11SourceRangeERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoENS_21UnresolvedSetIteratorESE_bb", "clang::OverloadExpr::OverloadExpr(clang::Stmt::StmtClass, clang::ASTContext&, clang::NestedNameSpecifier*, clang::SourceRange, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*, clang::UnresolvedSetIterator, clang::UnresolvedSetIterator, bool, bool)"},
    {"_ZN5clang12OverloadExprC2ENS_4Stmt9StmtClassERNS_10ASTContextEPNS_19NestedNameSpecifierENS_11SourceRangeERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoENS_21UnresolvedSetIteratorESE_bb", "clang::OverloadExpr::OverloadExpr(clang::Stmt::StmtClass, clang::ASTContext&, clang::NestedNameSpecifier*, clang::SourceRange, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*, clang::UnresolvedSetIterator, clang::UnresolvedSetIterator, bool, bool)"},
    {"_ZN5clang12OverloadExpr17initializeResultsERNS_10ASTContextENS_21UnresolvedSetIteratorES3_", "clang::OverloadExpr::initializeResults(clang::ASTContext&, clang::UnresolvedSetIterator, clang::UnresolvedSetIterator)"},
    {"_ZNK5clang12OverloadExpr14getNamingClassEv", "clang::OverloadExpr::getNamingClass() const"},
    {"_ZNK5clang20UnresolvedMemberExpr14getNamingClassEv", "clang::UnresolvedMemberExpr::getNamingClass() const"},
    {"_ZN5clang25DependentScopeDeclRefExprC1ENS_8QualTypeEPNS_19NestedNameSpecifierENS_11SourceRangeERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoE", "clang::DependentScopeDeclRefExpr::DependentScopeDeclRefExpr(clang::QualType, clang::NestedNameSpecifier*, clang::SourceRange, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang25DependentScopeDeclRefExprC2ENS_8QualTypeEPNS_19NestedNameSpecifierENS_11SourceRangeERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoE", "clang::DependentScopeDeclRefExpr::DependentScopeDeclRefExpr(clang::QualType, clang::NestedNameSpecifier*, clang::SourceRange, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang25DependentScopeDeclRefExpr6CreateERNS_10ASTContextEPNS_19NestedNameSpecifierENS_11SourceRangeERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoE", "clang::DependentScopeDeclRefExpr::Create(clang::ASTContext&, clang::NestedNameSpecifier*, clang::SourceRange, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang25DependentScopeDeclRefExpr11CreateEmptyERNS_10ASTContextEbj", "clang::DependentScopeDeclRefExpr::CreateEmpty(clang::ASTContext&, bool, unsigned int)"},
    {"_ZNK5clang16CXXConstructExpr14getSourceRangeEv", "clang::CXXConstructExpr::getSourceRange() const"},
    {"_ZNK5clang19CXXOperatorCallExpr14getSourceRangeEv", "clang::CXXOperatorCallExpr::getSourceRange() const"},
    {"_ZN5clang17CXXMemberCallExpr25getImplicitObjectArgumentEv", "clang::CXXMemberCallExpr::getImplicitObjectArgument()"},
    {"_ZN5clang17CXXMemberCallExpr13getRecordDeclEv", "clang::CXXMemberCallExpr::getRecordDecl()"},
    {"_ZNK5clang17CXXMemberCallExpr14getSourceRangeEv", "clang::CXXMemberCallExpr::getSourceRange() const"},
    {"_ZNK5clang16CXXNamedCastExpr11getCastNameEv", "clang::CXXNamedCastExpr::getCastName() const"},
    {"_ZN5clang17CXXStaticCastExpr6CreateERNS_10ASTContextENS_8QualTypeENS_13ExprValueKindENS_8CastKindEPNS_4ExprEPKN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEEPNS_14TypeSourceInfoENS_14SourceLocationESH_", "clang::CXXStaticCastExpr::Create(clang::ASTContext&, clang::QualType, clang::ExprValueKind, clang::CastKind, clang::Expr*, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u> const*, clang::TypeSourceInfo*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang17CXXStaticCastExpr11CreateEmptyERNS_10ASTContextEj", "clang::CXXStaticCastExpr::CreateEmpty(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang18CXXDynamicCastExpr6CreateERNS_10ASTContextENS_8QualTypeENS_13ExprValueKindENS_8CastKindEPNS_4ExprEPKN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEEPNS_14TypeSourceInfoENS_14SourceLocationESH_", "clang::CXXDynamicCastExpr::Create(clang::ASTContext&, clang::QualType, clang::ExprValueKind, clang::CastKind, clang::Expr*, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u> const*, clang::TypeSourceInfo*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang18CXXDynamicCastExpr11CreateEmptyERNS_10ASTContextEj", "clang::CXXDynamicCastExpr::CreateEmpty(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang22CXXReinterpretCastExpr6CreateERNS_10ASTContextENS_8QualTypeENS_13ExprValueKindENS_8CastKindEPNS_4ExprEPKN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEEPNS_14TypeSourceInfoENS_14SourceLocationESH_", "clang::CXXReinterpretCastExpr::Create(clang::ASTContext&, clang::QualType, clang::ExprValueKind, clang::CastKind, clang::Expr*, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u> const*, clang::TypeSourceInfo*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang22CXXReinterpretCastExpr11CreateEmptyERNS_10ASTContextEj", "clang::CXXReinterpretCastExpr::CreateEmpty(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang16CXXConstCastExpr6CreateERNS_10ASTContextENS_8QualTypeENS_13ExprValueKindEPNS_4ExprEPNS_14TypeSourceInfoENS_14SourceLocationES9_", "clang::CXXConstCastExpr::Create(clang::ASTContext&, clang::QualType, clang::ExprValueKind, clang::Expr*, clang::TypeSourceInfo*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang16CXXConstCastExpr11CreateEmptyERNS_10ASTContextE", "clang::CXXConstCastExpr::CreateEmpty(clang::ASTContext&)"},
    {"_ZN5clang21CXXFunctionalCastExpr6CreateERNS_10ASTContextENS_8QualTypeENS_13ExprValueKindEPNS_14TypeSourceInfoENS_14SourceLocationENS_8CastKindEPNS_4ExprEPKN4llvm11SmallVectorIPNS_16CXXBaseSpecifierELj4EEES7_", "clang::CXXFunctionalCastExpr::Create(clang::ASTContext&, clang::QualType, clang::ExprValueKind, clang::TypeSourceInfo*, clang::SourceLocation, clang::CastKind, clang::Expr*, llvm::SmallVector<clang::CXXBaseSpecifier*, 4u> const*, clang::SourceLocation)"},
    {"_ZN5clang21CXXFunctionalCastExpr11CreateEmptyERNS_10ASTContextEj", "clang::CXXFunctionalCastExpr::CreateEmpty(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang17CXXDefaultArgExpr6CreateERNS_10ASTContextENS_14SourceLocationEPNS_11ParmVarDeclEPNS_4ExprE", "clang::CXXDefaultArgExpr::Create(clang::ASTContext&, clang::SourceLocation, clang::ParmVarDecl*, clang::Expr*)"},
    {"_ZN5clang12CXXTemporary6CreateERNS_10ASTContextEPKNS_17CXXDestructorDeclE", "clang::CXXTemporary::Create(clang::ASTContext&, clang::CXXDestructorDecl const*)"},
    {"_ZN5clang20CXXBindTemporaryExpr6CreateERNS_10ASTContextEPNS_12CXXTemporaryEPNS_4ExprE", "clang::CXXBindTemporaryExpr::Create(clang::ASTContext&, clang::CXXTemporary*, clang::Expr*)"},
    {"_ZN5clang22CXXTemporaryObjectExprC1ERNS_10ASTContextEPNS_18CXXConstructorDeclEPNS_14TypeSourceInfoEPPNS_4ExprEjNS_11SourceRangeEb", "clang::CXXTemporaryObjectExpr::CXXTemporaryObjectExpr(clang::ASTContext&, clang::CXXConstructorDecl*, clang::TypeSourceInfo*, clang::Expr**, unsigned int, clang::SourceRange, bool)"},
    {"_ZN5clang22CXXTemporaryObjectExprC2ERNS_10ASTContextEPNS_18CXXConstructorDeclEPNS_14TypeSourceInfoEPPNS_4ExprEjNS_11SourceRangeEb", "clang::CXXTemporaryObjectExpr::CXXTemporaryObjectExpr(clang::ASTContext&, clang::CXXConstructorDecl*, clang::TypeSourceInfo*, clang::Expr**, unsigned int, clang::SourceRange, bool)"},
    {"_ZN5clang16CXXConstructExprC2ERNS_10ASTContextENS_4Stmt9StmtClassENS_8QualTypeENS_14SourceLocationEPNS_18CXXConstructorDeclEbPPNS_4ExprEjbNS0_16ConstructionKindENS_11SourceRangeE", "clang::CXXConstructExpr::CXXConstructExpr(clang::ASTContext&, clang::Stmt::StmtClass, clang::QualType, clang::SourceLocation, clang::CXXConstructorDecl*, bool, clang::Expr**, unsigned int, bool, clang::CXXConstructExpr::ConstructionKind, clang::SourceRange)"},
    {"_ZNK5clang22CXXTemporaryObjectExpr14getSourceRangeEv", "clang::CXXTemporaryObjectExpr::getSourceRange() const"},
    {"_ZN5clang16CXXConstructExpr6CreateERNS_10ASTContextENS_8QualTypeENS_14SourceLocationEPNS_18CXXConstructorDeclEbPPNS_4ExprEjbNS0_16ConstructionKindENS_11SourceRangeE", "clang::CXXConstructExpr::Create(clang::ASTContext&, clang::QualType, clang::SourceLocation, clang::CXXConstructorDecl*, bool, clang::Expr**, unsigned int, bool, clang::CXXConstructExpr::ConstructionKind, clang::SourceRange)"},
    {"_ZN5clang16CXXConstructExprC1ERNS_10ASTContextENS_4Stmt9StmtClassENS_8QualTypeENS_14SourceLocationEPNS_18CXXConstructorDeclEbPPNS_4ExprEjbNS0_16ConstructionKindENS_11SourceRangeE", "clang::CXXConstructExpr::CXXConstructExpr(clang::ASTContext&, clang::Stmt::StmtClass, clang::QualType, clang::SourceLocation, clang::CXXConstructorDecl*, bool, clang::Expr**, unsigned int, bool, clang::CXXConstructExpr::ConstructionKind, clang::SourceRange)"},
    {"_ZN5clang16ExprWithCleanupsC1ERNS_10ASTContextEPNS_4ExprEPPNS_12CXXTemporaryEj", "clang::ExprWithCleanups::ExprWithCleanups(clang::ASTContext&, clang::Expr*, clang::CXXTemporary**, unsigned int)"},
    {"_ZN5clang16ExprWithCleanupsC2ERNS_10ASTContextEPNS_4ExprEPPNS_12CXXTemporaryEj", "clang::ExprWithCleanups::ExprWithCleanups(clang::ASTContext&, clang::Expr*, clang::CXXTemporary**, unsigned int)"},
    {"_ZN5clang16ExprWithCleanups17setNumTemporariesERNS_10ASTContextEj", "clang::ExprWithCleanups::setNumTemporaries(clang::ASTContext&, unsigned int)"},
    {"_ZN5clang16ExprWithCleanups6CreateERNS_10ASTContextEPNS_4ExprEPPNS_12CXXTemporaryEj", "clang::ExprWithCleanups::Create(clang::ASTContext&, clang::Expr*, clang::CXXTemporary**, unsigned int)"},
    {"_ZN5clang26CXXUnresolvedConstructExprC1EPNS_14TypeSourceInfoENS_14SourceLocationEPPNS_4ExprEjS3_", "clang::CXXUnresolvedConstructExpr::CXXUnresolvedConstructExpr(clang::TypeSourceInfo*, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang26CXXUnresolvedConstructExprC2EPNS_14TypeSourceInfoENS_14SourceLocationEPPNS_4ExprEjS3_", "clang::CXXUnresolvedConstructExpr::CXXUnresolvedConstructExpr(clang::TypeSourceInfo*, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang26CXXUnresolvedConstructExpr6CreateERNS_10ASTContextEPNS_14TypeSourceInfoENS_14SourceLocationEPPNS_4ExprEjS5_", "clang::CXXUnresolvedConstructExpr::Create(clang::ASTContext&, clang::TypeSourceInfo*, clang::SourceLocation, clang::Expr**, unsigned int, clang::SourceLocation)"},
    {"_ZN5clang26CXXUnresolvedConstructExpr11CreateEmptyERNS_10ASTContextEj", "clang::CXXUnresolvedConstructExpr::CreateEmpty(clang::ASTContext&, unsigned int)"},
    {"_ZNK5clang26CXXUnresolvedConstructExpr14getSourceRangeEv", "clang::CXXUnresolvedConstructExpr::getSourceRange() const"},
    {"_ZN5clang27CXXDependentScopeMemberExprC1ERNS_10ASTContextEPNS_4ExprENS_8QualTypeEbNS_14SourceLocationEPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9NamedDeclENS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoE", "clang::CXXDependentScopeMemberExpr::CXXDependentScopeMemberExpr(clang::ASTContext&, clang::Expr*, clang::QualType, bool, clang::SourceLocation, clang::NestedNameSpecifier*, clang::SourceRange, clang::NamedDecl*, clang::DeclarationNameInfo, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang27CXXDependentScopeMemberExprC2ERNS_10ASTContextEPNS_4ExprENS_8QualTypeEbNS_14SourceLocationEPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9NamedDeclENS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoE", "clang::CXXDependentScopeMemberExpr::CXXDependentScopeMemberExpr(clang::ASTContext&, clang::Expr*, clang::QualType, bool, clang::SourceLocation, clang::NestedNameSpecifier*, clang::SourceRange, clang::NamedDecl*, clang::DeclarationNameInfo, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang27CXXDependentScopeMemberExprC1ERNS_10ASTContextEPNS_4ExprENS_8QualTypeEbNS_14SourceLocationEPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9NamedDeclENS_19DeclarationNameInfoE", "clang::CXXDependentScopeMemberExpr::CXXDependentScopeMemberExpr(clang::ASTContext&, clang::Expr*, clang::QualType, bool, clang::SourceLocation, clang::NestedNameSpecifier*, clang::SourceRange, clang::NamedDecl*, clang::DeclarationNameInfo)"},
    {"_ZN5clang27CXXDependentScopeMemberExprC2ERNS_10ASTContextEPNS_4ExprENS_8QualTypeEbNS_14SourceLocationEPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9NamedDeclENS_19DeclarationNameInfoE", "clang::CXXDependentScopeMemberExpr::CXXDependentScopeMemberExpr(clang::ASTContext&, clang::Expr*, clang::QualType, bool, clang::SourceLocation, clang::NestedNameSpecifier*, clang::SourceRange, clang::NamedDecl*, clang::DeclarationNameInfo)"},
    {"_ZN5clang27CXXDependentScopeMemberExpr6CreateERNS_10ASTContextEPNS_4ExprENS_8QualTypeEbNS_14SourceLocationEPNS_19NestedNameSpecifierENS_11SourceRangeEPNS_9NamedDeclENS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoE", "clang::CXXDependentScopeMemberExpr::Create(clang::ASTContext&, clang::Expr*, clang::QualType, bool, clang::SourceLocation, clang::NestedNameSpecifier*, clang::SourceRange, clang::NamedDecl*, clang::DeclarationNameInfo, clang::TemplateArgumentListInfo const*)"},
    {"_ZN5clang27CXXDependentScopeMemberExpr11CreateEmptyERNS_10ASTContextEbj", "clang::CXXDependentScopeMemberExpr::CreateEmpty(clang::ASTContext&, bool, unsigned int)"},
    {"_ZN5clang20UnresolvedMemberExprC1ERNS_10ASTContextEbPNS_4ExprENS_8QualTypeEbNS_14SourceLocationEPNS_19NestedNameSpecifierENS_11SourceRangeERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoENS_21UnresolvedSetIteratorESG_", "clang::UnresolvedMemberExpr::UnresolvedMemberExpr(clang::ASTContext&, bool, clang::Expr*, clang::QualType, bool, clang::SourceLocation, clang::NestedNameSpecifier*, clang::SourceRange, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*, clang::UnresolvedSetIterator, clang::UnresolvedSetIterator)"},
    {"_ZN5clang20UnresolvedMemberExprC2ERNS_10ASTContextEbPNS_4ExprENS_8QualTypeEbNS_14SourceLocationEPNS_19NestedNameSpecifierENS_11SourceRangeERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoENS_21UnresolvedSetIteratorESG_", "clang::UnresolvedMemberExpr::UnresolvedMemberExpr(clang::ASTContext&, bool, clang::Expr*, clang::QualType, bool, clang::SourceLocation, clang::NestedNameSpecifier*, clang::SourceRange, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*, clang::UnresolvedSetIterator, clang::UnresolvedSetIterator)"},
    {"_ZN5clang20UnresolvedMemberExpr6CreateERNS_10ASTContextEbPNS_4ExprENS_8QualTypeEbNS_14SourceLocationEPNS_19NestedNameSpecifierENS_11SourceRangeERKNS_19DeclarationNameInfoEPKNS_24TemplateArgumentListInfoENS_21UnresolvedSetIteratorESG_", "clang::UnresolvedMemberExpr::Create(clang::ASTContext&, bool, clang::Expr*, clang::QualType, bool, clang::SourceLocation, clang::NestedNameSpecifier*, clang::SourceRange, clang::DeclarationNameInfo const&, clang::TemplateArgumentListInfo const*, clang::UnresolvedSetIterator, clang::UnresolvedSetIterator)"},
    {"_ZN5clang20UnresolvedMemberExpr11CreateEmptyERNS_10ASTContextEbj", "clang::UnresolvedMemberExpr::CreateEmpty(clang::ASTContext&, bool, unsigned int)"},
    {"_ZN5clang32SubstNonTypeTemplateParmPackExprC1ENS_8QualTypeEPNS_23NonTypeTemplateParmDeclENS_14SourceLocationERKNS_16TemplateArgumentE", "clang::SubstNonTypeTemplateParmPackExpr::SubstNonTypeTemplateParmPackExpr(clang::QualType, clang::NonTypeTemplateParmDecl*, clang::SourceLocation, clang::TemplateArgument const&)"},
    {"_ZN5clang32SubstNonTypeTemplateParmPackExprC2ENS_8QualTypeEPNS_23NonTypeTemplateParmDeclENS_14SourceLocationERKNS_16TemplateArgumentE", "clang::SubstNonTypeTemplateParmPackExpr::SubstNonTypeTemplateParmPackExpr(clang::QualType, clang::NonTypeTemplateParmDecl*, clang::SourceLocation, clang::TemplateArgument const&)"},
    {"_ZNK5clang32SubstNonTypeTemplateParmPackExpr15getArgumentPackEv", "clang::SubstNonTypeTemplateParmPackExpr::getArgumentPack() const"},
    {"_ZNK5clang4Expr12ClassifyImplERNS_10ASTContextEPNS_14SourceLocationE", "clang::Expr::ClassifyImpl(clang::ASTContext&, clang::SourceLocation*) const"},
    {"_Z16ClassifyInternalRN5clang10ASTContextEPKNS_4ExprE", "ClassifyInternal(clang::ASTContext&, clang::Expr const*)"},
    {"_ZNK5clang4Expr14ClassifyLValueERNS_10ASTContextE", "clang::Expr::ClassifyLValue(clang::ASTContext&) const"},
    {"_ZNK5clang4Expr18isModifiableLvalueERNS_10ASTContextEPNS_14SourceLocationE", "clang::Expr::isModifiableLvalue(clang::ASTContext&, clang::SourceLocation*) const"},
    {"_Z15ClassifyUnnamedRN5clang10ASTContextENS_8QualTypeE", "ClassifyUnnamed(clang::ASTContext&, clang::QualType)"},
    {"_ZNK5clang4Expr8EvaluateERNS0_10EvalResultERKNS_10ASTContextE", "clang::Expr::Evaluate(clang::Expr::EvalResult&, clang::ASTContext const&) const"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_116IntExprEvaluatorEbE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::IntExprEvaluator, bool>::Visit(clang::Stmt*)"},
    {"_ZNK5clang4Expr26EvaluateAsBooleanConditionERbRKNS_10ASTContextE", "clang::Expr::EvaluateAsBooleanCondition(bool&, clang::ASTContext const&) const"},
    {"_Z22HandleConversionToBoolPKN5clang4ExprERbR8EvalInfo", "HandleConversionToBool(clang::Expr const*, bool&, EvalInfo&)"},
    {"_ZNK5clang4Expr16EvaluateAsLValueERNS0_10EvalResultERKNS_10ASTContextE", "clang::Expr::EvaluateAsLValue(clang::Expr::EvalResult&, clang::ASTContext const&) const"},
    {"_ZNK5clang4Expr19EvaluateAsAnyLValueERNS0_10EvalResultERKNS_10ASTContextE", "clang::Expr::EvaluateAsAnyLValue(clang::Expr::EvalResult&, clang::ASTContext const&) const"},
    {"_ZNK5clang4Expr13isEvaluatableERKNS_10ASTContextE", "clang::Expr::isEvaluatable(clang::ASTContext const&) const"},
    {"_ZNK5clang4Expr14HasSideEffectsERKNS_10ASTContextE", "clang::Expr::HasSideEffects(clang::ASTContext const&) const"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_113HasSideEffectEbE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::HasSideEffect, bool>::Visit(clang::Stmt*)"},
    {"_ZNK5clang4Expr13EvaluateAsIntERKNS_10ASTContextE", "clang::Expr::EvaluateAsInt(clang::ASTContext const&) const"},
    {"_ZNK5clang4Expr10EvalResult14isGlobalLValueEv", "clang::Expr::EvalResult::isGlobalLValue() const"},
    {"_ZNK5clang4Expr21isIntegerConstantExprERN4llvm6APSIntERNS_10ASTContextEPNS_14SourceLocationEb", "clang::Expr::isIntegerConstantExpr(llvm::APSInt&, clang::ASTContext&, clang::SourceLocation*, bool) const"},
    {"_Z8CheckICEPKN5clang4ExprERNS_10ASTContextE", "CheckICE(clang::Expr const*, clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_116IntExprEvaluator19VisitBinaryOperatorEPKN5clang14BinaryOperatorE", "(anonymous namespace)::IntExprEvaluator::VisitBinaryOperator(clang::BinaryOperator const*)"},
    {"_ZN12_GLOBAL__N_116IntExprEvaluator13VisitCallExprEPN5clang8CallExprE", "(anonymous namespace)::IntExprEvaluator::VisitCallExpr(clang::CallExpr*)"},
    {"_ZN12_GLOBAL__N_116IntExprEvaluator18VisitUnaryOperatorEPKN5clang13UnaryOperatorE", "(anonymous namespace)::IntExprEvaluator::VisitUnaryOperator(clang::UnaryOperator const*)"},
    {"_ZN12_GLOBAL__N_116IntExprEvaluator7SuccessEyPKN5clang4ExprE", "(anonymous namespace)::IntExprEvaluator::Success(unsigned long long, clang::Expr const*)"},
    {"_Z15EvaluateIntegerPKN5clang4ExprERN4llvm6APSIntER8EvalInfo", "EvaluateInteger(clang::Expr const*, llvm::APSInt&, EvalInfo&)"},
    {"_ZN12_GLOBAL__N_116IntExprEvaluator19CheckReferencedDeclEPKN5clang4ExprEPKNS1_4DeclE", "(anonymous namespace)::IntExprEvaluator::CheckReferencedDecl(clang::Expr const*, clang::Decl const*)"},
    {"_ZN12_GLOBAL__N_116IntExprEvaluator13VisitCastExprEPN5clang8CastExprE", "(anonymous namespace)::IntExprEvaluator::VisitCastExpr(clang::CastExpr*)"},
    {"_Z18HandleIntToIntCastN5clang8QualTypeES0_RN4llvm6APSIntERKNS_10ASTContextE", "HandleIntToIntCast(clang::QualType, clang::QualType, llvm::APSInt&, clang::ASTContext const&)"},
    {"_Z20HandleFloatToIntCastN5clang8QualTypeES0_RN4llvm7APFloatERKNS_10ASTContextE", "HandleFloatToIntCast(clang::QualType, clang::QualType, llvm::APFloat&, clang::ASTContext const&)"},
    {"_Z22EvalPointerValueAsBoolRN12_GLOBAL__N_16LValueERb", "EvalPointerValueAsBool((anonymous namespace)::LValue&, bool&)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_119LValueExprEvaluatorEbE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::LValueExprEvaluator, bool>::Visit(clang::Stmt*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_120ComplexExprEvaluatorEbE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::ComplexExprEvaluator, bool>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_120ComplexExprEvaluator19VisitBinaryOperatorEPKN5clang14BinaryOperatorE", "(anonymous namespace)::ComplexExprEvaluator::VisitBinaryOperator(clang::BinaryOperator const*)"},
    {"_ZN12_GLOBAL__N_120ComplexExprEvaluator18VisitUnaryOperatorEPKN5clang13UnaryOperatorE", "(anonymous namespace)::ComplexExprEvaluator::VisitUnaryOperator(clang::UnaryOperator const*)"},
    {"_ZN12_GLOBAL__N_120ComplexExprEvaluator13VisitCastExprEPN5clang8CastExprE", "(anonymous namespace)::ComplexExprEvaluator::VisitCastExpr(clang::CastExpr*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_118FloatExprEvaluatorEbE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::FloatExprEvaluator, bool>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_118FloatExprEvaluator19VisitBinaryOperatorEPKN5clang14BinaryOperatorE", "(anonymous namespace)::FloatExprEvaluator::VisitBinaryOperator(clang::BinaryOperator const*)"},
    {"_ZN12_GLOBAL__N_118FloatExprEvaluator13VisitCallExprEPKN5clang8CallExprE", "(anonymous namespace)::FloatExprEvaluator::VisitCallExpr(clang::CallExpr const*)"},
    {"_ZN12_GLOBAL__N_118FloatExprEvaluator13VisitCastExprEPN5clang8CastExprE", "(anonymous namespace)::FloatExprEvaluator::VisitCastExpr(clang::CastExpr*)"},
    {"_Z21TryEvaluateBuiltinNaNRKN5clang10ASTContextENS_8QualTypeEPKNS_4ExprEbRN4llvm7APFloatE", "TryEvaluateBuiltinNaN(clang::ASTContext const&, clang::QualType, clang::Expr const*, bool, llvm::APFloat&)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_120PointerExprEvaluatorEbE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::PointerExprEvaluator, bool>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_120PointerExprEvaluator19VisitBinaryOperatorEPKN5clang14BinaryOperatorE", "(anonymous namespace)::PointerExprEvaluator::VisitBinaryOperator(clang::BinaryOperator const*)"},
    {"_ZN12_GLOBAL__N_120PointerExprEvaluator13VisitCastExprEPN5clang8CastExprE", "(anonymous namespace)::PointerExprEvaluator::VisitCastExpr(clang::CastExpr*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_119VectorExprEvaluatorENS_7APValueEE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::VectorExprEvaluator, clang::APValue>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_119VectorExprEvaluator13GetZeroVectorEN5clang8QualTypeE", "(anonymous namespace)::VectorExprEvaluator::GetZeroVector(clang::QualType)"},
    {"_ZN12_GLOBAL__N_119VectorExprEvaluator13VisitCastExprEPKN5clang8CastExprE", "(anonymous namespace)::VectorExprEvaluator::VisitCastExpr(clang::CastExpr const*)"},
    {"_ZNK5clang10ASTContext12MakeIntValueEyNS_8QualTypeE", "clang::ASTContext::MakeIntValue(unsigned long long, clang::QualType) const"},
    {"_ZN5clang7APValueC2ERKN4llvm6APSIntE", "clang::APValue::APValue(llvm::APSInt const&)"},
    {"_ZNK4llvm5APIntcoEv", "llvm::APInt::operator~() const"},
    {"_ZNK5clang7VarDecl17setEvaluatedValueERKNS_7APValueE", "clang::VarDecl::setEvaluatedValue(clang::APValue const&) const"},
    {"_ZNK4llvm6APSIntanERKS0_", "llvm::APSInt::operator&(llvm::APSInt const&) const"},
    {"_ZNK4llvm6APSInteoERKS0_", "llvm::APSInt::operator^(llvm::APSInt const&) const"},
    {"_ZNK4llvm6APSIntorERKS0_", "llvm::APSInt::operator|(llvm::APSInt const&) const"},
    {"_ZNK4llvm6APSIntdvERKS0_", "llvm::APSInt::operator/(llvm::APSInt const&) const"},
    {"_ZNK4llvm6APSIntrmERKS0_", "llvm::APSInt::operator%(llvm::APSInt const&) const"},
    {"_ZNK4llvm6APSIntlsEj", "llvm::APSInt::operator<<(unsigned int) const"},
    {"_ZNK4llvm6APSIntrsEj", "llvm::APSInt::operator>>(unsigned int) const"},
    {"_ZN5clang7APValue13setComplexIntERKN4llvm6APSIntES4_", "clang::APValue::setComplexInt(llvm::APSInt const&, llvm::APSInt const&)"},
    {"_ZN5clang7APValue9setVectorEPKS0_j", "clang::APValue::setVector(clang::APValue const*, unsigned int)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang7APValueELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::APValue, false>::grow(unsigned long)"},
    {"_ZN4llvm11SmallVectorIN5clang7APValueELj4EEC2EjRKS2_", "llvm::SmallVector<clang::APValue, 4u>::SmallVector(unsigned int, clang::APValue const&)"},
    {"_ZN4llvm6APSIntrSEj", "llvm::APSInt::operator>>=(unsigned int)"},
    {"_ZN5clang26InheritanceHierarchyWriter9WriteNodeENS_8QualTypeEb", "clang::InheritanceHierarchyWriter::WriteNode(clang::QualType, bool)"},
    {"_ZN5clang26InheritanceHierarchyWriter18WriteNodeReferenceENS_8QualTypeEb", "clang::InheritanceHierarchyWriter::WriteNodeReference(clang::QualType, bool)"},
    {"_ZNK5clang13CXXRecordDecl15viewInheritanceERNS_10ASTContextE", "clang::CXXRecordDecl::viewInheritance(clang::ASTContext&) const"},
    {"_ZN5clang26InheritanceHierarchyWriter10WriteGraphENS_8QualTypeE", "clang::InheritanceHierarchyWriter::WriteGraph(clang::QualType)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_iESt10_Select1stIS4_ENS0_16QualTypeOrderingESaIS4_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS4_ERKS4_", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, int>, std::_Select1st<std::pair<clang::QualType const, int>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, int>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<clang::QualType const, int>>, std::pair<clang::QualType const, int> const&)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_iESt10_Select1stIS4_ENS0_16QualTypeOrderingESaIS4_EE16_M_insert_uniqueERKS4_", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, int>, std::_Select1st<std::pair<clang::QualType const, int>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, int>>>::_M_insert_unique(std::pair<clang::QualType const, int> const&)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeES1_St9_IdentityIS1_ENS0_16QualTypeOrderingESaIS1_EE16_M_insert_uniqueERKS1_", "std::_Rb_tree<clang::QualType, clang::QualType, std::_Identity<clang::QualType>, clang::QualTypeOrdering, std::allocator<clang::QualType>>::_M_insert_unique(clang::QualType const&)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeESt4pairIKS1_iESt10_Select1stIS4_ENS0_16QualTypeOrderingESaIS4_EE8_M_eraseEPSt13_Rb_tree_nodeIS4_E", "std::_Rb_tree<clang::QualType, std::pair<clang::QualType const, int>, std::_Select1st<std::pair<clang::QualType const, int>>, clang::QualTypeOrdering, std::allocator<std::pair<clang::QualType const, int>>>::_M_erase(std::_Rb_tree_node<std::pair<clang::QualType const, int>>*)"},
    {"_ZNSt8_Rb_treeIN5clang8QualTypeES1_St9_IdentityIS1_ENS0_16QualTypeOrderingESaIS1_EE8_M_eraseEPSt13_Rb_tree_nodeIS1_E", "std::_Rb_tree<clang::QualType, clang::QualType, std::_Identity<clang::QualType>, clang::QualTypeOrdering, std::allocator<clang::QualType>>::_M_erase(std::_Rb_tree_node<clang::QualType>*)"},
    {"_ZN5clang19CreateItaniumCXXABIERNS_10ASTContextE", "clang::CreateItaniumCXXABI(clang::ASTContext&)"},
    {"_ZN5clang15CreateARMCXXABIERNS_10ASTContextE", "clang::CreateARMCXXABI(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_19ARMCXXABID1Ev", "(anonymous namespace)::ARMCXXABI::~ARMCXXABI()"},
    {"_ZN12_GLOBAL__N_19ARMCXXABID0Ev", "(anonymous namespace)::ARMCXXABI::~ARMCXXABI()"},
    {"_ZNK12_GLOBAL__N_113ItaniumCXXABI20getMemberPointerSizeEPKN5clang17MemberPointerTypeE", "(anonymous namespace)::ItaniumCXXABI::getMemberPointerSize(clang::MemberPointerType const*) const"},
    {"_ZNK12_GLOBAL__N_113ItaniumCXXABI24getDefaultMethodCallConvEv", "(anonymous namespace)::ItaniumCXXABI::getDefaultMethodCallConv() const"},
    {"_ZNK12_GLOBAL__N_113ItaniumCXXABI13isNearlyEmptyEPKN5clang13CXXRecordDeclE", "(anonymous namespace)::ItaniumCXXABI::isNearlyEmpty(clang::CXXRecordDecl const*) const"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABID1Ev", "(anonymous namespace)::ItaniumCXXABI::~ItaniumCXXABI()"},
    {"_ZN12_GLOBAL__N_113ItaniumCXXABID0Ev", "(anonymous namespace)::ItaniumCXXABI::~ItaniumCXXABI()"},
    {"_ZN5clang26createItaniumMangleContextERNS_10ASTContextERNS_10DiagnosticE", "clang::createItaniumMangleContext(clang::ASTContext&, clang::Diagnostic&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContextD1Ev", "(anonymous namespace)::ItaniumMangleContext::~ItaniumMangleContext()"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContextD0Ev", "(anonymous namespace)::ItaniumMangleContext::~ItaniumMangleContext()"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext16startNewFunctionEv", "(anonymous namespace)::ItaniumMangleContext::startNewFunction()"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext20shouldMangleDeclNameEPKN5clang9NamedDeclE", "(anonymous namespace)::ItaniumMangleContext::shouldMangleDeclName(clang::NamedDecl const*)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext10mangleNameEPKN5clang9NamedDeclERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleName(clang::NamedDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext11mangleThunkEPKN5clang13CXXMethodDeclERKNS1_9ThunkInfoERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleThunk(clang::CXXMethodDecl const*, clang::ThunkInfo const&, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext18mangleCXXDtorThunkEPKN5clang17CXXDestructorDeclENS1_11CXXDtorTypeERKNS1_14ThisAdjustmentERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleCXXDtorThunk(clang::CXXDestructorDecl const*, clang::CXXDtorType, clang::ThisAdjustment const&, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext24mangleReferenceTemporaryEPKN5clang7VarDeclERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleReferenceTemporary(clang::VarDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext15mangleCXXVTableEPKN5clang13CXXRecordDeclERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleCXXVTable(clang::CXXRecordDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext12mangleCXXVTTEPKN5clang13CXXRecordDeclERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleCXXVTT(clang::CXXRecordDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext19mangleCXXCtorVTableEPKN5clang13CXXRecordDeclExS4_RN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleCXXCtorVTable(clang::CXXRecordDecl const*, long long, clang::CXXRecordDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext13mangleCXXRTTIEN5clang8QualTypeERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleCXXRTTI(clang::QualType, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext17mangleCXXRTTINameEN5clang8QualTypeERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleCXXRTTIName(clang::QualType, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext13mangleCXXCtorEPKN5clang18CXXConstructorDeclENS1_11CXXCtorTypeERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleCXXCtor(clang::CXXConstructorDecl const*, clang::CXXCtorType, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext13mangleCXXDtorEPKN5clang17CXXDestructorDeclENS1_11CXXDtorTypeERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleCXXDtor(clang::CXXDestructorDecl const*, clang::CXXDtorType, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_120ItaniumMangleContext26mangleItaniumGuardVariableEPKN5clang7VarDeclERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::ItaniumMangleContext::mangleItaniumGuardVariable(clang::VarDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler10mangleNameEPKN5clang9NamedDeclE", "(anonymous namespace)::CXXNameMangler::mangleName(clang::NamedDecl const*)"},
    {"_ZN12_GLOBAL__N_117GetLocalClassDeclEPKN5clang9NamedDeclE", "(anonymous namespace)::GetLocalClassDecl(clang::NamedDecl const*)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler15mangleLocalNameEPKN5clang9NamedDeclE", "(anonymous namespace)::CXXNameMangler::mangleLocalName(clang::NamedDecl const*)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler26mangleUnscopedTemplateNameEPKN5clang12TemplateDeclE", "(anonymous namespace)::CXXNameMangler::mangleUnscopedTemplateName(clang::TemplateDecl const*)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler16mangleNestedNameEPKN5clang9NamedDeclEPKNS1_11DeclContextEb", "(anonymous namespace)::CXXNameMangler::mangleNestedName(clang::NamedDecl const*, clang::DeclContext const*, bool)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler16mangleQualifiersEN5clang10QualifiersE", "(anonymous namespace)::CXXNameMangler::mangleQualifiers(clang::Qualifiers)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler20mangleTemplatePrefixEPKN5clang12TemplateDeclE", "(anonymous namespace)::CXXNameMangler::mangleTemplatePrefix(clang::TemplateDecl const*)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler12manglePrefixEPKN5clang11DeclContextEb", "(anonymous namespace)::CXXNameMangler::manglePrefix(clang::DeclContext const*, bool)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler21mangleUnqualifiedNameEPKN5clang9NamedDeclENS1_15DeclarationNameEj", "(anonymous namespace)::CXXNameMangler::mangleUnqualifiedName(clang::NamedDecl const*, clang::DeclarationName, unsigned int)"},
    {"_Z24FindFirstNamedDataMemberPKN5clang10RecordDeclE", "FindFirstNamedDataMember(clang::RecordDecl const*)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler10mangleTypeEN5clang8QualTypeE", "(anonymous namespace)::CXXNameMangler::mangleType(clang::QualType)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler18mangleOperatorNameEN5clang22OverloadedOperatorKindEj", "(anonymous namespace)::CXXNameMangler::mangleOperatorName(clang::OverloadedOperatorKind, unsigned int)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler18mangleSubstitutionEN5clang8QualTypeE", "(anonymous namespace)::CXXNameMangler::mangleSubstitution(clang::QualType)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler10mangleTypeEPKN5clang10VectorTypeE", "(anonymous namespace)::CXXNameMangler::mangleType(clang::VectorType const*)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler15addSubstitutionEN5clang8QualTypeE", "(anonymous namespace)::CXXNameMangler::addSubstitution(clang::QualType)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler15addSubstitutionEPKN5clang9NamedDeclE", "(anonymous namespace)::CXXNameMangler::addSubstitution(clang::NamedDecl const*)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler20mangleTemplatePrefixEN5clang12TemplateNameE", "(anonymous namespace)::CXXNameMangler::mangleTemplatePrefix(clang::TemplateName)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler18mangleTemplateArgsEN5clang12TemplateNameEPKNS1_16TemplateArgumentEj", "(anonymous namespace)::CXXNameMangler::mangleTemplateArgs(clang::TemplateName, clang::TemplateArgument const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler17mangleTemplateArgEPKN5clang9NamedDeclERKNS1_16TemplateArgumentE", "(anonymous namespace)::CXXNameMangler::mangleTemplateArg(clang::NamedDecl const*, clang::TemplateArgument const&)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler10mangleTypeEN5clang12TemplateNameE", "(anonymous namespace)::CXXNameMangler::mangleType(clang::TemplateName)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler16mangleExpressionEPKN5clang4ExprEj", "(anonymous namespace)::CXXNameMangler::mangleExpression(clang::Expr const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler20mangleIntegerLiteralEN5clang8QualTypeERKN4llvm6APSIntE", "(anonymous namespace)::CXXNameMangler::mangleIntegerLiteral(clang::QualType, llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler6mangleEPKN5clang9NamedDeclEN4llvm9StringRefE", "(anonymous namespace)::CXXNameMangler::mangle(clang::NamedDecl const*, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler22mangleFunctionEncodingEPKN5clang12FunctionDeclE", "(anonymous namespace)::CXXNameMangler::mangleFunctionEncoding(clang::FunctionDecl const*)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler22mangleBareFunctionTypeEPKN5clang12FunctionTypeEb", "(anonymous namespace)::CXXNameMangler::mangleBareFunctionType(clang::FunctionType const*, bool)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler12mangleNumberERKN4llvm6APSIntE", "(anonymous namespace)::CXXNameMangler::mangleNumber(llvm::APSInt const&)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler11mangleFloatERKN4llvm7APFloatE", "(anonymous namespace)::CXXNameMangler::mangleFloat(llvm::APFloat const&)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler21mangleUnresolvedScopeEPN5clang19NestedNameSpecifierE", "(anonymous namespace)::CXXNameMangler::mangleUnresolvedScope(clang::NestedNameSpecifier*)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler18mangleSubstitutionEN5clang12TemplateNameE", "(anonymous namespace)::CXXNameMangler::mangleSubstitution(clang::TemplateName)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler15addSubstitutionEN5clang12TemplateNameE", "(anonymous namespace)::CXXNameMangler::addSubstitution(clang::TemplateName)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler18mangleSubstitutionEm", "(anonymous namespace)::CXXNameMangler::mangleSubstitution(unsigned long)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler26mangleStandardSubstitutionEPKN5clang9NamedDeclE", "(anonymous namespace)::CXXNameMangler::mangleStandardSubstitution(clang::NamedDecl const*)"},
    {"_Z5isStdPKN5clang13NamespaceDeclE", "isStd(clang::NamespaceDecl const*)"},
    {"_Z20isCharSpecializationN5clang8QualTypeEPKc", "isCharSpecialization(clang::QualType, char const*)"},
    {"_Z26isStreamCharSpecializationILm14EEbPKN5clang31ClassTemplateSpecializationDeclERAT__Kc", "bool isStreamCharSpecialization<14ul>(clang::ClassTemplateSpecializationDecl const*, char const (&) [14ul])"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler10mangleNameEPKN5clang12TemplateDeclEPKNS1_16TemplateArgumentEj", "(anonymous namespace)::CXXNameMangler::mangleName(clang::TemplateDecl const*, clang::TemplateArgument const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_114CXXNameMangler16mangleCallOffsetExx", "(anonymous namespace)::CXXNameMangler::mangleCallOffset(long long, long long)"},
    {"_ZN4llvm8DenseMapImjNS_12DenseMapInfoImEENS1_IjEEE16InsertIntoBucketERKmRKjPSt4pairImjE", "llvm::DenseMap<unsigned long, unsigned int, llvm::DenseMapInfo<unsigned long>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(unsigned long const&, unsigned int const&, std::pair<unsigned long, unsigned int>*)"},
    {"_ZN4llvm8DenseMapImjNS_12DenseMapInfoImEENS1_IjEEE4growEj", "llvm::DenseMap<unsigned long, unsigned int, llvm::DenseMapInfo<unsigned long>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZNK5clang4Decl7getAttrINS_12AsmLabelAttrEEEPT_v", "clang::AsmLabelAttr* clang::Decl::getAttr<clang::AsmLabelAttr>() const"},
    {"_ZN4llvm8DenseMapIPKN5clang7TagDeclEyNS_12DenseMapInfoIS4_EENS5_IyEEE6insertERKSt4pairIS4_yE", "llvm::DenseMap<clang::TagDecl const*, unsigned long long, llvm::DenseMapInfo<clang::TagDecl const*>, llvm::DenseMapInfo<unsigned long long>>::insert(std::pair<clang::TagDecl const*, unsigned long long> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang7TagDeclEyNS_12DenseMapInfoIS4_EENS5_IyEEE16InsertIntoBucketERKS4_RKyPSt4pairIS4_yE", "llvm::DenseMap<clang::TagDecl const*, unsigned long long, llvm::DenseMapInfo<clang::TagDecl const*>, llvm::DenseMapInfo<unsigned long long>>::InsertIntoBucket(clang::TagDecl const* const&, unsigned long long const&, std::pair<clang::TagDecl const*, unsigned long long>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang7TagDeclEyNS_12DenseMapInfoIS4_EENS5_IyEEE4growEj", "llvm::DenseMap<clang::TagDecl const*, unsigned long long, llvm::DenseMapInfo<clang::TagDecl const*>, llvm::DenseMapInfo<unsigned long long>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang9NamedDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::NamedDecl const*, unsigned int, llvm::DenseMapInfo<clang::NamedDecl const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::NamedDecl const* const&, unsigned int const&, std::pair<clang::NamedDecl const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang9NamedDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::NamedDecl const*, unsigned int, llvm::DenseMapInfo<clang::NamedDecl const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN5clang13MangleContext16startNewFunctionEv", "clang::MangleContext::startNewFunction()"},
    {"_ZN4llvm8DenseMapIPKN5clang9BlockDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE16shrink_and_clearEv", "llvm::DenseMap<clang::BlockDecl const*, unsigned int, llvm::DenseMapInfo<clang::BlockDecl const*>, llvm::DenseMapInfo<unsigned int>>::shrink_and_clear()"},
    {"_ZN5clang13MangleContextD1Ev", "clang::MangleContext::~MangleContext()"},
    {"_ZN5clang13MangleContextD0Ev", "clang::MangleContext::~MangleContext()"},
    {"_ZN5clang13MangleContext26mangleItaniumGuardVariableEPKNS_7VarDeclERN4llvm15SmallVectorImplIcEE", "clang::MangleContext::mangleItaniumGuardVariable(clang::VarDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN5clang13MangleContext17mangleGlobalBlockEPKNS_9BlockDeclERN4llvm15SmallVectorImplIcEE", "clang::MangleContext::mangleGlobalBlock(clang::BlockDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN5clang13MangleContext15mangleCtorBlockEPKNS_18CXXConstructorDeclENS_11CXXCtorTypeEPKNS_9BlockDeclERN4llvm15SmallVectorImplIcEE", "clang::MangleContext::mangleCtorBlock(clang::CXXConstructorDecl const*, clang::CXXCtorType, clang::BlockDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_119mangleFunctionBlockERN5clang13MangleContextEN4llvm9StringRefEPKNS0_9BlockDeclERNS3_15SmallVectorImplIcEE", "(anonymous namespace)::mangleFunctionBlock(clang::MangleContext&, llvm::StringRef, clang::BlockDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN5clang13MangleContext15mangleDtorBlockEPKNS_17CXXDestructorDeclENS_11CXXDtorTypeEPKNS_9BlockDeclERN4llvm15SmallVectorImplIcEE", "clang::MangleContext::mangleDtorBlock(clang::CXXDestructorDecl const*, clang::CXXDtorType, clang::BlockDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN5clang13MangleContext11mangleBlockEPKNS_11DeclContextEPKNS_9BlockDeclERN4llvm15SmallVectorImplIcEE", "clang::MangleContext::mangleBlock(clang::DeclContext const*, clang::BlockDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN5clang13MangleContext20mangleObjCMethodNameEPKNS_14ObjCMethodDeclERN4llvm15SmallVectorImplIcEE", "clang::MangleContext::mangleObjCMethodName(clang::ObjCMethodDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN5clang13MangleContext11mangleBlockEPKNS_9BlockDeclERN4llvm15SmallVectorImplIcEE", "clang::MangleContext::mangleBlock(clang::BlockDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN4llvm8DenseMapIPKN5clang9BlockDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE6insertERKSt4pairIS4_jE", "llvm::DenseMap<clang::BlockDecl const*, unsigned int, llvm::DenseMapInfo<clang::BlockDecl const*>, llvm::DenseMapInfo<unsigned int>>::insert(std::pair<clang::BlockDecl const*, unsigned int> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang9BlockDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE16InsertIntoBucketERKS4_RKjPSt4pairIS4_jE", "llvm::DenseMap<clang::BlockDecl const*, unsigned int, llvm::DenseMapInfo<clang::BlockDecl const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(clang::BlockDecl const* const&, unsigned int const&, std::pair<clang::BlockDecl const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang9BlockDeclEjNS_12DenseMapInfoIS4_EENS5_IjEEE4growEj", "llvm::DenseMap<clang::BlockDecl const*, unsigned int, llvm::DenseMapInfo<clang::BlockDecl const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN5clang21CreateMicrosoftCXXABIERNS_10ASTContextE", "clang::CreateMicrosoftCXXABI(clang::ASTContext&)"},
    {"_ZN12_GLOBAL__N_115MicrosoftCXXABID1Ev", "(anonymous namespace)::MicrosoftCXXABI::~MicrosoftCXXABI()"},
    {"_ZN12_GLOBAL__N_115MicrosoftCXXABID0Ev", "(anonymous namespace)::MicrosoftCXXABI::~MicrosoftCXXABI()"},
    {"_ZNK12_GLOBAL__N_115MicrosoftCXXABI20getMemberPointerSizeEPKN5clang17MemberPointerTypeE", "(anonymous namespace)::MicrosoftCXXABI::getMemberPointerSize(clang::MemberPointerType const*) const"},
    {"_ZNK12_GLOBAL__N_115MicrosoftCXXABI24getDefaultMethodCallConvEv", "(anonymous namespace)::MicrosoftCXXABI::getDefaultMethodCallConv() const"},
    {"_ZNK12_GLOBAL__N_115MicrosoftCXXABI13isNearlyEmptyEPKN5clang13CXXRecordDeclE", "(anonymous namespace)::MicrosoftCXXABI::isNearlyEmpty(clang::CXXRecordDecl const*) const"},
    {"_ZN5clang28createMicrosoftMangleContextERNS_10ASTContextERNS_10DiagnosticE", "clang::createMicrosoftMangleContext(clang::ASTContext&, clang::Diagnostic&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContextD1Ev", "(anonymous namespace)::MicrosoftMangleContext::~MicrosoftMangleContext()"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContextD0Ev", "(anonymous namespace)::MicrosoftMangleContext::~MicrosoftMangleContext()"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext20shouldMangleDeclNameEPKN5clang9NamedDeclE", "(anonymous namespace)::MicrosoftMangleContext::shouldMangleDeclName(clang::NamedDecl const*)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext10mangleNameEPKN5clang9NamedDeclERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleName(clang::NamedDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext11mangleThunkEPKN5clang13CXXMethodDeclERKNS1_9ThunkInfoERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleThunk(clang::CXXMethodDecl const*, clang::ThunkInfo const&, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext18mangleCXXDtorThunkEPKN5clang17CXXDestructorDeclENS1_11CXXDtorTypeERKNS1_14ThisAdjustmentERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleCXXDtorThunk(clang::CXXDestructorDecl const*, clang::CXXDtorType, clang::ThisAdjustment const&, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext24mangleReferenceTemporaryEPKN5clang7VarDeclERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleReferenceTemporary(clang::VarDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext15mangleCXXVTableEPKN5clang13CXXRecordDeclERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleCXXVTable(clang::CXXRecordDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext12mangleCXXVTTEPKN5clang13CXXRecordDeclERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleCXXVTT(clang::CXXRecordDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext19mangleCXXCtorVTableEPKN5clang13CXXRecordDeclExS4_RN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleCXXCtorVTable(clang::CXXRecordDecl const*, long long, clang::CXXRecordDecl const*, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext13mangleCXXRTTIEN5clang8QualTypeERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleCXXRTTI(clang::QualType, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext17mangleCXXRTTINameEN5clang8QualTypeERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleCXXRTTIName(clang::QualType, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext13mangleCXXCtorEPKN5clang18CXXConstructorDeclENS1_11CXXCtorTypeERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleCXXCtor(clang::CXXConstructorDecl const*, clang::CXXCtorType, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_122MicrosoftMangleContext13mangleCXXDtorEPKN5clang17CXXDestructorDeclENS1_11CXXDtorTypeERN4llvm15SmallVectorImplIcEE", "(anonymous namespace)::MicrosoftMangleContext::mangleCXXDtor(clang::CXXDestructorDecl const*, clang::CXXDtorType, llvm::SmallVectorImpl<char>&)"},
    {"_ZN12_GLOBAL__N_123MicrosoftCXXNameMangler10mangleNameEPKN5clang9NamedDeclE", "(anonymous namespace)::MicrosoftCXXNameMangler::mangleName(clang::NamedDecl const*)"},
    {"_ZN12_GLOBAL__N_123MicrosoftCXXNameMangler10mangleTypeEN5clang8QualTypeE", "(anonymous namespace)::MicrosoftCXXNameMangler::mangleType(clang::QualType)"},
    {"_ZN12_GLOBAL__N_123MicrosoftCXXNameMangler16mangleQualifiersEN5clang10QualifiersEb", "(anonymous namespace)::MicrosoftCXXNameMangler::mangleQualifiers(clang::Qualifiers, bool)"},
    {"_ZN12_GLOBAL__N_123MicrosoftCXXNameMangler21mangleExtraDimensionsEN5clang8QualTypeE", "(anonymous namespace)::MicrosoftCXXNameMangler::mangleExtraDimensions(clang::QualType)"},
    {"_ZN12_GLOBAL__N_123MicrosoftCXXNameMangler12mangleNumberEx", "(anonymous namespace)::MicrosoftCXXNameMangler::mangleNumber(long long)"},
    {"_ZN12_GLOBAL__N_123MicrosoftCXXNameMangler10mangleTypeEPKN5clang7TagTypeE", "(anonymous namespace)::MicrosoftCXXNameMangler::mangleType(clang::TagType const*)"},
    {"_ZN12_GLOBAL__N_123MicrosoftCXXNameMangler10mangleTypeEPKN5clang12FunctionTypeEPKNS1_12FunctionDeclEbb", "(anonymous namespace)::MicrosoftCXXNameMangler::mangleType(clang::FunctionType const*, clang::FunctionDecl const*, bool, bool)"},
    {"_ZN12_GLOBAL__N_123MicrosoftCXXNameMangler21mangleUnqualifiedNameEPKN5clang9NamedDeclE", "(anonymous namespace)::MicrosoftCXXNameMangler::mangleUnqualifiedName(clang::NamedDecl const*)"},
    {"_ZN12_GLOBAL__N_123MicrosoftCXXNameMangler13manglePostfixEPKN5clang11DeclContextEb", "(anonymous namespace)::MicrosoftCXXNameMangler::manglePostfix(clang::DeclContext const*, bool)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_5APIntELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::APInt, false>::grow(unsigned long)"},
    {"_ZN5clang19NestedNameSpecifier12FindOrInsertERKNS_10ASTContextERKS0_", "clang::NestedNameSpecifier::FindOrInsert(clang::ASTContext const&, clang::NestedNameSpecifier const&)"},
    {"_ZN5clang19NestedNameSpecifier6CreateERKNS_10ASTContextEPS0_PNS_14IdentifierInfoE", "clang::NestedNameSpecifier::Create(clang::ASTContext const&, clang::NestedNameSpecifier*, clang::IdentifierInfo*)"},
    {"_ZN5clang19NestedNameSpecifier6CreateERKNS_10ASTContextEPS0_PNS_13NamespaceDeclE", "clang::NestedNameSpecifier::Create(clang::ASTContext const&, clang::NestedNameSpecifier*, clang::NamespaceDecl*)"},
    {"_ZN5clang19NestedNameSpecifier6CreateERKNS_10ASTContextEPS0_bPKNS_4TypeE", "clang::NestedNameSpecifier::Create(clang::ASTContext const&, clang::NestedNameSpecifier*, bool, clang::Type const*)"},
    {"_ZN5clang19NestedNameSpecifier6CreateERKNS_10ASTContextEPNS_14IdentifierInfoE", "clang::NestedNameSpecifier::Create(clang::ASTContext const&, clang::IdentifierInfo*)"},
    {"_ZN5clang19NestedNameSpecifier15GlobalSpecifierERKNS_10ASTContextE", "clang::NestedNameSpecifier::GlobalSpecifier(clang::ASTContext const&)"},
    {"_ZNK5clang19NestedNameSpecifier11isDependentEv", "clang::NestedNameSpecifier::isDependent() const"},
    {"_ZNK5clang19NestedNameSpecifier31containsUnexpandedParameterPackEv", "clang::NestedNameSpecifier::containsUnexpandedParameterPack() const"},
    {"_ZNK5clang19NestedNameSpecifier5printERN4llvm11raw_ostreamERKNS_14PrintingPolicyE", "clang::NestedNameSpecifier::print(llvm::raw_ostream&, clang::PrintingPolicy const&) const"},
    {"_ZN5clang19NestedNameSpecifier4dumpERKNS_11LangOptionsE", "clang::NestedNameSpecifier::dump(clang::LangOptions const&)"},
    {"_ZN5clang9ParentMapC1EPNS_4StmtE", "clang::ParentMap::ParentMap(clang::Stmt*)"},
    {"_ZN5clang9ParentMapC2EPNS_4StmtE", "clang::ParentMap::ParentMap(clang::Stmt*)"},
    {"_Z14BuildParentMapRN4llvm8DenseMapIPN5clang4StmtES3_NS_12DenseMapInfoIS3_EES5_EES3_", "BuildParentMap(llvm::DenseMap<clang::Stmt*, clang::Stmt*, llvm::DenseMapInfo<clang::Stmt*>, llvm::DenseMapInfo<clang::Stmt*>>&, clang::Stmt*)"},
    {"_ZN5clang9ParentMapD1Ev", "clang::ParentMap::~ParentMap()"},
    {"_ZN5clang9ParentMapD2Ev", "clang::ParentMap::~ParentMap()"},
    {"_ZN5clang9ParentMap7addStmtEPNS_4StmtE", "clang::ParentMap::addStmt(clang::Stmt*)"},
    {"_ZNK5clang9ParentMap9getParentEPNS_4StmtE", "clang::ParentMap::getParent(clang::Stmt*) const"},
    {"_ZNK5clang9ParentMap21getParentIgnoreParensEPNS_4StmtE", "clang::ParentMap::getParentIgnoreParens(clang::Stmt*) const"},
    {"_ZNK5clang9ParentMap14isConsumedExprEPNS_4ExprE", "clang::ParentMap::isConsumedExpr(clang::Expr*) const"},
    {"_ZN5clang15ASTRecordLayout7DestroyERNS_10ASTContextE", "clang::ASTRecordLayout::Destroy(clang::ASTContext&)"},
    {"_ZN5clang15ASTRecordLayoutC1ERKNS_10ASTContextENS_9CharUnitsEjjPKyj", "clang::ASTRecordLayout::ASTRecordLayout(clang::ASTContext const&, clang::CharUnits, unsigned int, unsigned int, unsigned long long const*, unsigned int)"},
    {"_ZN5clang15ASTRecordLayoutC2ERKNS_10ASTContextENS_9CharUnitsEjjPKyj", "clang::ASTRecordLayout::ASTRecordLayout(clang::ASTContext const&, clang::CharUnits, unsigned int, unsigned int, unsigned long long const*, unsigned int)"},
    {"_ZN5clang15ASTRecordLayoutC1ERKNS_10ASTContextENS_9CharUnitsEjyPKyjS4_S4_S4_PKNS_13CXXRecordDeclEbRKN4llvm8DenseMapIS9_S4_NSA_12DenseMapInfoIS9_EENSC_IS4_EEEESH_", "clang::ASTRecordLayout::ASTRecordLayout(clang::ASTContext const&, clang::CharUnits, unsigned int, unsigned long long, unsigned long long const*, unsigned int, clang::CharUnits, clang::CharUnits, clang::CharUnits, clang::CXXRecordDecl const*, bool, llvm::DenseMap<clang::CXXRecordDecl const*, clang::CharUnits, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CharUnits>> const&, llvm::DenseMap<clang::CXXRecordDecl const*, clang::CharUnits, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CharUnits>> const&)"},
    {"_ZN5clang15ASTRecordLayoutC2ERKNS_10ASTContextENS_9CharUnitsEjyPKyjS4_S4_S4_PKNS_13CXXRecordDeclEbRKN4llvm8DenseMapIS9_S4_NSA_12DenseMapInfoIS9_EENSC_IS4_EEEESH_", "clang::ASTRecordLayout::ASTRecordLayout(clang::ASTContext const&, clang::CharUnits, unsigned int, unsigned long long, unsigned long long const*, unsigned int, clang::CharUnits, clang::CharUnits, clang::CharUnits, clang::CXXRecordDecl const*, bool, llvm::DenseMap<clang::CXXRecordDecl const*, clang::CharUnits, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CharUnits>> const&, llvm::DenseMap<clang::CXXRecordDecl const*, clang::CharUnits, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CharUnits>> const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS1_9CharUnitsENS_12DenseMapInfoIS4_EENS6_IS5_EEE8CopyFromERKS9_", "llvm::DenseMap<clang::CXXRecordDecl const*, clang::CharUnits, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CharUnits>>::CopyFrom(llvm::DenseMap<clang::CXXRecordDecl const*, clang::CharUnits, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CharUnits>> const&)"},
    {"_ZNK5clang10ASTContext18getASTRecordLayoutEPKNS_10RecordDeclE", "clang::ASTContext::getASTRecordLayout(clang::RecordDecl const*) const"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilderD1Ev", "(anonymous namespace)::RecordLayoutBuilder::~RecordLayoutBuilder()"},
    {"_ZNK5clang10ASTContext16DumpRecordLayoutEPKNS_10RecordDeclERN4llvm11raw_ostreamE", "clang::ASTContext::DumpRecordLayout(clang::RecordDecl const*, llvm::raw_ostream&) const"},
    {"_ZN5clang10ASTContext14getKeyFunctionEPKNS_13CXXRecordDeclE", "clang::ASTContext::getKeyFunction(clang::CXXRecordDecl const*)"},
    {"_ZNK5clang10ASTContext13getObjCLayoutEPKNS_17ObjCInterfaceDeclEPKNS_22ObjCImplementationDeclE", "clang::ASTContext::getObjCLayout(clang::ObjCInterfaceDecl const*, clang::ObjCImplementationDecl const*) const"},
    {"_Z19DumpCXXRecordLayoutRN4llvm11raw_ostreamEPKN5clang13CXXRecordDeclERKNS2_10ASTContextENS2_9CharUnitsEjPKcb", "DumpCXXRecordLayout(llvm::raw_ostream&, clang::CXXRecordDecl const*, clang::ASTContext const&, clang::CharUnits, unsigned int, char const*, bool)"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilder16InitializeLayoutEPKN5clang4DeclE", "(anonymous namespace)::RecordLayoutBuilder::InitializeLayout(clang::Decl const*)"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilder11LayoutFieldEPKN5clang9FieldDeclE", "(anonymous namespace)::RecordLayoutBuilder::LayoutField(clang::FieldDecl const*)"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilder12FinishLayoutEPKN5clang9NamedDeclE", "(anonymous namespace)::RecordLayoutBuilder::FinishLayout(clang::NamedDecl const*)"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilder17CheckFieldPaddingEyyyjbPKN5clang9FieldDeclE", "(anonymous namespace)::RecordLayoutBuilder::CheckFieldPadding(unsigned long long, unsigned long long, unsigned long long, unsigned int, bool, clang::FieldDecl const*)"},
    {"_ZNK12_GLOBAL__N_117EmptySubobjectMap30CanPlaceFieldSubobjectAtOffsetEPKN5clang9FieldDeclENS1_9CharUnitsE", "(anonymous namespace)::EmptySubobjectMap::CanPlaceFieldSubobjectAtOffset(clang::FieldDecl const*, clang::CharUnits) const"},
    {"_ZN12_GLOBAL__N_117EmptySubobjectMap26UpdateEmptyFieldSubobjectsEPKN5clang9FieldDeclENS1_9CharUnitsE", "(anonymous namespace)::EmptySubobjectMap::UpdateEmptyFieldSubobjects(clang::FieldDecl const*, clang::CharUnits)"},
    {"_ZN12_GLOBAL__N_117EmptySubobjectMap26UpdateEmptyFieldSubobjectsEPKN5clang13CXXRecordDeclES4_NS1_9CharUnitsE", "(anonymous namespace)::EmptySubobjectMap::UpdateEmptyFieldSubobjects(clang::CXXRecordDecl const*, clang::CXXRecordDecl const*, clang::CharUnits)"},
    {"_ZN12_GLOBAL__N_117EmptySubobjectMap20AddSubobjectAtOffsetEPKN5clang13CXXRecordDeclENS1_9CharUnitsE", "(anonymous namespace)::EmptySubobjectMap::AddSubobjectAtOffset(clang::CXXRecordDecl const*, clang::CharUnits)"},
    {"_ZNK12_GLOBAL__N_117EmptySubobjectMap30CanPlaceFieldSubobjectAtOffsetEPKN5clang13CXXRecordDeclES4_NS1_9CharUnitsE", "(anonymous namespace)::EmptySubobjectMap::CanPlaceFieldSubobjectAtOffset(clang::CXXRecordDecl const*, clang::CXXRecordDecl const*, clang::CharUnits) const"},
    {"_ZNK12_GLOBAL__N_117EmptySubobjectMap25CanPlaceSubobjectAtOffsetEPKN5clang13CXXRecordDeclENS1_9CharUnitsE", "(anonymous namespace)::EmptySubobjectMap::CanPlaceSubobjectAtOffset(clang::CXXRecordDecl const*, clang::CharUnits) const"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilderD2Ev", "(anonymous namespace)::RecordLayoutBuilder::~RecordLayoutBuilder()"},
    {"_ZNK12_GLOBAL__N_119RecordLayoutBuilder22GetVirtualPointersSizeEPKN5clang13CXXRecordDeclE", "(anonymous namespace)::RecordLayoutBuilder::GetVirtualPointersSize(clang::CXXRecordDecl const*) const"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilderD0Ev", "(anonymous namespace)::RecordLayoutBuilder::~RecordLayoutBuilder()"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilder18LayoutVirtualBasesEPKN5clang13CXXRecordDeclES4_", "(anonymous namespace)::RecordLayoutBuilder::LayoutVirtualBases(clang::CXXRecordDecl const*, clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilder10LayoutBaseEPKNS_17BaseSubobjectInfoE", "(anonymous namespace)::RecordLayoutBuilder::LayoutBase((anonymous namespace)::BaseSubobjectInfo const*)"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilder28AddPrimaryVirtualBaseOffsetsEPKNS_17BaseSubobjectInfoEN5clang9CharUnitsE", "(anonymous namespace)::RecordLayoutBuilder::AddPrimaryVirtualBaseOffsets((anonymous namespace)::BaseSubobjectInfo const*, clang::CharUnits)"},
    {"_ZN12_GLOBAL__N_117EmptySubobjectMap29CanPlaceBaseSubobjectAtOffsetEPKNS_17BaseSubobjectInfoEN5clang9CharUnitsE", "(anonymous namespace)::EmptySubobjectMap::CanPlaceBaseSubobjectAtOffset((anonymous namespace)::BaseSubobjectInfo const*, clang::CharUnits)"},
    {"_ZN12_GLOBAL__N_117EmptySubobjectMap25UpdateEmptyBaseSubobjectsEPKNS_17BaseSubobjectInfoEN5clang9CharUnitsEb", "(anonymous namespace)::EmptySubobjectMap::UpdateEmptyBaseSubobjects((anonymous namespace)::BaseSubobjectInfo const*, clang::CharUnits, bool)"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilder24ComputeBaseSubobjectInfoEPKN5clang13CXXRecordDeclE", "(anonymous namespace)::RecordLayoutBuilder::ComputeBaseSubobjectInfo(clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilder24ComputeBaseSubobjectInfoEPKN5clang13CXXRecordDeclEbPNS_17BaseSubobjectInfoE", "(anonymous namespace)::RecordLayoutBuilder::ComputeBaseSubobjectInfo(clang::CXXRecordDecl const*, bool, (anonymous namespace)::BaseSubobjectInfo*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEPN12_GLOBAL__N_117BaseSubobjectInfoENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::CXXRecordDecl const*, (anonymous namespace)::BaseSubobjectInfo*, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<(anonymous namespace)::BaseSubobjectInfo*>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, (anonymous namespace)::BaseSubobjectInfo* const&, std::pair<clang::CXXRecordDecl const*, (anonymous namespace)::BaseSubobjectInfo*>*)"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilder18SelectPrimaryVBaseEPKN5clang13CXXRecordDeclE", "(anonymous namespace)::RecordLayoutBuilder::SelectPrimaryVBase(clang::CXXRecordDecl const*)"},
    {"_ZN12_GLOBAL__N_119RecordLayoutBuilderC2ERKN5clang10ASTContextEPNS_17EmptySubobjectMapE", "(anonymous namespace)::RecordLayoutBuilder::RecordLayoutBuilder(clang::ASTContext const&, (anonymous namespace)::EmptySubobjectMap*)"},
    {"_ZNK12_GLOBAL__N_121MSRecordLayoutBuilder22GetVirtualPointersSizeEPKN5clang13CXXRecordDeclE", "(anonymous namespace)::MSRecordLayoutBuilder::GetVirtualPointersSize(clang::CXXRecordDecl const*) const"},
    {"_ZN12_GLOBAL__N_121MSRecordLayoutBuilderD1Ev", "(anonymous namespace)::MSRecordLayoutBuilder::~MSRecordLayoutBuilder()"},
    {"_ZN12_GLOBAL__N_121MSRecordLayoutBuilderD0Ev", "(anonymous namespace)::MSRecordLayoutBuilder::~MSRecordLayoutBuilder()"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEPKNS1_13CXXMethodDeclENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::CXXRecordDecl const*, clang::CXXMethodDecl const*, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CXXMethodDecl const*>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, clang::CXXMethodDecl const* const&, std::pair<clang::CXXRecordDecl const*, clang::CXXMethodDecl const*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclEPKNS1_13CXXMethodDeclENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, clang::CXXMethodDecl const*, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CXXMethodDecl const*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang10RecordDeclEPKNS1_15ASTRecordLayoutENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::RecordDecl const*, clang::ASTRecordLayout const*, llvm::DenseMapInfo<clang::RecordDecl const*>, llvm::DenseMapInfo<clang::ASTRecordLayout const*>>::InsertIntoBucket(clang::RecordDecl const* const&, clang::ASTRecordLayout const* const&, std::pair<clang::RecordDecl const*, clang::ASTRecordLayout const*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang10RecordDeclEPKNS1_15ASTRecordLayoutENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::RecordDecl const*, clang::ASTRecordLayout const*, llvm::DenseMapInfo<clang::RecordDecl const*>, llvm::DenseMapInfo<clang::ASTRecordLayout const*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang17ObjCContainerDeclEPKNS1_15ASTRecordLayoutENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::ObjCContainerDecl const*, clang::ASTRecordLayout const*, llvm::DenseMapInfo<clang::ObjCContainerDecl const*>, llvm::DenseMapInfo<clang::ASTRecordLayout const*>>::InsertIntoBucket(clang::ObjCContainerDecl const* const&, clang::ASTRecordLayout const* const&, std::pair<clang::ObjCContainerDecl const*, clang::ASTRecordLayout const*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang17ObjCContainerDeclEPKNS1_15ASTRecordLayoutENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::ObjCContainerDecl const*, clang::ASTRecordLayout const*, llvm::DenseMapInfo<clang::ObjCContainerDecl const*>, llvm::DenseMapInfo<clang::ASTRecordLayout const*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS1_9CharUnitsENS_12DenseMapInfoIS4_EENS6_IS5_EEE16InsertIntoBucketERKS4_RKS5_PSt4pairIS4_S5_E", "llvm::DenseMap<clang::CXXRecordDecl const*, clang::CharUnits, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CharUnits>>::InsertIntoBucket(clang::CXXRecordDecl const* const&, clang::CharUnits const&, std::pair<clang::CXXRecordDecl const*, clang::CharUnits>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS1_9CharUnitsENS_12DenseMapInfoIS4_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::CXXRecordDecl const*, clang::CharUnits, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CharUnits>>::grow(unsigned int)"},
    {"_ZSt6__findIPPKN5clang13CXXRecordDeclES3_ET_S5_S5_RKT0_St26random_access_iterator_tag", "clang::CXXRecordDecl const** std::__find<clang::CXXRecordDecl const**, clang::CXXRecordDecl const*>(clang::CXXRecordDecl const**, clang::CXXRecordDecl const**, clang::CXXRecordDecl const* const&, std::random_access_iterator_tag)"},
    {"_ZN4llvm8DenseMapIN5clang9CharUnitsENS_11SmallVectorIPKNS1_13CXXRecordDeclELj1EEENS_12DenseMapInfoIS2_EENS8_IS7_EEE16FindAndConstructERKS2_", "llvm::DenseMap<clang::CharUnits, llvm::SmallVector<clang::CXXRecordDecl const*, 1u>, llvm::DenseMapInfo<clang::CharUnits>, llvm::DenseMapInfo<llvm::SmallVector<clang::CXXRecordDecl const*, 1u>>>::FindAndConstruct(clang::CharUnits const&)"},
    {"_ZN4llvm8DenseMapIN5clang9CharUnitsENS_11SmallVectorIPKNS1_13CXXRecordDeclELj1EEENS_12DenseMapInfoIS2_EENS8_IS7_EEE16InsertIntoBucketERKS2_RKS7_PSt4pairIS2_S7_E", "llvm::DenseMap<clang::CharUnits, llvm::SmallVector<clang::CXXRecordDecl const*, 1u>, llvm::DenseMapInfo<clang::CharUnits>, llvm::DenseMapInfo<llvm::SmallVector<clang::CXXRecordDecl const*, 1u>>>::InsertIntoBucket(clang::CharUnits const&, llvm::SmallVector<clang::CXXRecordDecl const*, 1u> const&, std::pair<clang::CharUnits, llvm::SmallVector<clang::CXXRecordDecl const*, 1u>>*)"},
    {"_ZN4llvm8DenseMapIN5clang9CharUnitsENS_11SmallVectorIPKNS1_13CXXRecordDeclELj1EEENS_12DenseMapInfoIS2_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::CharUnits, llvm::SmallVector<clang::CXXRecordDecl const*, 1u>, llvm::DenseMapInfo<clang::CharUnits>, llvm::DenseMapInfo<llvm::SmallVector<clang::CXXRecordDecl const*, 1u>>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIPKN5clang13CXXRecordDeclEEaSERKS5_", "llvm::SmallVectorImpl<clang::CXXRecordDecl const*>::operator=(llvm::SmallVectorImpl<clang::CXXRecordDecl const*> const&)"},
    {"_ZSt6__findIPKPKN5clang13CXXRecordDeclES3_ET_S6_S6_RKT0_St26random_access_iterator_tag", "clang::CXXRecordDecl const* const* std::__find<clang::CXXRecordDecl const* const*, clang::CXXRecordDecl const*>(clang::CXXRecordDecl const* const*, clang::CXXRecordDecl const* const*, clang::CXXRecordDecl const* const&, std::random_access_iterator_tag)"},
    {"_ZNK5clang4Decl7getAttrINS_21MaxFieldAlignmentAttrEEEPT_v", "clang::MaxFieldAlignmentAttr* clang::Decl::getAttr<clang::MaxFieldAlignmentAttr>() const"},
    {"_ZN4llvm8DenseMapIPKN5clang13CXXRecordDeclENS1_9CharUnitsENS_12DenseMapInfoIS4_EENS6_IS5_EEE6insertERKSt4pairIS4_S5_E", "llvm::DenseMap<clang::CXXRecordDecl const*, clang::CharUnits, llvm::DenseMapInfo<clang::CXXRecordDecl const*>, llvm::DenseMapInfo<clang::CharUnits>>::insert(std::pair<clang::CXXRecordDecl const*, clang::CharUnits> const&)"},
    {"_ZNK5clang4Stmt16getStmtClassNameEv", "clang::Stmt::getStmtClassName() const"},
    {"_Z21getStmtInfoTableEntryN5clang4Stmt9StmtClassE", "getStmtInfoTableEntry(clang::Stmt::StmtClass)"},
    {"_ZN5clang4Stmt10PrintStatsEv", "clang::Stmt::PrintStats()"},
    {"_ZN5clang4Stmt12addStmtClassENS0_9StmtClassE", "clang::Stmt::addStmtClass(clang::Stmt::StmtClass)"},
    {"_ZN5clang4Stmt15CollectingStatsEb", "clang::Stmt::CollectingStats(bool)"},
    {"_ZN5clang4Stmt8childrenEv", "clang::Stmt::children()"},
    {"_ZNK5clang4Stmt14getSourceRangeEv", "clang::Stmt::getSourceRange() const"},
    {"_ZNK5clang13ObjCAtTryStmt14getSourceRangeEv", "clang::ObjCAtTryStmt::getSourceRange() const"},
    {"_ZNK5clang10ReturnStmt14getSourceRangeEv", "clang::ReturnStmt::getSourceRange() const"},
    {"_ZN5clang12CompoundStmt8setStmtsERNS_10ASTContextEPPNS_4StmtEj", "clang::CompoundStmt::setStmts(clang::ASTContext&, clang::Stmt**, unsigned int)"},
    {"_ZNK5clang9LabelStmt7getNameEv", "clang::LabelStmt::getName() const"},
    {"_ZNK5clang4Stmt22hasImplicitControlFlowEv", "clang::Stmt::hasImplicitControlFlow() const"},
    {"_ZN5clang7AsmStmt13getOutputExprEj", "clang::AsmStmt::getOutputExpr(unsigned int)"},
    {"_ZNK5clang7AsmStmt19getOutputConstraintEj", "clang::AsmStmt::getOutputConstraint(unsigned int) const"},
    {"_ZNK5clang7AsmStmt18getNumPlusOperandsEv", "clang::AsmStmt::getNumPlusOperands() const"},
    {"_ZN5clang7AsmStmt12getInputExprEj", "clang::AsmStmt::getInputExpr(unsigned int)"},
    {"_ZNK5clang7AsmStmt18getInputConstraintEj", "clang::AsmStmt::getInputConstraint(unsigned int) const"},
    {"_ZN5clang7AsmStmt30setOutputsAndInputsAndClobbersERNS_10ASTContextEPPNS_14IdentifierInfoEPPNS_13StringLiteralEPPNS_4StmtEjjS8_j", "clang::AsmStmt::setOutputsAndInputsAndClobbers(clang::ASTContext&, clang::IdentifierInfo**, clang::StringLiteral**, clang::Stmt**, unsigned int, unsigned int, clang::StringLiteral**, unsigned int)"},
    {"_ZNK5clang7AsmStmt15getNamedOperandEN4llvm9StringRefE", "clang::AsmStmt::getNamedOperand(llvm::StringRef) const"},
    {"_ZNK5clang7AsmStmt16AnalyzeAsmStringERN4llvm15SmallVectorImplINS0_14AsmStringPieceEEERNS_10ASTContextERj", "clang::AsmStmt::AnalyzeAsmString(llvm::SmallVectorImpl<clang::AsmStmt::AsmStringPiece>&, clang::ASTContext&, unsigned int&) const"},
    {"_ZNK5clang12CXXCatchStmt13getCaughtTypeEv", "clang::CXXCatchStmt::getCaughtType() const"},
    {"_ZN5clang7AsmStmtC1ERNS_10ASTContextENS_14SourceLocationEbbbjjPPNS_14IdentifierInfoEPPNS_13StringLiteralEPPNS_4ExprES8_jS9_S3_", "clang::AsmStmt::AsmStmt(clang::ASTContext&, clang::SourceLocation, bool, bool, bool, unsigned int, unsigned int, clang::IdentifierInfo**, clang::StringLiteral**, clang::Expr**, clang::StringLiteral*, unsigned int, clang::StringLiteral**, clang::SourceLocation)"},
    {"_ZN5clang7AsmStmtC2ERNS_10ASTContextENS_14SourceLocationEbbbjjPPNS_14IdentifierInfoEPPNS_13StringLiteralEPPNS_4ExprES8_jS9_S3_", "clang::AsmStmt::AsmStmt(clang::ASTContext&, clang::SourceLocation, bool, bool, bool, unsigned int, unsigned int, clang::IdentifierInfo**, clang::StringLiteral**, clang::Expr**, clang::StringLiteral*, unsigned int, clang::StringLiteral**, clang::SourceLocation)"},
    {"_ZN5clang21ObjCForCollectionStmtC1EPNS_4StmtEPNS_4ExprES2_NS_14SourceLocationES5_", "clang::ObjCForCollectionStmt::ObjCForCollectionStmt(clang::Stmt*, clang::Expr*, clang::Stmt*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang21ObjCForCollectionStmtC2EPNS_4StmtEPNS_4ExprES2_NS_14SourceLocationES5_", "clang::ObjCForCollectionStmt::ObjCForCollectionStmt(clang::Stmt*, clang::Expr*, clang::Stmt*, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang13ObjCAtTryStmtC1ENS_14SourceLocationEPNS_4StmtEPS3_jS3_", "clang::ObjCAtTryStmt::ObjCAtTryStmt(clang::SourceLocation, clang::Stmt*, clang::Stmt**, unsigned int, clang::Stmt*)"},
    {"_ZN5clang13ObjCAtTryStmtC2ENS_14SourceLocationEPNS_4StmtEPS3_jS3_", "clang::ObjCAtTryStmt::ObjCAtTryStmt(clang::SourceLocation, clang::Stmt*, clang::Stmt**, unsigned int, clang::Stmt*)"},
    {"_ZN5clang13ObjCAtTryStmt6CreateERNS_10ASTContextENS_14SourceLocationEPNS_4StmtEPS5_jS5_", "clang::ObjCAtTryStmt::Create(clang::ASTContext&, clang::SourceLocation, clang::Stmt*, clang::Stmt**, unsigned int, clang::Stmt*)"},
    {"_ZN5clang13ObjCAtTryStmt11CreateEmptyERNS_10ASTContextEjb", "clang::ObjCAtTryStmt::CreateEmpty(clang::ASTContext&, unsigned int, bool)"},
    {"_ZN5clang10CXXTryStmt6CreateERNS_10ASTContextENS_14SourceLocationEPNS_4StmtEPS5_j", "clang::CXXTryStmt::Create(clang::ASTContext&, clang::SourceLocation, clang::Stmt*, clang::Stmt**, unsigned int)"},
    {"_ZN5clang10CXXTryStmtC1ENS_14SourceLocationEPNS_4StmtEPS3_j", "clang::CXXTryStmt::CXXTryStmt(clang::SourceLocation, clang::Stmt*, clang::Stmt**, unsigned int)"},
    {"_ZN5clang10CXXTryStmt6CreateERNS_10ASTContextENS_4Stmt10EmptyShellEj", "clang::CXXTryStmt::Create(clang::ASTContext&, clang::Stmt::EmptyShell, unsigned int)"},
    {"_ZN5clang10CXXTryStmtC2ENS_14SourceLocationEPNS_4StmtEPS3_j", "clang::CXXTryStmt::CXXTryStmt(clang::SourceLocation, clang::Stmt*, clang::Stmt**, unsigned int)"},
    {"_ZN5clang6IfStmtC1ERNS_10ASTContextENS_14SourceLocationEPNS_7VarDeclEPNS_4ExprEPNS_4StmtES3_S9_", "clang::IfStmt::IfStmt(clang::ASTContext&, clang::SourceLocation, clang::VarDecl*, clang::Expr*, clang::Stmt*, clang::SourceLocation, clang::Stmt*)"},
    {"_ZN5clang6IfStmtC2ERNS_10ASTContextENS_14SourceLocationEPNS_7VarDeclEPNS_4ExprEPNS_4StmtES3_S9_", "clang::IfStmt::IfStmt(clang::ASTContext&, clang::SourceLocation, clang::VarDecl*, clang::Expr*, clang::Stmt*, clang::SourceLocation, clang::Stmt*)"},
    {"_ZN5clang6IfStmt20setConditionVariableERNS_10ASTContextEPNS_7VarDeclE", "clang::IfStmt::setConditionVariable(clang::ASTContext&, clang::VarDecl*)"},
    {"_ZNK5clang6IfStmt20getConditionVariableEv", "clang::IfStmt::getConditionVariable() const"},
    {"_ZN5clang7ForStmtC1ERNS_10ASTContextEPNS_4StmtEPNS_4ExprEPNS_7VarDeclES6_S4_NS_14SourceLocationES9_S9_", "clang::ForStmt::ForStmt(clang::ASTContext&, clang::Stmt*, clang::Expr*, clang::VarDecl*, clang::Expr*, clang::Stmt*, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang7ForStmtC2ERNS_10ASTContextEPNS_4StmtEPNS_4ExprEPNS_7VarDeclES6_S4_NS_14SourceLocationES9_S9_", "clang::ForStmt::ForStmt(clang::ASTContext&, clang::Stmt*, clang::Expr*, clang::VarDecl*, clang::Expr*, clang::Stmt*, clang::SourceLocation, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang7ForStmt20setConditionVariableERNS_10ASTContextEPNS_7VarDeclE", "clang::ForStmt::setConditionVariable(clang::ASTContext&, clang::VarDecl*)"},
    {"_ZNK5clang7ForStmt20getConditionVariableEv", "clang::ForStmt::getConditionVariable() const"},
    {"_ZN5clang10SwitchStmtC1ERNS_10ASTContextEPNS_7VarDeclEPNS_4ExprE", "clang::SwitchStmt::SwitchStmt(clang::ASTContext&, clang::VarDecl*, clang::Expr*)"},
    {"_ZN5clang10SwitchStmtC2ERNS_10ASTContextEPNS_7VarDeclEPNS_4ExprE", "clang::SwitchStmt::SwitchStmt(clang::ASTContext&, clang::VarDecl*, clang::Expr*)"},
    {"_ZN5clang10SwitchStmt20setConditionVariableERNS_10ASTContextEPNS_7VarDeclE", "clang::SwitchStmt::setConditionVariable(clang::ASTContext&, clang::VarDecl*)"},
    {"_ZNK5clang10SwitchStmt20getConditionVariableEv", "clang::SwitchStmt::getConditionVariable() const"},
    {"_ZN5clang10SwitchCase10getSubStmtEv", "clang::SwitchCase::getSubStmt()"},
    {"_ZN5clang9WhileStmtC1ERNS_10ASTContextEPNS_7VarDeclEPNS_4ExprEPNS_4StmtENS_14SourceLocationE", "clang::WhileStmt::WhileStmt(clang::ASTContext&, clang::VarDecl*, clang::Expr*, clang::Stmt*, clang::SourceLocation)"},
    {"_ZN5clang9WhileStmtC2ERNS_10ASTContextEPNS_7VarDeclEPNS_4ExprEPNS_4StmtENS_14SourceLocationE", "clang::WhileStmt::WhileStmt(clang::ASTContext&, clang::VarDecl*, clang::Expr*, clang::Stmt*, clang::SourceLocation)"},
    {"_ZN5clang9WhileStmt20setConditionVariableERNS_10ASTContextEPNS_7VarDeclE", "clang::WhileStmt::setConditionVariable(clang::ASTContext&, clang::VarDecl*)"},
    {"_ZNK5clang9WhileStmt20getConditionVariableEv", "clang::WhileStmt::getConditionVariable() const"},
    {"_ZN5clang16IndirectGotoStmt17getConstantTargetEv", "clang::IndirectGotoStmt::getConstantTarget()"},
    {"_ZNK5clang10ReturnStmt11getRetValueEv", "clang::ReturnStmt::getRetValue() const"},
    {"_ZN5clang10ReturnStmt11getRetValueEv", "clang::ReturnStmt::getRetValue()"},
    {"_ZN5clang8DeclStmt8childrenEv", "clang::DeclStmt::children()"},
    {"_ZNK5clang27CXXDependentScopeMemberExpr14getSourceRangeEv", "clang::CXXDependentScopeMemberExpr::getSourceRange() const"},
    {"_ZNK5clang10MemberExpr14getSourceRangeEv", "clang::MemberExpr::getSourceRange() const"},
    {"_ZNK5clang20UnresolvedMemberExpr14getSourceRangeEv", "clang::UnresolvedMemberExpr::getSourceRange() const"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang7AsmStmt14AsmStringPieceELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::AsmStmt::AsmStringPiece, false>::grow(unsigned long)"},
    {"_ZNK5clang4Stmt4dumpERNS_13SourceManagerE", "clang::Stmt::dump(clang::SourceManager&) const"},
    {"_ZNK5clang4Stmt4dumpERN4llvm11raw_ostreamERNS_13SourceManagerE", "clang::Stmt::dump(llvm::raw_ostream&, clang::SourceManager&) const"},
    {"_ZN12_GLOBAL__N_110StmtDumper11DumpSubTreeEPN5clang4StmtE", "(anonymous namespace)::StmtDumper::DumpSubTree(clang::Stmt*)"},
    {"_ZNK5clang4Stmt4dumpEv", "clang::Stmt::dump() const"},
    {"_ZNK5clang4Stmt7dumpAllERNS_13SourceManagerE", "clang::Stmt::dumpAll(clang::SourceManager&) const"},
    {"_ZNK5clang4Stmt7dumpAllEv", "clang::Stmt::dumpAll() const"},
    {"_ZN12_GLOBAL__N_110StmtDumper13VisitDeclStmtEPN5clang8DeclStmtE", "(anonymous namespace)::StmtDumper::VisitDeclStmt(clang::DeclStmt*)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_110StmtDumperEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::StmtDumper, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_110StmtDumper19VisitBinaryOperatorEPN5clang14BinaryOperatorE", "(anonymous namespace)::StmtDumper::VisitBinaryOperator(clang::BinaryOperator*)"},
    {"_ZN12_GLOBAL__N_110StmtDumper27VisitCompoundAssignOperatorEPN5clang22CompoundAssignOperatorE", "(anonymous namespace)::StmtDumper::VisitCompoundAssignOperator(clang::CompoundAssignOperator*)"},
    {"_ZN12_GLOBAL__N_110StmtDumper21VisitCXXConstructExprEPN5clang16CXXConstructExprE", "(anonymous namespace)::StmtDumper::VisitCXXConstructExpr(clang::CXXConstructExpr*)"},
    {"_ZN12_GLOBAL__N_110StmtDumper18VisitUnaryOperatorEPN5clang13UnaryOperatorE", "(anonymous namespace)::StmtDumper::VisitUnaryOperator(clang::UnaryOperator*)"},
    {"_ZN12_GLOBAL__N_110StmtDumper8DumpStmtEPKN5clang4StmtE", "(anonymous namespace)::StmtDumper::DumpStmt(clang::Stmt const*)"},
    {"_ZN12_GLOBAL__N_110StmtDumper12DumpLocationEN5clang14SourceLocationE", "(anonymous namespace)::StmtDumper::DumpLocation(clang::SourceLocation)"},
    {"_ZN12_GLOBAL__N_110StmtDumper14DumpDeclaratorEPN5clang4DeclE", "(anonymous namespace)::StmtDumper::DumpDeclarator(clang::Decl*)"},
    {"_ZN12_GLOBAL__N_110StmtDumper8DumpExprEPKN5clang4ExprE", "(anonymous namespace)::StmtDumper::DumpExpr(clang::Expr const*)"},
    {"_ZN12_GLOBAL__N_110StmtDumper8DumpTypeEN5clang8QualTypeE", "(anonymous namespace)::StmtDumper::DumpType(clang::QualType)"},
    {"_ZN12_GLOBAL__N_110StmtDumper11DumpDeclRefEPN5clang4DeclE", "(anonymous namespace)::StmtDumper::DumpDeclRef(clang::Decl*)"},
    {"_Z12DumpBasePathRN4llvm11raw_ostreamEPN5clang8CastExprE", "DumpBasePath(llvm::raw_ostream&, clang::CastExpr*)"},
    {"_ZN12_GLOBAL__N_110StmtDumper21VisitCXXNamedCastExprEPN5clang16CXXNamedCastExprE", "(anonymous namespace)::StmtDumper::VisitCXXNamedCastExpr(clang::CXXNamedCastExpr*)"},
    {"_ZN5clang16StmtIteratorBase6NextVAEv", "clang::StmtIteratorBase::NextVA()"},
    {"_ZN5clang16StmtIteratorBase8NextDeclEb", "clang::StmtIteratorBase::NextDecl(bool)"},
    {"_ZN5clang16StmtIteratorBase10HandleDeclEPNS_4DeclE", "clang::StmtIteratorBase::HandleDecl(clang::Decl*)"},
    {"_ZN5clang16StmtIteratorBaseC1EPNS_4DeclEPPNS_4StmtE", "clang::StmtIteratorBase::StmtIteratorBase(clang::Decl*, clang::Stmt**)"},
    {"_ZN5clang16StmtIteratorBaseC2EPNS_4DeclEPPNS_4StmtE", "clang::StmtIteratorBase::StmtIteratorBase(clang::Decl*, clang::Stmt**)"},
    {"_ZN5clang16StmtIteratorBaseC1EPPNS_4DeclES3_", "clang::StmtIteratorBase::StmtIteratorBase(clang::Decl**, clang::Decl**)"},
    {"_ZN5clang16StmtIteratorBaseC2EPPNS_4DeclES3_", "clang::StmtIteratorBase::StmtIteratorBase(clang::Decl**, clang::Decl**)"},
    {"_ZN5clang16StmtIteratorBaseC1EPKNS_17VariableArrayTypeE", "clang::StmtIteratorBase::StmtIteratorBase(clang::VariableArrayType const*)"},
    {"_ZN5clang16StmtIteratorBaseC2EPKNS_17VariableArrayTypeE", "clang::StmtIteratorBase::StmtIteratorBase(clang::VariableArrayType const*)"},
    {"_ZNK5clang16StmtIteratorBase11GetDeclExprEv", "clang::StmtIteratorBase::GetDeclExpr() const"},
    {"_ZNK5clang4Stmt10dumpPrettyERNS_10ASTContextE", "clang::Stmt::dumpPretty(clang::ASTContext&) const"},
    {"_ZNK5clang4Stmt11printPrettyERN4llvm11raw_ostreamERNS_10ASTContextEPNS_13PrinterHelperERKNS_14PrintingPolicyEj", "clang::Stmt::printPretty(llvm::raw_ostream&, clang::ASTContext&, clang::PrinterHelper*, clang::PrintingPolicy const&, unsigned int) const"},
    {"_ZN5clang13PrinterHelperD0Ev", "clang::PrinterHelper::~PrinterHelper()"},
    {"_ZN5clang13PrinterHelperD1Ev", "clang::PrinterHelper::~PrinterHelper()"},
    {"_ZN5clang13PrinterHelperD2Ev", "clang::PrinterHelper::~PrinterHelper()"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_111StmtPrinterEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::StmtPrinter, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter13VisitCallExprEPN5clang8CallExprE", "(anonymous namespace)::StmtPrinter::VisitCallExpr(clang::CallExpr*)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter18VisitStringLiteralEPN5clang13StringLiteralE", "(anonymous namespace)::StmtPrinter::VisitStringLiteral(clang::StringLiteral*)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter18VisitUnaryOperatorEPN5clang13UnaryOperatorE", "(anonymous namespace)::StmtPrinter::VisitUnaryOperator(clang::UnaryOperator*)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter9PrintExprEPN5clang4ExprE", "(anonymous namespace)::StmtPrinter::PrintExpr(clang::Expr*)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter9PrintStmtEPN5clang4StmtEi", "(anonymous namespace)::StmtPrinter::PrintStmt(clang::Stmt*, int)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter20PrintRawCompoundStmtEPN5clang12CompoundStmtE", "(anonymous namespace)::StmtPrinter::PrintRawCompoundStmt(clang::CompoundStmt*)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter16PrintRawDeclStmtEPN5clang8DeclStmtE", "(anonymous namespace)::StmtPrinter::PrintRawDeclStmt(clang::DeclStmt*)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter14PrintRawIfStmtEPN5clang6IfStmtE", "(anonymous namespace)::StmtPrinter::PrintRawIfStmt(clang::IfStmt*)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter21VisitCXXNamedCastExprEPN5clang16CXXNamedCastExprE", "(anonymous namespace)::StmtPrinter::VisitCXXNamedCastExpr(clang::CXXNamedCastExpr*)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter13PrintCallArgsEPN5clang8CallExprE", "(anonymous namespace)::StmtPrinter::PrintCallArgs(clang::CallExpr*)"},
    {"_ZN12_GLOBAL__N_111StmtPrinter20PrintRawCXXCatchStmtEPN5clang12CXXCatchStmtE", "(anonymous namespace)::StmtPrinter::PrintRawCXXCatchStmt(clang::CXXCatchStmt*)"},
    {"_ZN5clang4Stmt7ProfileERN4llvm16FoldingSetNodeIDERKNS_10ASTContextEb", "clang::Stmt::Profile(llvm::FoldingSetNodeID&, clang::ASTContext const&, bool)"},
    {"_ZN5clang11StmtVisitorIN12_GLOBAL__N_112StmtProfilerEvE5VisitEPNS_4StmtE", "clang::StmtVisitor<(anonymous namespace)::StmtProfiler, void>::Visit(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_112StmtProfiler17VisitInitListExprEPN5clang12InitListExprE", "(anonymous namespace)::StmtProfiler::VisitInitListExpr(clang::InitListExpr*)"},
    {"_ZN12_GLOBAL__N_112StmtProfiler9VisitStmtEPN5clang4StmtE", "(anonymous namespace)::StmtProfiler::VisitStmt(clang::Stmt*)"},
    {"_ZN12_GLOBAL__N_112StmtProfiler9VisitDeclEPN5clang4DeclE", "(anonymous namespace)::StmtProfiler::VisitDecl(clang::Decl*)"},
    {"_ZN12_GLOBAL__N_112StmtProfiler21VisitTemplateArgumentERKN5clang16TemplateArgumentE", "(anonymous namespace)::StmtProfiler::VisitTemplateArgument(clang::TemplateArgument const&)"},
    {"_ZNK5clang4Stmt7viewASTEv", "clang::Stmt::viewAST() const"},
    {"_ZN5clang16TemplateArgument14CreatePackCopyERNS_10ASTContextEPKS0_j", "clang::TemplateArgument::CreatePackCopy(clang::ASTContext&, clang::TemplateArgument const*, unsigned int)"},
    {"_ZNK5clang16TemplateArgument11isDependentEv", "clang::TemplateArgument::isDependent() const"},
    {"_ZNK5clang16TemplateArgument15isPackExpansionEv", "clang::TemplateArgument::isPackExpansion() const"},
    {"_ZNK5clang16TemplateArgument31containsUnexpandedParameterPackEv", "clang::TemplateArgument::containsUnexpandedParameterPack() const"},
    {"_ZNK5clang16TemplateArgument24getNumTemplateExpansionsEv", "clang::TemplateArgument::getNumTemplateExpansions() const"},
    {"_ZNK5clang16TemplateArgument7ProfileERN4llvm16FoldingSetNodeIDERKNS_10ASTContextE", "clang::TemplateArgument::Profile(llvm::FoldingSetNodeID&, clang::ASTContext const&) const"},
    {"_ZNK5clang16TemplateArgument18structurallyEqualsERKS0_", "clang::TemplateArgument::structurallyEquals(clang::TemplateArgument const&) const"},
    {"_ZNK5clang16TemplateArgument23getPackExpansionPatternEv", "clang::TemplateArgument::getPackExpansionPattern() const"},
    {"_ZNK5clang16TemplateArgument5printERKNS_14PrintingPolicyERN4llvm11raw_ostreamE", "clang::TemplateArgument::print(clang::PrintingPolicy const&, llvm::raw_ostream&) const"},
    {"_ZN5clang23TemplateArgumentLocInfoC1Ev", "clang::TemplateArgumentLocInfo::TemplateArgumentLocInfo()"},
    {"_ZN5clang23TemplateArgumentLocInfoC2Ev", "clang::TemplateArgumentLocInfo::TemplateArgumentLocInfo()"},
    {"_ZNK5clang19TemplateArgumentLoc14getSourceRangeEv", "clang::TemplateArgumentLoc::getSourceRange() const"},
    {"_ZNK5clang19TemplateArgumentLoc23getPackExpansionPatternERNS_14SourceLocationERN4llvm8OptionalIjEERNS_10ASTContextE", "clang::TemplateArgumentLoc::getPackExpansionPattern(clang::SourceLocation&, llvm::Optional<unsigned int>&, clang::ASTContext&) const"},
    {"_ZN5clanglsERKNS_17DiagnosticBuilderERKNS_16TemplateArgumentE", "clang::operator<<(clang::DiagnosticBuilder const&, clang::TemplateArgument const&)"},
    {"_ZNK5clang36SubstTemplateTemplateParmPackStorage15getArgumentPackEv", "clang::SubstTemplateTemplateParmPackStorage::getArgumentPack() const"},
    {"_ZN5clang36SubstTemplateTemplateParmPackStorage7ProfileERN4llvm16FoldingSetNodeIDE", "clang::SubstTemplateTemplateParmPackStorage::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang36SubstTemplateTemplateParmPackStorage7ProfileERN4llvm16FoldingSetNodeIDERNS_10ASTContextEPNS_24TemplateTemplateParmDeclERKNS_16TemplateArgumentE", "clang::SubstTemplateTemplateParmPackStorage::Profile(llvm::FoldingSetNodeID&, clang::ASTContext&, clang::TemplateTemplateParmDecl*, clang::TemplateArgument const&)"},
    {"_ZNK5clang12TemplateName7getKindEv", "clang::TemplateName::getKind() const"},
    {"_ZNK5clang12TemplateName17getAsTemplateDeclEv", "clang::TemplateName::getAsTemplateDecl() const"},
    {"_ZNK5clang12TemplateName11isDependentEv", "clang::TemplateName::isDependent() const"},
    {"_ZNK5clang12TemplateName31containsUnexpandedParameterPackEv", "clang::TemplateName::containsUnexpandedParameterPack() const"},
    {"_ZNK5clang12TemplateName5printERN4llvm11raw_ostreamERKNS_14PrintingPolicyEb", "clang::TemplateName::print(llvm::raw_ostream&, clang::PrintingPolicy const&, bool) const"},
    {"_ZN5clanglsERKNS_17DiagnosticBuilderENS_12TemplateNameE", "clang::operator<<(clang::DiagnosticBuilder const&, clang::TemplateName)"},
    {"_ZNK5clang12TemplateName4dumpEv", "clang::TemplateName::dump() const"},
    {"_ZN5clang8QualType10isConstantES0_RNS_10ASTContextE", "clang::QualType::isConstant(clang::QualType, clang::ASTContext&)"},
    {"_ZN5clang17ConstantArrayType20getNumAddressingBitsERNS_10ASTContextENS_8QualTypeERKN4llvm5APIntE", "clang::ConstantArrayType::getNumAddressingBits(clang::ASTContext&, clang::QualType, llvm::APInt const&)"},
    {"_ZN5clang17ConstantArrayType14getMaxSizeBitsERNS_10ASTContextE", "clang::ConstantArrayType::getMaxSizeBits(clang::ASTContext&)"},
    {"_ZN5clang23DependentSizedArrayTypeC1ERKNS_10ASTContextENS_8QualTypeES4_PNS_4ExprENS_9ArrayType17ArraySizeModifierEjNS_11SourceRangeE", "clang::DependentSizedArrayType::DependentSizedArrayType(clang::ASTContext const&, clang::QualType, clang::QualType, clang::Expr*, clang::ArrayType::ArraySizeModifier, unsigned int, clang::SourceRange)"},
    {"_ZN5clang23DependentSizedArrayTypeC2ERKNS_10ASTContextENS_8QualTypeES4_PNS_4ExprENS_9ArrayType17ArraySizeModifierEjNS_11SourceRangeE", "clang::DependentSizedArrayType::DependentSizedArrayType(clang::ASTContext const&, clang::QualType, clang::QualType, clang::Expr*, clang::ArrayType::ArraySizeModifier, unsigned int, clang::SourceRange)"},
    {"_ZN5clang23DependentSizedArrayType7ProfileERN4llvm16FoldingSetNodeIDERKNS_10ASTContextENS_8QualTypeENS_9ArrayType17ArraySizeModifierEjPNS_4ExprE", "clang::DependentSizedArrayType::Profile(llvm::FoldingSetNodeID&, clang::ASTContext const&, clang::QualType, clang::ArrayType::ArraySizeModifier, unsigned int, clang::Expr*)"},
    {"_ZN5clang27DependentSizedExtVectorTypeC1ERKNS_10ASTContextENS_8QualTypeES4_PNS_4ExprENS_14SourceLocationE", "clang::DependentSizedExtVectorType::DependentSizedExtVectorType(clang::ASTContext const&, clang::QualType, clang::QualType, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang27DependentSizedExtVectorTypeC2ERKNS_10ASTContextENS_8QualTypeES4_PNS_4ExprENS_14SourceLocationE", "clang::DependentSizedExtVectorType::DependentSizedExtVectorType(clang::ASTContext const&, clang::QualType, clang::QualType, clang::Expr*, clang::SourceLocation)"},
    {"_ZN5clang27DependentSizedExtVectorType7ProfileERN4llvm16FoldingSetNodeIDERKNS_10ASTContextENS_8QualTypeEPNS_4ExprE", "clang::DependentSizedExtVectorType::Profile(llvm::FoldingSetNodeID&, clang::ASTContext const&, clang::QualType, clang::Expr*)"},
    {"_ZN5clang10VectorTypeC1ENS_8QualTypeEjS1_NS0_10VectorKindE", "clang::VectorType::VectorType(clang::QualType, unsigned int, clang::QualType, clang::VectorType::VectorKind)"},
    {"_ZN5clang10VectorTypeC2ENS_8QualTypeEjS1_NS0_10VectorKindE", "clang::VectorType::VectorType(clang::QualType, unsigned int, clang::QualType, clang::VectorType::VectorKind)"},
    {"_ZN5clang10VectorTypeC1ENS_4Type9TypeClassENS_8QualTypeEjS3_NS0_10VectorKindE", "clang::VectorType::VectorType(clang::Type::TypeClass, clang::QualType, unsigned int, clang::QualType, clang::VectorType::VectorKind)"},
    {"_ZN5clang10VectorTypeC2ENS_4Type9TypeClassENS_8QualTypeEjS3_NS0_10VectorKindE", "clang::VectorType::VectorType(clang::Type::TypeClass, clang::QualType, unsigned int, clang::QualType, clang::VectorType::VectorKind)"},
    {"_ZNK5clang4Type29getArrayElementTypeNoTypeQualEv", "clang::Type::getArrayElementTypeNoTypeQual() const"},
    {"_ZNK5clang4Type27getUnqualifiedDesugaredTypeEv", "clang::Type::getUnqualifiedDesugaredType() const"},
    {"_ZN5clang8QualType16getDesugaredTypeES0_RKNS_10ASTContextE", "clang::QualType::getDesugaredType(clang::QualType, clang::ASTContext const&)"},
    {"_ZN5clang8QualType21getSplitDesugaredTypeES0_", "clang::QualType::getSplitDesugaredType(clang::QualType)"},
    {"_ZNK5clang11TypedefType7desugarEv", "clang::TypedefType::desugar() const"},
    {"_ZNK5clang14TypeOfExprType7desugarEv", "clang::TypeOfExprType::desugar() const"},
    {"_ZN5clang8QualType27getSplitUnqualifiedTypeImplES0_", "clang::QualType::getSplitUnqualifiedTypeImpl(clang::QualType)"},
    {"_ZN5clang8QualType12IgnoreParensES0_", "clang::QualType::IgnoreParens(clang::QualType)"},
    {"_ZNK5clang4Type10isVoidTypeEv", "clang::Type::isVoidType() const"},
    {"_ZNK5clang4Type13isDerivedTypeEv", "clang::Type::isDerivedType() const"},
    {"_ZNK5clang4Type11isClassTypeEv", "clang::Type::isClassType() const"},
    {"_ZNK5clang4Type15isStructureTypeEv", "clang::Type::isStructureType() const"},
    {"_ZNK5clang4Type22isStructureOrClassTypeEv", "clang::Type::isStructureOrClassType() const"},
    {"_ZNK5clang4Type17isVoidPointerTypeEv", "clang::Type::isVoidPointerType() const"},
    {"_ZNK5clang4Type11isUnionTypeEv", "clang::Type::isUnionType() const"},
    {"_ZNK5clang4Type13isComplexTypeEv", "clang::Type::isComplexType() const"},
    {"_ZNK5clang4Type14isFloatingTypeEv", "clang::Type::isFloatingType() const"},
    {"_ZNK5clang4Type20isComplexIntegerTypeEv", "clang::Type::isComplexIntegerType() const"},
    {"_ZNK5clang4Type23getAsComplexIntegerTypeEv", "clang::Type::getAsComplexIntegerType() const"},
    {"_ZNK5clang4Type13isIntegerTypeEv", "clang::Type::isIntegerType() const"},
    {"_ZNK5clang4Type14getPointeeTypeEv", "clang::Type::getPointeeType() const"},
    {"_ZNK5clang4Type18getAsStructureTypeEv", "clang::Type::getAsStructureType() const"},
    {"_ZNK5clang4Type14getAsUnionTypeEv", "clang::Type::getAsUnionType() const"},
    {"_ZN5clang14ObjCObjectTypeC1ENS_8QualTypeES1_PKPNS_16ObjCProtocolDeclEj", "clang::ObjCObjectType::ObjCObjectType(clang::QualType, clang::QualType, clang::ObjCProtocolDecl* const*, unsigned int)"},
    {"_ZN5clang14ObjCObjectTypeC2ENS_8QualTypeES1_PKPNS_16ObjCProtocolDeclEj", "clang::ObjCObjectType::ObjCObjectType(clang::QualType, clang::QualType, clang::ObjCProtocolDecl* const*, unsigned int)"},
    {"_ZNK5clang4Type31getAsObjCQualifiedInterfaceTypeEv", "clang::Type::getAsObjCQualifiedInterfaceType() const"},
    {"_ZNK5clang4Type28isObjCQualifiedInterfaceTypeEv", "clang::Type::isObjCQualifiedInterfaceType() const"},
    {"_ZNK5clang4Type24getAsObjCQualifiedIdTypeEv", "clang::Type::getAsObjCQualifiedIdType() const"},
    {"_ZNK5clang4Type29getAsObjCInterfacePointerTypeEv", "clang::Type::getAsObjCInterfacePointerType() const"},
    {"_ZNK5clang4Type30getCXXRecordDeclForPointerTypeEv", "clang::Type::getCXXRecordDeclForPointerType() const"},
    {"_ZNK5clang4Type18getAsCXXRecordDeclEv", "clang::Type::getAsCXXRecordDecl() const"},
    {"_ZNK5clang21InjectedClassNameType7getDeclEv", "clang::InjectedClassNameType::getDecl() const"},
    {"_ZNK5clang4Type24hasIntegerRepresentationEv", "clang::Type::hasIntegerRepresentation() const"},
    {"_ZNK5clang4Type14isIntegralTypeERNS_10ASTContextE", "clang::Type::isIntegralType(clang::ASTContext&) const"},
    {"_ZNK5clang4Type27isIntegralOrEnumerationTypeEv", "clang::Type::isIntegralOrEnumerationType() const"},
    {"_ZNK5clang4Type35isIntegralOrUnscopedEnumerationTypeEv", "clang::Type::isIntegralOrUnscopedEnumerationType() const"},
    {"_ZNK5clang4Type13isBooleanTypeEv", "clang::Type::isBooleanType() const"},
    {"_ZNK5clang4Type10isCharTypeEv", "clang::Type::isCharType() const"},
    {"_ZNK5clang4Type14isWideCharTypeEv", "clang::Type::isWideCharType() const"},
    {"_ZNK5clang4Type18isAnyCharacterTypeEv", "clang::Type::isAnyCharacterType() const"},
    {"_ZNK5clang4Type19isSignedIntegerTypeEv", "clang::Type::isSignedIntegerType() const"},
    {"_ZNK5clang4Type30hasSignedIntegerRepresentationEv", "clang::Type::hasSignedIntegerRepresentation() const"},
    {"_ZNK5clang4Type21isUnsignedIntegerTypeEv", "clang::Type::isUnsignedIntegerType() const"},
    {"_ZNK5clang4Type32hasUnsignedIntegerRepresentationEv", "clang::Type::hasUnsignedIntegerRepresentation() const"},
    {"_ZNK5clang4Type25hasFloatingRepresentationEv", "clang::Type::hasFloatingRepresentation() const"},
    {"_ZNK5clang4Type18isRealFloatingTypeEv", "clang::Type::isRealFloatingType() const"},
    {"_ZNK5clang4Type10isRealTypeEv", "clang::Type::isRealType() const"},
    {"_ZNK5clang4Type16isArithmeticTypeEv", "clang::Type::isArithmeticType() const"},
    {"_ZNK5clang4Type12isScalarTypeEv", "clang::Type::isScalarType() const"},
    {"_ZNK5clang4Type17getScalarTypeKindEv", "clang::Type::getScalarTypeKind() const"},
    {"_ZNK5clang4Type15isAggregateTypeEv", "clang::Type::isAggregateType() const"},
    {"_ZNK5clang4Type18isConstantSizeTypeEv", "clang::Type::isConstantSizeType() const"},
    {"_ZNK5clang4Type16isIncompleteTypeEv", "clang::Type::isIncompleteType() const"},
    {"_ZNK5clang7TagType7getDeclEv", "clang::TagType::getDecl() const"},
    {"_ZNK5clang4Type9isPODTypeEv", "clang::Type::isPODType() const"},
    {"_ZNK5clang4Type13isLiteralTypeEv", "clang::Type::isLiteralType() const"},
    {"_ZNK5clang4Type23isPromotableIntegerTypeEv", "clang::Type::isPromotableIntegerType() const"},
    {"_ZNK5clang4Type13isNullPtrTypeEv", "clang::Type::isNullPtrType() const"},
    {"_ZNK5clang4Type15isSpecifierTypeEv", "clang::Type::isSpecifierType() const"},
    {"_ZN5clang15TypeWithKeyword21getKeywordForTypeSpecEj", "clang::TypeWithKeyword::getKeywordForTypeSpec(unsigned int)"},
    {"_ZN5clang15TypeWithKeyword25getTagTypeKindForTypeSpecEj", "clang::TypeWithKeyword::getTagTypeKindForTypeSpec(unsigned int)"},
    {"_ZN5clang15TypeWithKeyword24getKeywordForTagTypeKindENS_11TagTypeKindE", "clang::TypeWithKeyword::getKeywordForTagTypeKind(clang::TagTypeKind)"},
    {"_ZN5clang15TypeWithKeyword24getTagTypeKindForKeywordENS_21ElaboratedTypeKeywordE", "clang::TypeWithKeyword::getTagTypeKindForKeyword(clang::ElaboratedTypeKeyword)"},
    {"_ZN5clang15TypeWithKeyword20KeywordIsTagTypeKindENS_21ElaboratedTypeKeywordE", "clang::TypeWithKeyword::KeywordIsTagTypeKind(clang::ElaboratedTypeKeyword)"},
    {"_ZN5clang15TypeWithKeyword14getKeywordNameENS_21ElaboratedTypeKeywordE", "clang::TypeWithKeyword::getKeywordName(clang::ElaboratedTypeKeyword)"},
    {"_ZN5clang35DependentTemplateSpecializationTypeC1ENS_21ElaboratedTypeKeywordEPNS_19NestedNameSpecifierEPKNS_14IdentifierInfoEjPKNS_16TemplateArgumentENS_8QualTypeE", "clang::DependentTemplateSpecializationType::DependentTemplateSpecializationType(clang::ElaboratedTypeKeyword, clang::NestedNameSpecifier*, clang::IdentifierInfo const*, unsigned int, clang::TemplateArgument const*, clang::QualType)"},
    {"_ZN5clang35DependentTemplateSpecializationTypeC2ENS_21ElaboratedTypeKeywordEPNS_19NestedNameSpecifierEPKNS_14IdentifierInfoEjPKNS_16TemplateArgumentENS_8QualTypeE", "clang::DependentTemplateSpecializationType::DependentTemplateSpecializationType(clang::ElaboratedTypeKeyword, clang::NestedNameSpecifier*, clang::IdentifierInfo const*, unsigned int, clang::TemplateArgument const*, clang::QualType)"},
    {"_ZN5clang35DependentTemplateSpecializationType7ProfileERN4llvm16FoldingSetNodeIDERKNS_10ASTContextENS_21ElaboratedTypeKeywordEPNS_19NestedNameSpecifierEPKNS_14IdentifierInfoEjPKNS_16TemplateArgumentE", "clang::DependentTemplateSpecializationType::Profile(llvm::FoldingSetNodeID&, clang::ASTContext const&, clang::ElaboratedTypeKeyword, clang::NestedNameSpecifier*, clang::IdentifierInfo const*, unsigned int, clang::TemplateArgument const*)"},
    {"_ZNK5clang4Type25isElaboratedTypeSpecifierEv", "clang::Type::isElaboratedTypeSpecifier() const"},
    {"_ZNK5clang4Type16getTypeClassNameEv", "clang::Type::getTypeClassName() const"},
    {"_ZNK5clang11BuiltinType7getNameERKNS_11LangOptionsE", "clang::BuiltinType::getName(clang::LangOptions const&) const"},
    {"_ZNK5clang8QualType20getNonLValueExprTypeERNS_10ASTContextE", "clang::QualType::getNonLValueExprType(clang::ASTContext&) const"},
    {"_ZN5clang12FunctionType18getNameForCallConvENS_11CallingConvE", "clang::FunctionType::getNameForCallConv(clang::CallingConv)"},
    {"_ZN5clang17FunctionProtoTypeC1ENS_8QualTypeEPKS1_jS1_RKNS0_12ExtProtoInfoE", "clang::FunctionProtoType::FunctionProtoType(clang::QualType, clang::QualType const*, unsigned int, clang::QualType, clang::FunctionProtoType::ExtProtoInfo const&)"},
    {"_ZN5clang17FunctionProtoTypeC2ENS_8QualTypeEPKS1_jS1_RKNS0_12ExtProtoInfoE", "clang::FunctionProtoType::FunctionProtoType(clang::QualType, clang::QualType const*, unsigned int, clang::QualType, clang::FunctionProtoType::ExtProtoInfo const&)"},
    {"_ZNK5clang17FunctionProtoType18isTemplateVariadicEv", "clang::FunctionProtoType::isTemplateVariadic() const"},
    {"_ZN5clang17FunctionProtoType7ProfileERN4llvm16FoldingSetNodeIDENS_8QualTypeEPKS4_jRKNS0_12ExtProtoInfoE", "clang::FunctionProtoType::Profile(llvm::FoldingSetNodeID&, clang::QualType, clang::QualType const*, unsigned int, clang::FunctionProtoType::ExtProtoInfo const&)"},
    {"_ZN5clang17FunctionProtoType7ProfileERN4llvm16FoldingSetNodeIDE", "clang::FunctionProtoType::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang14TypeOfExprTypeC1EPNS_4ExprENS_8QualTypeE", "clang::TypeOfExprType::TypeOfExprType(clang::Expr*, clang::QualType)"},
    {"_ZN5clang14TypeOfExprTypeC2EPNS_4ExprENS_8QualTypeE", "clang::TypeOfExprType::TypeOfExprType(clang::Expr*, clang::QualType)"},
    {"_ZN5clang23DependentTypeOfExprType7ProfileERN4llvm16FoldingSetNodeIDERKNS_10ASTContextEPNS_4ExprE", "clang::DependentTypeOfExprType::Profile(llvm::FoldingSetNodeID&, clang::ASTContext const&, clang::Expr*)"},
    {"_ZN5clang12DecltypeTypeC1EPNS_4ExprENS_8QualTypeES3_", "clang::DecltypeType::DecltypeType(clang::Expr*, clang::QualType, clang::QualType)"},
    {"_ZN5clang12DecltypeTypeC2EPNS_4ExprENS_8QualTypeES3_", "clang::DecltypeType::DecltypeType(clang::Expr*, clang::QualType, clang::QualType)"},
    {"_ZN5clang21DependentDecltypeTypeC1ERKNS_10ASTContextEPNS_4ExprE", "clang::DependentDecltypeType::DependentDecltypeType(clang::ASTContext const&, clang::Expr*)"},
    {"_ZN5clang21DependentDecltypeTypeC2ERKNS_10ASTContextEPNS_4ExprE", "clang::DependentDecltypeType::DependentDecltypeType(clang::ASTContext const&, clang::Expr*)"},
    {"_ZN5clang21DependentDecltypeType7ProfileERN4llvm16FoldingSetNodeIDERKNS_10ASTContextEPNS_4ExprE", "clang::DependentDecltypeType::Profile(llvm::FoldingSetNodeID&, clang::ASTContext const&, clang::Expr*)"},
    {"_ZN5clang7TagTypeC1ENS_4Type9TypeClassEPKNS_7TagDeclENS_8QualTypeE", "clang::TagType::TagType(clang::Type::TypeClass, clang::TagDecl const*, clang::QualType)"},
    {"_ZN5clang7TagTypeC2ENS_4Type9TypeClassEPKNS_7TagDeclENS_8QualTypeE", "clang::TagType::TagType(clang::Type::TypeClass, clang::TagDecl const*, clang::QualType)"},
    {"_ZNK5clang7TagType14isBeingDefinedEv", "clang::TagType::isBeingDefined() const"},
    {"_ZN5clang10RecordType7classofEPKNS_7TagTypeE", "clang::RecordType::classof(clang::TagType const*)"},
    {"_ZN5clang8EnumType7classofEPKNS_7TagTypeE", "clang::EnumType::classof(clang::TagType const*)"},
    {"_ZN5clang29SubstTemplateTypeParmPackTypeC1EPKNS_20TemplateTypeParmTypeENS_8QualTypeERKNS_16TemplateArgumentE", "clang::SubstTemplateTypeParmPackType::SubstTemplateTypeParmPackType(clang::TemplateTypeParmType const*, clang::QualType, clang::TemplateArgument const&)"},
    {"_ZN5clang29SubstTemplateTypeParmPackTypeC2EPKNS_20TemplateTypeParmTypeENS_8QualTypeERKNS_16TemplateArgumentE", "clang::SubstTemplateTypeParmPackType::SubstTemplateTypeParmPackType(clang::TemplateTypeParmType const*, clang::QualType, clang::TemplateArgument const&)"},
    {"_ZNK5clang29SubstTemplateTypeParmPackType15getArgumentPackEv", "clang::SubstTemplateTypeParmPackType::getArgumentPack() const"},
    {"_ZN5clang29SubstTemplateTypeParmPackType7ProfileERN4llvm16FoldingSetNodeIDE", "clang::SubstTemplateTypeParmPackType::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZN5clang29SubstTemplateTypeParmPackType7ProfileERN4llvm16FoldingSetNodeIDEPKNS_20TemplateTypeParmTypeERKNS_16TemplateArgumentE", "clang::SubstTemplateTypeParmPackType::Profile(llvm::FoldingSetNodeID&, clang::TemplateTypeParmType const*, clang::TemplateArgument const&)"},
    {"_ZN5clang26TemplateSpecializationType29anyDependentTemplateArgumentsERKNS_24TemplateArgumentListInfoE", "clang::TemplateSpecializationType::anyDependentTemplateArguments(clang::TemplateArgumentListInfo const&)"},
    {"_ZN5clang26TemplateSpecializationType29anyDependentTemplateArgumentsEPKNS_19TemplateArgumentLocEj", "clang::TemplateSpecializationType::anyDependentTemplateArguments(clang::TemplateArgumentLoc const*, unsigned int)"},
    {"_ZN5clang26TemplateSpecializationType29anyDependentTemplateArgumentsEPKNS_16TemplateArgumentEj", "clang::TemplateSpecializationType::anyDependentTemplateArguments(clang::TemplateArgument const*, unsigned int)"},
    {"_ZN5clang26TemplateSpecializationTypeC1ENS_12TemplateNameEPKNS_16TemplateArgumentEjNS_8QualTypeE", "clang::TemplateSpecializationType::TemplateSpecializationType(clang::TemplateName, clang::TemplateArgument const*, unsigned int, clang::QualType)"},
    {"_ZN5clang26TemplateSpecializationTypeC2ENS_12TemplateNameEPKNS_16TemplateArgumentEjNS_8QualTypeE", "clang::TemplateSpecializationType::TemplateSpecializationType(clang::TemplateName, clang::TemplateArgument const*, unsigned int, clang::QualType)"},
    {"_ZN5clang26TemplateSpecializationType7ProfileERN4llvm16FoldingSetNodeIDENS_12TemplateNameEPKNS_16TemplateArgumentEjRKNS_10ASTContextE", "clang::TemplateSpecializationType::Profile(llvm::FoldingSetNodeID&, clang::TemplateName, clang::TemplateArgument const*, unsigned int, clang::ASTContext const&)"},
    {"_ZNK5clang18QualifierCollector5applyERKNS_10ASTContextENS_8QualTypeE", "clang::QualifierCollector::apply(clang::ASTContext const&, clang::QualType) const"},
    {"_ZNK5clang18QualifierCollector5applyERKNS_10ASTContextEPKNS_4TypeE", "clang::QualifierCollector::apply(clang::ASTContext const&, clang::Type const*) const"},
    {"_ZN5clang18ObjCObjectTypeImpl7ProfileERN4llvm16FoldingSetNodeIDENS_8QualTypeEPKPNS_16ObjCProtocolDeclEj", "clang::ObjCObjectTypeImpl::Profile(llvm::FoldingSetNodeID&, clang::QualType, clang::ObjCProtocolDecl* const*, unsigned int)"},
    {"_ZN5clang18ObjCObjectTypeImpl7ProfileERN4llvm16FoldingSetNodeIDE", "clang::ObjCObjectTypeImpl::Profile(llvm::FoldingSetNodeID&)"},
    {"_ZNK5clang4Type10getLinkageEv", "clang::Type::getLinkage() const"},
    {"_ZN5clang17TypePropertyCacheIN12_GLOBAL__N_17PrivateEE6ensureEPKNS_4TypeE", "clang::TypePropertyCache<(anonymous namespace)::Private>::ensure(clang::Type const*)"},
    {"_ZNK5clang4Type13getVisibilityEv", "clang::Type::getVisibility() const"},
    {"_ZNK5clang4Type21hasUnnamedOrLocalTypeEv", "clang::Type::hasUnnamedOrLocalType() const"},
    {"_ZNK5clang4Type23getLinkageAndVisibilityEv", "clang::Type::getLinkageAndVisibility() const"},
    {"_ZN5clang4Type17ClearLinkageCacheEv", "clang::Type::ClearLinkageCache()"},
    {"_ZNK5clang4Type15hasSizedVLATypeEv", "clang::Type::hasSizedVLAType() const"},
    {"_ZNK4llvm6APSInt6extendEj", "llvm::APSInt::extend(unsigned int) const"},
    {"_ZN5clang7TypeLoc23getLocalSourceRangeImplES0_", "clang::TypeLoc::getLocalSourceRangeImpl(clang::TypeLoc)"},
    {"_ZN5clang7TypeLoc22getFullDataSizeForTypeENS_8QualTypeE", "clang::TypeLoc::getFullDataSizeForType(clang::QualType)"},
    {"_ZN5clang14TypeLocVisitorIN12_GLOBAL__N_19TypeSizerEjE5VisitENS_7TypeLocE", "clang::TypeLocVisitor<(anonymous namespace)::TypeSizer, unsigned int>::Visit(clang::TypeLoc)"},
    {"_ZN5clang7TypeLoc18getNextTypeLocImplES0_", "clang::TypeLoc::getNextTypeLocImpl(clang::TypeLoc)"},
    {"_ZN5clang7TypeLoc14initializeImplERNS_10ASTContextES0_NS_14SourceLocationE", "clang::TypeLoc::initializeImpl(clang::ASTContext&, clang::TypeLoc, clang::SourceLocation)"},
    {"_ZNK5clang7TypeLoc11getBeginLocEv", "clang::TypeLoc::getBeginLoc() const"},
    {"_ZNK5clang7TypeLoc9getEndLocEv", "clang::TypeLoc::getEndLoc() const"},
    {"_ZN5clang15TypeSpecTypeLoc7classofEPKNS_7TypeLocE", "clang::TypeSpecTypeLoc::classof(clang::TypeLoc const*)"},
    {"_ZNK5clang17TypeOfExprTypeLoc19getLocalSourceRangeEv", "clang::TypeOfExprTypeLoc::getLocalSourceRange() const"},
    {"_ZNK5clang14BuiltinTypeLoc18getWrittenTypeSpecEv", "clang::BuiltinTypeLoc::getWrittenTypeSpec() const"},
    {"_ZN5clang7TypeLoc16IgnoreParensImplES0_", "clang::TypeLoc::IgnoreParensImpl(clang::TypeLoc)"},
    {"_ZN5clang29TemplateSpecializationTypeLoc17initializeArgLocsERNS_10ASTContextEjPKNS_16TemplateArgumentEPNS_23TemplateArgumentLocInfoENS_14SourceLocationE", "clang::TemplateSpecializationTypeLoc::initializeArgLocs(clang::ASTContext&, unsigned int, clang::TemplateArgument const*, clang::TemplateArgumentLocInfo*, clang::SourceLocation)"},
    {"_ZN5clang29TemplateSpecializationTypeLoc15initializeLocalERNS_10ASTContextENS_14SourceLocationE", "clang::TemplateSpecializationTypeLoc::initializeLocal(clang::ASTContext&, clang::SourceLocation)"},
    {"_ZN5clang38DependentTemplateSpecializationTypeLoc15initializeLocalERNS_10ASTContextENS_14SourceLocationE", "clang::DependentTemplateSpecializationTypeLoc::initializeLocal(clang::ASTContext&, clang::SourceLocation)"},
    {"_ZN5clang26TemplateSpecializationType25PrintTemplateArgumentListERKNS_24TemplateArgumentListInfoERKNS_14PrintingPolicyE", "clang::TemplateSpecializationType::PrintTemplateArgumentList(clang::TemplateArgumentListInfo const&, clang::PrintingPolicy const&)"},
    {"_ZN5clang26TemplateSpecializationType25PrintTemplateArgumentListEPKNS_19TemplateArgumentLocEjRKNS_14PrintingPolicyE", "clang::TemplateSpecializationType::PrintTemplateArgumentList(clang::TemplateArgumentLoc const*, unsigned int, clang::PrintingPolicy const&)"},
    {"_ZN5clang26TemplateSpecializationType25PrintTemplateArgumentListEPKNS_16TemplateArgumentEjRKNS_14PrintingPolicyEb", "clang::TemplateSpecializationType::PrintTemplateArgumentList(clang::TemplateArgument const*, unsigned int, clang::PrintingPolicy const&, bool)"},
    {"_ZNK5clang8QualType4dumpEPKc", "clang::QualType::dump(char const*) const"},
    {"_ZNK5clang8QualType4dumpEv", "clang::QualType::dump() const"},
    {"_ZNK5clang4Type4dumpEv", "clang::Type::dump() const"},
    {"_ZNK5clang10Qualifiers11getAsStringEv", "clang::Qualifiers::getAsString() const"},
    {"_ZNK5clang10Qualifiers19getAsStringInternalERSsRKNS_14PrintingPolicyE", "clang::Qualifiers::getAsStringInternal(std::string&, clang::PrintingPolicy const&) const"},
    {"_Z18AppendTypeQualListRSsj", "AppendTypeQualList(std::string&, unsigned int)"},
    {"_ZN5clang8QualType11getAsStringEPKNS_4TypeENS_10QualifiersE", "clang::QualType::getAsString(clang::Type const*, clang::Qualifiers)"},
    {"_ZN5clang8QualType19getAsStringInternalEPKNS_4TypeENS_10QualifiersERSsRKNS_14PrintingPolicyE", "clang::QualType::getAsStringInternal(clang::Type const*, clang::Qualifiers, std::string&, clang::PrintingPolicy const&)"},
    {"_ZN12_GLOBAL__N_111TypePrinter5printEPKN5clang4TypeENS1_10QualifiersERSs", "(anonymous namespace)::TypePrinter::print(clang::Type const*, clang::Qualifiers, std::string&)"},
    {"_ZN12_GLOBAL__N_111TypePrinter21printTemplateTypeParmEPKN5clang20TemplateTypeParmTypeERSs", "(anonymous namespace)::TypePrinter::printTemplateTypeParm(clang::TemplateTypeParmType const*, std::string&)"},
    {"_ZN12_GLOBAL__N_111TypePrinter27printTemplateSpecializationEPKN5clang26TemplateSpecializationTypeERSs", "(anonymous namespace)::TypePrinter::printTemplateSpecialization(clang::TemplateSpecializationType const*, std::string&)"},
    {"_ZN12_GLOBAL__N_111TypePrinter8printTagEPN5clang7TagDeclERSs", "(anonymous namespace)::TypePrinter::printTag(clang::TagDecl*, std::string&)"},
    {"_ZN12_GLOBAL__N_111TypePrinter11AppendScopeEPN5clang11DeclContextERSs", "(anonymous namespace)::TypePrinter::AppendScope(clang::DeclContext*, std::string&)"},
    {"_Z13printTypeSpecPKN5clang9NamedDeclERSs", "printTypeSpec(clang::NamedDecl const*, std::string&)"},
    {"_ZN5clang9HeaderMap6CreateEPKNS_9FileEntryERNS_11FileManagerE", "clang::HeaderMap::Create(clang::FileEntry const*, clang::FileManager&)"},
    {"_ZN5clang9HeaderMapD1Ev", "clang::HeaderMap::~HeaderMap()"},
    {"_ZN5clang9HeaderMapD2Ev", "clang::HeaderMap::~HeaderMap()"},
    {"_ZNK5clang9HeaderMap11getFileNameEv", "clang::HeaderMap::getFileName() const"},
    {"_ZNK5clang9HeaderMap21getEndianAdjustedWordEj", "clang::HeaderMap::getEndianAdjustedWord(unsigned int) const"},
    {"_ZNK5clang9HeaderMap9getHeaderEv", "clang::HeaderMap::getHeader() const"},
    {"_ZNK5clang9HeaderMap9getBucketEj", "clang::HeaderMap::getBucket(unsigned int) const"},
    {"_ZNK5clang9HeaderMap9getStringEj", "clang::HeaderMap::getString(unsigned int) const"},
    {"_ZNK5clang9HeaderMap4dumpEv", "clang::HeaderMap::dump() const"},
    {"_ZNK5clang9HeaderMap10LookupFileEN4llvm9StringRefERNS_11FileManagerE", "clang::HeaderMap::LookupFile(llvm::StringRef, clang::FileManager&) const"},
    {"_ZN5clang14HeaderFileInfo19getControllingMacroEPNS_24ExternalIdentifierLookupE", "clang::HeaderFileInfo::getControllingMacro(clang::ExternalIdentifierLookup*)"},
    {"_ZN5clang12HeaderSearchC1ERNS_11FileManagerE", "clang::HeaderSearch::HeaderSearch(clang::FileManager&)"},
    {"_ZN5clang12HeaderSearchC2ERNS_11FileManagerE", "clang::HeaderSearch::HeaderSearch(clang::FileManager&)"},
    {"_ZN5clang12HeaderSearchD1Ev", "clang::HeaderSearch::~HeaderSearch()"},
    {"_ZN5clang12HeaderSearchD2Ev", "clang::HeaderSearch::~HeaderSearch()"},
    {"_ZN5clang12HeaderSearch10PrintStatsEv", "clang::HeaderSearch::PrintStats()"},
    {"_ZN5clang12HeaderSearch15CreateHeaderMapEPKNS_9FileEntryE", "clang::HeaderSearch::CreateHeaderMap(clang::FileEntry const*)"},
    {"_ZNK5clang15DirectoryLookup7getNameEv", "clang::DirectoryLookup::getName() const"},
    {"_ZNK5clang15DirectoryLookup10LookupFileEN4llvm9StringRefERNS_12HeaderSearchE", "clang::DirectoryLookup::LookupFile(llvm::StringRef, clang::HeaderSearch&) const"},
    {"_ZNK5clang15DirectoryLookup17DoFrameworkLookupEN4llvm9StringRefERNS_12HeaderSearchE", "clang::DirectoryLookup::DoFrameworkLookup(llvm::StringRef, clang::HeaderSearch&) const"},
    {"_ZN5clang12HeaderSearch10LookupFileEN4llvm9StringRefEbPKNS_15DirectoryLookupERS5_PKNS_9FileEntryE", "clang::HeaderSearch::LookupFile(llvm::StringRef, bool, clang::DirectoryLookup const*, clang::DirectoryLookup const*&, clang::FileEntry const*)"},
    {"_ZN5clang12HeaderSearch11getFileInfoEPKNS_9FileEntryE", "clang::HeaderSearch::getFileInfo(clang::FileEntry const*)"},
    {"_ZN5clang12HeaderSearch24LookupSubframeworkHeaderEN4llvm9StringRefEPKNS_9FileEntryE", "clang::HeaderSearch::LookupSubframeworkHeader(llvm::StringRef, clang::FileEntry const*)"},
    {"_ZN5clang12HeaderSearch23setHeaderFileInfoForUIDENS_14HeaderFileInfoEj", "clang::HeaderSearch::setHeaderFileInfoForUID(clang::HeaderFileInfo, unsigned int)"},
    {"_ZN5clang12HeaderSearch22ShouldEnterIncludeFileEPKNS_9FileEntryEb", "clang::HeaderSearch::ShouldEnterIncludeFile(clang::FileEntry const*, bool)"},
    {"_ZNSt6vectorIN5clang14HeaderFileInfoESaIS1_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS1_S3_EEmRKS1_", "std::vector<clang::HeaderFileInfo, std::allocator<clang::HeaderFileInfo>>::_M_fill_insert(__gnu_cxx::__normal_iterator<clang::HeaderFileInfo*, std::vector<clang::HeaderFileInfo, std::allocator<clang::HeaderFileInfo>>>, unsigned long, clang::HeaderFileInfo const&)"},
    {"_ZN4llvm15SmallVectorImplIcEaSERKS1_", "llvm::SmallVectorImpl<char>::operator=(llvm::SmallVectorImpl<char> const&)"},
    {"_ZN4llvm9StringMapISt4pairIjjENS_15MallocAllocatorEE16GetOrCreateValueIS2_EERNS_14StringMapEntryIS2_EENS_9StringRefET_", "llvm::StringMapEntry<std::pair<unsigned int, unsigned int>>& llvm::StringMap<std::pair<unsigned int, unsigned int>, llvm::MallocAllocator>::GetOrCreateValue<std::pair<unsigned int, unsigned int>>(llvm::StringRef, std::pair<unsigned int, unsigned int>)"},
    {"_ZNSt6vectorISt4pairIPKN5clang9FileEntryEPKNS1_9HeaderMapEESaIS8_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS8_SA_EERKS8_", "std::vector<std::pair<clang::FileEntry const*, clang::HeaderMap const*>, std::allocator<std::pair<clang::FileEntry const*, clang::HeaderMap const*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<clang::FileEntry const*, clang::HeaderMap const*>*, std::vector<std::pair<clang::FileEntry const*, clang::HeaderMap const*>, std::allocator<std::pair<clang::FileEntry const*, clang::HeaderMap const*>>>>, std::pair<clang::FileEntry const*, clang::HeaderMap const*> const&)"},
    {"_ZN4llvm9StringMapIPKN5clang14DirectoryEntryENS_15MallocAllocatorEE16GetOrCreateValueIS4_EERNS_14StringMapEntryIS4_EENS_9StringRefET_", "llvm::StringMapEntry<clang::DirectoryEntry const*>& llvm::StringMap<clang::DirectoryEntry const*, llvm::MallocAllocator>::GetOrCreateValue<clang::DirectoryEntry const*>(llvm::StringRef, clang::DirectoryEntry const*)"},
    {"_ZNK5clang5Token15isObjCAtKeywordENS_3tok15ObjCKeywordKindE", "clang::Token::isObjCAtKeyword(clang::tok::ObjCKeywordKind) const"},
    {"_ZNK5clang5Token16getObjCKeywordIDEv", "clang::Token::getObjCKeywordID() const"},
    {"_ZN5clang5Lexer9InitLexerEPKcS2_S2_", "clang::Lexer::InitLexer(char const*, char const*, char const*)"},
    {"_ZN5clang5LexerC1ENS_6FileIDEPKN4llvm12MemoryBufferERNS_12PreprocessorE", "clang::Lexer::Lexer(clang::FileID, llvm::MemoryBuffer const*, clang::Preprocessor&)"},
    {"_ZN5clang5LexerC2ENS_6FileIDEPKN4llvm12MemoryBufferERNS_12PreprocessorE", "clang::Lexer::Lexer(clang::FileID, llvm::MemoryBuffer const*, clang::Preprocessor&)"},
    {"_ZN5clang5LexerC1ENS_14SourceLocationERKNS_11LangOptionsEPKcS6_S6_", "clang::Lexer::Lexer(clang::SourceLocation, clang::LangOptions const&, char const*, char const*, char const*)"},
    {"_ZN5clang5LexerC2ENS_14SourceLocationERKNS_11LangOptionsEPKcS6_S6_", "clang::Lexer::Lexer(clang::SourceLocation, clang::LangOptions const&, char const*, char const*, char const*)"},
    {"_ZN5clang5LexerC1ENS_6FileIDEPKN4llvm12MemoryBufferERKNS_13SourceManagerERKNS_11LangOptionsE", "clang::Lexer::Lexer(clang::FileID, llvm::MemoryBuffer const*, clang::SourceManager const&, clang::LangOptions const&)"},
    {"_ZN5clang5LexerC2ENS_6FileIDEPKN4llvm12MemoryBufferERKNS_13SourceManagerERKNS_11LangOptionsE", "clang::Lexer::Lexer(clang::FileID, llvm::MemoryBuffer const*, clang::SourceManager const&, clang::LangOptions const&)"},
    {"_ZN5clang5Lexer18Create_PragmaLexerENS_14SourceLocationES1_S1_jRNS_12PreprocessorE", "clang::Lexer::Create_PragmaLexer(clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, unsigned int, clang::Preprocessor&)"},
    {"_ZN5clang5Lexer9StringifyERKSsb", "clang::Lexer::Stringify(std::string const&, bool)"},
    {"_ZN5clang5Lexer9StringifyERN4llvm15SmallVectorImplIcEE", "clang::Lexer::Stringify(llvm::SmallVectorImpl<char>&)"},
    {"_ZN5clang5Lexer11getSpellingERKNS_5TokenERKNS_13SourceManagerERKNS_11LangOptionsEPb", "clang::Lexer::getSpelling(clang::Token const&, clang::SourceManager const&, clang::LangOptions const&, bool*)"},
    {"_ZN5clang5Lexer11getSpellingERKNS_5TokenERPKcRKNS_13SourceManagerERKNS_11LangOptionsEPb", "clang::Lexer::getSpelling(clang::Token const&, char const*&, clang::SourceManager const&, clang::LangOptions const&, bool*)"},
    {"_ZN5clang5Lexer18MeasureTokenLengthENS_14SourceLocationERKNS_13SourceManagerERKNS_11LangOptionsE", "clang::Lexer::MeasureTokenLength(clang::SourceLocation, clang::SourceManager const&, clang::LangOptions const&)"},
    {"_ZN5clang5Lexer19GetBeginningOfTokenENS_14SourceLocationERKNS_13SourceManagerERKNS_11LangOptionsE", "clang::Lexer::GetBeginningOfToken(clang::SourceLocation, clang::SourceManager const&, clang::LangOptions const&)"},
    {"_ZN5clang5Lexer15ComputePreambleEPKN4llvm12MemoryBufferEj", "clang::Lexer::ComputePreamble(llvm::MemoryBuffer const*, unsigned int)"},
    {"_ZN5clang5Lexer23AdvanceToTokenCharacterENS_14SourceLocationEjRKNS_13SourceManagerERKNS_11LangOptionsE", "clang::Lexer::AdvanceToTokenCharacter(clang::SourceLocation, unsigned int, clang::SourceManager const&, clang::LangOptions const&)"},
    {"_ZN5clang5Lexer19SkipEscapedNewLinesEPKc", "clang::Lexer::SkipEscapedNewLines(char const*)"},
    {"_ZN5clang5Lexer19getLocForEndOfTokenENS_14SourceLocationEjRKNS_13SourceManagerERKNS_11LangOptionsE", "clang::Lexer::getLocForEndOfToken(clang::SourceLocation, unsigned int, clang::SourceManager const&, clang::LangOptions const&)"},
    {"_ZNK5clang5Lexer17getSourceLocationEPKcj", "clang::Lexer::getSourceLocation(char const*, unsigned int) const"},
    {"_Z17GetMappedTokenLocRN5clang12PreprocessorENS_14SourceLocationEjj", "GetMappedTokenLoc(clang::Preprocessor&, clang::SourceLocation, unsigned int, unsigned int)"},
    {"_ZNK5clang5Lexer4DiagEPKcj", "clang::Lexer::Diag(char const*, unsigned int) const"},
    {"_ZN5clang5Lexer21getEscapedNewLineSizeEPKc", "clang::Lexer::getEscapedNewLineSize(char const*)"},
    {"_ZN5clang5Lexer18getCharAndSizeSlowEPKcRjPNS_5TokenE", "clang::Lexer::getCharAndSizeSlow(char const*, unsigned int&, clang::Token*)"},
    {"_ZN5clang5Lexer24getCharAndSizeSlowNoWarnEPKcRjRKNS_11LangOptionsE", "clang::Lexer::getCharAndSizeSlowNoWarn(char const*, unsigned int&, clang::LangOptions const&)"},
    {"_ZN5clang5Lexer9SkipBytesEjb", "clang::Lexer::SkipBytes(unsigned int, bool)"},
    {"_ZN5clang5Lexer13LexIdentifierERNS_5TokenEPKc", "clang::Lexer::LexIdentifier(clang::Token&, char const*)"},
    {"_ZN5clang5Lexer18LexNumericConstantERNS_5TokenEPKc", "clang::Lexer::LexNumericConstant(clang::Token&, char const*)"},
    {"_ZN5clang5Lexer16LexStringLiteralERNS_5TokenEPKcb", "clang::Lexer::LexStringLiteral(clang::Token&, char const*, bool)"},
    {"_ZN5clang5Lexer22LexAngledStringLiteralERNS_5TokenEPKc", "clang::Lexer::LexAngledStringLiteral(clang::Token&, char const*)"},
    {"_ZN5clang5Lexer15LexCharConstantERNS_5TokenEPKc", "clang::Lexer::LexCharConstant(clang::Token&, char const*)"},
    {"_ZN5clang5Lexer14SkipWhitespaceERNS_5TokenEPKc", "clang::Lexer::SkipWhitespace(clang::Token&, char const*)"},
    {"_ZN5clang5Lexer15SkipBCPLCommentERNS_5TokenEPKc", "clang::Lexer::SkipBCPLComment(clang::Token&, char const*)"},
    {"_ZN5clang5Lexer15SaveBCPLCommentERNS_5TokenEPKc", "clang::Lexer::SaveBCPLComment(clang::Token&, char const*)"},
    {"_ZN5clang5Lexer16SkipBlockCommentERNS_5TokenEPKc", "clang::Lexer::SkipBlockComment(clang::Token&, char const*)"},
    {"_ZN5clang5Lexer15ReadToEndOfLineEv", "clang::Lexer::ReadToEndOfLine()"},
    {"_ZN5clang5Lexer12LexEndOfFileERNS_5TokenEPKc", "clang::Lexer::LexEndOfFile(clang::Token&, char const*)"},
    {"_ZN5clang5Lexer19isNextPPTokenLParenEv", "clang::Lexer::isNextPPTokenLParen()"},
    {"_ZN5clang5Lexer16LexTokenInternalERNS_5TokenE", "clang::Lexer::LexTokenInternal(clang::Token&)"},
    {"_ZN5clang5Lexer23IsStartOfConflictMarkerEPKc", "clang::Lexer::IsStartOfConflictMarker(char const*)"},
    {"_ZN5clang5Lexer25HandleEndOfConflictMarkerEPKc", "clang::Lexer::HandleEndOfConflictMarker(char const*)"},
    {"_ZN5clang20NumericLiteralParserC1EPKcS2_NS_14SourceLocationERNS_12PreprocessorE", "clang::NumericLiteralParser::NumericLiteralParser(char const*, char const*, clang::SourceLocation, clang::Preprocessor&)"},
    {"_ZN5clang20NumericLiteralParserC2EPKcS2_NS_14SourceLocationERNS_12PreprocessorE", "clang::NumericLiteralParser::NumericLiteralParser(char const*, char const*, clang::SourceLocation, clang::Preprocessor&)"},
    {"_ZN5clang20NumericLiteralParser27ParseNumberStartingWithZeroENS_14SourceLocationE", "clang::NumericLiteralParser::ParseNumberStartingWithZero(clang::SourceLocation)"},
    {"_ZN5clang20NumericLiteralParser15GetIntegerValueERN4llvm5APIntE", "clang::NumericLiteralParser::GetIntegerValue(llvm::APInt&)"},
    {"_ZN5clang20NumericLiteralParser13GetFloatValueERN4llvm7APFloatE", "clang::NumericLiteralParser::GetFloatValue(llvm::APFloat&)"},
    {"_ZN5clang17CharLiteralParserC1EPKcS2_NS_14SourceLocationERNS_12PreprocessorE", "clang::CharLiteralParser::CharLiteralParser(char const*, char const*, clang::SourceLocation, clang::Preprocessor&)"},
    {"_ZN5clang17CharLiteralParserC2EPKcS2_NS_14SourceLocationERNS_12PreprocessorE", "clang::CharLiteralParser::CharLiteralParser(char const*, char const*, clang::SourceLocation, clang::Preprocessor&)"},
    {"_Z16ProcessUCNEscapeRPKcS0_RjRtN5clang13FullSourceLocEPNS4_10DiagnosticERKNS4_11LangOptionsE", "ProcessUCNEscape(char const*&, char const*, unsigned int&, unsigned short&, clang::FullSourceLoc, clang::Diagnostic*, clang::LangOptions const&)"},
    {"_Z17ProcessCharEscapeRPKcS0_RbN5clang13FullSourceLocEbPNS3_10DiagnosticERKNS3_10TargetInfoE", "ProcessCharEscape(char const*&, char const*, bool&, clang::FullSourceLoc, bool, clang::Diagnostic*, clang::TargetInfo const&)"},
    {"_ZN5clang19StringLiteralParserC1EPKNS_5TokenEjRNS_12PreprocessorEb", "clang::StringLiteralParser::StringLiteralParser(clang::Token const*, unsigned int, clang::Preprocessor&, bool)"},
    {"_ZN5clang19StringLiteralParserC2EPKNS_5TokenEjRNS_12PreprocessorEb", "clang::StringLiteralParser::StringLiteralParser(clang::Token const*, unsigned int, clang::Preprocessor&, bool)"},
    {"_ZN5clang19StringLiteralParser4initEPKNS_5TokenEj", "clang::StringLiteralParser::init(clang::Token const*, unsigned int)"},
    {"_ZNK5clang19StringLiteralParser21getOffsetOfStringByteERKNS_5TokenEj", "clang::StringLiteralParser::getOffsetOfStringByte(clang::Token const&, unsigned int) const"},
    {"_ZN5clang9MacroArgs6createEPKNS_9MacroInfoEPKNS_5TokenEjbRNS_12PreprocessorE", "clang::MacroArgs::create(clang::MacroInfo const*, clang::Token const*, unsigned int, bool, clang::Preprocessor&)"},
    {"_ZNK5clang9MacroArgs16getUnexpArgumentEj", "clang::MacroArgs::getUnexpArgument(unsigned int) const"},
    {"_ZN5clang9MacroArgs7destroyERNS_12PreprocessorE", "clang::MacroArgs::destroy(clang::Preprocessor&)"},
    {"_ZN5clang9MacroArgs10deallocateEv", "clang::MacroArgs::deallocate()"},
    {"_ZN5clang9MacroArgs12getArgLengthEPKNS_5TokenE", "clang::MacroArgs::getArgLength(clang::Token const*)"},
    {"_ZNK5clang9MacroArgs20ArgNeedsPreexpansionEPKNS_5TokenERNS_12PreprocessorE", "clang::MacroArgs::ArgNeedsPreexpansion(clang::Token const*, clang::Preprocessor&) const"},
    {"_ZN5clang9MacroArgs17getPreExpArgumentEjPKNS_9MacroInfoERNS_12PreprocessorE", "clang::MacroArgs::getPreExpArgument(unsigned int, clang::MacroInfo const*, clang::Preprocessor&)"},
    {"_ZN5clang9MacroArgs17StringifyArgumentEPKNS_5TokenERNS_12PreprocessorEb", "clang::MacroArgs::StringifyArgument(clang::Token const*, clang::Preprocessor&, bool)"},
    {"_ZN5clang9MacroArgs22getStringifiedArgumentEjRNS_12PreprocessorE", "clang::MacroArgs::getStringifiedArgument(unsigned int, clang::Preprocessor&)"},
    {"_ZNSt6vectorIN5clang5TokenESaIS1_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS1_S3_EEmRKS1_", "std::vector<clang::Token, std::allocator<clang::Token>>::_M_fill_insert(__gnu_cxx::__normal_iterator<clang::Token*, std::vector<clang::Token, std::allocator<clang::Token>>>, unsigned long, clang::Token const&)"},
    {"_ZNSt6vectorIN5clang5TokenESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<clang::Token, std::allocator<clang::Token>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::Token*, std::vector<clang::Token, std::allocator<clang::Token>>>, clang::Token const&)"},
    {"_ZNSt6vectorIS_IN5clang5TokenESaIS1_EESaIS3_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS3_S5_EEmRKS3_", "std::vector<std::vector<clang::Token, std::allocator<clang::Token>>, std::allocator<std::vector<clang::Token, std::allocator<clang::Token>>>>::_M_fill_insert(__gnu_cxx::__normal_iterator<std::vector<clang::Token, std::allocator<clang::Token>>*, std::vector<std::vector<clang::Token, std::allocator<clang::Token>>, std::allocator<std::vector<clang::Token, std::allocator<clang::Token>>>>>, unsigned long, std::vector<clang::Token, std::allocator<clang::Token>> const&)"},
    {"_ZNSt6vectorIN5clang5TokenESaIS1_EEaSERKS3_", "std::vector<clang::Token, std::allocator<clang::Token>>::operator=(std::vector<clang::Token, std::allocator<clang::Token>> const&)"},
    {"_ZNSt6vectorIN5clang5TokenESaIS1_EEC2ERKS3_", "std::vector<clang::Token, std::allocator<clang::Token>>::vector(std::vector<clang::Token, std::allocator<clang::Token>> const&)"},
    {"_ZN5clang9MacroInfoC1ENS_14SourceLocationE", "clang::MacroInfo::MacroInfo(clang::SourceLocation)"},
    {"_ZN5clang9MacroInfoC2ENS_14SourceLocationE", "clang::MacroInfo::MacroInfo(clang::SourceLocation)"},
    {"_ZN5clang9MacroInfoC1ERKS0_RN4llvm16BumpPtrAllocatorE", "clang::MacroInfo::MacroInfo(clang::MacroInfo const&, llvm::BumpPtrAllocator&)"},
    {"_ZN5clang9MacroInfoC2ERKS0_RN4llvm16BumpPtrAllocatorE", "clang::MacroInfo::MacroInfo(clang::MacroInfo const&, llvm::BumpPtrAllocator&)"},
    {"_ZNK5clang9MacroInfo13isIdenticalToERKS0_RNS_12PreprocessorE", "clang::MacroInfo::isIdenticalTo(clang::MacroInfo const&, clang::Preprocessor&) const"},
    {"_ZN4llvm15SmallVectorImplIN5clang5TokenEEaSERKS3_", "llvm::SmallVectorImpl<clang::Token>::operator=(llvm::SmallVectorImpl<clang::Token> const&)"},
    {"_ZN5clang12Preprocessor24EnableBacktrackAtThisPosEv", "clang::Preprocessor::EnableBacktrackAtThisPos()"},
    {"_ZN5clang12Preprocessor19EnterCachingLexModeEv", "clang::Preprocessor::EnterCachingLexMode()"},
    {"_ZN5clang12Preprocessor23CommitBacktrackedTokensEv", "clang::Preprocessor::CommitBacktrackedTokens()"},
    {"_ZN5clang12Preprocessor9BacktrackEv", "clang::Preprocessor::Backtrack()"},
    {"_ZN5clang12Preprocessor10CachingLexERNS_5TokenE", "clang::Preprocessor::CachingLex(clang::Token&)"},
    {"_ZN5clang12Preprocessor9PeekAheadEj", "clang::Preprocessor::PeekAhead(unsigned int)"},
    {"_ZN5clang12Preprocessor28AnnotatePreviousCachedTokensERKNS_5TokenE", "clang::Preprocessor::AnnotatePreviousCachedTokens(clang::Token const&)"},
    {"_ZNSt6vectorImSaImEE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPmS1_EERKm", "std::vector<unsigned long, std::allocator<unsigned long>>::_M_insert_aux(__gnu_cxx::__normal_iterator<unsigned long*, std::vector<unsigned long, std::allocator<unsigned long>>>, unsigned long const&)"},
    {"_ZN5clang12Preprocessor17AllocateMacroInfoEv", "clang::Preprocessor::AllocateMacroInfo()"},
    {"_ZN5clang12Preprocessor17AllocateMacroInfoENS_14SourceLocationE", "clang::Preprocessor::AllocateMacroInfo(clang::SourceLocation)"},
    {"_ZN5clang12Preprocessor14CloneMacroInfoERKNS_9MacroInfoE", "clang::Preprocessor::CloneMacroInfo(clang::MacroInfo const&)"},
    {"_ZN5clang12Preprocessor16ReleaseMacroInfoEPNS_9MacroInfoE", "clang::Preprocessor::ReleaseMacroInfo(clang::MacroInfo*)"},
    {"_ZN5clang12Preprocessor26DiscardUntilEndOfDirectiveEv", "clang::Preprocessor::DiscardUntilEndOfDirective()"},
    {"_ZN5clang12Preprocessor13ReadMacroNameERNS_5TokenEc", "clang::Preprocessor::ReadMacroName(clang::Token&, char)"},
    {"_ZN5clang12Preprocessor19CheckEndOfDirectiveEPKcb", "clang::Preprocessor::CheckEndOfDirective(char const*, bool)"},
    {"_ZN5clang12Preprocessor28SkipExcludedConditionalBlockENS_14SourceLocationEbb", "clang::Preprocessor::SkipExcludedConditionalBlock(clang::SourceLocation, bool, bool)"},
    {"_ZN5clang12Preprocessor31PTHSkipExcludedConditionalBlockEv", "clang::Preprocessor::PTHSkipExcludedConditionalBlock()"},
    {"_ZN5clang12Preprocessor10LookupFileEN4llvm9StringRefEbPKNS_15DirectoryLookupERS5_", "clang::Preprocessor::LookupFile(llvm::StringRef, bool, clang::DirectoryLookup const*, clang::DirectoryLookup const*&)"},
    {"_ZN5clang12Preprocessor15HandleDirectiveERNS_5TokenE", "clang::Preprocessor::HandleDirective(clang::Token&)"},
    {"_ZN5clang12Preprocessor20HandleDigitDirectiveERNS_5TokenE", "clang::Preprocessor::HandleDigitDirective(clang::Token&)"},
    {"_ZN5clang12Preprocessor17HandleIfDirectiveERNS_5TokenEb", "clang::Preprocessor::HandleIfDirective(clang::Token&, bool)"},
    {"_ZN5clang12Preprocessor20HandleIfdefDirectiveERNS_5TokenEbb", "clang::Preprocessor::HandleIfdefDirective(clang::Token&, bool, bool)"},
    {"_ZN5clang12Preprocessor19HandleElifDirectiveERNS_5TokenE", "clang::Preprocessor::HandleElifDirective(clang::Token&)"},
    {"_ZN5clang12Preprocessor19HandleElseDirectiveERNS_5TokenE", "clang::Preprocessor::HandleElseDirective(clang::Token&)"},
    {"_ZN5clang12Preprocessor20HandleEndifDirectiveERNS_5TokenE", "clang::Preprocessor::HandleEndifDirective(clang::Token&)"},
    {"_ZN5clang12Preprocessor22HandleIncludeDirectiveENS_14SourceLocationERNS_5TokenEPKNS_15DirectoryLookupEb", "clang::Preprocessor::HandleIncludeDirective(clang::SourceLocation, clang::Token&, clang::DirectoryLookup const*, bool)"},
    {"_ZN5clang12Preprocessor28HandleIncludeMacrosDirectiveENS_14SourceLocationERNS_5TokenE", "clang::Preprocessor::HandleIncludeMacrosDirective(clang::SourceLocation, clang::Token&)"},
    {"_ZN5clang12Preprocessor21HandleDefineDirectiveERNS_5TokenE", "clang::Preprocessor::HandleDefineDirective(clang::Token&)"},
    {"_ZN5clang12Preprocessor20HandleUndefDirectiveERNS_5TokenE", "clang::Preprocessor::HandleUndefDirective(clang::Token&)"},
    {"_ZN5clang12Preprocessor19HandleLineDirectiveERNS_5TokenE", "clang::Preprocessor::HandleLineDirective(clang::Token&)"},
    {"_ZN5clang12Preprocessor29HandleUserDiagnosticDirectiveERNS_5TokenEb", "clang::Preprocessor::HandleUserDiagnosticDirective(clang::Token&, bool)"},
    {"_ZN5clang12Preprocessor21HandleImportDirectiveENS_14SourceLocationERNS_5TokenE", "clang::Preprocessor::HandleImportDirective(clang::SourceLocation, clang::Token&)"},
    {"_ZN5clang12Preprocessor26HandleIncludeNextDirectiveENS_14SourceLocationERNS_5TokenE", "clang::Preprocessor::HandleIncludeNextDirective(clang::SourceLocation, clang::Token&)"},
    {"_ZN5clang12Preprocessor24HandleIdentSCCSDirectiveERNS_5TokenE", "clang::Preprocessor::HandleIdentSCCSDirective(clang::Token&)"},
    {"_Z12GetLineValueRN5clang5TokenERjjRNS_12PreprocessorE", "GetLineValue(clang::Token&, unsigned int&, unsigned int, clang::Preprocessor&)"},
    {"_ZN5clang12Preprocessor26GetIncludeFilenameSpellingENS_14SourceLocationERN4llvm9StringRefE", "clang::Preprocessor::GetIncludeFilenameSpelling(clang::SourceLocation, llvm::StringRef&)"},
    {"_ZN5clang12Preprocessor22ConcatenateIncludeNameERN4llvm11SmallStringILj128EEERNS_14SourceLocationE", "clang::Preprocessor::ConcatenateIncludeName(llvm::SmallString<128u>&, clang::SourceLocation&)"},
    {"_ZN5clang12Preprocessor26ReadMacroDefinitionArgListEPNS_9MacroInfoE", "clang::Preprocessor::ReadMacroDefinitionArgList(clang::MacroInfo*)"},
    {"_ZSt6__findIPPN5clang14IdentifierInfoES2_ET_S4_S4_RKT0_St26random_access_iterator_tag", "clang::IdentifierInfo** std::__find<clang::IdentifierInfo**, clang::IdentifierInfo*>(clang::IdentifierInfo**, clang::IdentifierInfo**, clang::IdentifierInfo* const&, std::random_access_iterator_tag)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN5clang17PPConditionalInfoELb0EE4growEm", "llvm::SmallVectorTemplateBase<clang::PPConditionalInfo, false>::grow(unsigned long)"},
    {"_ZN5clang12Preprocessor27EvaluateDirectiveExpressionERPNS_14IdentifierInfoE", "clang::Preprocessor::EvaluateDirectiveExpression(clang::IdentifierInfo*&)"},
    {"_Z13EvaluateValueRN12_GLOBAL__N_17PPValueERN5clang5TokenER14DefinedTrackerbRNS2_12PreprocessorE", "EvaluateValue((anonymous namespace)::PPValue&, clang::Token&, DefinedTracker&, bool, clang::Preprocessor&)"},
    {"_Z24EvaluateDirectiveSubExprRN12_GLOBAL__N_17PPValueEjRN5clang5TokenEbRNS2_12PreprocessorE", "EvaluateDirectiveSubExpr((anonymous namespace)::PPValue&, unsigned int, clang::Token&, bool, clang::Preprocessor&)"},
    {"_ZN5clang11PPCallbacksD0Ev", "clang::PPCallbacks::~PPCallbacks()"},
    {"_ZN5clang11PPCallbacksD1Ev", "clang::PPCallbacks::~PPCallbacks()"},
    {"_ZN5clang11PPCallbacksD2Ev", "clang::PPCallbacks::~PPCallbacks()"},
    {"_ZNK5clang12Preprocessor15isInPrimaryFileEv", "clang::Preprocessor::isInPrimaryFile() const"},
    {"_ZNK5clang12Preprocessor19getCurrentFileLexerEv", "clang::Preprocessor::getCurrentFileLexer() const"},
    {"_ZN5clang12Preprocessor15EnterSourceFileENS_6FileIDEPKNS_15DirectoryLookupENS_14SourceLocationE", "clang::Preprocessor::EnterSourceFile(clang::FileID, clang::DirectoryLookup const*, clang::SourceLocation)"},
    {"_ZN5clang12Preprocessor22EnterSourceFileWithPTHEPNS_8PTHLexerEPKNS_15DirectoryLookupE", "clang::Preprocessor::EnterSourceFileWithPTH(clang::PTHLexer*, clang::DirectoryLookup const*)"},
    {"_ZN5clang12Preprocessor24EnterSourceFileWithLexerEPNS_5LexerEPKNS_15DirectoryLookupE", "clang::Preprocessor::EnterSourceFileWithLexer(clang::Lexer*, clang::DirectoryLookup const*)"},
    {"_ZN5clang12Preprocessor10EnterMacroERNS_5TokenENS_14SourceLocationEPNS_9MacroArgsE", "clang::Preprocessor::EnterMacro(clang::Token&, clang::SourceLocation, clang::MacroArgs*)"},
    {"_ZN5clang12Preprocessor16EnterTokenStreamEPKNS_5TokenEjbb", "clang::Preprocessor::EnterTokenStream(clang::Token const*, unsigned int, bool, bool)"},
    {"_ZN5clang12Preprocessor15HandleEndOfFileERNS_5TokenEb", "clang::Preprocessor::HandleEndOfFile(clang::Token&, bool)"},
    {"_ZN5clang12Preprocessor21RemoveTopOfLexerStackEv", "clang::Preprocessor::RemoveTopOfLexerStack()"},
    {"_ZN5clang12Preprocessor21HandleEndOfTokenLexerERNS_5TokenE", "clang::Preprocessor::HandleEndOfTokenLexer(clang::Token&)"},
    {"_ZN5clang12Preprocessor27HandleMicrosoftCommentPasteERNS_5TokenE", "clang::Preprocessor::HandleMicrosoftCommentPaste(clang::Token&)"},
    {"_ZNK5clang13SourceManager9getBufferENS_6FileIDENS_14SourceLocationEPb", "clang::SourceManager::getBuffer(clang::FileID, clang::SourceLocation, bool*) const"},
    {"_ZN5clang12Preprocessor20PopIncludeMacroStackEv", "clang::Preprocessor::PopIncludeMacroStack()"},
    {"_ZNSt6vectorIN5clang12Preprocessor16IncludeStackInfoESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::Preprocessor::IncludeStackInfo, std::allocator<clang::Preprocessor::IncludeStackInfo>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::Preprocessor::IncludeStackInfo*, std::vector<clang::Preprocessor::IncludeStackInfo, std::allocator<clang::Preprocessor::IncludeStackInfo>>>, clang::Preprocessor::IncludeStackInfo const&)"},
    {"_ZNK5clang12Preprocessor15getInfoForMacroEPNS_14IdentifierInfoE", "clang::Preprocessor::getInfoForMacro(clang::IdentifierInfo*) const"},
    {"_ZN5clang12Preprocessor12setMacroInfoEPNS_14IdentifierInfoEPNS_9MacroInfoE", "clang::Preprocessor::setMacroInfo(clang::IdentifierInfo*, clang::MacroInfo*)"},
    {"_ZN5clang12Preprocessor21RegisterBuiltinMacrosEv", "clang::Preprocessor::RegisterBuiltinMacros()"},
    {"_ZN5clang12Preprocessor19isNextPPTokenLParenEv", "clang::Preprocessor::isNextPPTokenLParen()"},
    {"_ZN5clang12Preprocessor29HandleMacroExpandedIdentifierERNS_5TokenEPNS_9MacroInfoE", "clang::Preprocessor::HandleMacroExpandedIdentifier(clang::Token&, clang::MacroInfo*)"},
    {"_ZN5clang12Preprocessor18ExpandBuiltinMacroERNS_5TokenE", "clang::Preprocessor::ExpandBuiltinMacro(clang::Token&)"},
    {"_ZN5clang12Preprocessor25ReadFunctionLikeMacroArgsERNS_5TokenEPNS_9MacroInfoERNS_14SourceLocationE", "clang::Preprocessor::ReadFunctionLikeMacroArgs(clang::Token&, clang::MacroInfo*, clang::SourceLocation&)"},
    {"_ZN5clang12Preprocessor15markMacroAsUsedEPNS_9MacroInfoE", "clang::Preprocessor::markMacroAsUsed(clang::MacroInfo*)"},
    {"_Z16ComputeDATE_TIMERN5clang14SourceLocationES1_RNS_12PreprocessorE", "ComputeDATE_TIME(clang::SourceLocation&, clang::SourceLocation&, clang::Preprocessor&)"},
    {"_Z24EvaluateHasIncludeCommonRN5clang5TokenEPNS_14IdentifierInfoERNS_12PreprocessorEPKNS_15DirectoryLookupE", "EvaluateHasIncludeCommon(clang::Token&, clang::IdentifierInfo*, clang::Preprocessor&, clang::DirectoryLookup const*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEPNS1_9MacroInfoENS_12DenseMapInfoIS3_EENS6_IS5_EEE16InsertIntoBucketERKS3_RKS5_PSt4pairIS3_S5_E", "llvm::DenseMap<clang::IdentifierInfo*, clang::MacroInfo*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::MacroInfo*>>::InsertIntoBucket(clang::IdentifierInfo* const&, clang::MacroInfo* const&, std::pair<clang::IdentifierInfo*, clang::MacroInfo*>*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoEPNS1_9MacroInfoENS_12DenseMapInfoIS3_EENS6_IS5_EEE4growEj", "llvm::DenseMap<clang::IdentifierInfo*, clang::MacroInfo*, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<clang::MacroInfo*>>::grow(unsigned int)"},
    {"_ZN5clang8PTHLexerC1ERNS_12PreprocessorENS_6FileIDEPKhS5_RNS_10PTHManagerE", "clang::PTHLexer::PTHLexer(clang::Preprocessor&, clang::FileID, unsigned char const*, unsigned char const*, clang::PTHManager&)"},
    {"_ZN5clang8PTHLexerC2ERNS_12PreprocessorENS_6FileIDEPKhS5_RNS_10PTHManagerE", "clang::PTHLexer::PTHLexer(clang::Preprocessor&, clang::FileID, unsigned char const*, unsigned char const*, clang::PTHManager&)"},
    {"_ZN5clang8PTHLexer3LexERNS_5TokenE", "clang::PTHLexer::Lex(clang::Token&)"},
    {"_ZN5clang8PTHLexer12LexEndOfFileERNS_5TokenE", "clang::PTHLexer::LexEndOfFile(clang::Token&)"},
    {"_ZN5clang8PTHLexer6getEOFERNS_5TokenE", "clang::PTHLexer::getEOF(clang::Token&)"},
    {"_ZN5clang8PTHLexer18DiscardToEndOfLineEv", "clang::PTHLexer::DiscardToEndOfLine()"},
    {"_ZN5clang8PTHLexer9SkipBlockEv", "clang::PTHLexer::SkipBlock()"},
    {"_ZN5clang8PTHLexer17getSourceLocationEv", "clang::PTHLexer::getSourceLocation()"},
    {"_ZN5clang10PTHManagerC1EPKN4llvm12MemoryBufferEPvPKhPPNS_14IdentifierInfoES5_jS7_PKc", "clang::PTHManager::PTHManager(llvm::MemoryBuffer const*, void*, unsigned char const*, clang::IdentifierInfo**, void*, unsigned int, unsigned char const*, char const*)"},
    {"_ZN5clang10PTHManagerC2EPKN4llvm12MemoryBufferEPvPKhPPNS_14IdentifierInfoES5_jS7_PKc", "clang::PTHManager::PTHManager(llvm::MemoryBuffer const*, void*, unsigned char const*, clang::IdentifierInfo**, void*, unsigned int, unsigned char const*, char const*)"},
    {"_ZN5clang10PTHManagerD0Ev", "clang::PTHManager::~PTHManager()"},
    {"_ZN5clang10PTHManagerD1Ev", "clang::PTHManager::~PTHManager()"},
    {"_ZN5clang10PTHManagerD2Ev", "clang::PTHManager::~PTHManager()"},
    {"_ZN5clang10PTHManager6CreateERKSsRNS_10DiagnosticE", "clang::PTHManager::Create(std::string const&, clang::Diagnostic&)"},
    {"_ZN5clang10PTHManager26LazilyCreateIdentifierInfoEj", "clang::PTHManager::LazilyCreateIdentifierInfo(unsigned int)"},
    {"_ZN5clang10PTHManager3getEN4llvm9StringRefE", "clang::PTHManager::get(llvm::StringRef)"},
    {"_ZN5clang10PTHManager11CreateLexerENS_6FileIDE", "clang::PTHManager::CreateLexer(clang::FileID)"},
    {"_ZN5clang10PTHManager15createStatCacheEv", "clang::PTHManager::createStatCache()"},
    {"_ZN12_GLOBAL__N_112PTHStatCacheD1Ev", "(anonymous namespace)::PTHStatCache::~PTHStatCache()"},
    {"_ZN12_GLOBAL__N_112PTHStatCacheD0Ev", "(anonymous namespace)::PTHStatCache::~PTHStatCache()"},
    {"_ZN12_GLOBAL__N_112PTHStatCache7getStatEPKcR4statPi", "(anonymous namespace)::PTHStatCache::getStat(char const*, stat&, int*)"},
    {"_ZN5clang8PTHLexerD1Ev", "clang::PTHLexer::~PTHLexer()"},
    {"_ZN5clang8PTHLexerD0Ev", "clang::PTHLexer::~PTHLexer()"},
    {"_ZN5clang8PTHLexer11IndirectLexERNS_5TokenE", "clang::PTHLexer::IndirectLex(clang::Token&)"},
    {"_ZN5clang13PragmaHandlerD0Ev", "clang::PragmaHandler::~PragmaHandler()"},
    {"_ZN5clang13PragmaHandlerD1Ev", "clang::PragmaHandler::~PragmaHandler()"},
    {"_ZN5clang13PragmaHandlerD2Ev", "clang::PragmaHandler::~PragmaHandler()"},
    {"_ZN5clang18EmptyPragmaHandlerC1Ev", "clang::EmptyPragmaHandler::EmptyPragmaHandler()"},
    {"_ZN5clang18EmptyPragmaHandlerC2Ev", "clang::EmptyPragmaHandler::EmptyPragmaHandler()"},
    {"_ZN5clang18EmptyPragmaHandler12HandlePragmaERNS_12PreprocessorENS_20PragmaIntroducerKindERNS_5TokenE", "clang::EmptyPragmaHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN5clang15PragmaNamespaceD0Ev", "clang::PragmaNamespace::~PragmaNamespace()"},
    {"_ZN5clang15PragmaNamespaceD1Ev", "clang::PragmaNamespace::~PragmaNamespace()"},
    {"_ZN5clang15PragmaNamespaceD2Ev", "clang::PragmaNamespace::~PragmaNamespace()"},
    {"_ZNK5clang15PragmaNamespace11FindHandlerEN4llvm9StringRefEb", "clang::PragmaNamespace::FindHandler(llvm::StringRef, bool) const"},
    {"_ZN5clang15PragmaNamespace9AddPragmaEPNS_13PragmaHandlerE", "clang::PragmaNamespace::AddPragma(clang::PragmaHandler*)"},
    {"_ZN5clang15PragmaNamespace19RemovePragmaHandlerEPNS_13PragmaHandlerE", "clang::PragmaNamespace::RemovePragmaHandler(clang::PragmaHandler*)"},
    {"_ZN5clang15PragmaNamespace12HandlePragmaERNS_12PreprocessorENS_20PragmaIntroducerKindERNS_5TokenE", "clang::PragmaNamespace::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN5clang12Preprocessor21HandlePragmaDirectiveEj", "clang::Preprocessor::HandlePragmaDirective(unsigned int)"},
    {"_ZN5clang12Preprocessor13Handle_PragmaERNS_5TokenE", "clang::Preprocessor::Handle_Pragma(clang::Token&)"},
    {"_ZN5clang12Preprocessor13Handle_PragmaEjRKSsNS_14SourceLocationES3_", "clang::Preprocessor::Handle_Pragma(unsigned int, std::string const&, clang::SourceLocation, clang::SourceLocation)"},
    {"_ZN5clang12Preprocessor23HandleMicrosoft__pragmaERNS_5TokenE", "clang::Preprocessor::HandleMicrosoft__pragma(clang::Token&)"},
    {"_ZN5clang12Preprocessor16HandlePragmaOnceERNS_5TokenE", "clang::Preprocessor::HandlePragmaOnce(clang::Token&)"},
    {"_ZN5clang12Preprocessor16HandlePragmaMarkEv", "clang::Preprocessor::HandlePragmaMark()"},
    {"_ZN5clang12Preprocessor18HandlePragmaPoisonERNS_5TokenE", "clang::Preprocessor::HandlePragmaPoison(clang::Token&)"},
    {"_ZN5clang12Preprocessor24HandlePragmaSystemHeaderERNS_5TokenE", "clang::Preprocessor::HandlePragmaSystemHeader(clang::Token&)"},
    {"_ZN5clang12Preprocessor22HandlePragmaDependencyERNS_5TokenE", "clang::Preprocessor::HandlePragmaDependency(clang::Token&)"},
    {"_ZN5clang12Preprocessor19HandlePragmaCommentERNS_5TokenE", "clang::Preprocessor::HandlePragmaComment(clang::Token&)"},
    {"_ZN5clang12Preprocessor19HandlePragmaMessageERNS_5TokenE", "clang::Preprocessor::HandlePragmaMessage(clang::Token&)"},
    {"_ZN5clang12Preprocessor25ParsePragmaPushOrPopMacroERNS_5TokenE", "clang::Preprocessor::ParsePragmaPushOrPopMacro(clang::Token&)"},
    {"_ZN5clang12Preprocessor21HandlePragmaPushMacroERNS_5TokenE", "clang::Preprocessor::HandlePragmaPushMacro(clang::Token&)"},
    {"_ZN5clang12Preprocessor20HandlePragmaPopMacroERNS_5TokenE", "clang::Preprocessor::HandlePragmaPopMacro(clang::Token&)"},
    {"_ZN5clang12Preprocessor16AddPragmaHandlerEN4llvm9StringRefEPNS_13PragmaHandlerE", "clang::Preprocessor::AddPragmaHandler(llvm::StringRef, clang::PragmaHandler*)"},
    {"_ZN5clang12Preprocessor19RemovePragmaHandlerEN4llvm9StringRefEPNS_13PragmaHandlerE", "clang::Preprocessor::RemovePragmaHandler(llvm::StringRef, clang::PragmaHandler*)"},
    {"_ZN5clang12Preprocessor22RegisterBuiltinPragmasEv", "clang::Preprocessor::RegisterBuiltinPragmas()"},
    {"_ZN12_GLOBAL__N_120PragmaCommentHandlerD1Ev", "(anonymous namespace)::PragmaCommentHandler::~PragmaCommentHandler()"},
    {"_ZN12_GLOBAL__N_120PragmaCommentHandlerD0Ev", "(anonymous namespace)::PragmaCommentHandler::~PragmaCommentHandler()"},
    {"_ZN12_GLOBAL__N_120PragmaCommentHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaCommentHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_125PragmaSTDC_UnknownHandlerD1Ev", "(anonymous namespace)::PragmaSTDC_UnknownHandler::~PragmaSTDC_UnknownHandler()"},
    {"_ZN12_GLOBAL__N_125PragmaSTDC_UnknownHandlerD0Ev", "(anonymous namespace)::PragmaSTDC_UnknownHandler::~PragmaSTDC_UnknownHandler()"},
    {"_ZN12_GLOBAL__N_125PragmaSTDC_UnknownHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaSTDC_UnknownHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_134PragmaSTDC_CX_LIMITED_RANGEHandlerD1Ev", "(anonymous namespace)::PragmaSTDC_CX_LIMITED_RANGEHandler::~PragmaSTDC_CX_LIMITED_RANGEHandler()"},
    {"_ZN12_GLOBAL__N_134PragmaSTDC_CX_LIMITED_RANGEHandlerD0Ev", "(anonymous namespace)::PragmaSTDC_CX_LIMITED_RANGEHandler::~PragmaSTDC_CX_LIMITED_RANGEHandler()"},
    {"_ZN12_GLOBAL__N_134PragmaSTDC_CX_LIMITED_RANGEHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaSTDC_CX_LIMITED_RANGEHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_114LexOnOffSwitchERN5clang12PreprocessorE", "(anonymous namespace)::LexOnOffSwitch(clang::Preprocessor&)"},
    {"_ZN12_GLOBAL__N_129PragmaSTDC_FENV_ACCESSHandlerD1Ev", "(anonymous namespace)::PragmaSTDC_FENV_ACCESSHandler::~PragmaSTDC_FENV_ACCESSHandler()"},
    {"_ZN12_GLOBAL__N_129PragmaSTDC_FENV_ACCESSHandlerD0Ev", "(anonymous namespace)::PragmaSTDC_FENV_ACCESSHandler::~PragmaSTDC_FENV_ACCESSHandler()"},
    {"_ZN12_GLOBAL__N_129PragmaSTDC_FENV_ACCESSHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaSTDC_FENV_ACCESSHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_129PragmaSTDC_FP_CONTRACTHandlerD1Ev", "(anonymous namespace)::PragmaSTDC_FP_CONTRACTHandler::~PragmaSTDC_FP_CONTRACTHandler()"},
    {"_ZN12_GLOBAL__N_129PragmaSTDC_FP_CONTRACTHandlerD0Ev", "(anonymous namespace)::PragmaSTDC_FP_CONTRACTHandler::~PragmaSTDC_FP_CONTRACTHandler()"},
    {"_ZN12_GLOBAL__N_129PragmaSTDC_FP_CONTRACTHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaSTDC_FP_CONTRACTHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_118PragmaDebugHandlerD1Ev", "(anonymous namespace)::PragmaDebugHandler::~PragmaDebugHandler()"},
    {"_ZN12_GLOBAL__N_118PragmaDebugHandlerD0Ev", "(anonymous namespace)::PragmaDebugHandler::~PragmaDebugHandler()"},
    {"_ZN12_GLOBAL__N_118PragmaDebugHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaDebugHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_123PragmaDiagnosticHandlerD1Ev", "(anonymous namespace)::PragmaDiagnosticHandler::~PragmaDiagnosticHandler()"},
    {"_ZN12_GLOBAL__N_123PragmaDiagnosticHandlerD0Ev", "(anonymous namespace)::PragmaDiagnosticHandler::~PragmaDiagnosticHandler()"},
    {"_ZN12_GLOBAL__N_123PragmaDiagnosticHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaDiagnosticHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_123PragmaDependencyHandlerD1Ev", "(anonymous namespace)::PragmaDependencyHandler::~PragmaDependencyHandler()"},
    {"_ZN12_GLOBAL__N_123PragmaDependencyHandlerD0Ev", "(anonymous namespace)::PragmaDependencyHandler::~PragmaDependencyHandler()"},
    {"_ZN12_GLOBAL__N_123PragmaDependencyHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaDependencyHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_125PragmaSystemHeaderHandlerD1Ev", "(anonymous namespace)::PragmaSystemHeaderHandler::~PragmaSystemHeaderHandler()"},
    {"_ZN12_GLOBAL__N_125PragmaSystemHeaderHandlerD0Ev", "(anonymous namespace)::PragmaSystemHeaderHandler::~PragmaSystemHeaderHandler()"},
    {"_ZN12_GLOBAL__N_125PragmaSystemHeaderHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaSystemHeaderHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_119PragmaPoisonHandlerD1Ev", "(anonymous namespace)::PragmaPoisonHandler::~PragmaPoisonHandler()"},
    {"_ZN12_GLOBAL__N_119PragmaPoisonHandlerD0Ev", "(anonymous namespace)::PragmaPoisonHandler::~PragmaPoisonHandler()"},
    {"_ZN12_GLOBAL__N_119PragmaPoisonHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaPoisonHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_120PragmaMessageHandlerD1Ev", "(anonymous namespace)::PragmaMessageHandler::~PragmaMessageHandler()"},
    {"_ZN12_GLOBAL__N_120PragmaMessageHandlerD0Ev", "(anonymous namespace)::PragmaMessageHandler::~PragmaMessageHandler()"},
    {"_ZN12_GLOBAL__N_120PragmaMessageHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaMessageHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_121PragmaPopMacroHandlerD1Ev", "(anonymous namespace)::PragmaPopMacroHandler::~PragmaPopMacroHandler()"},
    {"_ZN12_GLOBAL__N_121PragmaPopMacroHandlerD0Ev", "(anonymous namespace)::PragmaPopMacroHandler::~PragmaPopMacroHandler()"},
    {"_ZN12_GLOBAL__N_121PragmaPopMacroHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaPopMacroHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_122PragmaPushMacroHandlerD1Ev", "(anonymous namespace)::PragmaPushMacroHandler::~PragmaPushMacroHandler()"},
    {"_ZN12_GLOBAL__N_122PragmaPushMacroHandlerD0Ev", "(anonymous namespace)::PragmaPushMacroHandler::~PragmaPushMacroHandler()"},
    {"_ZN12_GLOBAL__N_122PragmaPushMacroHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaPushMacroHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_117PragmaMarkHandlerD1Ev", "(anonymous namespace)::PragmaMarkHandler::~PragmaMarkHandler()"},
    {"_ZN12_GLOBAL__N_117PragmaMarkHandlerD0Ev", "(anonymous namespace)::PragmaMarkHandler::~PragmaMarkHandler()"},
    {"_ZN12_GLOBAL__N_117PragmaMarkHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaMarkHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN12_GLOBAL__N_117PragmaOnceHandlerD1Ev", "(anonymous namespace)::PragmaOnceHandler::~PragmaOnceHandler()"},
    {"_ZN12_GLOBAL__N_117PragmaOnceHandlerD0Ev", "(anonymous namespace)::PragmaOnceHandler::~PragmaOnceHandler()"},
    {"_ZN12_GLOBAL__N_117PragmaOnceHandler12HandlePragmaERN5clang12PreprocessorENS1_20PragmaIntroducerKindERNS1_5TokenE", "(anonymous namespace)::PragmaOnceHandler::HandlePragma(clang::Preprocessor&, clang::PragmaIntroducerKind, clang::Token&)"},
    {"_ZN5clang18EmptyPragmaHandlerD1Ev", "clang::EmptyPragmaHandler::~EmptyPragmaHandler()"},
    {"_ZN5clang18EmptyPragmaHandlerD0Ev", "clang::EmptyPragmaHandler::~EmptyPragmaHandler()"},
    {"_ZNSt6vectorIPN5clang9MacroInfoESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::MacroInfo*, std::allocator<clang::MacroInfo*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::MacroInfo**, std::vector<clang::MacroInfo*, std::allocator<clang::MacroInfo*>>>, clang::MacroInfo* const&)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoESt6vectorIPNS1_9MacroInfoESaIS6_EENS_12DenseMapInfoIS3_EENS9_IS8_EEE16FindAndConstructERKS3_", "llvm::DenseMap<clang::IdentifierInfo*, std::vector<clang::MacroInfo*, std::allocator<clang::MacroInfo*>>, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<std::vector<clang::MacroInfo*, std::allocator<clang::MacroInfo*>>>>::FindAndConstruct(clang::IdentifierInfo* const&)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoESt6vectorIPNS1_9MacroInfoESaIS6_EENS_12DenseMapInfoIS3_EENS9_IS8_EEE16InsertIntoBucketERKS3_RKS8_PSt4pairIS3_S8_E", "llvm::DenseMap<clang::IdentifierInfo*, std::vector<clang::MacroInfo*, std::allocator<clang::MacroInfo*>>, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<std::vector<clang::MacroInfo*, std::allocator<clang::MacroInfo*>>>>::InsertIntoBucket(clang::IdentifierInfo* const&, std::vector<clang::MacroInfo*, std::allocator<clang::MacroInfo*>> const&, std::pair<clang::IdentifierInfo*, std::vector<clang::MacroInfo*, std::allocator<clang::MacroInfo*>>>*)"},
    {"_ZN4llvm8DenseMapIPN5clang14IdentifierInfoESt6vectorIPNS1_9MacroInfoESaIS6_EENS_12DenseMapInfoIS3_EENS9_IS8_EEE4growEj", "llvm::DenseMap<clang::IdentifierInfo*, std::vector<clang::MacroInfo*, std::allocator<clang::MacroInfo*>>, llvm::DenseMapInfo<clang::IdentifierInfo*>, llvm::DenseMapInfo<std::vector<clang::MacroInfo*, std::allocator<clang::MacroInfo*>>>>::grow(unsigned int)"},
    {"_ZN4llvm9StringMapIPN5clang13PragmaHandlerENS_15MallocAllocatorEE16GetOrCreateValueIS3_EERNS_14StringMapEntryIS3_EENS_9StringRefET_", "llvm::StringMapEntry<clang::PragmaHandler*>& llvm::StringMap<clang::PragmaHandler*, llvm::MallocAllocator>::GetOrCreateValue<clang::PragmaHandler*>(llvm::StringRef, clang::PragmaHandler*)"},
    {"_ZN5clang33ExternalPreprocessingRecordSourceD0Ev", "clang::ExternalPreprocessingRecordSource::~ExternalPreprocessingRecordSource()"},
    {"_ZN5clang33ExternalPreprocessingRecordSourceD1Ev", "clang::ExternalPreprocessingRecordSource::~ExternalPreprocessingRecordSource()"},
    {"_ZN5clang33ExternalPreprocessingRecordSourceD2Ev", "clang::ExternalPreprocessingRecordSource::~ExternalPreprocessingRecordSource()"},
    {"_ZN5clang18InclusionDirectiveC1ERNS_19PreprocessingRecordENS0_13InclusionKindEN4llvm9StringRefEbPKNS_9FileEntryENS_11SourceRangeE", "clang::InclusionDirective::InclusionDirective(clang::PreprocessingRecord&, clang::InclusionDirective::InclusionKind, llvm::StringRef, bool, clang::FileEntry const*, clang::SourceRange)"},
    {"_ZN5clang18InclusionDirectiveC2ERNS_19PreprocessingRecordENS0_13InclusionKindEN4llvm9StringRefEbPKNS_9FileEntryENS_11SourceRangeE", "clang::InclusionDirective::InclusionDirective(clang::PreprocessingRecord&, clang::InclusionDirective::InclusionKind, llvm::StringRef, bool, clang::FileEntry const*, clang::SourceRange)"},
    {"_ZNK5clang19PreprocessingRecord29MaybeLoadPreallocatedEntitiesEv", "clang::PreprocessingRecord::MaybeLoadPreallocatedEntities() const"},
    {"_ZN5clang19PreprocessingRecordC1Ev", "clang::PreprocessingRecord::PreprocessingRecord()"},
    {"_ZN5clang19PreprocessingRecordC2Ev", "clang::PreprocessingRecord::PreprocessingRecord()"},
    {"_ZN5clang19PreprocessingRecord5beginEb", "clang::PreprocessingRecord::begin(bool)"},
    {"_ZN5clang19PreprocessingRecord3endEb", "clang::PreprocessingRecord::end(bool)"},
    {"_ZNK5clang19PreprocessingRecord5beginEb", "clang::PreprocessingRecord::begin(bool) const"},
    {"_ZNK5clang19PreprocessingRecord3endEb", "clang::PreprocessingRecord::end(bool) const"},
    {"_ZN5clang19PreprocessingRecord21addPreprocessedEntityEPNS_18PreprocessedEntityE", "clang::PreprocessingRecord::addPreprocessedEntity(clang::PreprocessedEntity*)"},
    {"_ZN5clang19PreprocessingRecord17SetExternalSourceERNS_33ExternalPreprocessingRecordSourceEj", "clang::PreprocessingRecord::SetExternalSource(clang::ExternalPreprocessingRecordSource&, unsigned int)"},
    {"_ZN5clang19PreprocessingRecord21SetPreallocatedEntityEjPNS_18PreprocessedEntityE", "clang::PreprocessingRecord::SetPreallocatedEntity(unsigned int, clang::PreprocessedEntity*)"},
    {"_ZN5clang19PreprocessingRecord23RegisterMacroDefinitionEPNS_9MacroInfoEPNS_15MacroDefinitionE", "clang::PreprocessingRecord::RegisterMacroDefinition(clang::MacroInfo*, clang::MacroDefinition*)"},
    {"_ZN5clang19PreprocessingRecord19findMacroDefinitionEPKNS_9MacroInfoE", "clang::PreprocessingRecord::findMacroDefinition(clang::MacroInfo const*)"},
    {"_ZN5clang19PreprocessingRecord12MacroExpandsERKNS_5TokenEPKNS_9MacroInfoE", "clang::PreprocessingRecord::MacroExpands(clang::Token const&, clang::MacroInfo const*)"},
    {"_ZN5clang19PreprocessingRecord12MacroDefinedERKNS_5TokenEPKNS_9MacroInfoE", "clang::PreprocessingRecord::MacroDefined(clang::Token const&, clang::MacroInfo const*)"},
    {"_ZN5clang19PreprocessingRecord14MacroUndefinedERKNS_5TokenEPKNS_9MacroInfoE", "clang::PreprocessingRecord::MacroUndefined(clang::Token const&, clang::MacroInfo const*)"},
    {"_ZN5clang19PreprocessingRecord18InclusionDirectiveENS_14SourceLocationERKNS_5TokenEN4llvm9StringRefEbPKNS_9FileEntryES1_", "clang::PreprocessingRecord::InclusionDirective(clang::SourceLocation, clang::Token const&, llvm::StringRef, bool, clang::FileEntry const*, clang::SourceLocation)"},
    {"_ZN5clang19PreprocessingRecordD1Ev", "clang::PreprocessingRecord::~PreprocessingRecord()"},
    {"_ZN5clang19PreprocessingRecordD0Ev", "clang::PreprocessingRecord::~PreprocessingRecord()"},
    {"_ZN4llvm8DenseMapIPKN5clang9MacroInfoEPNS1_15MacroDefinitionENS_12DenseMapInfoIS4_EENS7_IS6_EEE16InsertIntoBucketERKS4_RKS6_PSt4pairIS4_S6_E", "llvm::DenseMap<clang::MacroInfo const*, clang::MacroDefinition*, llvm::DenseMapInfo<clang::MacroInfo const*>, llvm::DenseMapInfo<clang::MacroDefinition*>>::InsertIntoBucket(clang::MacroInfo const* const&, clang::MacroDefinition* const&, std::pair<clang::MacroInfo const*, clang::MacroDefinition*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang9MacroInfoEPNS1_15MacroDefinitionENS_12DenseMapInfoIS4_EENS7_IS6_EEE4growEj", "llvm::DenseMap<clang::MacroInfo const*, clang::MacroDefinition*, llvm::DenseMapInfo<clang::MacroInfo const*>, llvm::DenseMapInfo<clang::MacroDefinition*>>::grow(unsigned int)"},
    {"_ZNSt6vectorIPN5clang18PreprocessedEntityESaIS2_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS2_S4_EEmRKS2_", "std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>::_M_fill_insert(__gnu_cxx::__normal_iterator<clang::PreprocessedEntity**, std::vector<clang::PreprocessedEntity*, std::allocator<clang::PreprocessedEntity*>>>, unsigned long, clang::PreprocessedEntity* const&)"},
    {"_ZN5clang26ExternalPreprocessorSourceD0Ev", "clang::ExternalPreprocessorSource::~ExternalPreprocessorSource()"},
    {"_ZN5clang26ExternalPreprocessorSourceD1Ev", "clang::ExternalPreprocessorSource::~ExternalPreprocessorSource()"},
    {"_ZN5clang26ExternalPreprocessorSourceD2Ev", "clang::ExternalPreprocessorSource::~ExternalPreprocessorSource()"},
    {"_ZN5clang12PreprocessorC1ERNS_10DiagnosticERKNS_11LangOptionsERKNS_10TargetInfoERNS_13SourceManagerERNS_12HeaderSearchEPNS_20IdentifierInfoLookupEb", "clang::Preprocessor::Preprocessor(clang::Diagnostic&, clang::LangOptions const&, clang::TargetInfo const&, clang::SourceManager&, clang::HeaderSearch&, clang::IdentifierInfoLookup*, bool)"},
    {"_ZN5clang12PreprocessorC2ERNS_10DiagnosticERKNS_11LangOptionsERKNS_10TargetInfoERNS_13SourceManagerERNS_12HeaderSearchEPNS_20IdentifierInfoLookupEb", "clang::Preprocessor::Preprocessor(clang::Diagnostic&, clang::LangOptions const&, clang::TargetInfo const&, clang::SourceManager&, clang::HeaderSearch&, clang::IdentifierInfoLookup*, bool)"},
    {"_ZN5clang12PreprocessorD1Ev", "clang::Preprocessor::~Preprocessor()"},
    {"_ZN5clang12PreprocessorD2Ev", "clang::Preprocessor::~Preprocessor()"},
    {"_ZN5clang12Preprocessor13setPTHManagerEPNS_10PTHManagerE", "clang::Preprocessor::setPTHManager(clang::PTHManager*)"},
    {"_ZNK5clang12Preprocessor9DumpTokenERKNS_5TokenEb", "clang::Preprocessor::DumpToken(clang::Token const&, bool) const"},
    {"_ZNK5clang12Preprocessor12DumpLocationENS_14SourceLocationE", "clang::Preprocessor::DumpLocation(clang::SourceLocation) const"},
    {"_ZNK5clang12Preprocessor9DumpMacroERKNS_9MacroInfoE", "clang::Preprocessor::DumpMacro(clang::MacroInfo const&) const"},
    {"_ZN5clang12Preprocessor10PrintStatsEv", "clang::Preprocessor::PrintStats()"},
    {"_ZNK5clang12Preprocessor11macro_beginEb", "clang::Preprocessor::macro_begin(bool) const"},
    {"_ZNK5clang12Preprocessor9macro_endEb", "clang::Preprocessor::macro_end(bool) const"},
    {"_ZN5clang12Preprocessor22SetCodeCompletionPointEPKNS_9FileEntryEjj", "clang::Preprocessor::SetCodeCompletionPoint(clang::FileEntry const*, unsigned int, unsigned int)"},
    {"_ZNK5clang12Preprocessor20isCodeCompletionFileENS_14SourceLocationE", "clang::Preprocessor::isCodeCompletionFile(clang::SourceLocation) const"},
    {"_ZN5clang12Preprocessor27CodeCompleteNaturalLanguageEv", "clang::Preprocessor::CodeCompleteNaturalLanguage()"},
    {"_ZNK5clang12Preprocessor11getSpellingERKNS_5TokenERN4llvm15SmallVectorImplIcEEPb", "clang::Preprocessor::getSpelling(clang::Token const&, llvm::SmallVectorImpl<char>&, bool*) const"},
    {"_ZN5clang12Preprocessor12CreateStringEPKcjRNS_5TokenENS_14SourceLocationE", "clang::Preprocessor::CreateString(char const*, unsigned int, clang::Token&, clang::SourceLocation)"},
    {"_ZN5clang12Preprocessor19EnterMainSourceFileEv", "clang::Preprocessor::EnterMainSourceFile()"},
    {"_ZN5clang12Preprocessor13EndSourceFileEv", "clang::Preprocessor::EndSourceFile()"},
    {"_ZNK5clang12Preprocessor20LookUpIdentifierInfoERNS_5TokenE", "clang::Preprocessor::LookUpIdentifierInfo(clang::Token&) const"},
    {"_ZN5clang12Preprocessor16HandleIdentifierERNS_5TokenE", "clang::Preprocessor::HandleIdentifier(clang::Token&)"},
    {"_ZN5clang12Preprocessor17AddCommentHandlerEPNS_14CommentHandlerE", "clang::Preprocessor::AddCommentHandler(clang::CommentHandler*)"},
    {"_ZN5clang12Preprocessor20RemoveCommentHandlerEPNS_14CommentHandlerE", "clang::Preprocessor::RemoveCommentHandler(clang::CommentHandler*)"},
    {"_ZN5clang12Preprocessor13HandleCommentERNS_5TokenENS_11SourceRangeE", "clang::Preprocessor::HandleComment(clang::Token&, clang::SourceRange)"},
    {"_ZN5clang14CommentHandlerD0Ev", "clang::CommentHandler::~CommentHandler()"},
    {"_ZN5clang14CommentHandlerD1Ev", "clang::CommentHandler::~CommentHandler()"},
    {"_ZN5clang14CommentHandlerD2Ev", "clang::CommentHandler::~CommentHandler()"},
    {"_ZN5clang21CodeCompletionHandlerD0Ev", "clang::CodeCompletionHandler::~CodeCompletionHandler()"},
    {"_ZN5clang21CodeCompletionHandlerD1Ev", "clang::CodeCompletionHandler::~CodeCompletionHandler()"},
    {"_ZN5clang21CodeCompletionHandlerD2Ev", "clang::CodeCompletionHandler::~CodeCompletionHandler()"},
    {"_ZN5clang12Preprocessor25createPreprocessingRecordEv", "clang::Preprocessor::createPreprocessingRecord()"},
    {"_ZN5clang21CodeCompletionHandler21CodeCompleteDirectiveEb", "clang::CodeCompletionHandler::CodeCompleteDirective(bool)"},
    {"_ZN5clang21CodeCompletionHandler34CodeCompleteInConditionalExclusionEv", "clang::CodeCompletionHandler::CodeCompleteInConditionalExclusion()"},
    {"_ZN5clang21CodeCompletionHandler21CodeCompleteMacroNameEb", "clang::CodeCompletionHandler::CodeCompleteMacroName(bool)"},
    {"_ZN5clang21CodeCompletionHandler34CodeCompletePreprocessorExpressionEv", "clang::CodeCompletionHandler::CodeCompletePreprocessorExpression()"},
    {"_ZN5clang21CodeCompletionHandler25CodeCompleteMacroArgumentEPNS_14IdentifierInfoEPNS_9MacroInfoEj", "clang::CodeCompletionHandler::CodeCompleteMacroArgument(clang::IdentifierInfo*, clang::MacroInfo*, unsigned int)"},
    {"_ZN5clang21CodeCompletionHandler27CodeCompleteNaturalLanguageEv", "clang::CodeCompletionHandler::CodeCompleteNaturalLanguage()"},
    {"_ZSt6__findIN9__gnu_cxx17__normal_iteratorIPPN5clang14CommentHandlerESt6vectorIS4_SaIS4_EEEES4_ET_SA_SA_RKT0_St26random_access_iterator_tag", "__gnu_cxx::__normal_iterator<clang::CommentHandler**, std::vector<clang::CommentHandler*, std::allocator<clang::CommentHandler*>>> std::__find<__gnu_cxx::__normal_iterator<clang::CommentHandler**, std::vector<clang::CommentHandler*, std::allocator<clang::CommentHandler*>>>, clang::CommentHandler*>(__gnu_cxx::__normal_iterator<clang::CommentHandler**, std::vector<clang::CommentHandler*, std::allocator<clang::CommentHandler*>>>, __gnu_cxx::__normal_iterator<clang::CommentHandler**, std::vector<clang::CommentHandler*, std::allocator<clang::CommentHandler*>>>, clang::CommentHandler* const&, std::random_access_iterator_tag)"},
    {"_ZNSt6vectorIPN5clang14CommentHandlerESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::CommentHandler*, std::allocator<clang::CommentHandler*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::CommentHandler**, std::vector<clang::CommentHandler*, std::allocator<clang::CommentHandler*>>>, clang::CommentHandler* const&)"},
    {"_ZN5clang18PPChainedCallbacksD1Ev", "clang::PPChainedCallbacks::~PPChainedCallbacks()"},
    {"_ZN5clang18PPChainedCallbacksD0Ev", "clang::PPChainedCallbacks::~PPChainedCallbacks()"},
    {"_ZN5clang18PPChainedCallbacks11FileChangedENS_14SourceLocationENS_11PPCallbacks16FileChangeReasonENS_6SrcMgr18CharacteristicKindE", "clang::PPChainedCallbacks::FileChanged(clang::SourceLocation, clang::PPCallbacks::FileChangeReason, clang::SrcMgr::CharacteristicKind)"},
    {"_ZN5clang18PPChainedCallbacks11FileSkippedERKNS_9FileEntryERKNS_5TokenENS_6SrcMgr18CharacteristicKindE", "clang::PPChainedCallbacks::FileSkipped(clang::FileEntry const&, clang::Token const&, clang::SrcMgr::CharacteristicKind)"},
    {"_ZN5clang11PPCallbacks18InclusionDirectiveENS_14SourceLocationERKNS_5TokenEN4llvm9StringRefEbPKNS_9FileEntryES1_", "clang::PPCallbacks::InclusionDirective(clang::SourceLocation, clang::Token const&, llvm::StringRef, bool, clang::FileEntry const*, clang::SourceLocation)"},
    {"_ZN5clang18PPChainedCallbacks13EndOfMainFileEv", "clang::PPChainedCallbacks::EndOfMainFile()"},
    {"_ZN5clang18PPChainedCallbacks5IdentENS_14SourceLocationERKSs", "clang::PPChainedCallbacks::Ident(clang::SourceLocation, std::string const&)"},
    {"_ZN5clang18PPChainedCallbacks13PragmaCommentENS_14SourceLocationEPKNS_14IdentifierInfoERKSs", "clang::PPChainedCallbacks::PragmaComment(clang::SourceLocation, clang::IdentifierInfo const*, std::string const&)"},
    {"_ZN5clang18PPChainedCallbacks13PragmaMessageENS_14SourceLocationEN4llvm9StringRefE", "clang::PPChainedCallbacks::PragmaMessage(clang::SourceLocation, llvm::StringRef)"},
    {"_ZN5clang18PPChainedCallbacks12MacroExpandsERKNS_5TokenEPKNS_9MacroInfoE", "clang::PPChainedCallbacks::MacroExpands(clang::Token const&, clang::MacroInfo const*)"},
    {"_ZN5clang18PPChainedCallbacks12MacroDefinedERKNS_5TokenEPKNS_9MacroInfoE", "clang::PPChainedCallbacks::MacroDefined(clang::Token const&, clang::MacroInfo const*)"},
    {"_ZN5clang18PPChainedCallbacks14MacroUndefinedERKNS_5TokenEPKNS_9MacroInfoE", "clang::PPChainedCallbacks::MacroUndefined(clang::Token const&, clang::MacroInfo const*)"},
    {"_ZN5clang18PPChainedCallbacks2IfENS_11SourceRangeE", "clang::PPChainedCallbacks::If(clang::SourceRange)"},
    {"_ZN5clang18PPChainedCallbacks4ElifENS_11SourceRangeE", "clang::PPChainedCallbacks::Elif(clang::SourceRange)"},
    {"_ZN5clang18PPChainedCallbacks5IfdefERKNS_5TokenE", "clang::PPChainedCallbacks::Ifdef(clang::Token const&)"},
    {"_ZN5clang18PPChainedCallbacks6IfndefERKNS_5TokenE", "clang::PPChainedCallbacks::Ifndef(clang::Token const&)"},
    {"_ZN5clang18PPChainedCallbacks4ElseEv", "clang::PPChainedCallbacks::Else()"},
    {"_ZN5clang18PPChainedCallbacks5EndifEv", "clang::PPChainedCallbacks::Endif()"},
    {"_ZN5clang11PPCallbacks11FileChangedENS_14SourceLocationENS0_16FileChangeReasonENS_6SrcMgr18CharacteristicKindE", "clang::PPCallbacks::FileChanged(clang::SourceLocation, clang::PPCallbacks::FileChangeReason, clang::SrcMgr::CharacteristicKind)"},
    {"_ZN5clang11PPCallbacks11FileSkippedERKNS_9FileEntryERKNS_5TokenENS_6SrcMgr18CharacteristicKindE", "clang::PPCallbacks::FileSkipped(clang::FileEntry const&, clang::Token const&, clang::SrcMgr::CharacteristicKind)"},
    {"_ZN5clang11PPCallbacks13EndOfMainFileEv", "clang::PPCallbacks::EndOfMainFile()"},
    {"_ZN5clang11PPCallbacks5IdentENS_14SourceLocationERKSs", "clang::PPCallbacks::Ident(clang::SourceLocation, std::string const&)"},
    {"_ZN5clang11PPCallbacks13PragmaCommentENS_14SourceLocationEPKNS_14IdentifierInfoERKSs", "clang::PPCallbacks::PragmaComment(clang::SourceLocation, clang::IdentifierInfo const*, std::string const&)"},
    {"_ZN5clang11PPCallbacks13PragmaMessageENS_14SourceLocationEN4llvm9StringRefE", "clang::PPCallbacks::PragmaMessage(clang::SourceLocation, llvm::StringRef)"},
    {"_ZN5clang11PPCallbacks12MacroExpandsERKNS_5TokenEPKNS_9MacroInfoE", "clang::PPCallbacks::MacroExpands(clang::Token const&, clang::MacroInfo const*)"},
    {"_ZN5clang11PPCallbacks12MacroDefinedERKNS_5TokenEPKNS_9MacroInfoE", "clang::PPCallbacks::MacroDefined(clang::Token const&, clang::MacroInfo const*)"},
    {"_ZN5clang11PPCallbacks14MacroUndefinedERKNS_5TokenEPKNS_9MacroInfoE", "clang::PPCallbacks::MacroUndefined(clang::Token const&, clang::MacroInfo const*)"},
    {"_ZN5clang11PPCallbacks2IfENS_11SourceRangeE", "clang::PPCallbacks::If(clang::SourceRange)"},
    {"_ZN5clang11PPCallbacks4ElifENS_11SourceRangeE", "clang::PPCallbacks::Elif(clang::SourceRange)"},
    {"_ZN5clang11PPCallbacks5IfdefERKNS_5TokenE", "clang::PPCallbacks::Ifdef(clang::Token const&)"},
    {"_ZN5clang11PPCallbacks6IfndefERKNS_5TokenE", "clang::PPCallbacks::Ifndef(clang::Token const&)"},
    {"_ZN5clang11PPCallbacks4ElseEv", "clang::PPCallbacks::Else()"},
    {"_ZN5clang11PPCallbacks5EndifEv", "clang::PPCallbacks::Endif()"},
    {"_ZN5clang15PragmaNamespace14getIfNamespaceEv", "clang::PragmaNamespace::getIfNamespace()"},
    {"_ZN5clang13PragmaHandler14getIfNamespaceEv", "clang::PragmaHandler::getIfNamespace()"},
    {"_ZN5clang15IdentifierTable3getEN4llvm9StringRefE", "clang::IdentifierTable::get(llvm::StringRef)"},
    {"_ZN4llvm9StringMapIPN5clang14IdentifierInfoENS_16BumpPtrAllocatorEE16GetOrCreateValueIS3_EERNS_14StringMapEntryIS3_EENS_9StringRefET_", "llvm::StringMapEntry<clang::IdentifierInfo*>& llvm::StringMap<clang::IdentifierInfo*, llvm::BumpPtrAllocator>::GetOrCreateValue<clang::IdentifierInfo*>(llvm::StringRef, clang::IdentifierInfo*)"},
    {"_ZN5clang11LangOptionsC2ERKS0_", "clang::LangOptions::LangOptions(clang::LangOptions const&)"},
    {"_ZN5clang17PreprocessorLexer18LexIncludeFilenameERNS_5TokenE", "clang::PreprocessorLexer::LexIncludeFilename(clang::Token&)"},
    {"_ZNK5clang17PreprocessorLexer12getFileEntryEv", "clang::PreprocessorLexer::getFileEntry() const"},
    {"_ZN5clang13ScratchBufferC1ERNS_13SourceManagerE", "clang::ScratchBuffer::ScratchBuffer(clang::SourceManager&)"},
    {"_ZN5clang13ScratchBufferC2ERNS_13SourceManagerE", "clang::ScratchBuffer::ScratchBuffer(clang::SourceManager&)"},
    {"_ZN5clang13ScratchBuffer8getTokenEPKcjRS2_", "clang::ScratchBuffer::getToken(char const*, unsigned int, char const*&)"},
    {"_ZN5clang13ScratchBuffer18AllocScratchBufferEj", "clang::ScratchBuffer::AllocScratchBuffer(unsigned int)"},
    {"_ZNK5clang18TokenConcatenation11StartsWithLERKNS_5TokenE", "clang::TokenConcatenation::StartsWithL(clang::Token const&) const"},
    {"_ZNK5clang18TokenConcatenation13IsIdentifierLERKNS_5TokenE", "clang::TokenConcatenation::IsIdentifierL(clang::Token const&) const"},
    {"_ZN5clang18TokenConcatenationC1ERNS_12PreprocessorE", "clang::TokenConcatenation::TokenConcatenation(clang::Preprocessor&)"},
    {"_ZN5clang18TokenConcatenationC2ERNS_12PreprocessorE", "clang::TokenConcatenation::TokenConcatenation(clang::Preprocessor&)"},
    {"_ZNK5clang18TokenConcatenation11AvoidConcatERKNS_5TokenES3_S3_", "clang::TokenConcatenation::AvoidConcat(clang::Token const&, clang::Token const&, clang::Token const&) const"},
    {"_Z12GetFirstCharRN5clang12PreprocessorERKNS_5TokenE", "GetFirstChar(clang::Preprocessor&, clang::Token const&)"},
    {"_ZN5clang10TokenLexer4InitERNS_5TokenENS_14SourceLocationEPNS_9MacroArgsE", "clang::TokenLexer::Init(clang::Token&, clang::SourceLocation, clang::MacroArgs*)"},
    {"_ZN5clang10TokenLexer7destroyEv", "clang::TokenLexer::destroy()"},
    {"_ZN5clang10TokenLexer23ExpandFunctionArgumentsEv", "clang::TokenLexer::ExpandFunctionArguments()"},
    {"_ZN5clang10TokenLexer4InitEPKNS_5TokenEjbb", "clang::TokenLexer::Init(clang::Token const*, unsigned int, bool, bool)"},
    {"_ZN5clang10TokenLexer3LexERNS_5TokenE", "clang::TokenLexer::Lex(clang::Token&)"},
    {"_ZN5clang10TokenLexer11PasteTokensERNS_5TokenE", "clang::TokenLexer::PasteTokens(clang::Token&)"},
    {"_ZN5clang10TokenLexer27HandleMicrosoftCommentPasteERNS_5TokenE", "clang::TokenLexer::HandleMicrosoftCommentPaste(clang::Token&)"},
    {"_ZNK5clang10TokenLexer17isNextTokenLParenEv", "clang::TokenLexer::isNextTokenLParen() const"},
    {"_ZNK5clang7Builtin7Context9GetRecordEj", "clang::Builtin::Context::GetRecord(unsigned int) const"},
    {"_ZN5clang7Builtin7ContextC1ERKNS_10TargetInfoE", "clang::Builtin::Context::Context(clang::TargetInfo const&)"},
    {"_ZN5clang7Builtin7ContextC2ERKNS_10TargetInfoE", "clang::Builtin::Context::Context(clang::TargetInfo const&)"},
    {"_ZN5clang7Builtin7Context18InitializeBuiltinsERNS_15IdentifierTableERKNS_11LangOptionsE", "clang::Builtin::Context::InitializeBuiltins(clang::IdentifierTable&, clang::LangOptions const&)"},
    {"_ZN5clang7Builtin7Context15GetBuiltinNamesERN4llvm15SmallVectorImplIPKcEEb", "clang::Builtin::Context::GetBuiltinNames(llvm::SmallVectorImpl<char const*>&, bool)"},
    {"_ZN5clang7Builtin7Context13ForgetBuiltinEjRNS_15IdentifierTableE", "clang::Builtin::Context::ForgetBuiltin(unsigned int, clang::IdentifierTable&)"},
    {"_ZN5clang7Builtin7Context12isPrintfLikeEjRjRb", "clang::Builtin::Context::isPrintfLike(unsigned int, unsigned int&, bool&)"},
    {"_ZN5clang7Builtin7Context11isScanfLikeEjRjRb", "clang::Builtin::Context::isScanfLike(unsigned int, unsigned int&, bool&)"},
    {"_ZN5clang10DiagnosticC1ERKN4llvm18IntrusiveRefCntPtrINS_13DiagnosticIDsEEEPNS_16DiagnosticClientEb", "clang::Diagnostic::Diagnostic(llvm::IntrusiveRefCntPtr<clang::DiagnosticIDs> const&, clang::DiagnosticClient*, bool)"},
    {"_ZN5clang10DiagnosticC2ERKN4llvm18IntrusiveRefCntPtrINS_13DiagnosticIDsEEEPNS_16DiagnosticClientEb", "clang::Diagnostic::Diagnostic(llvm::IntrusiveRefCntPtr<clang::DiagnosticIDs> const&, clang::DiagnosticClient*, bool)"},
    {"_Z18DummyArgToStringFnN5clang10Diagnostic12ArgumentKindElPKcjS3_jPKSt4pairIS1_lEjRN4llvm15SmallVectorImplIcEEPv", "DummyArgToStringFn(clang::Diagnostic::ArgumentKind, long, char const*, unsigned int, char const*, unsigned int, std::pair<clang::Diagnostic::ArgumentKind, long> const*, unsigned int, llvm::SmallVectorImpl<char>&, void*)"},
    {"_ZN5clang10Diagnostic5ResetEv", "clang::Diagnostic::Reset()"},
    {"_ZN5clang10DiagnosticD1Ev", "clang::Diagnostic::~Diagnostic()"},
    {"_ZN5clang10DiagnosticD2Ev", "clang::Diagnostic::~Diagnostic()"},
    {"_ZN5clang10Diagnostic9setClientEPNS_16DiagnosticClientEb", "clang::Diagnostic::setClient(clang::DiagnosticClient*, bool)"},
    {"_ZN5clang10Diagnostic12pushMappingsENS_14SourceLocationE", "clang::Diagnostic::pushMappings(clang::SourceLocation)"},
    {"_ZN5clang10Diagnostic11popMappingsENS_14SourceLocationE", "clang::Diagnostic::popMappings(clang::SourceLocation)"},
    {"_ZN5clang10Diagnostic20SetDelayedDiagnosticEjN4llvm9StringRefES2_", "clang::Diagnostic::SetDelayedDiagnostic(unsigned int, llvm::StringRef, llvm::StringRef)"},
    {"_ZN5clang10Diagnostic13ReportDelayedEv", "clang::Diagnostic::ReportDelayed()"},
    {"_ZNK5clang10Diagnostic23GetDiagStatePointForLocENS_14SourceLocationE", "clang::Diagnostic::GetDiagStatePointForLoc(clang::SourceLocation) const"},
    {"_ZN5clang10Diagnostic20setDiagnosticMappingEjNS_4diag7MappingENS_14SourceLocationE", "clang::Diagnostic::setDiagnosticMapping(unsigned int, clang::diag::Mapping, clang::SourceLocation)"},
    {"_ZN5clang17DiagnosticBuilder11FlushCountsEv", "clang::DiagnosticBuilder::FlushCounts()"},
    {"_ZN5clang17DiagnosticBuilder4EmitEv", "clang::DiagnosticBuilder::Emit()"},
    {"_ZN5clang16DiagnosticClientD0Ev", "clang::DiagnosticClient::~DiagnosticClient()"},
    {"_ZN5clang16DiagnosticClientD1Ev", "clang::DiagnosticClient::~DiagnosticClient()"},
    {"_ZN5clang16DiagnosticClientD2Ev", "clang::DiagnosticClient::~DiagnosticClient()"},
    {"_ZN5clang16DiagnosticClient16HandleDiagnosticENS_10Diagnostic5LevelERKNS_14DiagnosticInfoE", "clang::DiagnosticClient::HandleDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_ZNK5clang14DiagnosticInfo16FormatDiagnosticERN4llvm15SmallVectorImplIcEE", "clang::DiagnosticInfo::FormatDiagnostic(llvm::SmallVectorImpl<char>&) const"},
    {"_ZNK5clang14DiagnosticInfo16FormatDiagnosticEPKcS2_RN4llvm15SmallVectorImplIcEE", "clang::DiagnosticInfo::FormatDiagnostic(char const*, char const*, llvm::SmallVectorImpl<char>&) const"},
    {"_Z10ScanFormatPKcS0_c", "ScanFormat(char const*, char const*, char)"},
    {"_Z20HandlePluralModifierRKN5clang14DiagnosticInfoEjPKcjRN4llvm15SmallVectorImplIcEE", "HandlePluralModifier(clang::DiagnosticInfo const&, unsigned int, char const*, unsigned int, llvm::SmallVectorImpl<char>&)"},
    {"_Z21HandleOrdinalModifierjRN4llvm15SmallVectorImplIcEE", "HandleOrdinalModifier(unsigned int, llvm::SmallVectorImpl<char>&)"},
    {"_ZN5clang16StoredDiagnosticC1Ev", "clang::StoredDiagnostic::StoredDiagnostic()"},
    {"_ZN5clang16StoredDiagnosticC2Ev", "clang::StoredDiagnostic::StoredDiagnostic()"},
    {"_ZN5clang16StoredDiagnosticC1ENS_10Diagnostic5LevelEjN4llvm9StringRefE", "clang::StoredDiagnostic::StoredDiagnostic(clang::Diagnostic::Level, unsigned int, llvm::StringRef)"},
    {"_ZN5clang16StoredDiagnosticC2ENS_10Diagnostic5LevelEjN4llvm9StringRefE", "clang::StoredDiagnostic::StoredDiagnostic(clang::Diagnostic::Level, unsigned int, llvm::StringRef)"},
    {"_ZN5clang16StoredDiagnosticC1ENS_10Diagnostic5LevelERKNS_14DiagnosticInfoE", "clang::StoredDiagnostic::StoredDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_ZN5clang16StoredDiagnosticC2ENS_10Diagnostic5LevelERKNS_14DiagnosticInfoE", "clang::StoredDiagnostic::StoredDiagnostic(clang::Diagnostic::Level, clang::DiagnosticInfo const&)"},
    {"_ZN5clang16StoredDiagnosticD1Ev", "clang::StoredDiagnostic::~StoredDiagnostic()"},
    {"_ZN5clang16StoredDiagnosticD2Ev", "clang::StoredDiagnostic::~StoredDiagnostic()"},
    {"_ZNK5clang16DiagnosticClient25IncludeInDiagnosticCountsEv", "clang::DiagnosticClient::IncludeInDiagnosticCounts() const"},
    {"_ZN5clang17PartialDiagnostic16StorageAllocatorC1Ev", "clang::PartialDiagnostic::StorageAllocator::StorageAllocator()"},
    {"_ZN5clang17PartialDiagnostic16StorageAllocatorC2Ev", "clang::PartialDiagnostic::StorageAllocator::StorageAllocator()"},
    {"_ZN5clang17PartialDiagnostic16StorageAllocatorD1Ev", "clang::PartialDiagnostic::StorageAllocator::~StorageAllocator()"},
    {"_ZN5clang17PartialDiagnostic16StorageAllocatorD2Ev", "clang::PartialDiagnostic::StorageAllocator::~StorageAllocator()"},
    {"_ZNSt6vectorIN5clang15CharSourceRangeESaIS1_EE7reserveEm", "std::vector<clang::CharSourceRange, std::allocator<clang::CharSourceRange>>::reserve(unsigned long)"},
    {"_ZNSt6vectorIN5clang9FixItHintESaIS1_EE7reserveEm", "std::vector<clang::FixItHint, std::allocator<clang::FixItHint>>::reserve(unsigned long)"},
    {"_ZNSt6vectorIN5clang9FixItHintESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<clang::FixItHint, std::allocator<clang::FixItHint>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::FixItHint*, std::vector<clang::FixItHint, std::allocator<clang::FixItHint>>>, clang::FixItHint const&)"},
    {"_ZNSt6vectorIN5clang15CharSourceRangeESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<clang::CharSourceRange, std::allocator<clang::CharSourceRange>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::CharSourceRange*, std::vector<clang::CharSourceRange, std::allocator<clang::CharSourceRange>>>, clang::CharSourceRange const&)"},
    {"_ZNSt6vectorIN5clang10Diagnostic14DiagStatePointESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::Diagnostic::DiagStatePoint, std::allocator<clang::Diagnostic::DiagStatePoint>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::Diagnostic::DiagStatePoint*, std::vector<clang::Diagnostic::DiagStatePoint, std::allocator<clang::Diagnostic::DiagStatePoint>>>, clang::Diagnostic::DiagStatePoint const&)"},
    {"_ZNSt6vectorIPN5clang10Diagnostic9DiagStateESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<clang::Diagnostic::DiagState*, std::allocator<clang::Diagnostic::DiagState*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::Diagnostic::DiagState**, std::vector<clang::Diagnostic::DiagState*, std::allocator<clang::Diagnostic::DiagState*>>>, clang::Diagnostic::DiagState* const&)"},
    {"_ZN4llvm8DenseMapIjjNS_12DenseMapInfoIjEES2_E8CopyFromERKS3_", "llvm::DenseMap<unsigned int, unsigned int, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<unsigned int>>::CopyFrom(llvm::DenseMap<unsigned int, unsigned int, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<unsigned int>> const&)"},
    {"_ZN5clang17PartialDiagnostic7StorageD2Ev", "clang::PartialDiagnostic::Storage::~Storage()"},
    {"_ZN5clang13DiagnosticIDs23getWarningOptionForDiagEj", "clang::DiagnosticIDs::getWarningOptionForDiag(unsigned int)"},
    {"_ZN5clang13DiagnosticIDs24getCategoryNumberForDiagEj", "clang::DiagnosticIDs::getCategoryNumberForDiag(unsigned int)"},
    {"_ZN5clang13DiagnosticIDs21getCategoryNameFromIDEj", "clang::DiagnosticIDs::getCategoryNameFromID(unsigned int)"},
    {"_ZN5clang13DiagnosticIDs27getDiagnosticSFINAEResponseEj", "clang::DiagnosticIDs::getDiagnosticSFINAEResponse(unsigned int)"},
    {"_ZN5clang13DiagnosticIDsC1Ev", "clang::DiagnosticIDs::DiagnosticIDs()"},
    {"_ZN5clang13DiagnosticIDsC2Ev", "clang::DiagnosticIDs::DiagnosticIDs()"},
    {"_ZN5clang13DiagnosticIDsD1Ev", "clang::DiagnosticIDs::~DiagnosticIDs()"},
    {"_ZN5clang13DiagnosticIDsD2Ev", "clang::DiagnosticIDs::~DiagnosticIDs()"},
    {"_ZN5clang13DiagnosticIDs15getCustomDiagIDENS0_5LevelEN4llvm9StringRefE", "clang::DiagnosticIDs::getCustomDiagID(clang::DiagnosticIDs::Level, llvm::StringRef)"},
    {"_ZN5clang13DiagnosticIDs27isBuiltinWarningOrExtensionEj", "clang::DiagnosticIDs::isBuiltinWarningOrExtension(unsigned int)"},
    {"_ZN5clang13DiagnosticIDs13isBuiltinNoteEj", "clang::DiagnosticIDs::isBuiltinNote(unsigned int)"},
    {"_ZN5clang13DiagnosticIDs22isBuiltinExtensionDiagEjRb", "clang::DiagnosticIDs::isBuiltinExtensionDiag(unsigned int, bool&)"},
    {"_ZNK5clang13DiagnosticIDs14getDescriptionEj", "clang::DiagnosticIDs::getDescription(unsigned int) const"},
    {"_ZNK5clang13DiagnosticIDs18getDiagnosticLevelEjNS_14SourceLocationERKNS_10DiagnosticE", "clang::DiagnosticIDs::getDiagnosticLevel(unsigned int, clang::SourceLocation, clang::Diagnostic const&) const"},
    {"_ZNK5clang13DiagnosticIDs18getDiagnosticLevelEjjNS_14SourceLocationERKNS_10DiagnosticE", "clang::DiagnosticIDs::getDiagnosticLevel(unsigned int, unsigned int, clang::SourceLocation, clang::Diagnostic const&) const"},
    {"_ZNK5clang13DiagnosticIDs25setDiagnosticGroupMappingEPKcNS_4diag7MappingENS_14SourceLocationERNS_10DiagnosticE", "clang::DiagnosticIDs::setDiagnosticGroupMapping(char const*, clang::diag::Mapping, clang::SourceLocation, clang::Diagnostic&) const"},
    {"_Z15MapGroupMembersPK13WarningOptionN5clang4diag7MappingENS2_14SourceLocationERNS2_10DiagnosticE", "MapGroupMembers(WarningOption const*, clang::diag::Mapping, clang::SourceLocation, clang::Diagnostic&)"},
    {"_ZNK5clang13DiagnosticIDs11ProcessDiagERNS_10DiagnosticE", "clang::DiagnosticIDs::ProcessDiag(clang::Diagnostic&) const"},
    {"_ZN5clang4diag14CustomDiagInfo17getOrCreateDiagIDENS_13DiagnosticIDs5LevelEN4llvm9StringRefERS2_", "clang::diag::CustomDiagInfo::getOrCreateDiagID(clang::DiagnosticIDs::Level, llvm::StringRef, clang::DiagnosticIDs&)"},
    {"_ZN4llvm8DenseMapIjjNS_12DenseMapInfoIjEES2_E16InsertIntoBucketERKjS5_PSt4pairIjjE", "llvm::DenseMap<unsigned int, unsigned int, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(unsigned int const&, unsigned int const&, std::pair<unsigned int, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIjjNS_12DenseMapInfoIjEES2_E4growEj", "llvm::DenseMap<unsigned int, unsigned int, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZNSt6vectorISt4pairIN5clang13DiagnosticIDs5LevelESsESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<std::pair<clang::DiagnosticIDs::Level, std::string>, std::allocator<std::pair<clang::DiagnosticIDs::Level, std::string>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<clang::DiagnosticIDs::Level, std::string>*, std::vector<std::pair<clang::DiagnosticIDs::Level, std::string>, std::allocator<std::pair<clang::DiagnosticIDs::Level, std::string>>>>, std::pair<clang::DiagnosticIDs::Level, std::string> const&)"},
    {"_ZNSt8_Rb_treeISt4pairIN5clang13DiagnosticIDs5LevelESsES0_IKS4_jESt10_Select1stIS6_ESt4lessIS4_ESaIS6_EE16_M_insert_uniqueERKS6_", "std::_Rb_tree<std::pair<clang::DiagnosticIDs::Level, std::string>, std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int>, std::_Select1st<std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int>>, std::less<std::pair<clang::DiagnosticIDs::Level, std::string>>, std::allocator<std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int>>>::_M_insert_unique(std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int> const&)"},
    {"_ZNSt8_Rb_treeISt4pairIN5clang13DiagnosticIDs5LevelESsES0_IKS4_jESt10_Select1stIS6_ESt4lessIS4_ESaIS6_EE9_M_insertEPSt18_Rb_tree_node_baseSE_RKS6_", "std::_Rb_tree<std::pair<clang::DiagnosticIDs::Level, std::string>, std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int>, std::_Select1st<std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int>>, std::less<std::pair<clang::DiagnosticIDs::Level, std::string>>, std::allocator<std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int> const&)"},
    {"_ZNSt8_Rb_treeISt4pairIN5clang13DiagnosticIDs5LevelESsES0_IKS4_jESt10_Select1stIS6_ESt4lessIS4_ESaIS6_EE8_M_eraseEPSt13_Rb_tree_nodeIS6_E", "std::_Rb_tree<std::pair<clang::DiagnosticIDs::Level, std::string>, std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int>, std::_Select1st<std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int>>, std::less<std::pair<clang::DiagnosticIDs::Level, std::string>>, std::allocator<std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int>>>::_M_erase(std::_Rb_tree_node<std::pair<std::pair<clang::DiagnosticIDs::Level, std::string> const, unsigned int>>*)"},
    {"_ZN5clang9FileEntryD1Ev", "clang::FileEntry::~FileEntry()"},
    {"_ZN5clang9FileEntryD2Ev", "clang::FileEntry::~FileEntry()"},
    {"_ZN5clang11FileManagerC1ERKNS_17FileSystemOptionsE", "clang::FileManager::FileManager(clang::FileSystemOptions const&)"},
    {"_ZN5clang11FileManagerC2ERKNS_17FileSystemOptionsE", "clang::FileManager::FileManager(clang::FileSystemOptions const&)"},
    {"_ZN5clang11FileManagerD1Ev", "clang::FileManager::~FileManager()"},
    {"_ZN5clang11FileManagerD2Ev", "clang::FileManager::~FileManager()"},
    {"_ZN5clang11FileManager12addStatCacheEPNS_19FileSystemStatCacheEb", "clang::FileManager::addStatCache(clang::FileSystemStatCache*, bool)"},
    {"_ZN5clang11FileManager15removeStatCacheEPNS_19FileSystemStatCacheE", "clang::FileManager::removeStatCache(clang::FileSystemStatCache*)"},
    {"_ZN5clang11FileManager12getDirectoryEN4llvm9StringRefE", "clang::FileManager::getDirectory(llvm::StringRef)"},
    {"_ZN5clang11FileManager12getStatValueEPKcR4statPi", "clang::FileManager::getStatValue(char const*, stat&, int*)"},
    {"_ZN5clang11FileManager7getFileEN4llvm9StringRefE", "clang::FileManager::getFile(llvm::StringRef)"},
    {"_ZN5clang11FileManager14getVirtualFileEN4llvm9StringRefExl", "clang::FileManager::getVirtualFile(llvm::StringRef, long long, long)"},
    {"_ZN5clang11FileManager17FixupRelativePathERN4llvm3sys4PathERKNS_17FileSystemOptionsE", "clang::FileManager::FixupRelativePath(llvm::sys::Path&, clang::FileSystemOptions const&)"},
    {"_ZN5clang11FileManager16getBufferForFileEPKNS_9FileEntryEPSs", "clang::FileManager::getBufferForFile(clang::FileEntry const*, std::string*)"},
    {"_ZN5clang11FileManager16getBufferForFileEN4llvm9StringRefEPSs", "clang::FileManager::getBufferForFile(llvm::StringRef, std::string*)"},
    {"_ZNK5clang11FileManager10PrintStatsEv", "clang::FileManager::PrintStats() const"},
    {"_ZN4llvm9StringMapIPN5clang9FileEntryENS_16BumpPtrAllocatorEE16GetOrCreateValueIS3_EERNS_14StringMapEntryIS3_EENS_9StringRefET_", "llvm::StringMapEntry<clang::FileEntry*>& llvm::StringMap<clang::FileEntry*, llvm::BumpPtrAllocator>::GetOrCreateValue<clang::FileEntry*>(llvm::StringRef, clang::FileEntry*)"},
    {"_ZN4llvm9StringMapIPN5clang14DirectoryEntryENS_16BumpPtrAllocatorEE16GetOrCreateValueIS3_EERNS_14StringMapEntryIS3_EENS_9StringRefET_", "llvm::StringMapEntry<clang::DirectoryEntry*>& llvm::StringMap<clang::DirectoryEntry*, llvm::BumpPtrAllocator>::GetOrCreateValue<clang::DirectoryEntry*>(llvm::StringRef, clang::DirectoryEntry*)"},
    {"_ZNSt8_Rb_treeIN5clang9FileEntryES1_St9_IdentityIS1_ESt4lessIS1_ESaIS1_EE16_M_insert_uniqueERKS1_", "std::_Rb_tree<clang::FileEntry, clang::FileEntry, std::_Identity<clang::FileEntry>, std::less<clang::FileEntry>, std::allocator<clang::FileEntry>>::_M_insert_unique(clang::FileEntry const&)"},
    {"_ZNSt8_Rb_treeISt4pairIiyES0_IKS1_N5clang14DirectoryEntryEESt10_Select1stIS5_ESt4lessIS1_ESaIS5_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS5_ERKS5_", "std::_Rb_tree<std::pair<int, unsigned long long>, std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>, std::_Select1st<std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>>, std::less<std::pair<int, unsigned long long>>, std::allocator<std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>>, std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry> const&)"},
    {"_ZNSt8_Rb_treeISt4pairIiyES0_IKS1_N5clang14DirectoryEntryEESt10_Select1stIS5_ESt4lessIS1_ESaIS5_EE16_M_insert_uniqueERKS5_", "std::_Rb_tree<std::pair<int, unsigned long long>, std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>, std::_Select1st<std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>>, std::less<std::pair<int, unsigned long long>>, std::allocator<std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>>>::_M_insert_unique(std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry> const&)"},
    {"_ZNSt8_Rb_treeIN5clang9FileEntryES1_St9_IdentityIS1_ESt4lessIS1_ESaIS1_EE8_M_eraseEPSt13_Rb_tree_nodeIS1_E", "std::_Rb_tree<clang::FileEntry, clang::FileEntry, std::_Identity<clang::FileEntry>, std::less<clang::FileEntry>, std::allocator<clang::FileEntry>>::_M_erase(std::_Rb_tree_node<clang::FileEntry>*)"},
    {"_ZNSt8_Rb_treeISt4pairIiyES0_IKS1_N5clang14DirectoryEntryEESt10_Select1stIS5_ESt4lessIS1_ESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<std::pair<int, unsigned long long>, std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>, std::_Select1st<std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>>, std::less<std::pair<int, unsigned long long>>, std::allocator<std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>>>::_M_erase(std::_Rb_tree_node<std::pair<std::pair<int, unsigned long long> const, clang::DirectoryEntry>>*)"},
    {"_ZN5clang19FileSystemStatCache3getEPKcR4statPiPS0_", "clang::FileSystemStatCache::get(char const*, stat&, int*, clang::FileSystemStatCache*)"},
    {"_ZN5clang17MemorizeStatCalls7getStatEPKcR4statPi", "clang::MemorizeStatCalls::getStat(char const*, stat&, int*)"},
    {"_ZN5clang17MemorizeStatCallsD1Ev", "clang::MemorizeStatCalls::~MemorizeStatCalls()"},
    {"_ZN5clang17MemorizeStatCallsD0Ev", "clang::MemorizeStatCalls::~MemorizeStatCalls()"},
    {"_ZN4llvm9StringMapI4statNS_16BumpPtrAllocatorEE16GetOrCreateValueIS1_EERNS_14StringMapEntryIS1_EENS_9StringRefET_", "llvm::StringMapEntry<stat>& llvm::StringMap<stat, llvm::BumpPtrAllocator>::GetOrCreateValue<stat>(llvm::StringRef, stat)"},
    {"_ZN5clang14IdentifierInfoC1Ev", "clang::IdentifierInfo::IdentifierInfo()"},
    {"_ZN5clang14IdentifierInfoC2Ev", "clang::IdentifierInfo::IdentifierInfo()"},
    {"_ZN5clang18IdentifierIteratorD0Ev", "clang::IdentifierIterator::~IdentifierIterator()"},
    {"_ZN5clang18IdentifierIteratorD1Ev", "clang::IdentifierIterator::~IdentifierIterator()"},
    {"_ZN5clang18IdentifierIteratorD2Ev", "clang::IdentifierIterator::~IdentifierIterator()"},
    {"_ZN5clang20IdentifierInfoLookupD0Ev", "clang::IdentifierInfoLookup::~IdentifierInfoLookup()"},
    {"_ZN5clang20IdentifierInfoLookupD1Ev", "clang::IdentifierInfoLookup::~IdentifierInfoLookup()"},
    {"_ZN5clang20IdentifierInfoLookupD2Ev", "clang::IdentifierInfoLookup::~IdentifierInfoLookup()"},
    {"_ZNK5clang20IdentifierInfoLookup14getIdentifiersEv", "clang::IdentifierInfoLookup::getIdentifiers() const"},
    {"_ZN5clang24ExternalIdentifierLookupD0Ev", "clang::ExternalIdentifierLookup::~ExternalIdentifierLookup()"},
    {"_ZN5clang24ExternalIdentifierLookupD1Ev", "clang::ExternalIdentifierLookup::~ExternalIdentifierLookup()"},
    {"_ZN5clang24ExternalIdentifierLookupD2Ev", "clang::ExternalIdentifierLookup::~ExternalIdentifierLookup()"},
    {"_ZN5clang15IdentifierTableC1ERKNS_11LangOptionsEPNS_20IdentifierInfoLookupE", "clang::IdentifierTable::IdentifierTable(clang::LangOptions const&, clang::IdentifierInfoLookup*)"},
    {"_ZN5clang15IdentifierTableC2ERKNS_11LangOptionsEPNS_20IdentifierInfoLookupE", "clang::IdentifierTable::IdentifierTable(clang::LangOptions const&, clang::IdentifierInfoLookup*)"},
    {"_ZN5clang15IdentifierTable11AddKeywordsERKNS_11LangOptionsE", "clang::IdentifierTable::AddKeywords(clang::LangOptions const&)"},
    {"_ZNK5clang14IdentifierInfo14getPPKeywordIDEv", "clang::IdentifierInfo::getPPKeywordID() const"},
    {"_ZNK5clang15IdentifierTable10PrintStatsEv", "clang::IdentifierTable::PrintStats() const"},
    {"_ZN4llvm12DenseMapInfoIN5clang8SelectorEE12getHashValueES2_", "llvm::DenseMapInfo<clang::Selector>::getHashValue(clang::Selector)"},
    {"_ZNK5clang8Selector10getNumArgsEv", "clang::Selector::getNumArgs() const"},
    {"_ZNK5clang8Selector24getIdentifierInfoForSlotEj", "clang::Selector::getIdentifierInfoForSlot(unsigned int) const"},
    {"_ZNK5clang20MultiKeywordSelector7getNameEv", "clang::MultiKeywordSelector::getName() const"},
    {"_ZNK5clang8Selector11getAsStringEv", "clang::Selector::getAsString() const"},
    {"_ZN5clang13SelectorTable11getSelectorEjPPNS_14IdentifierInfoE", "clang::SelectorTable::getSelector(unsigned int, clang::IdentifierInfo**)"},
    {"_ZN5clang13SelectorTableC1Ev", "clang::SelectorTable::SelectorTable()"},
    {"_ZN5clang13SelectorTableC2Ev", "clang::SelectorTable::SelectorTable()"},
    {"_ZN5clang13SelectorTableD1Ev", "clang::SelectorTable::~SelectorTable()"},
    {"_ZN5clang13SelectorTableD2Ev", "clang::SelectorTable::~SelectorTable()"},
    {"_ZN5clang19getOperatorSpellingENS_22OverloadedOperatorKindE", "clang::getOperatorSpelling(clang::OverloadedOperatorKind)"},
    {"_ZN12_GLOBAL__N_119EmptyLookupIteratorD1Ev", "(anonymous namespace)::EmptyLookupIterator::~EmptyLookupIterator()"},
    {"_ZN12_GLOBAL__N_119EmptyLookupIteratorD0Ev", "(anonymous namespace)::EmptyLookupIterator::~EmptyLookupIterator()"},
    {"_ZN12_GLOBAL__N_119EmptyLookupIterator4NextEv", "(anonymous namespace)::EmptyLookupIterator::Next()"},
    {"_ZN4llvm10FoldingSetIN5clang20MultiKeywordSelectorEED1Ev", "llvm::FoldingSet<clang::MultiKeywordSelector>::~FoldingSet()"},
    {"_ZN4llvm10FoldingSetIN5clang20MultiKeywordSelectorEED0Ev", "llvm::FoldingSet<clang::MultiKeywordSelector>::~FoldingSet()"},
    {"_ZNK4llvm10FoldingSetIN5clang20MultiKeywordSelectorEE14GetNodeProfileEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::MultiKeywordSelector>::GetNodeProfile(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang20MultiKeywordSelectorEE10NodeEqualsEPNS_14FoldingSetImpl4NodeERKNS_16FoldingSetNodeIDERS7_", "llvm::FoldingSet<clang::MultiKeywordSelector>::NodeEquals(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID const&, llvm::FoldingSetNodeID&) const"},
    {"_ZNK4llvm10FoldingSetIN5clang20MultiKeywordSelectorEE15ComputeNodeHashEPNS_14FoldingSetImpl4NodeERNS_16FoldingSetNodeIDE", "llvm::FoldingSet<clang::MultiKeywordSelector>::ComputeNodeHash(llvm::FoldingSetImpl::Node*, llvm::FoldingSetNodeID&) const"},
    {"_ZNK5clang19PrettyStackTraceLoc5printERN4llvm11raw_ostreamE", "clang::PrettyStackTraceLoc::print(llvm::raw_ostream&) const"},
    {"_ZNK5clang14SourceLocation5printERN4llvm11raw_ostreamERKNS_13SourceManagerE", "clang::SourceLocation::print(llvm::raw_ostream&, clang::SourceManager const&) const"},
    {"_ZNK5clang14SourceLocation4dumpERKNS_13SourceManagerE", "clang::SourceLocation::dump(clang::SourceManager const&) const"},
    {"_ZNK5clang13FullSourceLoc9getFileIDEv", "clang::FullSourceLoc::getFileID() const"},
    {"_ZNK5clang13FullSourceLoc19getInstantiationLocEv", "clang::FullSourceLoc::getInstantiationLoc() const"},
    {"_ZNK5clang13FullSourceLoc14getSpellingLocEv", "clang::FullSourceLoc::getSpellingLoc() const"},
    {"_ZNK5clang13FullSourceLoc26getInstantiationLineNumberEPb", "clang::FullSourceLoc::getInstantiationLineNumber(bool*) const"},
    {"_ZNK5clang13FullSourceLoc28getInstantiationColumnNumberEPb", "clang::FullSourceLoc::getInstantiationColumnNumber(bool*) const"},
    {"_ZNK5clang13FullSourceLoc21getSpellingLineNumberEPb", "clang::FullSourceLoc::getSpellingLineNumber(bool*) const"},
    {"_ZNK5clang13FullSourceLoc23getSpellingColumnNumberEPb", "clang::FullSourceLoc::getSpellingColumnNumber(bool*) const"},
    {"_ZNK5clang13FullSourceLoc16isInSystemHeaderEv", "clang::FullSourceLoc::isInSystemHeader() const"},
    {"_ZNK5clang13FullSourceLoc29isBeforeInTranslationUnitThanENS_14SourceLocationE", "clang::FullSourceLoc::isBeforeInTranslationUnitThan(clang::SourceLocation) const"},
    {"_ZNK5clang13FullSourceLoc16getCharacterDataEPb", "clang::FullSourceLoc::getCharacterData(bool*) const"},
    {"_ZNK5clang13FullSourceLoc9getBufferEPb", "clang::FullSourceLoc::getBuffer(bool*) const"},
    {"_ZNK5clang13FullSourceLoc13getBufferDataEPb", "clang::FullSourceLoc::getBufferData(bool*) const"},
    {"_ZNK5clang13FullSourceLoc16getDecomposedLocEv", "clang::FullSourceLoc::getDecomposedLoc() const"},
    {"_ZN5clang19PrettyStackTraceLocD1Ev", "clang::PrettyStackTraceLoc::~PrettyStackTraceLoc()"},
    {"_ZN5clang19PrettyStackTraceLocD0Ev", "clang::PrettyStackTraceLoc::~PrettyStackTraceLoc()"},
    {"_ZN5clang6SrcMgr12ContentCacheD1Ev", "clang::SrcMgr::ContentCache::~ContentCache()"},
    {"_ZN5clang6SrcMgr12ContentCacheD2Ev", "clang::SrcMgr::ContentCache::~ContentCache()"},
    {"_ZNK5clang6SrcMgr12ContentCache18getSizeBytesMappedEv", "clang::SrcMgr::ContentCache::getSizeBytesMapped() const"},
    {"_ZNK5clang6SrcMgr12ContentCache7getSizeEv", "clang::SrcMgr::ContentCache::getSize() const"},
    {"_ZN5clang6SrcMgr12ContentCache13replaceBufferEPKN4llvm12MemoryBufferEb", "clang::SrcMgr::ContentCache::replaceBuffer(llvm::MemoryBuffer const*, bool)"},
    {"_ZNK5clang6SrcMgr12ContentCache9getBufferERNS_10DiagnosticERKNS_13SourceManagerENS_14SourceLocationEPb", "clang::SrcMgr::ContentCache::getBuffer(clang::Diagnostic&, clang::SourceManager const&, clang::SourceLocation, bool*) const"},
    {"_ZN5clang13LineTableInfo22getLineTableFilenameIDEPKcj", "clang::LineTableInfo::getLineTableFilenameID(char const*, unsigned int)"},
    {"_ZN5clang13LineTableInfo11AddLineNoteEjjji", "clang::LineTableInfo::AddLineNote(unsigned int, unsigned int, unsigned int, int)"},
    {"_ZN5clang13LineTableInfo11AddLineNoteEjjjijNS_6SrcMgr18CharacteristicKindE", "clang::LineTableInfo::AddLineNote(unsigned int, unsigned int, unsigned int, int, unsigned int, clang::SrcMgr::CharacteristicKind)"},
    {"_ZN5clang13LineTableInfo20FindNearestLineEntryEjj", "clang::LineTableInfo::FindNearestLineEntry(unsigned int, unsigned int)"},
    {"_ZN5clang13LineTableInfo8AddEntryEjRKSt6vectorINS_9LineEntryESaIS2_EE", "clang::LineTableInfo::AddEntry(unsigned int, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>> const&)"},
    {"_ZN5clang13SourceManager22getLineTableFilenameIDEPKcj", "clang::SourceManager::getLineTableFilenameID(char const*, unsigned int)"},
    {"_ZN5clang13SourceManager11AddLineNoteENS_14SourceLocationEji", "clang::SourceManager::AddLineNote(clang::SourceLocation, unsigned int, int)"},
    {"_ZN5clang13SourceManager11AddLineNoteENS_14SourceLocationEjibbbb", "clang::SourceManager::AddLineNote(clang::SourceLocation, unsigned int, int, bool, bool, bool, bool)"},
    {"_ZN5clang13SourceManager12getLineTableEv", "clang::SourceManager::getLineTable()"},
    {"_ZN5clang13SourceManagerC1ERNS_10DiagnosticERNS_11FileManagerE", "clang::SourceManager::SourceManager(clang::Diagnostic&, clang::FileManager&)"},
    {"_ZN5clang13SourceManagerC2ERNS_10DiagnosticERNS_11FileManagerE", "clang::SourceManager::SourceManager(clang::Diagnostic&, clang::FileManager&)"},
    {"_ZN5clang13SourceManager13clearIDTablesEv", "clang::SourceManager::clearIDTables()"},
    {"_ZN5clang13SourceManagerD1Ev", "clang::SourceManager::~SourceManager()"},
    {"_ZN5clang13SourceManagerD2Ev", "clang::SourceManager::~SourceManager()"},
    {"_ZN5clang13SourceManager22createInstantiationLocENS_14SourceLocationES1_S1_jjj", "clang::SourceManager::createInstantiationLoc(clang::SourceLocation, clang::SourceLocation, clang::SourceLocation, unsigned int, unsigned int, unsigned int)"},
    {"_ZN5clang13SourceManager23getOrCreateContentCacheEPKNS_9FileEntryE", "clang::SourceManager::getOrCreateContentCache(clang::FileEntry const*)"},
    {"_ZN5clang13SourceManager27createMemBufferContentCacheEPKN4llvm12MemoryBufferE", "clang::SourceManager::createMemBufferContentCache(llvm::MemoryBuffer const*)"},
    {"_ZN5clang13SourceManager22PreallocateSLocEntriesEPNS_23ExternalSLocEntrySourceEjj", "clang::SourceManager::PreallocateSLocEntries(clang::ExternalSLocEntrySource*, unsigned int, unsigned int)"},
    {"_ZN5clang13SourceManager28ClearPreallocatedSLocEntriesEv", "clang::SourceManager::ClearPreallocatedSLocEntries()"},
    {"_ZN5clang13SourceManager12createFileIDEPKNS_6SrcMgr12ContentCacheENS_14SourceLocationENS1_18CharacteristicKindEjj", "clang::SourceManager::createFileID(clang::SrcMgr::ContentCache const*, clang::SourceLocation, clang::SrcMgr::CharacteristicKind, unsigned int, unsigned int)"},
    {"_ZN5clang13SourceManager22getMemoryBufferForFileEPKNS_9FileEntryEPb", "clang::SourceManager::getMemoryBufferForFile(clang::FileEntry const*, bool*)"},
    {"_ZN5clang13SourceManager20overrideFileContentsEPKNS_9FileEntryEPKN4llvm12MemoryBufferEb", "clang::SourceManager::overrideFileContents(clang::FileEntry const*, llvm::MemoryBuffer const*, bool)"},
    {"_ZNK5clang13SourceManager13getBufferDataENS_6FileIDEPb", "clang::SourceManager::getBufferData(clang::FileID, bool*) const"},
    {"_ZNK5clang13SourceManager13getFileIDSlowEj", "clang::SourceManager::getFileIDSlow(unsigned int) const"},
    {"_ZNK5clang13SourceManager27getInstantiationLocSlowCaseENS_14SourceLocationE", "clang::SourceManager::getInstantiationLocSlowCase(clang::SourceLocation) const"},
    {"_ZNK5clang13SourceManager22getSpellingLocSlowCaseENS_14SourceLocationE", "clang::SourceManager::getSpellingLocSlowCase(clang::SourceLocation) const"},
    {"_ZNK5clang13SourceManager37getDecomposedInstantiationLocSlowCaseEPKNS_6SrcMgr9SLocEntryEj", "clang::SourceManager::getDecomposedInstantiationLocSlowCase(clang::SrcMgr::SLocEntry const*, unsigned int) const"},
    {"_ZNK5clang13SourceManager32getDecomposedSpellingLocSlowCaseEPKNS_6SrcMgr9SLocEntryEj", "clang::SourceManager::getDecomposedSpellingLocSlowCase(clang::SrcMgr::SLocEntry const*, unsigned int) const"},
    {"_ZNK5clang13SourceManager23getImmediateSpellingLocENS_14SourceLocationE", "clang::SourceManager::getImmediateSpellingLoc(clang::SourceLocation) const"},
    {"_ZNK5clang13SourceManager30getImmediateInstantiationRangeENS_14SourceLocationE", "clang::SourceManager::getImmediateInstantiationRange(clang::SourceLocation) const"},
    {"_ZNK5clang13SourceManager21getInstantiationRangeENS_14SourceLocationE", "clang::SourceManager::getInstantiationRange(clang::SourceLocation) const"},
    {"_ZNK5clang13SourceManager16getCharacterDataENS_14SourceLocationEPb", "clang::SourceManager::getCharacterData(clang::SourceLocation, bool*) const"},
    {"_ZNK5clang13SourceManager15getColumnNumberENS_6FileIDEjPb", "clang::SourceManager::getColumnNumber(clang::FileID, unsigned int, bool*) const"},
    {"_ZNK5clang13SourceManager23getSpellingColumnNumberENS_14SourceLocationEPb", "clang::SourceManager::getSpellingColumnNumber(clang::SourceLocation, bool*) const"},
    {"_ZNK5clang13SourceManager28getInstantiationColumnNumberENS_14SourceLocationEPb", "clang::SourceManager::getInstantiationColumnNumber(clang::SourceLocation, bool*) const"},
    {"_ZNK5clang13SourceManager13getLineNumberENS_6FileIDEjPb", "clang::SourceManager::getLineNumber(clang::FileID, unsigned int, bool*) const"},
    {"_Z18ComputeLineNumbersRN5clang10DiagnosticEPNS_6SrcMgr12ContentCacheERN4llvm16BumpPtrAllocatorERKNS_13SourceManagerERb", "ComputeLineNumbers(clang::Diagnostic&, clang::SrcMgr::ContentCache*, llvm::BumpPtrAllocator&, clang::SourceManager const&, bool&)"},
    {"_ZNK5clang13SourceManager26getInstantiationLineNumberENS_14SourceLocationEPb", "clang::SourceManager::getInstantiationLineNumber(clang::SourceLocation, bool*) const"},
    {"_ZNK5clang13SourceManager21getSpellingLineNumberENS_14SourceLocationEPb", "clang::SourceManager::getSpellingLineNumber(clang::SourceLocation, bool*) const"},
    {"_ZNK5clang13SourceManager21getFileCharacteristicENS_14SourceLocationE", "clang::SourceManager::getFileCharacteristic(clang::SourceLocation) const"},
    {"_ZNK5clang13SourceManager13getBufferNameENS_14SourceLocationEPb", "clang::SourceManager::getBufferName(clang::SourceLocation, bool*) const"},
    {"_ZNK5clang13SourceManager14getPresumedLocENS_14SourceLocationE", "clang::SourceManager::getPresumedLoc(clang::SourceLocation) const"},
    {"_ZN5clang13SourceManager11getLocationEPKNS_9FileEntryEjj", "clang::SourceManager::getLocation(clang::FileEntry const*, unsigned int, unsigned int)"},
    {"_ZNK5clang13SourceManager25isBeforeInTranslationUnitENS_14SourceLocationES1_", "clang::SourceManager::isBeforeInTranslationUnit(clang::SourceLocation, clang::SourceLocation) const"},
    {"_Z22MoveUpIncludeHierarchyRSt4pairIN5clang6FileIDEjERKNS0_13SourceManagerE", "MoveUpIncludeHierarchy(std::pair<clang::FileID, unsigned int>&, clang::SourceManager const&)"},
    {"_ZNK5clang13SourceManager10PrintStatsEv", "clang::SourceManager::PrintStats() const"},
    {"_ZN5clang23ExternalSLocEntrySourceD0Ev", "clang::ExternalSLocEntrySource::~ExternalSLocEntrySource()"},
    {"_ZN5clang23ExternalSLocEntrySourceD1Ev", "clang::ExternalSLocEntrySource::~ExternalSLocEntrySource()"},
    {"_ZN5clang23ExternalSLocEntrySourceD2Ev", "clang::ExternalSLocEntrySource::~ExternalSLocEntrySource()"},
    {"_ZNSt6vectorIN5clang9LineEntryESaIS1_EEaSERKS3_", "std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>::operator=(std::vector<clang::LineEntry, std::allocator<clang::LineEntry>> const&)"},
    {"_ZNSt6vectorIbSaIbEE6resizeEmb", "std::vector<bool, std::allocator<bool>>::resize(unsigned long, bool)"},
    {"_ZNK5clang13SourceManager24getDecomposedSpellingLocENS_14SourceLocationE", "clang::SourceManager::getDecomposedSpellingLoc(clang::SourceLocation) const"},
    {"_ZNK5clang13SourceManager9getBufferENS_6FileIDEPb", "clang::SourceManager::getBuffer(clang::FileID, bool*) const"},
    {"_ZNSt6vectorIN5clang6SrcMgr9SLocEntryESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<clang::SrcMgr::SLocEntry, std::allocator<clang::SrcMgr::SLocEntry>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::SrcMgr::SLocEntry*, std::vector<clang::SrcMgr::SLocEntry, std::allocator<clang::SrcMgr::SLocEntry>>>, clang::SrcMgr::SLocEntry const&)"},
    {"_ZNSt6vectorIN5clang6SrcMgr9SLocEntryESaIS2_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS2_S4_EEmRKS2_", "std::vector<clang::SrcMgr::SLocEntry, std::allocator<clang::SrcMgr::SLocEntry>>::_M_fill_insert(__gnu_cxx::__normal_iterator<clang::SrcMgr::SLocEntry*, std::vector<clang::SrcMgr::SLocEntry, std::allocator<clang::SrcMgr::SLocEntry>>>, unsigned long, clang::SrcMgr::SLocEntry const&)"},
    {"_ZNSt6vectorIbSaIbEE14_M_fill_insertESt13_Bit_iteratormb", "std::vector<bool, std::allocator<bool>>::_M_fill_insert(std::_Bit_iterator, unsigned long, bool)"},
    {"_ZSt4fillSt13_Bit_iteratorS_RKb", "std::fill(std::_Bit_iterator, std::_Bit_iterator, bool const&)"},
    {"_ZNSt6__copyILb0ESt26random_access_iterator_tagE4copyISt13_Bit_iteratorS3_EET0_T_S5_S4_", "std::_Bit_iterator std::__copy<false, std::random_access_iterator_tag>::copy<std::_Bit_iterator, std::_Bit_iterator>(std::_Bit_iterator, std::_Bit_iterator, std::_Bit_iterator)"},
    {"_ZNSt6__copyILb0ESt26random_access_iterator_tagE4copyISt19_Bit_const_iteratorSt13_Bit_iteratorEET0_T_S6_S5_", "std::_Bit_iterator std::__copy<false, std::random_access_iterator_tag>::copy<std::_Bit_const_iterator, std::_Bit_iterator>(std::_Bit_const_iterator, std::_Bit_const_iterator, std::_Bit_iterator)"},
    {"_ZNSt15__copy_backwardILb0ESt26random_access_iterator_tagE8__copy_bISt13_Bit_iteratorS3_EET0_T_S5_S4_", "std::_Bit_iterator std::__copy_backward<false, std::random_access_iterator_tag>::__copy_b<std::_Bit_iterator, std::_Bit_iterator>(std::_Bit_iterator, std::_Bit_iterator, std::_Bit_iterator)"},
    {"_ZNSt6vectorIPN5clang6SrcMgr12ContentCacheESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<clang::SrcMgr::ContentCache*, std::allocator<clang::SrcMgr::ContentCache*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::SrcMgr::ContentCache**, std::vector<clang::SrcMgr::ContentCache*, std::allocator<clang::SrcMgr::ContentCache*>>>, clang::SrcMgr::ContentCache* const&)"},
    {"_ZN4llvm8DenseMapIPKN5clang9FileEntryEPNS1_6SrcMgr12ContentCacheENS_12DenseMapInfoIS4_EENS8_IS7_EEE16InsertIntoBucketERKS4_RKS7_PSt4pairIS4_S7_E", "llvm::DenseMap<clang::FileEntry const*, clang::SrcMgr::ContentCache*, llvm::DenseMapInfo<clang::FileEntry const*>, llvm::DenseMapInfo<clang::SrcMgr::ContentCache*>>::InsertIntoBucket(clang::FileEntry const* const&, clang::SrcMgr::ContentCache* const&, std::pair<clang::FileEntry const*, clang::SrcMgr::ContentCache*>*)"},
    {"_ZN4llvm8DenseMapIPKN5clang9FileEntryEPNS1_6SrcMgr12ContentCacheENS_12DenseMapInfoIS4_EENS8_IS7_EEE4growEj", "llvm::DenseMap<clang::FileEntry const*, clang::SrcMgr::ContentCache*, llvm::DenseMapInfo<clang::FileEntry const*>, llvm::DenseMapInfo<clang::SrcMgr::ContentCache*>>::grow(unsigned int)"},
    {"_ZNSt6vectorIN5clang9LineEntryESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>::_M_insert_aux(__gnu_cxx::__normal_iterator<clang::LineEntry*, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>, clang::LineEntry const&)"},
    {"_ZNSt6vectorIN5clang9LineEntryESaIS1_EEC2ERKS3_", "std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>::vector(std::vector<clang::LineEntry, std::allocator<clang::LineEntry>> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjSt6vectorIN5clang9LineEntryESaIS4_EEESt10_Select1stIS7_ESt4lessIjESaIS7_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS7_ERKS7_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>, std::_Select1st<std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>>, std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjSt6vectorIN5clang9LineEntryESaIS4_EEESt10_Select1stIS7_ESt4lessIjESaIS7_EE16_M_insert_uniqueERKS7_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>, std::_Select1st<std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>>>::_M_insert_unique(std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>> const&)"},
    {"_ZNSt6vectorIPN4llvm14StringMapEntryIjEESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<llvm::StringMapEntry<unsigned int>*, std::allocator<llvm::StringMapEntry<unsigned int>*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::StringMapEntry<unsigned int>**, std::vector<llvm::StringMapEntry<unsigned int>*, std::allocator<llvm::StringMapEntry<unsigned int>*>>>, llvm::StringMapEntry<unsigned int>* const&)"},
    {"_ZN4llvm9StringMapIjNS_16BumpPtrAllocatorEE16GetOrCreateValueIjEERNS_14StringMapEntryIjEENS_9StringRefET_", "llvm::StringMapEntry<unsigned int>& llvm::StringMap<unsigned int, llvm::BumpPtrAllocator>::GetOrCreateValue<unsigned int>(llvm::StringRef, unsigned int)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjSt6vectorIN5clang9LineEntryESaIS4_EEESt10_Select1stIS7_ESt4lessIjESaIS7_EE8_M_eraseEPSt13_Rb_tree_nodeIS7_E", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>, std::_Select1st<std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>>>::_M_erase(std::_Rb_tree_node<std::pair<unsigned int const, std::vector<clang::LineEntry, std::allocator<clang::LineEntry>>>>*)"},
    {"_ZN5clang13LineTableInfoD2Ev", "clang::LineTableInfo::~LineTableInfo()"},
    {"_ZN5clang10TargetInfoC1ERKSs", "clang::TargetInfo::TargetInfo(std::string const&)"},
    {"_ZN5clang10TargetInfoC2ERKSs", "clang::TargetInfo::TargetInfo(std::string const&)"},
    {"_ZN5clang10TargetInfoD0Ev", "clang::TargetInfo::~TargetInfo()"},
    {"_ZN5clang10TargetInfoD1Ev", "clang::TargetInfo::~TargetInfo()"},
    {"_ZN5clang10TargetInfoD2Ev", "clang::TargetInfo::~TargetInfo()"},
    {"_ZN5clang10TargetInfo11getTypeNameENS0_7IntTypeE", "clang::TargetInfo::getTypeName(clang::TargetInfo::IntType)"},
    {"_ZN5clang10TargetInfo21getTypeConstantSuffixENS0_7IntTypeE", "clang::TargetInfo::getTypeConstantSuffix(clang::TargetInfo::IntType)"},
    {"_ZNK5clang10TargetInfo12getTypeWidthENS0_7IntTypeE", "clang::TargetInfo::getTypeWidth(clang::TargetInfo::IntType) const"},
    {"_ZNK5clang10TargetInfo12getTypeAlignENS0_7IntTypeE", "clang::TargetInfo::getTypeAlign(clang::TargetInfo::IntType) const"},
    {"_ZN5clang10TargetInfo12isTypeSignedENS0_7IntTypeE", "clang::TargetInfo::isTypeSigned(clang::TargetInfo::IntType)"},
    {"_ZN5clang10TargetInfo20setForcedLangOptionsERNS_11LangOptionsE", "clang::TargetInfo::setForcedLangOptions(clang::LangOptions&)"},
    {"_ZNK5clang10TargetInfo22isValidGCCRegisterNameEN4llvm9StringRefE", "clang::TargetInfo::isValidGCCRegisterName(llvm::StringRef) const"},
    {"_ZNK5clang10TargetInfo28getNormalizedGCCRegisterNameEN4llvm9StringRefE", "clang::TargetInfo::getNormalizedGCCRegisterName(llvm::StringRef) const"},
    {"_ZNK5clang10TargetInfo24validateOutputConstraintERNS0_14ConstraintInfoE", "clang::TargetInfo::validateOutputConstraint(clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZNK5clang10TargetInfo19resolveSymbolicNameERPKcPNS0_14ConstraintInfoEjRj", "clang::TargetInfo::resolveSymbolicName(char const*&, clang::TargetInfo::ConstraintInfo*, unsigned int, unsigned int&) const"},
    {"_ZNK5clang10TargetInfo23validateInputConstraintEPNS0_14ConstraintInfoEjRS1_", "clang::TargetInfo::validateInputConstraint(clang::TargetInfo::ConstraintInfo*, unsigned int, clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZN5clang10TargetInfo16CreateTargetInfoERNS_10DiagnosticERNS_13TargetOptionsE", "clang::TargetInfo::CreateTargetInfo(clang::Diagnostic&, clang::TargetOptions&)"},
    {"_ZN12_GLOBAL__N_122DarwinX86_64TargetInfoC1ERKSs", "(anonymous namespace)::DarwinX86_64TargetInfo::DarwinX86_64TargetInfo(std::string const&)"},
    {"_ZN12_GLOBAL__N_116X86_64TargetInfoD1Ev", "(anonymous namespace)::X86_64TargetInfo::~X86_64TargetInfo()"},
    {"_ZN12_GLOBAL__N_116X86_64TargetInfoD0Ev", "(anonymous namespace)::X86_64TargetInfo::~X86_64TargetInfo()"},
    {"_ZNK12_GLOBAL__N_113X86TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::X86TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_113X86TargetInfo17getTargetBuiltinsERPKN5clang7Builtin4InfoERj", "(anonymous namespace)::X86TargetInfo::getTargetBuiltins(clang::Builtin::Info const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_116X86_64TargetInfo20getVAListDeclarationEv", "(anonymous namespace)::X86_64TargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_113X86TargetInfo17convertConstraintEc", "(anonymous namespace)::X86TargetInfo::convertConstraint(char) const"},
    {"_ZNK12_GLOBAL__N_113X86TargetInfo11getClobbersEv", "(anonymous namespace)::X86TargetInfo::getClobbers() const"},
    {"_ZNK12_GLOBAL__N_113X86TargetInfo18getDefaultFeaturesERKSsRN4llvm9StringMapIbNS3_15MallocAllocatorEEE", "(anonymous namespace)::X86TargetInfo::getDefaultFeatures(std::string const&, llvm::StringMap<bool, llvm::MallocAllocator>&) const"},
    {"_ZNK12_GLOBAL__N_113X86TargetInfo17setFeatureEnabledERN4llvm9StringMapIbNS1_15MallocAllocatorEEERKSsb", "(anonymous namespace)::X86TargetInfo::setFeatureEnabled(llvm::StringMap<bool, llvm::MallocAllocator>&, std::string const&, bool) const"},
    {"_ZN12_GLOBAL__N_113X86TargetInfo20HandleTargetFeaturesERSt6vectorISsSaISsEE", "(anonymous namespace)::X86TargetInfo::HandleTargetFeatures(std::vector<std::string, std::allocator<std::string>>&)"},
    {"_ZNK12_GLOBAL__N_116X86_64TargetInfo23getEHDataRegisterNumberEj", "(anonymous namespace)::X86_64TargetInfo::getEHDataRegisterNumber(unsigned int) const"},
    {"_ZNK12_GLOBAL__N_113X86TargetInfo19adjustInlineAsmTypeERSsPKN4llvm4TypeERNS2_11LLVMContextE", "(anonymous namespace)::X86TargetInfo::adjustInlineAsmType(std::string&, llvm::Type const*, llvm::LLVMContext&) const"},
    {"_ZNK12_GLOBAL__N_113X86TargetInfo14getGCCRegNamesERPKPKcRj", "(anonymous namespace)::X86TargetInfo::getGCCRegNames(char const* const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_113X86TargetInfo16getGCCRegAliasesERPKN5clang10TargetInfo11GCCRegAliasERj", "(anonymous namespace)::X86TargetInfo::getGCCRegAliases(clang::TargetInfo::GCCRegAlias const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_113X86TargetInfo21validateAsmConstraintERPKcRN5clang10TargetInfo14ConstraintInfoE", "(anonymous namespace)::X86TargetInfo::validateAsmConstraint(char const*&, clang::TargetInfo::ConstraintInfo&) const"},
    {"_Z9DefineStdRN5clang12MacroBuilderEN4llvm9StringRefERKNS_11LangOptionsE", "DefineStd(clang::MacroBuilder&, llvm::StringRef, clang::LangOptions const&)"},
    {"_ZN12_GLOBAL__N_113X86TargetInfoD1Ev", "(anonymous namespace)::X86TargetInfo::~X86TargetInfo()"},
    {"_ZN12_GLOBAL__N_113X86TargetInfoD0Ev", "(anonymous namespace)::X86TargetInfo::~X86TargetInfo()"},
    {"_ZN12_GLOBAL__N_135VisualStudioWindowsX86_64TargetInfoD1Ev", "(anonymous namespace)::VisualStudioWindowsX86_64TargetInfo::~VisualStudioWindowsX86_64TargetInfo()"},
    {"_ZN12_GLOBAL__N_135VisualStudioWindowsX86_64TargetInfoD0Ev", "(anonymous namespace)::VisualStudioWindowsX86_64TargetInfo::~VisualStudioWindowsX86_64TargetInfo()"},
    {"_ZNK12_GLOBAL__N_135VisualStudioWindowsX86_64TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::VisualStudioWindowsX86_64TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_123WindowsX86_64TargetInfo20getVAListDeclarationEv", "(anonymous namespace)::WindowsX86_64TargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_117WindowsTargetInfoINS_16X86_64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::WindowsTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_123WindowsX86_64TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::WindowsX86_64TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_112OSTargetInfoINS_16X86_64TargetInfoEE16getTargetDefinesERKN5clang11LangOptionsERNS3_12MacroBuilderE", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_123WindowsX86_64TargetInfoD1Ev", "(anonymous namespace)::WindowsX86_64TargetInfo::~WindowsX86_64TargetInfo()"},
    {"_ZN12_GLOBAL__N_123WindowsX86_64TargetInfoD0Ev", "(anonymous namespace)::WindowsX86_64TargetInfo::~WindowsX86_64TargetInfo()"},
    {"_ZN12_GLOBAL__N_117WindowsTargetInfoINS_16X86_64TargetInfoEED1Ev", "(anonymous namespace)::WindowsTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~WindowsTargetInfo()"},
    {"_ZN12_GLOBAL__N_117WindowsTargetInfoINS_16X86_64TargetInfoEED0Ev", "(anonymous namespace)::WindowsTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~WindowsTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_16X86_64TargetInfoEED1Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_16X86_64TargetInfoEED0Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_121MinGWX86_64TargetInfoD1Ev", "(anonymous namespace)::MinGWX86_64TargetInfo::~MinGWX86_64TargetInfo()"},
    {"_ZN12_GLOBAL__N_121MinGWX86_64TargetInfoD0Ev", "(anonymous namespace)::MinGWX86_64TargetInfo::~MinGWX86_64TargetInfo()"},
    {"_ZNK12_GLOBAL__N_121MinGWX86_64TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::MinGWX86_64TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_117SolarisTargetInfoINS_16X86_64TargetInfoEED1Ev", "(anonymous namespace)::SolarisTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~SolarisTargetInfo()"},
    {"_ZN12_GLOBAL__N_117SolarisTargetInfoINS_16X86_64TargetInfoEED0Ev", "(anonymous namespace)::SolarisTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~SolarisTargetInfo()"},
    {"_ZNK12_GLOBAL__N_117SolarisTargetInfoINS_16X86_64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::SolarisTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_117FreeBSDTargetInfoINS_16X86_64TargetInfoEED1Ev", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~FreeBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_117FreeBSDTargetInfoINS_16X86_64TargetInfoEED0Ev", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~FreeBSDTargetInfo()"},
    {"_ZNK12_GLOBAL__N_117FreeBSDTargetInfoINS_16X86_64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_123OpenBSDX86_64TargetInfoD1Ev", "(anonymous namespace)::OpenBSDX86_64TargetInfo::~OpenBSDX86_64TargetInfo()"},
    {"_ZN12_GLOBAL__N_123OpenBSDX86_64TargetInfoD0Ev", "(anonymous namespace)::OpenBSDX86_64TargetInfo::~OpenBSDX86_64TargetInfo()"},
    {"_ZNK12_GLOBAL__N_117OpenBSDTargetInfoINS_16X86_64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::OpenBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_117OpenBSDTargetInfoINS_16X86_64TargetInfoEED1Ev", "(anonymous namespace)::OpenBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~OpenBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_117OpenBSDTargetInfoINS_16X86_64TargetInfoEED0Ev", "(anonymous namespace)::OpenBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~OpenBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_116NetBSDTargetInfoINS_16X86_64TargetInfoEED1Ev", "(anonymous namespace)::NetBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~NetBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_116NetBSDTargetInfoINS_16X86_64TargetInfoEED0Ev", "(anonymous namespace)::NetBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~NetBSDTargetInfo()"},
    {"_ZNK12_GLOBAL__N_116NetBSDTargetInfoINS_16X86_64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::NetBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_122DragonFlyBSDTargetInfoINS_16X86_64TargetInfoEED1Ev", "(anonymous namespace)::DragonFlyBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~DragonFlyBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_122DragonFlyBSDTargetInfoINS_16X86_64TargetInfoEED0Ev", "(anonymous namespace)::DragonFlyBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~DragonFlyBSDTargetInfo()"},
    {"_ZNK12_GLOBAL__N_122DragonFlyBSDTargetInfoINS_16X86_64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::DragonFlyBSDTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_115LinuxTargetInfoINS_16X86_64TargetInfoEED1Ev", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~LinuxTargetInfo()"},
    {"_ZN12_GLOBAL__N_115LinuxTargetInfoINS_16X86_64TargetInfoEED0Ev", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~LinuxTargetInfo()"},
    {"_ZNK12_GLOBAL__N_115LinuxTargetInfoINS_16X86_64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_122DarwinX86_64TargetInfoD1Ev", "(anonymous namespace)::DarwinX86_64TargetInfo::~DarwinX86_64TargetInfo()"},
    {"_ZN12_GLOBAL__N_122DarwinX86_64TargetInfoD0Ev", "(anonymous namespace)::DarwinX86_64TargetInfo::~DarwinX86_64TargetInfo()"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_16X86_64TargetInfoEE23isValidSectionSpecifierEN4llvm9StringRefE", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::X86_64TargetInfo>::isValidSectionSpecifier(llvm::StringRef) const"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_16X86_64TargetInfoEE29getStaticInitSectionSpecifierEv", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getStaticInitSectionSpecifier() const"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_16X86_64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_Z16getDarwinDefinesRN5clang12MacroBuilderERKNS_11LangOptionsERKN4llvm6TripleE", "getDarwinDefines(clang::MacroBuilder&, clang::LangOptions const&, llvm::Triple const&)"},
    {"_ZN12_GLOBAL__N_116DarwinTargetInfoINS_16X86_64TargetInfoEED1Ev", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~DarwinTargetInfo()"},
    {"_ZN12_GLOBAL__N_116DarwinTargetInfoINS_16X86_64TargetInfoEED0Ev", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~DarwinTargetInfo()"},
    {"_ZN12_GLOBAL__N_118AuroraUXTargetInfoINS_16X86_64TargetInfoEED1Ev", "(anonymous namespace)::AuroraUXTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~AuroraUXTargetInfo()"},
    {"_ZN12_GLOBAL__N_118AuroraUXTargetInfoINS_16X86_64TargetInfoEED0Ev", "(anonymous namespace)::AuroraUXTargetInfo<(anonymous namespace)::X86_64TargetInfo>::~AuroraUXTargetInfo()"},
    {"_ZNK12_GLOBAL__N_118AuroraUXTargetInfoINS_16X86_64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::AuroraUXTargetInfo<(anonymous namespace)::X86_64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_116X86_32TargetInfoD1Ev", "(anonymous namespace)::X86_32TargetInfo::~X86_32TargetInfo()"},
    {"_ZN12_GLOBAL__N_116X86_32TargetInfoD0Ev", "(anonymous namespace)::X86_32TargetInfo::~X86_32TargetInfo()"},
    {"_ZNK12_GLOBAL__N_116X86_32TargetInfo20getVAListDeclarationEv", "(anonymous namespace)::X86_32TargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_116X86_32TargetInfo23getEHDataRegisterNumberEj", "(anonymous namespace)::X86_32TargetInfo::getEHDataRegisterNumber(unsigned int) const"},
    {"_ZN12_GLOBAL__N_121HaikuX86_32TargetInfoD1Ev", "(anonymous namespace)::HaikuX86_32TargetInfo::~HaikuX86_32TargetInfo()"},
    {"_ZN12_GLOBAL__N_121HaikuX86_32TargetInfoD0Ev", "(anonymous namespace)::HaikuX86_32TargetInfo::~HaikuX86_32TargetInfo()"},
    {"_ZNK12_GLOBAL__N_121HaikuX86_32TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::HaikuX86_32TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_135VisualStudioWindowsX86_32TargetInfoD1Ev", "(anonymous namespace)::VisualStudioWindowsX86_32TargetInfo::~VisualStudioWindowsX86_32TargetInfo()"},
    {"_ZN12_GLOBAL__N_135VisualStudioWindowsX86_32TargetInfoD0Ev", "(anonymous namespace)::VisualStudioWindowsX86_32TargetInfo::~VisualStudioWindowsX86_32TargetInfo()"},
    {"_ZNK12_GLOBAL__N_135VisualStudioWindowsX86_32TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::VisualStudioWindowsX86_32TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_117WindowsTargetInfoINS_16X86_32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::WindowsTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_123WindowsX86_32TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::WindowsX86_32TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_112OSTargetInfoINS_16X86_32TargetInfoEE16getTargetDefinesERKN5clang11LangOptionsERNS3_12MacroBuilderE", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_123WindowsX86_32TargetInfoD1Ev", "(anonymous namespace)::WindowsX86_32TargetInfo::~WindowsX86_32TargetInfo()"},
    {"_ZN12_GLOBAL__N_123WindowsX86_32TargetInfoD0Ev", "(anonymous namespace)::WindowsX86_32TargetInfo::~WindowsX86_32TargetInfo()"},
    {"_ZN12_GLOBAL__N_117WindowsTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::WindowsTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~WindowsTargetInfo()"},
    {"_ZN12_GLOBAL__N_117WindowsTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::WindowsTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~WindowsTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_121MinGWX86_32TargetInfoD1Ev", "(anonymous namespace)::MinGWX86_32TargetInfo::~MinGWX86_32TargetInfo()"},
    {"_ZN12_GLOBAL__N_121MinGWX86_32TargetInfoD0Ev", "(anonymous namespace)::MinGWX86_32TargetInfo::~MinGWX86_32TargetInfo()"},
    {"_ZNK12_GLOBAL__N_121MinGWX86_32TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::MinGWX86_32TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_122CygwinX86_32TargetInfoD1Ev", "(anonymous namespace)::CygwinX86_32TargetInfo::~CygwinX86_32TargetInfo()"},
    {"_ZN12_GLOBAL__N_122CygwinX86_32TargetInfoD0Ev", "(anonymous namespace)::CygwinX86_32TargetInfo::~CygwinX86_32TargetInfo()"},
    {"_ZNK12_GLOBAL__N_122CygwinX86_32TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::CygwinX86_32TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_117SolarisTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::SolarisTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~SolarisTargetInfo()"},
    {"_ZN12_GLOBAL__N_117SolarisTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::SolarisTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~SolarisTargetInfo()"},
    {"_ZNK12_GLOBAL__N_117SolarisTargetInfoINS_16X86_32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::SolarisTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_115MinixTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::MinixTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~MinixTargetInfo()"},
    {"_ZN12_GLOBAL__N_115MinixTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::MinixTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~MinixTargetInfo()"},
    {"_ZNK12_GLOBAL__N_115MinixTargetInfoINS_16X86_32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::MinixTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_117FreeBSDTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~FreeBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_117FreeBSDTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~FreeBSDTargetInfo()"},
    {"_ZNK12_GLOBAL__N_117FreeBSDTargetInfoINS_16X86_32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_121OpenBSDI386TargetInfoD1Ev", "(anonymous namespace)::OpenBSDI386TargetInfo::~OpenBSDI386TargetInfo()"},
    {"_ZN12_GLOBAL__N_121OpenBSDI386TargetInfoD0Ev", "(anonymous namespace)::OpenBSDI386TargetInfo::~OpenBSDI386TargetInfo()"},
    {"_ZNK12_GLOBAL__N_117OpenBSDTargetInfoINS_16X86_32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::OpenBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_117OpenBSDTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::OpenBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~OpenBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_117OpenBSDTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::OpenBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~OpenBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_116NetBSDTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::NetBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~NetBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_116NetBSDTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::NetBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~NetBSDTargetInfo()"},
    {"_ZNK12_GLOBAL__N_116NetBSDTargetInfoINS_16X86_32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::NetBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_122DragonFlyBSDTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::DragonFlyBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~DragonFlyBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_122DragonFlyBSDTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::DragonFlyBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~DragonFlyBSDTargetInfo()"},
    {"_ZNK12_GLOBAL__N_122DragonFlyBSDTargetInfoINS_16X86_32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::DragonFlyBSDTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_115LinuxTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~LinuxTargetInfo()"},
    {"_ZN12_GLOBAL__N_115LinuxTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~LinuxTargetInfo()"},
    {"_ZNK12_GLOBAL__N_115LinuxTargetInfoINS_16X86_32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_120DarwinI386TargetInfoD1Ev", "(anonymous namespace)::DarwinI386TargetInfo::~DarwinI386TargetInfo()"},
    {"_ZN12_GLOBAL__N_120DarwinI386TargetInfoD0Ev", "(anonymous namespace)::DarwinI386TargetInfo::~DarwinI386TargetInfo()"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_16X86_32TargetInfoEE23isValidSectionSpecifierEN4llvm9StringRefE", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::X86_32TargetInfo>::isValidSectionSpecifier(llvm::StringRef) const"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_16X86_32TargetInfoEE29getStaticInitSectionSpecifierEv", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getStaticInitSectionSpecifier() const"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_16X86_32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_116DarwinTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~DarwinTargetInfo()"},
    {"_ZN12_GLOBAL__N_116DarwinTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~DarwinTargetInfo()"},
    {"_ZN12_GLOBAL__N_118AuroraUXTargetInfoINS_16X86_32TargetInfoEED1Ev", "(anonymous namespace)::AuroraUXTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~AuroraUXTargetInfo()"},
    {"_ZN12_GLOBAL__N_118AuroraUXTargetInfoINS_16X86_32TargetInfoEED0Ev", "(anonymous namespace)::AuroraUXTargetInfo<(anonymous namespace)::X86_32TargetInfo>::~AuroraUXTargetInfo()"},
    {"_ZNK12_GLOBAL__N_118AuroraUXTargetInfoINS_16X86_32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::AuroraUXTargetInfo<(anonymous namespace)::X86_32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_113TCETargetInfoD1Ev", "(anonymous namespace)::TCETargetInfo::~TCETargetInfo()"},
    {"_ZN12_GLOBAL__N_113TCETargetInfoD0Ev", "(anonymous namespace)::TCETargetInfo::~TCETargetInfo()"},
    {"_ZNK12_GLOBAL__N_113TCETargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::TCETargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_113TCETargetInfo17getTargetBuiltinsERPKN5clang7Builtin4InfoERj", "(anonymous namespace)::TCETargetInfo::getTargetBuiltins(clang::Builtin::Info const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_113TCETargetInfo20getVAListDeclarationEv", "(anonymous namespace)::TCETargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_113TCETargetInfo11getClobbersEv", "(anonymous namespace)::TCETargetInfo::getClobbers() const"},
    {"_ZNK12_GLOBAL__N_113TCETargetInfo14getGCCRegNamesERPKPKcRj", "(anonymous namespace)::TCETargetInfo::getGCCRegNames(char const* const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_113TCETargetInfo16getGCCRegAliasesERPKN5clang10TargetInfo11GCCRegAliasERj", "(anonymous namespace)::TCETargetInfo::getGCCRegAliases(clang::TargetInfo::GCCRegAlias const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_113TCETargetInfo21validateAsmConstraintERPKcRN5clang10TargetInfo14ConstraintInfoE", "(anonymous namespace)::TCETargetInfo::validateAsmConstraint(char const*&, clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZN12_GLOBAL__N_117SystemZTargetInfoD1Ev", "(anonymous namespace)::SystemZTargetInfo::~SystemZTargetInfo()"},
    {"_ZN12_GLOBAL__N_117SystemZTargetInfoD0Ev", "(anonymous namespace)::SystemZTargetInfo::~SystemZTargetInfo()"},
    {"_ZNK12_GLOBAL__N_117SystemZTargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::SystemZTargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_117SystemZTargetInfo17getTargetBuiltinsERPKN5clang7Builtin4InfoERj", "(anonymous namespace)::SystemZTargetInfo::getTargetBuiltins(clang::Builtin::Info const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_117SystemZTargetInfo20getVAListDeclarationEv", "(anonymous namespace)::SystemZTargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_117SystemZTargetInfo11getClobbersEv", "(anonymous namespace)::SystemZTargetInfo::getClobbers() const"},
    {"_ZNK12_GLOBAL__N_117SystemZTargetInfo14getGCCRegNamesERPKPKcRj", "(anonymous namespace)::SystemZTargetInfo::getGCCRegNames(char const* const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_117SystemZTargetInfo16getGCCRegAliasesERPKN5clang10TargetInfo11GCCRegAliasERj", "(anonymous namespace)::SystemZTargetInfo::getGCCRegAliases(clang::TargetInfo::GCCRegAlias const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_117SystemZTargetInfo21validateAsmConstraintERPKcRN5clang10TargetInfo14ConstraintInfoE", "(anonymous namespace)::SystemZTargetInfo::validateAsmConstraint(char const*&, clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZN12_GLOBAL__N_116PS3SPUTargetInfoINS_15PPC64TargetInfoEED1Ev", "(anonymous namespace)::PS3SPUTargetInfo<(anonymous namespace)::PPC64TargetInfo>::~PS3SPUTargetInfo()"},
    {"_ZN12_GLOBAL__N_116PS3SPUTargetInfoINS_15PPC64TargetInfoEED0Ev", "(anonymous namespace)::PS3SPUTargetInfo<(anonymous namespace)::PPC64TargetInfo>::~PS3SPUTargetInfo()"},
    {"_ZNK12_GLOBAL__N_112OSTargetInfoINS_15PPC64TargetInfoEE16getTargetDefinesERKN5clang11LangOptionsERNS3_12MacroBuilderE", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::PPC64TargetInfo>::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_113PPCTargetInfo17getTargetBuiltinsERPKN5clang7Builtin4InfoERj", "(anonymous namespace)::PPCTargetInfo::getTargetBuiltins(clang::Builtin::Info const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_115PPC64TargetInfo20getVAListDeclarationEv", "(anonymous namespace)::PPC64TargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_113PPCTargetInfo11getClobbersEv", "(anonymous namespace)::PPCTargetInfo::getClobbers() const"},
    {"_ZNK12_GLOBAL__N_113PPCTargetInfo14getGCCRegNamesERPKPKcRj", "(anonymous namespace)::PPCTargetInfo::getGCCRegNames(char const* const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_113PPCTargetInfo16getGCCRegAliasesERPKN5clang10TargetInfo11GCCRegAliasERj", "(anonymous namespace)::PPCTargetInfo::getGCCRegAliases(clang::TargetInfo::GCCRegAlias const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_113PPCTargetInfo21validateAsmConstraintERPKcRN5clang10TargetInfo14ConstraintInfoE", "(anonymous namespace)::PPCTargetInfo::validateAsmConstraint(char const*&, clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZNK12_GLOBAL__N_116PS3SPUTargetInfoINS_15PPC64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::PS3SPUTargetInfo<(anonymous namespace)::PPC64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_113PPCTargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::PPCTargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_15PPC64TargetInfoEED1Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::PPC64TargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_15PPC64TargetInfoEED0Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::PPC64TargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_115PPC64TargetInfoD1Ev", "(anonymous namespace)::PPC64TargetInfo::~PPC64TargetInfo()"},
    {"_ZN12_GLOBAL__N_115PPC64TargetInfoD0Ev", "(anonymous namespace)::PPC64TargetInfo::~PPC64TargetInfo()"},
    {"_ZN12_GLOBAL__N_113PPCTargetInfoD1Ev", "(anonymous namespace)::PPCTargetInfo::~PPCTargetInfo()"},
    {"_ZN12_GLOBAL__N_113PPCTargetInfoD0Ev", "(anonymous namespace)::PPCTargetInfo::~PPCTargetInfo()"},
    {"_ZN12_GLOBAL__N_117SparcV8TargetInfoD1Ev", "(anonymous namespace)::SparcV8TargetInfo::~SparcV8TargetInfo()"},
    {"_ZN12_GLOBAL__N_117SparcV8TargetInfoD0Ev", "(anonymous namespace)::SparcV8TargetInfo::~SparcV8TargetInfo()"},
    {"_ZNK12_GLOBAL__N_117SparcV8TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::SparcV8TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_117SparcV8TargetInfo17getTargetBuiltinsERPKN5clang7Builtin4InfoERj", "(anonymous namespace)::SparcV8TargetInfo::getTargetBuiltins(clang::Builtin::Info const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_117SparcV8TargetInfo20getVAListDeclarationEv", "(anonymous namespace)::SparcV8TargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_117SparcV8TargetInfo11getClobbersEv", "(anonymous namespace)::SparcV8TargetInfo::getClobbers() const"},
    {"_ZNK12_GLOBAL__N_117SparcV8TargetInfo17setFeatureEnabledERN4llvm9StringMapIbNS1_15MallocAllocatorEEERKSsb", "(anonymous namespace)::SparcV8TargetInfo::setFeatureEnabled(llvm::StringMap<bool, llvm::MallocAllocator>&, std::string const&, bool) const"},
    {"_ZN12_GLOBAL__N_117SparcV8TargetInfo20HandleTargetFeaturesERSt6vectorISsSaISsEE", "(anonymous namespace)::SparcV8TargetInfo::HandleTargetFeatures(std::vector<std::string, std::allocator<std::string>>&)"},
    {"_ZNK12_GLOBAL__N_117SparcV8TargetInfo14getGCCRegNamesERPKPKcRj", "(anonymous namespace)::SparcV8TargetInfo::getGCCRegNames(char const* const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_117SparcV8TargetInfo16getGCCRegAliasesERPKN5clang10TargetInfo11GCCRegAliasERj", "(anonymous namespace)::SparcV8TargetInfo::getGCCRegAliases(clang::TargetInfo::GCCRegAlias const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_117SparcV8TargetInfo21validateAsmConstraintERPKcRN5clang10TargetInfo14ConstraintInfoE", "(anonymous namespace)::SparcV8TargetInfo::validateAsmConstraint(char const*&, clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZN12_GLOBAL__N_124SolarisSparcV8TargetInfoD1Ev", "(anonymous namespace)::SolarisSparcV8TargetInfo::~SolarisSparcV8TargetInfo()"},
    {"_ZN12_GLOBAL__N_124SolarisSparcV8TargetInfoD0Ev", "(anonymous namespace)::SolarisSparcV8TargetInfo::~SolarisSparcV8TargetInfo()"},
    {"_ZNK12_GLOBAL__N_112OSTargetInfoINS_17SparcV8TargetInfoEE16getTargetDefinesERKN5clang11LangOptionsERNS3_12MacroBuilderE", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::SparcV8TargetInfo>::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_117SolarisTargetInfoINS_17SparcV8TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::SolarisTargetInfo<(anonymous namespace)::SparcV8TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_117SolarisTargetInfoINS_17SparcV8TargetInfoEED1Ev", "(anonymous namespace)::SolarisTargetInfo<(anonymous namespace)::SparcV8TargetInfo>::~SolarisTargetInfo()"},
    {"_ZN12_GLOBAL__N_117SolarisTargetInfoINS_17SparcV8TargetInfoEED0Ev", "(anonymous namespace)::SolarisTargetInfo<(anonymous namespace)::SparcV8TargetInfo>::~SolarisTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_17SparcV8TargetInfoEED1Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::SparcV8TargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_17SparcV8TargetInfoEED0Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::SparcV8TargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_125AuroraUXSparcV8TargetInfoD1Ev", "(anonymous namespace)::AuroraUXSparcV8TargetInfo::~AuroraUXSparcV8TargetInfo()"},
    {"_ZN12_GLOBAL__N_125AuroraUXSparcV8TargetInfoD0Ev", "(anonymous namespace)::AuroraUXSparcV8TargetInfo::~AuroraUXSparcV8TargetInfo()"},
    {"_ZNK12_GLOBAL__N_118AuroraUXTargetInfoINS_17SparcV8TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::AuroraUXTargetInfo<(anonymous namespace)::SparcV8TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_118AuroraUXTargetInfoINS_17SparcV8TargetInfoEED1Ev", "(anonymous namespace)::AuroraUXTargetInfo<(anonymous namespace)::SparcV8TargetInfo>::~AuroraUXTargetInfo()"},
    {"_ZN12_GLOBAL__N_118AuroraUXTargetInfoINS_17SparcV8TargetInfoEED0Ev", "(anonymous namespace)::AuroraUXTargetInfo<(anonymous namespace)::SparcV8TargetInfo>::~AuroraUXTargetInfo()"},
    {"_ZN12_GLOBAL__N_116MBlazeTargetInfoD1Ev", "(anonymous namespace)::MBlazeTargetInfo::~MBlazeTargetInfo()"},
    {"_ZN12_GLOBAL__N_116MBlazeTargetInfoD0Ev", "(anonymous namespace)::MBlazeTargetInfo::~MBlazeTargetInfo()"},
    {"_ZNK12_GLOBAL__N_116MBlazeTargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::MBlazeTargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_116MBlazeTargetInfo17getTargetBuiltinsERPKN5clang7Builtin4InfoERj", "(anonymous namespace)::MBlazeTargetInfo::getTargetBuiltins(clang::Builtin::Info const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_116MBlazeTargetInfo20getVAListDeclarationEv", "(anonymous namespace)::MBlazeTargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_116MBlazeTargetInfo11getClobbersEv", "(anonymous namespace)::MBlazeTargetInfo::getClobbers() const"},
    {"_ZNK12_GLOBAL__N_116MBlazeTargetInfo14getGCCRegNamesERPKPKcRj", "(anonymous namespace)::MBlazeTargetInfo::getGCCRegNames(char const* const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_116MBlazeTargetInfo16getGCCRegAliasesERPKN5clang10TargetInfo11GCCRegAliasERj", "(anonymous namespace)::MBlazeTargetInfo::getGCCRegAliases(clang::TargetInfo::GCCRegAlias const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_116MBlazeTargetInfo21validateAsmConstraintERPKcRN5clang10TargetInfo14ConstraintInfoE", "(anonymous namespace)::MBlazeTargetInfo::validateAsmConstraint(char const*&, clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZNK12_GLOBAL__N_116MBlazeTargetInfo15getTargetPrefixEv", "(anonymous namespace)::MBlazeTargetInfo::getTargetPrefix() const"},
    {"_ZN12_GLOBAL__N_117FreeBSDTargetInfoINS_15PPC64TargetInfoEED1Ev", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::PPC64TargetInfo>::~FreeBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_117FreeBSDTargetInfoINS_15PPC64TargetInfoEED0Ev", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::PPC64TargetInfo>::~FreeBSDTargetInfo()"},
    {"_ZNK12_GLOBAL__N_117FreeBSDTargetInfoINS_15PPC64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::PPC64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_116PS3PPUTargetInfoINS_15PPC64TargetInfoEED1Ev", "(anonymous namespace)::PS3PPUTargetInfo<(anonymous namespace)::PPC64TargetInfo>::~PS3PPUTargetInfo()"},
    {"_ZN12_GLOBAL__N_116PS3PPUTargetInfoINS_15PPC64TargetInfoEED0Ev", "(anonymous namespace)::PS3PPUTargetInfo<(anonymous namespace)::PPC64TargetInfo>::~PS3PPUTargetInfo()"},
    {"_ZNK12_GLOBAL__N_116PS3PPUTargetInfoINS_15PPC64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::PS3PPUTargetInfo<(anonymous namespace)::PPC64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_121DarwinPPC64TargetInfoD1Ev", "(anonymous namespace)::DarwinPPC64TargetInfo::~DarwinPPC64TargetInfo()"},
    {"_ZN12_GLOBAL__N_121DarwinPPC64TargetInfoD0Ev", "(anonymous namespace)::DarwinPPC64TargetInfo::~DarwinPPC64TargetInfo()"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_15PPC64TargetInfoEE23isValidSectionSpecifierEN4llvm9StringRefE", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::PPC64TargetInfo>::isValidSectionSpecifier(llvm::StringRef) const"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_15PPC64TargetInfoEE29getStaticInitSectionSpecifierEv", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::PPC64TargetInfo>::getStaticInitSectionSpecifier() const"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_15PPC64TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::PPC64TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_116DarwinTargetInfoINS_15PPC64TargetInfoEED1Ev", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::PPC64TargetInfo>::~DarwinTargetInfo()"},
    {"_ZN12_GLOBAL__N_116DarwinTargetInfoINS_15PPC64TargetInfoEED0Ev", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::PPC64TargetInfo>::~DarwinTargetInfo()"},
    {"_ZN12_GLOBAL__N_115PPC32TargetInfoD1Ev", "(anonymous namespace)::PPC32TargetInfo::~PPC32TargetInfo()"},
    {"_ZN12_GLOBAL__N_115PPC32TargetInfoD0Ev", "(anonymous namespace)::PPC32TargetInfo::~PPC32TargetInfo()"},
    {"_ZNK12_GLOBAL__N_115PPC32TargetInfo20getVAListDeclarationEv", "(anonymous namespace)::PPC32TargetInfo::getVAListDeclaration() const"},
    {"_ZN12_GLOBAL__N_117FreeBSDTargetInfoINS_15PPC32TargetInfoEED1Ev", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::PPC32TargetInfo>::~FreeBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_117FreeBSDTargetInfoINS_15PPC32TargetInfoEED0Ev", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::PPC32TargetInfo>::~FreeBSDTargetInfo()"},
    {"_ZNK12_GLOBAL__N_112OSTargetInfoINS_15PPC32TargetInfoEE16getTargetDefinesERKN5clang11LangOptionsERNS3_12MacroBuilderE", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::PPC32TargetInfo>::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_117FreeBSDTargetInfoINS_15PPC32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::PPC32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_15PPC32TargetInfoEED1Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::PPC32TargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_15PPC32TargetInfoEED0Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::PPC32TargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_121DarwinPPC32TargetInfoD1Ev", "(anonymous namespace)::DarwinPPC32TargetInfo::~DarwinPPC32TargetInfo()"},
    {"_ZN12_GLOBAL__N_121DarwinPPC32TargetInfoD0Ev", "(anonymous namespace)::DarwinPPC32TargetInfo::~DarwinPPC32TargetInfo()"},
    {"_ZNK12_GLOBAL__N_121DarwinPPC32TargetInfo20getVAListDeclarationEv", "(anonymous namespace)::DarwinPPC32TargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_15PPC32TargetInfoEE23isValidSectionSpecifierEN4llvm9StringRefE", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::PPC32TargetInfo>::isValidSectionSpecifier(llvm::StringRef) const"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_15PPC32TargetInfoEE29getStaticInitSectionSpecifierEv", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::PPC32TargetInfo>::getStaticInitSectionSpecifier() const"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_15PPC32TargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::PPC32TargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_116DarwinTargetInfoINS_15PPC32TargetInfoEED1Ev", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::PPC32TargetInfo>::~DarwinTargetInfo()"},
    {"_ZN12_GLOBAL__N_116DarwinTargetInfoINS_15PPC32TargetInfoEED0Ev", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::PPC32TargetInfo>::~DarwinTargetInfo()"},
    {"_ZN12_GLOBAL__N_116MipselTargetInfoD1Ev", "(anonymous namespace)::MipselTargetInfo::~MipselTargetInfo()"},
    {"_ZN12_GLOBAL__N_116MipselTargetInfoD0Ev", "(anonymous namespace)::MipselTargetInfo::~MipselTargetInfo()"},
    {"_ZNK12_GLOBAL__N_116MipselTargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::MipselTargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_114MipsTargetInfo17getTargetBuiltinsERPKN5clang7Builtin4InfoERj", "(anonymous namespace)::MipsTargetInfo::getTargetBuiltins(clang::Builtin::Info const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_114MipsTargetInfo20getVAListDeclarationEv", "(anonymous namespace)::MipsTargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_114MipsTargetInfo11getClobbersEv", "(anonymous namespace)::MipsTargetInfo::getClobbers() const"},
    {"_ZNK12_GLOBAL__N_114MipsTargetInfo18getDefaultFeaturesERKSsRN4llvm9StringMapIbNS3_15MallocAllocatorEEE", "(anonymous namespace)::MipsTargetInfo::getDefaultFeatures(std::string const&, llvm::StringMap<bool, llvm::MallocAllocator>&) const"},
    {"_ZNK12_GLOBAL__N_114MipsTargetInfo6getABIEv", "(anonymous namespace)::MipsTargetInfo::getABI() const"},
    {"_ZN12_GLOBAL__N_114MipsTargetInfo6setCPUERKSs", "(anonymous namespace)::MipsTargetInfo::setCPU(std::string const&)"},
    {"_ZN12_GLOBAL__N_114MipsTargetInfo6setABIERKSs", "(anonymous namespace)::MipsTargetInfo::setABI(std::string const&)"},
    {"_ZNK12_GLOBAL__N_114MipsTargetInfo14getGCCRegNamesERPKPKcRj", "(anonymous namespace)::MipsTargetInfo::getGCCRegNames(char const* const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_114MipsTargetInfo16getGCCRegAliasesERPKN5clang10TargetInfo11GCCRegAliasERj", "(anonymous namespace)::MipsTargetInfo::getGCCRegAliases(clang::TargetInfo::GCCRegAlias const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_114MipsTargetInfo21validateAsmConstraintERPKcRN5clang10TargetInfo14ConstraintInfoE", "(anonymous namespace)::MipsTargetInfo::validateAsmConstraint(char const*&, clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZNK12_GLOBAL__N_114MipsTargetInfo14getArchDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::MipsTargetInfo::getArchDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_114MipsTargetInfoD1Ev", "(anonymous namespace)::MipsTargetInfo::~MipsTargetInfo()"},
    {"_ZN12_GLOBAL__N_114MipsTargetInfoD0Ev", "(anonymous namespace)::MipsTargetInfo::~MipsTargetInfo()"},
    {"_ZNK12_GLOBAL__N_114MipsTargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::MipsTargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_115LinuxTargetInfoINS_16MipselTargetInfoEED1Ev", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::MipselTargetInfo>::~LinuxTargetInfo()"},
    {"_ZN12_GLOBAL__N_115LinuxTargetInfoINS_16MipselTargetInfoEED0Ev", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::MipselTargetInfo>::~LinuxTargetInfo()"},
    {"_ZNK12_GLOBAL__N_112OSTargetInfoINS_16MipselTargetInfoEE16getTargetDefinesERKN5clang11LangOptionsERNS3_12MacroBuilderE", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::MipselTargetInfo>::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_115LinuxTargetInfoINS_16MipselTargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::MipselTargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_16MipselTargetInfoEED1Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::MipselTargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_16MipselTargetInfoEED0Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::MipselTargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_113PSPTargetInfoINS_16MipselTargetInfoEED1Ev", "(anonymous namespace)::PSPTargetInfo<(anonymous namespace)::MipselTargetInfo>::~PSPTargetInfo()"},
    {"_ZN12_GLOBAL__N_113PSPTargetInfoINS_16MipselTargetInfoEED0Ev", "(anonymous namespace)::PSPTargetInfo<(anonymous namespace)::MipselTargetInfo>::~PSPTargetInfo()"},
    {"_ZNK12_GLOBAL__N_113PSPTargetInfoINS_16MipselTargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::PSPTargetInfo<(anonymous namespace)::MipselTargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_115LinuxTargetInfoINS_14MipsTargetInfoEED1Ev", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::MipsTargetInfo>::~LinuxTargetInfo()"},
    {"_ZN12_GLOBAL__N_115LinuxTargetInfoINS_14MipsTargetInfoEED0Ev", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::MipsTargetInfo>::~LinuxTargetInfo()"},
    {"_ZNK12_GLOBAL__N_112OSTargetInfoINS_14MipsTargetInfoEE16getTargetDefinesERKN5clang11LangOptionsERNS3_12MacroBuilderE", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::MipsTargetInfo>::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_115LinuxTargetInfoINS_14MipsTargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::MipsTargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_14MipsTargetInfoEED1Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::MipsTargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_14MipsTargetInfoEED0Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::MipsTargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_113PSPTargetInfoINS_14MipsTargetInfoEED1Ev", "(anonymous namespace)::PSPTargetInfo<(anonymous namespace)::MipsTargetInfo>::~PSPTargetInfo()"},
    {"_ZN12_GLOBAL__N_113PSPTargetInfoINS_14MipsTargetInfoEED0Ev", "(anonymous namespace)::PSPTargetInfo<(anonymous namespace)::MipsTargetInfo>::~PSPTargetInfo()"},
    {"_ZNK12_GLOBAL__N_113PSPTargetInfoINS_14MipsTargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::PSPTargetInfo<(anonymous namespace)::MipsTargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_116MSP430TargetInfoD1Ev", "(anonymous namespace)::MSP430TargetInfo::~MSP430TargetInfo()"},
    {"_ZN12_GLOBAL__N_116MSP430TargetInfoD0Ev", "(anonymous namespace)::MSP430TargetInfo::~MSP430TargetInfo()"},
    {"_ZNK12_GLOBAL__N_116MSP430TargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::MSP430TargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_116MSP430TargetInfo17getTargetBuiltinsERPKN5clang7Builtin4InfoERj", "(anonymous namespace)::MSP430TargetInfo::getTargetBuiltins(clang::Builtin::Info const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_116MSP430TargetInfo20getVAListDeclarationEv", "(anonymous namespace)::MSP430TargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_116MSP430TargetInfo11getClobbersEv", "(anonymous namespace)::MSP430TargetInfo::getClobbers() const"},
    {"_ZNK12_GLOBAL__N_116MSP430TargetInfo14getGCCRegNamesERPKPKcRj", "(anonymous namespace)::MSP430TargetInfo::getGCCRegNames(char const* const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_116MSP430TargetInfo16getGCCRegAliasesERPKN5clang10TargetInfo11GCCRegAliasERj", "(anonymous namespace)::MSP430TargetInfo::getGCCRegAliases(clang::TargetInfo::GCCRegAlias const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_116MSP430TargetInfo21validateAsmConstraintERPKcRN5clang10TargetInfo14ConstraintInfoE", "(anonymous namespace)::MSP430TargetInfo::validateAsmConstraint(char const*&, clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZN12_GLOBAL__N_118BlackfinTargetInfoD1Ev", "(anonymous namespace)::BlackfinTargetInfo::~BlackfinTargetInfo()"},
    {"_ZN12_GLOBAL__N_118BlackfinTargetInfoD0Ev", "(anonymous namespace)::BlackfinTargetInfo::~BlackfinTargetInfo()"},
    {"_ZNK12_GLOBAL__N_118BlackfinTargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::BlackfinTargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_118BlackfinTargetInfo17getTargetBuiltinsERPKN5clang7Builtin4InfoERj", "(anonymous namespace)::BlackfinTargetInfo::getTargetBuiltins(clang::Builtin::Info const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_118BlackfinTargetInfo20getVAListDeclarationEv", "(anonymous namespace)::BlackfinTargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_118BlackfinTargetInfo11getClobbersEv", "(anonymous namespace)::BlackfinTargetInfo::getClobbers() const"},
    {"_ZNK12_GLOBAL__N_118BlackfinTargetInfo14getGCCRegNamesERPKPKcRj", "(anonymous namespace)::BlackfinTargetInfo::getGCCRegNames(char const* const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_118BlackfinTargetInfo16getGCCRegAliasesERPKN5clang10TargetInfo11GCCRegAliasERj", "(anonymous namespace)::BlackfinTargetInfo::getGCCRegAliases(clang::TargetInfo::GCCRegAlias const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_118BlackfinTargetInfo21validateAsmConstraintERPKcRN5clang10TargetInfo14ConstraintInfoE", "(anonymous namespace)::BlackfinTargetInfo::validateAsmConstraint(char const*&, clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZN12_GLOBAL__N_113ARMTargetInfoC2ERKSs", "(anonymous namespace)::ARMTargetInfo::ARMTargetInfo(std::string const&)"},
    {"_ZN12_GLOBAL__N_113ARMTargetInfoD1Ev", "(anonymous namespace)::ARMTargetInfo::~ARMTargetInfo()"},
    {"_ZN12_GLOBAL__N_113ARMTargetInfoD0Ev", "(anonymous namespace)::ARMTargetInfo::~ARMTargetInfo()"},
    {"_ZNK12_GLOBAL__N_113ARMTargetInfo16getTargetDefinesERKN5clang11LangOptionsERNS1_12MacroBuilderE", "(anonymous namespace)::ARMTargetInfo::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_113ARMTargetInfo17getTargetBuiltinsERPKN5clang7Builtin4InfoERj", "(anonymous namespace)::ARMTargetInfo::getTargetBuiltins(clang::Builtin::Info const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_113ARMTargetInfo20getVAListDeclarationEv", "(anonymous namespace)::ARMTargetInfo::getVAListDeclaration() const"},
    {"_ZNK12_GLOBAL__N_113ARMTargetInfo11getClobbersEv", "(anonymous namespace)::ARMTargetInfo::getClobbers() const"},
    {"_ZNK12_GLOBAL__N_113ARMTargetInfo18getDefaultFeaturesERKSsRN4llvm9StringMapIbNS3_15MallocAllocatorEEE", "(anonymous namespace)::ARMTargetInfo::getDefaultFeatures(std::string const&, llvm::StringMap<bool, llvm::MallocAllocator>&) const"},
    {"_ZNK12_GLOBAL__N_113ARMTargetInfo6getABIEv", "(anonymous namespace)::ARMTargetInfo::getABI() const"},
    {"_ZN12_GLOBAL__N_113ARMTargetInfo6setCPUERKSs", "(anonymous namespace)::ARMTargetInfo::setCPU(std::string const&)"},
    {"_ZN12_GLOBAL__N_113ARMTargetInfo6setABIERKSs", "(anonymous namespace)::ARMTargetInfo::setABI(std::string const&)"},
    {"_ZNK12_GLOBAL__N_113ARMTargetInfo17setFeatureEnabledERN4llvm9StringMapIbNS1_15MallocAllocatorEEERKSsb", "(anonymous namespace)::ARMTargetInfo::setFeatureEnabled(llvm::StringMap<bool, llvm::MallocAllocator>&, std::string const&, bool) const"},
    {"_ZN12_GLOBAL__N_113ARMTargetInfo20HandleTargetFeaturesERSt6vectorISsSaISsEE", "(anonymous namespace)::ARMTargetInfo::HandleTargetFeatures(std::vector<std::string, std::allocator<std::string>>&)"},
    {"_ZNK12_GLOBAL__N_113ARMTargetInfo14getGCCRegNamesERPKPKcRj", "(anonymous namespace)::ARMTargetInfo::getGCCRegNames(char const* const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_113ARMTargetInfo16getGCCRegAliasesERPKN5clang10TargetInfo11GCCRegAliasERj", "(anonymous namespace)::ARMTargetInfo::getGCCRegAliases(clang::TargetInfo::GCCRegAlias const*&, unsigned int&) const"},
    {"_ZNK12_GLOBAL__N_113ARMTargetInfo21validateAsmConstraintERPKcRN5clang10TargetInfo14ConstraintInfoE", "(anonymous namespace)::ARMTargetInfo::validateAsmConstraint(char const*&, clang::TargetInfo::ConstraintInfo&) const"},
    {"_ZN12_GLOBAL__N_113ARMTargetInfo18getCPUDefineSuffixEN4llvm9StringRefE", "(anonymous namespace)::ARMTargetInfo::getCPUDefineSuffix(llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_117FreeBSDTargetInfoINS_13ARMTargetInfoEED1Ev", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::ARMTargetInfo>::~FreeBSDTargetInfo()"},
    {"_ZN12_GLOBAL__N_117FreeBSDTargetInfoINS_13ARMTargetInfoEED0Ev", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::ARMTargetInfo>::~FreeBSDTargetInfo()"},
    {"_ZNK12_GLOBAL__N_112OSTargetInfoINS_13ARMTargetInfoEE16getTargetDefinesERKN5clang11LangOptionsERNS3_12MacroBuilderE", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::ARMTargetInfo>::getTargetDefines(clang::LangOptions const&, clang::MacroBuilder&) const"},
    {"_ZNK12_GLOBAL__N_117FreeBSDTargetInfoINS_13ARMTargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::FreeBSDTargetInfo<(anonymous namespace)::ARMTargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_13ARMTargetInfoEED1Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::ARMTargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_112OSTargetInfoINS_13ARMTargetInfoEED0Ev", "(anonymous namespace)::OSTargetInfo<(anonymous namespace)::ARMTargetInfo>::~OSTargetInfo()"},
    {"_ZN12_GLOBAL__N_119DarwinARMTargetInfoD1Ev", "(anonymous namespace)::DarwinARMTargetInfo::~DarwinARMTargetInfo()"},
    {"_ZN12_GLOBAL__N_119DarwinARMTargetInfoD0Ev", "(anonymous namespace)::DarwinARMTargetInfo::~DarwinARMTargetInfo()"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_13ARMTargetInfoEE23isValidSectionSpecifierEN4llvm9StringRefE", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::ARMTargetInfo>::isValidSectionSpecifier(llvm::StringRef) const"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_13ARMTargetInfoEE29getStaticInitSectionSpecifierEv", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::ARMTargetInfo>::getStaticInitSectionSpecifier() const"},
    {"_ZNK12_GLOBAL__N_119DarwinARMTargetInfo12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS1_12MacroBuilderE", "(anonymous namespace)::DarwinARMTargetInfo::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_116DarwinTargetInfoINS_13ARMTargetInfoEED1Ev", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::ARMTargetInfo>::~DarwinTargetInfo()"},
    {"_ZN12_GLOBAL__N_116DarwinTargetInfoINS_13ARMTargetInfoEED0Ev", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::ARMTargetInfo>::~DarwinTargetInfo()"},
    {"_ZNK12_GLOBAL__N_116DarwinTargetInfoINS_13ARMTargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::DarwinTargetInfo<(anonymous namespace)::ARMTargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN12_GLOBAL__N_115LinuxTargetInfoINS_13ARMTargetInfoEED1Ev", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::ARMTargetInfo>::~LinuxTargetInfo()"},
    {"_ZN12_GLOBAL__N_115LinuxTargetInfoINS_13ARMTargetInfoEED0Ev", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::ARMTargetInfo>::~LinuxTargetInfo()"},
    {"_ZNK12_GLOBAL__N_115LinuxTargetInfoINS_13ARMTargetInfoEE12getOSDefinesERKN5clang11LangOptionsERKN4llvm6TripleERNS3_12MacroBuilderE", "(anonymous namespace)::LinuxTargetInfo<(anonymous namespace)::ARMTargetInfo>::getOSDefines(clang::LangOptions const&, llvm::Triple const&, clang::MacroBuilder&) const"},
    {"_ZN5clang10TargetInfo9setCXXABIERKSs", "clang::TargetInfo::setCXXABI(std::string const&)"},
    {"_ZNK5clang10TargetInfo31useGlobalsForAutomaticVariablesEv", "clang::TargetInfo::useGlobalsForAutomaticVariables() const"},
    {"_ZNK5clang10TargetInfo18getCFStringSectionEv", "clang::TargetInfo::getCFStringSection() const"},
    {"_ZNK5clang10TargetInfo18getNSStringSectionEv", "clang::TargetInfo::getNSStringSection() const"},
    {"_ZNK5clang10TargetInfo31getNSStringNonFragileABISectionEv", "clang::TargetInfo::getNSStringNonFragileABISection() const"},
    {"_ZNK5clang10TargetInfo23isValidSectionSpecifierEN4llvm9StringRefE", "clang::TargetInfo::isValidSectionSpecifier(llvm::StringRef) const"},
    {"_ZNK5clang10TargetInfo6getABIEv", "clang::TargetInfo::getABI() const"},
    {"_ZNK5clang10TargetInfo9getCXXABIEv", "clang::TargetInfo::getCXXABI() const"},
    {"_ZN5clang10TargetInfo6setCPUERKSs", "clang::TargetInfo::setCPU(std::string const&)"},
    {"_ZN5clang10TargetInfo6setABIERKSs", "clang::TargetInfo::setABI(std::string const&)"},
    {"_ZN5clang10TargetInfo9setCXXABIENS_12TargetCXXABIE", "clang::TargetInfo::setCXXABI(clang::TargetCXXABI)"},
    {"_ZNK5clang10TargetInfo29getStaticInitSectionSpecifierEv", "clang::TargetInfo::getStaticInitSectionSpecifier() const"},
    {"_ZNK5clang10TargetInfo16getPointerWidthVEj", "clang::TargetInfo::getPointerWidthV(unsigned int) const"},
    {"_ZNK5clang10TargetInfo16getPointerAlignVEj", "clang::TargetInfo::getPointerAlignV(unsigned int) const"},
    {"_ZNK5clang10TargetInfo15getPtrDiffTypeVEj", "clang::TargetInfo::getPtrDiffTypeV(unsigned int) const"},
    {"_ZN5clang12MacroBuilder11defineMacroERKN4llvm5TwineES4_", "clang::MacroBuilder::defineMacro(llvm::Twine const&, llvm::Twine const&)"},
    {"_ZNK5clang10TargetInfo23getEHDataRegisterNumberEj", "clang::TargetInfo::getEHDataRegisterNumber(unsigned int) const"},
    {"_ZNK5clang10TargetInfo17convertConstraintEc", "clang::TargetInfo::convertConstraint(char) const"},
    {"_ZNK5clang10TargetInfo18getDefaultFeaturesERKSsRN4llvm9StringMapIbNS3_15MallocAllocatorEEE", "clang::TargetInfo::getDefaultFeatures(std::string const&, llvm::StringMap<bool, llvm::MallocAllocator>&) const"},
    {"_ZNK5clang10TargetInfo17setFeatureEnabledERN4llvm9StringMapIbNS1_15MallocAllocatorEEERKSsb", "clang::TargetInfo::setFeatureEnabled(llvm::StringMap<bool, llvm::MallocAllocator>&, std::string const&, bool) const"},
    {"_ZN5clang10TargetInfo20HandleTargetFeaturesERSt6vectorISsSaISsEE", "clang::TargetInfo::HandleTargetFeatures(std::vector<std::string, std::allocator<std::string>>&)"},
    {"_ZNK5clang10TargetInfo19adjustInlineAsmTypeERSsPKN4llvm4TypeERNS2_11LLVMContextE", "clang::TargetInfo::adjustInlineAsmType(std::string&, llvm::Type const*, llvm::LLVMContext&) const"},
    {"_ZSt6__findIN9__gnu_cxx17__normal_iteratorIPSsSt6vectorISsSaISsEEEEA16_cET_S8_S8_RKT0_St26random_access_iterator_tag", "__gnu_cxx::__normal_iterator<std::string*, std::vector<std::string, std::allocator<std::string>>> std::__find<__gnu_cxx::__normal_iterator<std::string*, std::vector<std::string, std::allocator<std::string>>>, char [16]>(__gnu_cxx::__normal_iterator<std::string*, std::vector<std::string, std::allocator<std::string>>>, __gnu_cxx::__normal_iterator<std::string*, std::vector<std::string, std::allocator<std::string>>>, char const (&) [16], std::random_access_iterator_tag)"},
    {"_ZSt6__findIN9__gnu_cxx17__normal_iteratorIPSsSt6vectorISsSaISsEEEEA12_cET_S8_S8_RKT0_St26random_access_iterator_tag", "__gnu_cxx::__normal_iterator<std::string*, std::vector<std::string, std::allocator<std::string>>> std::__find<__gnu_cxx::__normal_iterator<std::string*, std::vector<std::string, std::allocator<std::string>>>, char [12]>(__gnu_cxx::__normal_iterator<std::string*, std::vector<std::string, std::allocator<std::string>>>, __gnu_cxx::__normal_iterator<std::string*, std::vector<std::string, std::allocator<std::string>>>, char const (&) [12], std::random_access_iterator_tag)"},
    {"_ZN4llvm12StringSwitchIPKcS2_E5CasesILj10ELj13ELj14ELj14EEERS3_RAT__S1_RAT0__S1_RAT1__S1_RAT2__S1_RKS2_", "llvm::StringSwitch<char const*, char const*>& llvm::StringSwitch<char const*, char const*>::Cases<10u, 13u, 14u, 14u>(char const (&) [10u], char const (&) [13u], char const (&) [14u], char const (&) [14u], char const* const&)"},
    {"_ZN4llvm12StringSwitchIPKcS2_E5CasesILj9ELj11ELj8ELj8ELj5EEERS3_RAT__S1_RAT0__S1_RAT1__S1_RAT2__S1_RAT3__S1_RKS2_", "llvm::StringSwitch<char const*, char const*>& llvm::StringSwitch<char const*, char const*>::Cases<9u, 11u, 8u, 8u, 5u>(char const (&) [9u], char const (&) [11u], char const (&) [8u], char const (&) [8u], char const (&) [5u], char const* const&)"},
    {"_ZN4llvm12StringSwitchIPKcS2_E5CasesILj9ELj7ELj8ELj8ELj8EEERS3_RAT__S1_RAT0__S1_RAT1__S1_RAT2__S1_RAT3__S1_RKS2_", "llvm::StringSwitch<char const*, char const*>& llvm::StringSwitch<char const*, char const*>::Cases<9u, 7u, 8u, 8u, 8u>(char const (&) [9u], char const (&) [7u], char const (&) [8u], char const (&) [8u], char const (&) [8u], char const* const&)"},
    {"_ZN4llvm12StringSwitchIPKcS2_E5CasesILj6ELj10ELj10ELj10EEERS3_RAT__S1_RAT0__S1_RAT1__S1_RAT2__S1_RKS2_", "llvm::StringSwitch<char const*, char const*>& llvm::StringSwitch<char const*, char const*>::Cases<6u, 10u, 10u, 10u>(char const (&) [6u], char const (&) [10u], char const (&) [10u], char const (&) [10u], char const* const&)"},
    {"_ZN4llvm12StringSwitchIPKcS2_E5CasesILj7ELj9ELj9EEERS3_RAT__S1_RAT0__S1_RAT1__S1_RKS2_", "llvm::StringSwitch<char const*, char const*>& llvm::StringSwitch<char const*, char const*>::Cases<7u, 9u, 9u>(char const (&) [7u], char const (&) [9u], char const (&) [9u], char const* const&)"},
    {"_ZN4llvm12StringSwitchIPKcS2_E5CasesILj12ELj12ELj7EEERS3_RAT__S1_RAT0__S1_RAT1__S1_RKS2_", "llvm::StringSwitch<char const*, char const*>& llvm::StringSwitch<char const*, char const*>::Cases<12u, 12u, 7u>(char const (&) [12u], char const (&) [12u], char const (&) [7u], char const* const&)"},
    {"_ZN5clang3tok12getTokenNameENS0_9TokenKindE", "clang::tok::getTokenName(clang::tok::TokenKind)"},
    {"_ZN5clang3tok22getTokenSimpleSpellingENS0_9TokenKindE", "clang::tok::getTokenSimpleSpelling(clang::tok::TokenKind)"},
    {"_ZN5clang22getClangRepositoryPathEv", "clang::getClangRepositoryPath()"},
    {"_ZN5clang16getClangRevisionEv", "clang::getClangRevision()"},
    {"_ZN5clang29getClangFullRepositoryVersionEv", "clang::getClangFullRepositoryVersion()"},
    {"_ZN5clang19getClangFullVersionEv", "clang::getClangFullVersion()"},
    {"_ZN4llvm26initializeArgPromotionPassERNS_12PassRegistryE", "llvm::initializeArgPromotionPass(llvm::PassRegistry&)"},
    {"_ZN4llvm27createArgumentPromotionPassEj", "llvm::createArgumentPromotionPass(unsigned int)"},
    {"_ZN12_GLOBAL__N_112ArgPromotionD1Ev", "(anonymous namespace)::ArgPromotion::~ArgPromotion()"},
    {"_ZN12_GLOBAL__N_112ArgPromotionD0Ev", "(anonymous namespace)::ArgPromotion::~ArgPromotion()"},
    {"_ZNK12_GLOBAL__N_112ArgPromotion16getAnalysisUsageERN4llvm13AnalysisUsageE", "(anonymous namespace)::ArgPromotion::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_112ArgPromotion8runOnSCCERN4llvm12CallGraphSCCE", "(anonymous namespace)::ArgPromotion::runOnSCC(llvm::CallGraphSCC&)"},
    {"_ZNK12_GLOBAL__N_112ArgPromotion23isSafeToPromoteArgumentEPN4llvm8ArgumentEb", "(anonymous namespace)::ArgPromotion::isSafeToPromoteArgument(llvm::Argument*, bool) const"},
    {"_ZN12_GLOBAL__N_112ArgPromotion11DoPromotionEPN4llvm8FunctionERNS1_11SmallPtrSetIPNS1_8ArgumentELj8EEES8_", "(anonymous namespace)::ArgPromotion::DoPromotion(llvm::Function*, llvm::SmallPtrSet<llvm::Argument*, 8u>&, llvm::SmallPtrSet<llvm::Argument*, 8u>&)"},
    {"_Z15MarkIndicesSafeRKSt6vectorIySaIyEERSt3setIS1_St4lessIS1_ESaIS1_EE", "MarkIndicesSafe(std::vector<unsigned long long, std::allocator<unsigned long long>> const&, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>&)"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_112ArgPromotionEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::ArgPromotion>()"},
    {"_ZNK4llvm16CallGraphSCCPass27getPotentialPassManagerTypeEv", "llvm::CallGraphSCCPass::getPotentialPassManagerType() const"},
    {"_ZN4llvm16CallGraphSCCPass16doInitializationERNS_9CallGraphE", "llvm::CallGraphSCCPass::doInitialization(llvm::CallGraph&)"},
    {"_ZN4llvm16CallGraphSCCPass14doFinalizationERNS_9CallGraphE", "llvm::CallGraphSCCPass::doFinalization(llvm::CallGraph&)"},
    {"_ZNSt3mapIPN4llvm8ArgumentESt3setISt6vectorIySaIyEESt4lessIS6_ESaIS6_EES7_IS2_ESaISt4pairIKS2_SA_EEEixERSD_", "std::map<llvm::Argument*, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>, std::less<llvm::Argument*>, std::allocator<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>>::operator[](llvm::Argument* const&)"},
    {"_ZNSt3mapISt6vectorIySaIyEEPN4llvm8LoadInstESt4lessIS2_ESaISt4pairIKS2_S5_EEEixERS9_", "std::map<std::vector<unsigned long long, std::allocator<unsigned long long>>, llvm::LoadInst*, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>>::operator[](std::vector<unsigned long long, std::allocator<unsigned long long>> const&)"},
    {"_ZNSt8_Rb_treeIPN4llvm8ArgumentESt4pairIKS2_St3setISt6vectorIySaIyEESt4lessIS8_ESaIS8_EEESt10_Select1stISD_ES9_IS2_ESaISD_EE8_M_eraseEPSt13_Rb_tree_nodeISD_E", "std::_Rb_tree<llvm::Argument*, std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>, std::_Select1st<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>, std::less<llvm::Argument*>, std::allocator<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>>::_M_erase(std::_Rb_tree_node<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>*)"},
    {"_ZNSt8_Rb_treeISt6vectorIySaIyEES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE8_M_eraseEPSt13_Rb_tree_nodeIS2_E", "std::_Rb_tree<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::vector<unsigned long long, std::allocator<unsigned long long>>, std::_Identity<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>::_M_erase(std::_Rb_tree_node<std::vector<unsigned long long, std::allocator<unsigned long long>>>*)"},
    {"_ZNSt8_Rb_treeISt6vectorIySaIyEESt4pairIKS2_PN4llvm8LoadInstEESt10_Select1stIS8_ESt4lessIS2_ESaIS8_EE8_M_eraseEPSt13_Rb_tree_nodeIS8_E", "std::_Rb_tree<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>, std::_Select1st<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>>::_M_erase(std::_Rb_tree_node<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>*)"},
    {"_ZN4llvm17GetElementPtrInstC2IN9__gnu_cxx17__normal_iteratorIPPNS_5ValueESt6vectorIS5_SaIS5_EEEEEES5_T_SB_jRKNS_5TwineEPNS_11InstructionE", "llvm::GetElementPtrInst::GetElementPtrInst<__gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>>(llvm::Value*, __gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>, __gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>, unsigned int, llvm::Twine const&, llvm::Instruction*)"},
    {"_ZNSt8_Rb_treeISt6vectorIySaIyEESt4pairIKS2_PN4llvm8LoadInstEESt10_Select1stIS8_ESt4lessIS2_ESaIS8_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS8_ERKS8_", "std::_Rb_tree<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>, std::_Select1st<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>, std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*> const&)"},
    {"_ZNSt8_Rb_treeISt6vectorIySaIyEESt4pairIKS2_PN4llvm8LoadInstEESt10_Select1stIS8_ESt4lessIS2_ESaIS8_EE16_M_insert_uniqueERKS8_", "std::_Rb_tree<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>, std::_Select1st<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>>::_M_insert_unique(std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*> const&)"},
    {"_ZNSt8_Rb_treeISt6vectorIySaIyEESt4pairIKS2_PN4llvm8LoadInstEESt10_Select1stIS8_ESt4lessIS2_ESaIS8_EE14_M_create_nodeERKS8_", "std::_Rb_tree<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>, std::_Select1st<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*>>>::_M_create_node(std::pair<std::vector<unsigned long long, std::allocator<unsigned long long>> const, llvm::LoadInst*> const&)"},
    {"_ZNSt8_Rb_treeISt6vectorIySaIyEES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE16_M_insert_uniqueERKS2_", "std::_Rb_tree<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::vector<unsigned long long, std::allocator<unsigned long long>>, std::_Identity<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>::_M_insert_unique(std::vector<unsigned long long, std::allocator<unsigned long long>> const&)"},
    {"_ZNSt8_Rb_treeISt6vectorIySaIyEES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE14_M_create_nodeERKS2_", "std::_Rb_tree<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::vector<unsigned long long, std::allocator<unsigned long long>>, std::_Identity<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>::_M_create_node(std::vector<unsigned long long, std::allocator<unsigned long long>> const&)"},
    {"_ZNSt8_Rb_treeISt6vectorIySaIyEES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE7_M_copyEPKSt13_Rb_tree_nodeIS2_EPSA_", "std::_Rb_tree<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::vector<unsigned long long, std::allocator<unsigned long long>>, std::_Identity<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>::_M_copy(std::_Rb_tree_node<std::vector<unsigned long long, std::allocator<unsigned long long>>> const*, std::_Rb_tree_node<std::vector<unsigned long long, std::allocator<unsigned long long>>>*)"},
    {"_ZNSt8_Rb_treeIPN4llvm8ArgumentESt4pairIKS2_St3setISt6vectorIySaIyEESt4lessIS8_ESaIS8_EEESt10_Select1stISD_ES9_IS2_ESaISD_EE16_M_insert_uniqueESt17_Rb_tree_iteratorISD_ERKSD_", "std::_Rb_tree<llvm::Argument*, std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>, std::_Select1st<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>, std::less<llvm::Argument*>, std::allocator<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>, std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>> const&)"},
    {"_ZNSt8_Rb_treeIPN4llvm8ArgumentESt4pairIKS2_St3setISt6vectorIySaIyEESt4lessIS8_ESaIS8_EEESt10_Select1stISD_ES9_IS2_ESaISD_EE9_M_insertEPSt18_Rb_tree_node_baseSK_RKSD_", "std::_Rb_tree<llvm::Argument*, std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>, std::_Select1st<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>, std::less<llvm::Argument*>, std::allocator<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>> const&)"},
    {"_ZNSt8_Rb_treeIPN4llvm8ArgumentESt4pairIKS2_St3setISt6vectorIySaIyEESt4lessIS8_ESaIS8_EEESt10_Select1stISD_ES9_IS2_ESaISD_EE16_M_insert_uniqueERKSD_", "std::_Rb_tree<llvm::Argument*, std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>, std::_Select1st<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>, std::less<llvm::Argument*>, std::allocator<std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>>>>::_M_insert_unique(std::pair<llvm::Argument* const, std::set<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>> const&)"},
    {"_ZN4llvm11df_iteratorINS_7InverseIPNS_10BasicBlockEEENS_11SmallPtrSetIS3_Lj16EEELb1ENS_11GraphTraitsIS4_EEE6toNextEv", "llvm::df_iterator<llvm::Inverse<llvm::BasicBlock*>, llvm::SmallPtrSet<llvm::BasicBlock*, 16u>, true, llvm::GraphTraits<llvm::Inverse<llvm::BasicBlock*>>>::toNext()"},
    {"_ZNSt6vectorISt4pairIN4llvm14PointerIntPairIPNS1_10BasicBlockELj1EjNS1_21PointerLikeTypeTraitsIS4_EEEENS1_12PredIteratorIS3_NS1_18value_use_iteratorINS1_4UserEEEEEESaISD_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPSD_SF_EERKSD_", "std::vector<std::pair<llvm::PointerIntPair<llvm::BasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::BasicBlock*>>, llvm::PredIterator<llvm::BasicBlock, llvm::value_use_iterator<llvm::User>>>, std::allocator<std::pair<llvm::PointerIntPair<llvm::BasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::BasicBlock*>>, llvm::PredIterator<llvm::BasicBlock, llvm::value_use_iterator<llvm::User>>>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::PointerIntPair<llvm::BasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::BasicBlock*>>, llvm::PredIterator<llvm::BasicBlock, llvm::value_use_iterator<llvm::User>>>*, std::vector<std::pair<llvm::PointerIntPair<llvm::BasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::BasicBlock*>>, llvm::PredIterator<llvm::BasicBlock, llvm::value_use_iterator<llvm::User>>>, std::allocator<std::pair<llvm::PointerIntPair<llvm::BasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::BasicBlock*>>, llvm::PredIterator<llvm::BasicBlock, llvm::value_use_iterator<llvm::User>>>>>>, std::pair<llvm::PointerIntPair<llvm::BasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::BasicBlock*>>, llvm::PredIterator<llvm::BasicBlock, llvm::value_use_iterator<llvm::User>>> const&)"},
    {"_ZNSt6vectorISt4pairIN4llvm14PointerIntPairIPNS1_10BasicBlockELj1EjNS1_21PointerLikeTypeTraitsIS4_EEEENS1_12PredIteratorIS3_NS1_18value_use_iteratorINS1_4UserEEEEEESaISD_EEC2ERKSF_", "std::vector<std::pair<llvm::PointerIntPair<llvm::BasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::BasicBlock*>>, llvm::PredIterator<llvm::BasicBlock, llvm::value_use_iterator<llvm::User>>>, std::allocator<std::pair<llvm::PointerIntPair<llvm::BasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::BasicBlock*>>, llvm::PredIterator<llvm::BasicBlock, llvm::value_use_iterator<llvm::User>>>>>::vector(std::vector<std::pair<llvm::PointerIntPair<llvm::BasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::BasicBlock*>>, llvm::PredIterator<llvm::BasicBlock, llvm::value_use_iterator<llvm::User>>>, std::allocator<std::pair<llvm::PointerIntPair<llvm::BasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::BasicBlock*>>, llvm::PredIterator<llvm::BasicBlock, llvm::value_use_iterator<llvm::User>>>>> const&)"},
    {"_ZN4llvm11df_iteratorINS_7InverseIPNS_10BasicBlockEEENS_11SmallPtrSetIS3_Lj16EEELb1ENS_11GraphTraitsIS4_EEEC2ES3_RS6_", "llvm::df_iterator<llvm::Inverse<llvm::BasicBlock*>, llvm::SmallPtrSet<llvm::BasicBlock*, 16u>, true, llvm::GraphTraits<llvm::Inverse<llvm::BasicBlock*>>>::df_iterator(llvm::BasicBlock*, llvm::SmallPtrSet<llvm::BasicBlock*, 16u>&)"},
    {"_ZNSt8_Rb_treeISt6vectorIySaIyEES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE4findERKS2_", "std::_Rb_tree<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::vector<unsigned long long, std::allocator<unsigned long long>>, std::_Identity<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>::find(std::vector<unsigned long long, std::allocator<unsigned long long>> const&)"},
    {"_ZNSt8_Rb_treeISt6vectorIySaIyEES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE16_M_insert_uniqueESt23_Rb_tree_const_iteratorIS2_ERKS2_", "std::_Rb_tree<std::vector<unsigned long long, std::allocator<unsigned long long>>, std::vector<unsigned long long, std::allocator<unsigned long long>>, std::_Identity<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::less<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::allocator<std::vector<unsigned long long, std::allocator<unsigned long long>>>>::_M_insert_unique(std::_Rb_tree_const_iterator<std::vector<unsigned long long, std::allocator<unsigned long long>>>, std::vector<unsigned long long, std::allocator<unsigned long long>> const&)"},
    {"_ZN4llvm16CallGraphSCCPassD1Ev", "llvm::CallGraphSCCPass::~CallGraphSCCPass()"},
    {"_ZN4llvm16CallGraphSCCPassD0Ev", "llvm::CallGraphSCCPass::~CallGraphSCCPass()"},
    {"_ZN4llvm27initializeConstantMergePassERNS_12PassRegistryE", "llvm::initializeConstantMergePass(llvm::PassRegistry&)"},
    {"_ZN4llvm23createConstantMergePassEv", "llvm::createConstantMergePass()"},
    {"_ZN12_GLOBAL__N_113ConstantMergeD1Ev", "(anonymous namespace)::ConstantMerge::~ConstantMerge()"},
    {"_ZN12_GLOBAL__N_113ConstantMergeD0Ev", "(anonymous namespace)::ConstantMerge::~ConstantMerge()"},
    {"_ZN12_GLOBAL__N_113ConstantMerge11runOnModuleERN4llvm6ModuleE", "(anonymous namespace)::ConstantMerge::runOnModule(llvm::Module&)"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_113ConstantMergeEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::ConstantMerge>()"},
    {"_ZN4llvm8DenseMapIPNS_8ConstantEPNS_14GlobalVariableENS_12DenseMapInfoIS2_EENS5_IS4_EEE16shrink_and_clearEv", "llvm::DenseMap<llvm::Constant*, llvm::GlobalVariable*, llvm::DenseMapInfo<llvm::Constant*>, llvm::DenseMapInfo<llvm::GlobalVariable*>>::shrink_and_clear()"},
    {"_ZN4llvm8DenseMapIPNS_8ConstantEPNS_14GlobalVariableENS_12DenseMapInfoIS2_EENS5_IS4_EEE16InsertIntoBucketERKS2_RKS4_PSt4pairIS2_S4_E", "llvm::DenseMap<llvm::Constant*, llvm::GlobalVariable*, llvm::DenseMapInfo<llvm::Constant*>, llvm::DenseMapInfo<llvm::GlobalVariable*>>::InsertIntoBucket(llvm::Constant* const&, llvm::GlobalVariable* const&, std::pair<llvm::Constant*, llvm::GlobalVariable*>*)"},
    {"_ZN4llvm8DenseMapIPNS_8ConstantEPNS_14GlobalVariableENS_12DenseMapInfoIS2_EENS5_IS4_EEE4growEj", "llvm::DenseMap<llvm::Constant*, llvm::GlobalVariable*, llvm::DenseMapInfo<llvm::Constant*>, llvm::DenseMapInfo<llvm::GlobalVariable*>>::grow(unsigned int)"},
    {"_ZN4llvm17initializeDAEPassERNS_12PassRegistryE", "llvm::initializeDAEPass(llvm::PassRegistry&)"},
    {"_ZN4llvm17initializeDAHPassERNS_12PassRegistryE", "llvm::initializeDAHPass(llvm::PassRegistry&)"},
    {"_ZN4llvm28createDeadArgEliminationPassEv", "llvm::createDeadArgEliminationPass()"},
    {"_ZN4llvm24createDeadArgHackingPassEv", "llvm::createDeadArgHackingPass()"},
    {"_ZN12_GLOBAL__N_13DAHD1Ev", "(anonymous namespace)::DAH::~DAH()"},
    {"_ZN12_GLOBAL__N_13DAHD0Ev", "(anonymous namespace)::DAH::~DAH()"},
    {"_ZN12_GLOBAL__N_13DAE11runOnModuleERN4llvm6ModuleE", "(anonymous namespace)::DAE::runOnModule(llvm::Module&)"},
    {"_ZNK12_GLOBAL__N_13DAH19ShouldHackArgumentsEv", "(anonymous namespace)::DAH::ShouldHackArguments() const"},
    {"_ZNSt3setIN12_GLOBAL__N_13DAE8RetOrArgESt4lessIS2_ESaIS2_EE5eraseERKS2_", "std::set<(anonymous namespace)::DAE::RetOrArg, std::less<(anonymous namespace)::DAE::RetOrArg>, std::allocator<(anonymous namespace)::DAE::RetOrArg>>::erase((anonymous namespace)::DAE::RetOrArg const&)"},
    {"_ZNSt8_Rb_treeIN12_GLOBAL__N_13DAE8RetOrArgES2_St9_IdentityIS2_ESt4lessIS2_ESaIS2_EE8_M_eraseEPSt13_Rb_tree_nodeIS2_E", "std::_Rb_tree<(anonymous namespace)::DAE::RetOrArg, (anonymous namespace)::DAE::RetOrArg, std::_Identity<(anonymous namespace)::DAE::RetOrArg>, std::less<(anonymous namespace)::DAE::RetOrArg>, std::allocator<(anonymous namespace)::DAE::RetOrArg>>::_M_erase(std::_Rb_tree_node<(anonymous namespace)::DAE::RetOrArg>*)"},
    {"_ZN12_GLOBAL__N_13DAE8MarkLiveERKN4llvm8FunctionE", "(anonymous namespace)::DAE::MarkLive(llvm::Function const&)"},
    {"_ZN12_GLOBAL__N_13DAE9MarkValueERKNS0_8RetOrArgENS0_8LivenessERKN4llvm11SmallVectorIS1_Lj5EEE", "(anonymous namespace)::DAE::MarkValue((anonymous namespace)::DAE::RetOrArg const&, (anonymous namespace)::DAE::Liveness, llvm::SmallVector<(anonymous namespace)::DAE::RetOrArg, 5u> const&)"},
    {"_ZN12_GLOBAL__N_13DAE8MarkLiveERKNS0_8RetOrArgE", "(anonymous namespace)::DAE::MarkLive((anonymous namespace)::DAE::RetOrArg const&)"},
    {"_ZN12_GLOBAL__N_13DAE17PropagateLivenessERKNS0_8RetOrArgE", "(anonymous namespace)::DAE::PropagateLiveness((anonymous namespace)::DAE::RetOrArg const&)"},
    {"_ZNSt8_Rb_treeIN12_GLOBAL__N_13DAE8RetOrArgESt4pairIKS2_S2_ESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<(anonymous namespace)::DAE::RetOrArg, std::pair<(anonymous namespace)::DAE::RetOrArg const, (anonymous namespace)::DAE::RetOrArg>, std::_Select1st<std::pair<(anonymous namespace)::DAE::RetOrArg const, (anonymous namespace)::DAE::RetOrArg>>, std::less<(anonymous namespace)::DAE::RetOrArg>, std::allocator<std::pair<(anonymous namespace)::DAE::RetOrArg const, (anonymous namespace)::DAE::RetOrArg>>>::_M_erase(std::_Rb_tree_node<std::pair<(anonymous namespace)::DAE::RetOrArg const, (anonymous namespace)::DAE::RetOrArg>>*)"},
    {"_ZN12_GLOBAL__N_13DAE9SurveyUseEN4llvm18value_use_iteratorIKNS1_4UserEEERNS1_11SmallVectorINS0_8RetOrArgELj5EEEj", "(anonymous namespace)::DAE::SurveyUse(llvm::value_use_iterator<llvm::User const>, llvm::SmallVector<(anonymous namespace)::DAE::RetOrArg, 5u>&, unsigned int)"},
    {"_ZN12_GLOBAL__N_13DAE13MarkIfNotLiveENS0_8RetOrArgERN4llvm11SmallVectorIS1_Lj5EEE", "(anonymous namespace)::DAE::MarkIfNotLive((anonymous namespace)::DAE::RetOrArg, llvm::SmallVector<(anonymous namespace)::DAE::RetOrArg, 5u>&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseIN12_GLOBAL__N_13DAE8RetOrArgELb0EE4growEm", "llvm::SmallVectorTemplateBase<(anonymous namespace)::DAE::RetOrArg, false>::grow(unsigned long)"},
    {"_ZN4llvm11SmallVectorIN12_GLOBAL__N_13DAE8RetOrArgELj5EEC1ERKS4_", "llvm::SmallVector<(anonymous namespace)::DAE::RetOrArg, 5u>::SmallVector(llvm::SmallVector<(anonymous namespace)::DAE::RetOrArg, 5u> const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_11SmallVectorIN12_GLOBAL__N_13DAE8RetOrArgELj5EEELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::SmallVector<(anonymous namespace)::DAE::RetOrArg, 5u>, false>::grow(unsigned long)"},
    {"_ZN12_GLOBAL__N_13DAED1Ev", "(anonymous namespace)::DAE::~DAE()"},
    {"_ZN12_GLOBAL__N_13DAED0Ev", "(anonymous namespace)::DAE::~DAE()"},
    {"_ZNK12_GLOBAL__N_13DAE19ShouldHackArgumentsEv", "(anonymous namespace)::DAE::ShouldHackArguments() const"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_13DAHEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::DAH>()"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_13DAEEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::DAE>()"},
    {"_ZN4llvm8CallInstC2IN9__gnu_cxx17__normal_iteratorIPPNS_5ValueESt6vectorIS5_SaIS5_EEEEEES5_T_SB_RKNS_5TwineEPNS_11InstructionE", "llvm::CallInst::CallInst<__gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>>(llvm::Value*, __gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>, __gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>, llvm::Twine const&, llvm::Instruction*)"},
    {"_ZN4llvm10InvokeInstC2IN9__gnu_cxx17__normal_iteratorIPPNS_5ValueESt6vectorIS5_SaIS5_EEEEEES5_PNS_10BasicBlockESC_T_SD_jRKNS_5TwineEPNS_11InstructionE", "llvm::InvokeInst::InvokeInst<__gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>>(llvm::Value*, llvm::BasicBlock*, llvm::BasicBlock*, __gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>, __gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>, unsigned int, llvm::Twine const&, llvm::Instruction*)"},
    {"_ZN4llvm11SmallVectorIiLj5EEC2EjRKi", "llvm::SmallVector<int, 5u>::SmallVector(unsigned int, int const&)"},
    {"_ZNSt8_Rb_treeIPKN4llvm8FunctionES3_St9_IdentityIS3_ESt4lessIS3_ESaIS3_EE16_M_insert_uniqueERKS3_", "std::_Rb_tree<llvm::Function const*, llvm::Function const*, std::_Identity<llvm::Function const*>, std::less<llvm::Function const*>, std::allocator<llvm::Function const*>>::_M_insert_unique(llvm::Function const* const&)"},
    {"_ZNSt6vectorIPN4llvm5ValueESaIS2_EE13_M_assign_auxIPNS0_3UseEEEvT_S8_St20forward_iterator_tag", "void std::vector<llvm::Value*, std::allocator<llvm::Value*>>::_M_assign_aux<llvm::Use*>(llvm::Use*, llvm::Use*, std::forward_iterator_tag)"},
    {"_ZNSt8_Rb_treeIPKN4llvm8FunctionES3_St9_IdentityIS3_ESt4lessIS3_ESaIS3_EE8_M_eraseEPSt13_Rb_tree_nodeIS3_E", "std::_Rb_tree<llvm::Function const*, llvm::Function const*, std::_Identity<llvm::Function const*>, std::less<llvm::Function const*>, std::allocator<llvm::Function const*>>::_M_erase(std::_Rb_tree_node<llvm::Function const*>*)"},
    {"_ZN4llvm17initializeDTEPassERNS_12PassRegistryE", "llvm::initializeDTEPass(llvm::PassRegistry&)"},
    {"_ZN4llvm29createDeadTypeEliminationPassEv", "llvm::createDeadTypeEliminationPass()"},
    {"_ZN12_GLOBAL__N_13DTED1Ev", "(anonymous namespace)::DTE::~DTE()"},
    {"_ZN12_GLOBAL__N_13DTED0Ev", "(anonymous namespace)::DTE::~DTE()"},
    {"_ZNK12_GLOBAL__N_13DTE16getAnalysisUsageERN4llvm13AnalysisUsageE", "(anonymous namespace)::DTE::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_13DTE11runOnModuleERN4llvm6ModuleE", "(anonymous namespace)::DTE::runOnModule(llvm::Module&)"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_13DTEEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::DTE>()"},
    {"_ZNSt8_Rb_treeIPKN4llvm4TypeES3_St9_IdentityIS3_ESt4lessIS3_ESaIS3_EE8_M_eraseEPSt13_Rb_tree_nodeIS3_E", "std::_Rb_tree<llvm::Type const*, llvm::Type const*, std::_Identity<llvm::Type const*>, std::less<llvm::Type const*>, std::allocator<llvm::Type const*>>::_M_erase(std::_Rb_tree_node<llvm::Type const*>*)"},
    {"_ZNSt8_Rb_treeIPKN4llvm4TypeES3_St9_IdentityIS3_ESt4lessIS3_ESaIS3_EE5eraseESt17_Rb_tree_iteratorIS3_ESB_", "std::_Rb_tree<llvm::Type const*, llvm::Type const*, std::_Identity<llvm::Type const*>, std::less<llvm::Type const*>, std::allocator<llvm::Type const*>>::erase(std::_Rb_tree_iterator<llvm::Type const*>, std::_Rb_tree_iterator<llvm::Type const*>)"},
    {"_ZNSt8_Rb_treeIPKN4llvm4TypeES3_St9_IdentityIS3_ESt4lessIS3_ESaIS3_EE7_M_copyEPKSt13_Rb_tree_nodeIS3_EPSB_", "std::_Rb_tree<llvm::Type const*, llvm::Type const*, std::_Identity<llvm::Type const*>, std::less<llvm::Type const*>, std::allocator<llvm::Type const*>>::_M_copy(std::_Rb_tree_node<llvm::Type const*> const*, std::_Rb_tree_node<llvm::Type const*>*)"},
    {"_ZN4llvm27initializeFunctionAttrsPassERNS_12PassRegistryE", "llvm::initializeFunctionAttrsPass(llvm::PassRegistry&)"},
    {"_ZN4llvm23createFunctionAttrsPassEv", "llvm::createFunctionAttrsPass()"},
    {"_ZN12_GLOBAL__N_113FunctionAttrsD1Ev", "(anonymous namespace)::FunctionAttrs::~FunctionAttrs()"},
    {"_ZN12_GLOBAL__N_113FunctionAttrsD0Ev", "(anonymous namespace)::FunctionAttrs::~FunctionAttrs()"},
    {"_ZNK12_GLOBAL__N_113FunctionAttrs16getAnalysisUsageERN4llvm13AnalysisUsageE", "(anonymous namespace)::FunctionAttrs::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_113FunctionAttrs8runOnSCCERN4llvm12CallGraphSCCE", "(anonymous namespace)::FunctionAttrs::runOnSCC(llvm::CallGraphSCC&)"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_113FunctionAttrsEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::FunctionAttrs>()"},
    {"_ZN4llvm12UniqueVectorIPNS_5ValueEE6insertERKS2_", "llvm::UniqueVector<llvm::Value*>::insert(llvm::Value* const&)"},
    {"_ZNSt8_Rb_treeIPN4llvm5ValueESt4pairIKS2_jESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE8_M_eraseEPSt13_Rb_tree_nodeIS5_E", "std::_Rb_tree<llvm::Value*, std::pair<llvm::Value* const, unsigned int>, std::_Select1st<std::pair<llvm::Value* const, unsigned int>>, std::less<llvm::Value*>, std::allocator<std::pair<llvm::Value* const, unsigned int>>>::_M_erase(std::_Rb_tree_node<std::pair<llvm::Value* const, unsigned int>>*)"},
    {"_ZNSt8_Rb_treeIPN4llvm5ValueESt4pairIKS2_jESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS5_ERKS5_", "std::_Rb_tree<llvm::Value*, std::pair<llvm::Value* const, unsigned int>, std::_Select1st<std::pair<llvm::Value* const, unsigned int>>, std::less<llvm::Value*>, std::allocator<std::pair<llvm::Value* const, unsigned int>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<llvm::Value* const, unsigned int>>, std::pair<llvm::Value* const, unsigned int> const&)"},
    {"_ZNSt8_Rb_treeIPN4llvm5ValueESt4pairIKS2_jESt10_Select1stIS5_ESt4lessIS2_ESaIS5_EE16_M_insert_uniqueERKS5_", "std::_Rb_tree<llvm::Value*, std::pair<llvm::Value* const, unsigned int>, std::_Select1st<std::pair<llvm::Value* const, unsigned int>>, std::less<llvm::Value*>, std::allocator<std::pair<llvm::Value* const, unsigned int>>>::_M_insert_unique(std::pair<llvm::Value* const, unsigned int> const&)"},
    {"_ZN4llvm23initializeGlobalDCEPassERNS_12PassRegistryE", "llvm::initializeGlobalDCEPass(llvm::PassRegistry&)"},
    {"_ZN4llvm19createGlobalDCEPassEv", "llvm::createGlobalDCEPass()"},
    {"_ZN12_GLOBAL__N_19GlobalDCED1Ev", "(anonymous namespace)::GlobalDCE::~GlobalDCE()"},
    {"_ZN12_GLOBAL__N_19GlobalDCED0Ev", "(anonymous namespace)::GlobalDCE::~GlobalDCE()"},
    {"_ZN12_GLOBAL__N_19GlobalDCE11runOnModuleERN4llvm6ModuleE", "(anonymous namespace)::GlobalDCE::runOnModule(llvm::Module&)"},
    {"_ZN12_GLOBAL__N_19GlobalDCE14GlobalIsNeededEPN4llvm11GlobalValueE", "(anonymous namespace)::GlobalDCE::GlobalIsNeeded(llvm::GlobalValue*)"},
    {"_ZN12_GLOBAL__N_19GlobalDCE23MarkUsedGlobalsAsNeededEPN4llvm8ConstantE", "(anonymous namespace)::GlobalDCE::MarkUsedGlobalsAsNeeded(llvm::Constant*)"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_19GlobalDCEEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::GlobalDCE>()"},
    {"_ZNSt6vectorIPN4llvm11GlobalAliasESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::GlobalAlias*, std::allocator<llvm::GlobalAlias*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::GlobalAlias**, std::vector<llvm::GlobalAlias*, std::allocator<llvm::GlobalAlias*>>>, llvm::GlobalAlias* const&)"},
    {"_ZN4llvm23initializeGlobalOptPassERNS_12PassRegistryE", "llvm::initializeGlobalOptPass(llvm::PassRegistry&)"},
    {"_ZN4llvm25createGlobalOptimizerPassEv", "llvm::createGlobalOptimizerPass()"},
    {"_ZN12_GLOBAL__N_19GlobalOptD1Ev", "(anonymous namespace)::GlobalOpt::~GlobalOpt()"},
    {"_ZN12_GLOBAL__N_19GlobalOptD0Ev", "(anonymous namespace)::GlobalOpt::~GlobalOpt()"},
    {"_ZNK12_GLOBAL__N_19GlobalOpt16getAnalysisUsageERN4llvm13AnalysisUsageE", "(anonymous namespace)::GlobalOpt::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_19GlobalOpt11runOnModuleERN4llvm6ModuleE", "(anonymous namespace)::GlobalOpt::runOnModule(llvm::Module&)"},
    {"_Z13AnalyzeGlobalPKN4llvm5ValueERN12_GLOBAL__N_112GlobalStatusERNS_11SmallPtrSetIPKNS_7PHINodeELj16EEE", "AnalyzeGlobal(llvm::Value const*, (anonymous namespace)::GlobalStatus&, llvm::SmallPtrSet<llvm::PHINode const*, 16u>&)"},
    {"_ZN12_GLOBAL__N_19GlobalOpt21ProcessInternalGlobalEPN4llvm14GlobalVariableERNS1_14ilist_iteratorIS2_EERKNS1_11SmallPtrSetIPKNS1_7PHINodeELj16EEERKNS_12GlobalStatusE", "(anonymous namespace)::GlobalOpt::ProcessInternalGlobal(llvm::GlobalVariable*, llvm::ilist_iterator<llvm::GlobalVariable>&, llvm::SmallPtrSet<llvm::PHINode const*, 16u> const&, (anonymous namespace)::GlobalStatus const&)"},
    {"_Z26CleanupConstantGlobalUsersPN4llvm5ValueEPNS_8ConstantE", "CleanupConstantGlobalUsers(llvm::Value*, llvm::Constant*)"},
    {"_Z41ValueIsOnlyUsedLocallyOrStoredToOneGlobalPKN4llvm11InstructionEPKNS_14GlobalVariableERNS_11SmallPtrSetIPKNS_7PHINodeELj8EEE", "ValueIsOnlyUsedLocallyOrStoredToOneGlobal(llvm::Instruction const*, llvm::GlobalVariable const*, llvm::SmallPtrSet<llvm::PHINode const*, 8u>&)"},
    {"_Z29ReplaceUsesOfMallocWithGlobalPN4llvm11InstructionEPNS_14GlobalVariableE", "ReplaceUsesOfMallocWithGlobal(llvm::Instruction*, llvm::GlobalVariable*)"},
    {"_Z16GetHeapSROAValuePN4llvm5ValueEjRNS_8DenseMapIS1_St6vectorIS1_SaIS1_EENS_12DenseMapInfoIS1_EENS6_IS5_EEEERS3_ISt4pairIPNS_7PHINodeEjESaISE_EE", "GetHeapSROAValue(llvm::Value*, unsigned int, llvm::DenseMap<llvm::Value*, std::vector<llvm::Value*, std::allocator<llvm::Value*>>, llvm::DenseMapInfo<llvm::Value*>, llvm::DenseMapInfo<std::vector<llvm::Value*, std::allocator<llvm::Value*>>>>&, std::vector<std::pair<llvm::PHINode*, unsigned int>, std::allocator<std::pair<llvm::PHINode*, unsigned int>>>&)"},
    {"_Z23RewriteHeapSROALoadUserPN4llvm11InstructionERNS_8DenseMapIPNS_5ValueESt6vectorIS4_SaIS4_EENS_12DenseMapInfoIS4_EENS8_IS7_EEEERS5_ISt4pairIPNS_7PHINodeEjESaISG_EE", "RewriteHeapSROALoadUser(llvm::Instruction*, llvm::DenseMap<llvm::Value*, std::vector<llvm::Value*, std::allocator<llvm::Value*>>, llvm::DenseMapInfo<llvm::Value*>, llvm::DenseMapInfo<std::vector<llvm::Value*, std::allocator<llvm::Value*>>>>&, std::vector<std::pair<llvm::PHINode*, unsigned int>, std::allocator<std::pair<llvm::PHINode*, unsigned int>>>&)"},
    {"_Z30LoadUsesSimpleEnoughForHeapSRAPKN4llvm5ValueERNS_11SmallPtrSetIPKNS_7PHINodeELj32EEES8_", "LoadUsesSimpleEnoughForHeapSRA(llvm::Value const*, llvm::SmallPtrSet<llvm::PHINode const*, 32u>&, llvm::SmallPtrSet<llvm::PHINode const*, 32u>&)"},
    {"_Z19ConstantPropUsersOfPN4llvm5ValueE", "ConstantPropUsersOf(llvm::Value*)"},
    {"_Z28AllUsesOfValueWillTrapIfNullPKN4llvm5ValueERNS_11SmallPtrSetIPKNS_7PHINodeELj8EEE", "AllUsesOfValueWillTrapIfNull(llvm::Value const*, llvm::SmallPtrSet<llvm::PHINode const*, 8u>&)"},
    {"_Z31OptimizeAwayTrappingUsesOfValuePN4llvm5ValueEPNS_8ConstantE", "OptimizeAwayTrappingUsesOfValue(llvm::Value*, llvm::Constant*)"},
    {"_Z27getAggregateConstantElementPN4llvm8ConstantES1_", "getAggregateConstantElement(llvm::Constant*, llvm::Constant*)"},
    {"_Z20isSafeSROAElementUsePN4llvm5ValueE", "isSafeSROAElementUse(llvm::Value*)"},
    {"_Z21SafeToDestroyConstantPKN4llvm8ConstantE", "SafeToDestroyConstant(llvm::Constant const*)"},
    {"_Z16EvaluateFunctionPN4llvm8FunctionERPNS_8ConstantERKNS_15SmallVectorImplIS3_EERSt6vectorIS1_SaIS1_EERNS_8DenseMapIS3_S3_NS_12DenseMapInfoIS3_EESF_EERS9_IPNS_14GlobalVariableESaISJ_EERNS_11SmallPtrSetIS3_Lj8EEEPKNS_10DataLayoutE", "EvaluateFunction(llvm::Function*, llvm::Constant*&, llvm::SmallVectorImpl<llvm::Constant*> const&, std::vector<llvm::Function*, std::allocator<llvm::Function*>>&, llvm::DenseMap<llvm::Constant*, llvm::Constant*, llvm::DenseMapInfo<llvm::Constant*>, llvm::DenseMapInfo<llvm::Constant*>>&, std::vector<llvm::GlobalVariable*, std::allocator<llvm::GlobalVariable*>>&, llvm::SmallPtrSet<llvm::Constant*, 8u>&, llvm::DataLayout const*)"},
    {"_Z17EvaluateStoreIntoPN4llvm8ConstantES1_PNS_12ConstantExprEj", "EvaluateStoreInto(llvm::Constant*, llvm::Constant*, llvm::ConstantExpr*, unsigned int)"},
    {"_Z33isSimpleEnoughValueToCommitHelperPN4llvm8ConstantERNS_11SmallPtrSetIS1_Lj8EEE", "isSimpleEnoughValueToCommitHelper(llvm::Constant*, llvm::SmallPtrSet<llvm::Constant*, 8u>&)"},
    {"_Z9StripNestRKN4llvm11AttrListPtrE", "StripNest(llvm::AttrListPtr const&)"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_19GlobalOptEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::GlobalOpt>()"},
    {"_ZNSt6vectorIPN4llvm5ValueESaIS2_EEaSERKS4_", "std::vector<llvm::Value*, std::allocator<llvm::Value*>>::operator=(std::vector<llvm::Value*, std::allocator<llvm::Value*>> const&)"},
    {"_ZNSt6vectorISt4pairIPN4llvm7PHINodeEjESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<std::pair<llvm::PHINode*, unsigned int>, std::allocator<std::pair<llvm::PHINode*, unsigned int>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::PHINode*, unsigned int>*, std::vector<std::pair<llvm::PHINode*, unsigned int>, std::allocator<std::pair<llvm::PHINode*, unsigned int>>>>, std::pair<llvm::PHINode*, unsigned int> const&)"},
    {"_ZNSt6vectorIPN4llvm5ValueESaIS2_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS2_S4_EEmRKS2_", "std::vector<llvm::Value*, std::allocator<llvm::Value*>>::_M_fill_insert(__gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>, unsigned long, llvm::Value* const&)"},
    {"_ZN4llvm8DenseMapIPNS_5ValueESt6vectorIS2_SaIS2_EENS_12DenseMapInfoIS2_EENS6_IS5_EEE6insertERKSt4pairIS2_S5_E", "llvm::DenseMap<llvm::Value*, std::vector<llvm::Value*, std::allocator<llvm::Value*>>, llvm::DenseMapInfo<llvm::Value*>, llvm::DenseMapInfo<std::vector<llvm::Value*, std::allocator<llvm::Value*>>>>::insert(std::pair<llvm::Value*, std::vector<llvm::Value*, std::allocator<llvm::Value*>>> const&)"},
    {"_ZN4llvm8DenseMapIPNS_5ValueESt6vectorIS2_SaIS2_EENS_12DenseMapInfoIS2_EENS6_IS5_EEE16InsertIntoBucketERKS2_RKS5_PSt4pairIS2_S5_E", "llvm::DenseMap<llvm::Value*, std::vector<llvm::Value*, std::allocator<llvm::Value*>>, llvm::DenseMapInfo<llvm::Value*>, llvm::DenseMapInfo<std::vector<llvm::Value*, std::allocator<llvm::Value*>>>>::InsertIntoBucket(llvm::Value* const&, std::vector<llvm::Value*, std::allocator<llvm::Value*>> const&, std::pair<llvm::Value*, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>*)"},
    {"_ZN4llvm8DenseMapIPNS_5ValueESt6vectorIS2_SaIS2_EENS_12DenseMapInfoIS2_EENS6_IS5_EEE4growEj", "llvm::DenseMap<llvm::Value*, std::vector<llvm::Value*, std::allocator<llvm::Value*>>, llvm::DenseMapInfo<llvm::Value*>, llvm::DenseMapInfo<std::vector<llvm::Value*, std::allocator<llvm::Value*>>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPNS_5ValueESt6vectorIS2_SaIS2_EENS_12DenseMapInfoIS2_EENS6_IS5_EEE16FindAndConstructERKS2_", "llvm::DenseMap<llvm::Value*, std::vector<llvm::Value*, std::allocator<llvm::Value*>>, llvm::DenseMapInfo<llvm::Value*>, llvm::DenseMapInfo<std::vector<llvm::Value*, std::allocator<llvm::Value*>>>>::FindAndConstruct(llvm::Value* const&)"},
    {"_ZNSt6vectorIPN4llvm5ValueESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::Value*, std::allocator<llvm::Value*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::Value**, std::vector<llvm::Value*, std::allocator<llvm::Value*>>>, llvm::Value* const&)"},
    {"_ZNSt6vectorIPN4llvm14GlobalVariableESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::GlobalVariable*, std::allocator<llvm::GlobalVariable*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::GlobalVariable**, std::vector<llvm::GlobalVariable*, std::allocator<llvm::GlobalVariable*>>>, llvm::GlobalVariable* const&)"},
    {"_ZNSt6vectorIPN4llvm8ConstantESaIS2_EE14_M_fill_assignEmRKS2_", "std::vector<llvm::Constant*, std::allocator<llvm::Constant*>>::_M_fill_assign(unsigned long, llvm::Constant* const&)"},
    {"_ZN4llvm8DenseMapIPNS_8ConstantES2_NS_12DenseMapInfoIS2_EES4_E16InsertIntoBucketERKS2_S7_PSt4pairIS2_S2_E", "llvm::DenseMap<llvm::Constant*, llvm::Constant*, llvm::DenseMapInfo<llvm::Constant*>, llvm::DenseMapInfo<llvm::Constant*>>::InsertIntoBucket(llvm::Constant* const&, llvm::Constant* const&, std::pair<llvm::Constant*, llvm::Constant*>*)"},
    {"_ZN4llvm8DenseMapIPNS_8ConstantES2_NS_12DenseMapInfoIS2_EES4_E4growEj", "llvm::DenseMap<llvm::Constant*, llvm::Constant*, llvm::DenseMapInfo<llvm::Constant*>, llvm::DenseMapInfo<llvm::Constant*>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPNS_5ValueEPNS_8ConstantENS_12DenseMapInfoIS2_EENS5_IS4_EEE16InsertIntoBucketERKS2_RKS4_PSt4pairIS2_S4_E", "llvm::DenseMap<llvm::Value*, llvm::Constant*, llvm::DenseMapInfo<llvm::Value*>, llvm::DenseMapInfo<llvm::Constant*>>::InsertIntoBucket(llvm::Value* const&, llvm::Constant* const&, std::pair<llvm::Value*, llvm::Constant*>*)"},
    {"_ZN4llvm8DenseMapIPNS_5ValueEPNS_8ConstantENS_12DenseMapInfoIS2_EENS5_IS4_EEE4growEj", "llvm::DenseMap<llvm::Value*, llvm::Constant*, llvm::DenseMapInfo<llvm::Value*>, llvm::DenseMapInfo<llvm::Constant*>>::grow(unsigned int)"},
    {"_ZSt6__findIN9__gnu_cxx17__normal_iteratorIPPN4llvm8FunctionESt6vectorIS4_SaIS4_EEEES4_ET_SA_SA_RKT0_St26random_access_iterator_tag", "__gnu_cxx::__normal_iterator<llvm::Function**, std::vector<llvm::Function*, std::allocator<llvm::Function*>>> std::__find<__gnu_cxx::__normal_iterator<llvm::Function**, std::vector<llvm::Function*, std::allocator<llvm::Function*>>>, llvm::Function*>(__gnu_cxx::__normal_iterator<llvm::Function**, std::vector<llvm::Function*, std::allocator<llvm::Function*>>>, __gnu_cxx::__normal_iterator<llvm::Function**, std::vector<llvm::Function*, std::allocator<llvm::Function*>>>, llvm::Function* const&, std::random_access_iterator_tag)"},
    {"_ZNSt6vectorIPN4llvm8FunctionESaIS2_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS2_S4_EEmRKS2_", "std::vector<llvm::Function*, std::allocator<llvm::Function*>>::_M_fill_insert(__gnu_cxx::__normal_iterator<llvm::Function**, std::vector<llvm::Function*, std::allocator<llvm::Function*>>>, unsigned long, llvm::Function* const&)"},
    {"_ZN4llvm27initializeAlwaysInlinerPassERNS_12PassRegistryE", "llvm::initializeAlwaysInlinerPass(llvm::PassRegistry&)"},
    {"_ZN4llvm23createAlwaysInlinerPassEv", "llvm::createAlwaysInlinerPass()"},
    {"_ZN12_GLOBAL__N_113AlwaysInlinerD1Ev", "(anonymous namespace)::AlwaysInliner::~AlwaysInliner()"},
    {"_ZN12_GLOBAL__N_113AlwaysInlinerD0Ev", "(anonymous namespace)::AlwaysInliner::~AlwaysInliner()"},
    {"_ZN12_GLOBAL__N_113AlwaysInliner13releaseMemoryEv", "(anonymous namespace)::AlwaysInliner::releaseMemory()"},
    {"_ZN12_GLOBAL__N_113AlwaysInliner16doInitializationERN4llvm9CallGraphE", "(anonymous namespace)::AlwaysInliner::doInitialization(llvm::CallGraph&)"},
    {"_ZN12_GLOBAL__N_113AlwaysInliner14doFinalizationERN4llvm9CallGraphE", "(anonymous namespace)::AlwaysInliner::doFinalization(llvm::CallGraph&)"},
    {"_ZN12_GLOBAL__N_113AlwaysInliner13getInlineCostEN4llvm8CallSiteE", "(anonymous namespace)::AlwaysInliner::getInlineCost(llvm::CallSite)"},
    {"_ZN12_GLOBAL__N_113AlwaysInliner20getInlineFudgeFactorEN4llvm8CallSiteE", "(anonymous namespace)::AlwaysInliner::getInlineFudgeFactor(llvm::CallSite)"},
    {"_ZN12_GLOBAL__N_113AlwaysInliner19resetCachedCostInfoEPN4llvm8FunctionE", "(anonymous namespace)::AlwaysInliner::resetCachedCostInfo(llvm::Function*)"},
    {"_ZN12_GLOBAL__N_113AlwaysInliner18growCachedCostInfoEPN4llvm8FunctionES3_", "(anonymous namespace)::AlwaysInliner::growCachedCostInfo(llvm::Function*, llvm::Function*)"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_113AlwaysInlinerEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::AlwaysInliner>()"},
    {"_ZN4llvm18InlineCostAnalyzer19resetCachedCostInfoEPNS_8FunctionE", "llvm::InlineCostAnalyzer::resetCachedCostInfo(llvm::Function*)"},
    {"_ZNSt6vectorIN4llvm18InlineCostAnalyzer7ArgInfoESaIS2_EEaSERKS4_", "std::vector<llvm::InlineCostAnalyzer::ArgInfo, std::allocator<llvm::InlineCostAnalyzer::ArgInfo>>::operator=(std::vector<llvm::InlineCostAnalyzer::ArgInfo, std::allocator<llvm::InlineCostAnalyzer::ArgInfo>> const&)"},
    {"_ZN4llvm8DenseMapIPKNS_10BasicBlockEjNS_12DenseMapInfoIS3_EENS4_IjEEE8CopyFromERKS7_", "llvm::DenseMap<llvm::BasicBlock const*, unsigned int, llvm::DenseMapInfo<llvm::BasicBlock const*>, llvm::DenseMapInfo<unsigned int>>::CopyFrom(llvm::DenseMap<llvm::BasicBlock const*, unsigned int, llvm::DenseMapInfo<llvm::BasicBlock const*>, llvm::DenseMapInfo<unsigned int>> const&)"},
    {"_ZN4llvm18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS3_EENS_12DenseMapInfoIS5_EEED1Ev", "llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::~ValueMapCallbackVH()"},
    {"_ZN4llvm18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS3_EENS_12DenseMapInfoIS5_EEED0Ev", "llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::~ValueMapCallbackVH()"},
    {"_ZN4llvm18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS3_EENS_12DenseMapInfoIS5_EEE7deletedEv", "llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::deleted()"},
    {"_ZN4llvm18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS3_EENS_12DenseMapInfoIS5_EEE19allUsesReplacedWithEPNS_5ValueE", "llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::allUsesReplacedWith(llvm::Value*)"},
    {"_ZN4llvm8DenseMapINS_18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS4_EENS_12DenseMapInfoIS6_EEEES6_NS9_ISB_EESA_E4findERKSB_", "llvm::DenseMap<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::find(llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>> const&)"},
    {"_ZN4llvm8DenseMapINS_18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS4_EENS_12DenseMapInfoIS6_EEEES6_NS9_ISB_EESA_E5eraseENS_16DenseMapIteratorISB_S6_SC_SA_Lb0EEE", "llvm::DenseMap<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::erase(llvm::DenseMapIterator<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>, false>)"},
    {"_ZN4llvm8ValueMapIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS3_EENS_12DenseMapInfoIS5_EEE6insertERKSt4pairIS3_S5_E", "llvm::ValueMap<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::insert(std::pair<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo> const&)"},
    {"_ZN4llvm8DenseMapINS_18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS4_EENS_12DenseMapInfoIS6_EEEES6_NS9_ISB_EESA_E6insertERKSt4pairISB_S6_E", "llvm::DenseMap<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::insert(std::pair<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo> const&)"},
    {"_ZNSt4pairIN4llvm18ValueMapCallbackVHIPKNS0_8FunctionENS0_18InlineCostAnalyzer12FunctionInfoENS0_14ValueMapConfigIS4_EENS0_12DenseMapInfoIS6_EEEES6_EC2ERKSB_RKS6_", "std::pair<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo>::pair(llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>> const&, llvm::InlineCostAnalyzer::FunctionInfo const&)"},
    {"_ZNK4llvm8DenseMapINS_18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS4_EENS_12DenseMapInfoIS6_EEEES6_NS9_ISB_EESA_E15LookupBucketForERKSB_RPSt4pairISB_S6_E", "llvm::DenseMap<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::LookupBucketFor(llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>> const&, std::pair<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo>*&) const"},
    {"_ZN4llvm8DenseMapINS_18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS4_EENS_12DenseMapInfoIS6_EEEES6_NS9_ISB_EESA_E16InsertIntoBucketERKSB_RKS6_PSt4pairISB_S6_E", "llvm::DenseMap<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::InsertIntoBucket(llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>> const&, llvm::InlineCostAnalyzer::FunctionInfo const&, std::pair<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo>*)"},
    {"_ZN4llvm8DenseMapINS_18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS4_EENS_12DenseMapInfoIS6_EEEES6_NS9_ISB_EESA_E4growEj", "llvm::DenseMap<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::grow(unsigned int)"},
    {"_ZNSt6vectorIN4llvm18InlineCostAnalyzer7ArgInfoESaIS2_EEC2ERKS4_", "std::vector<llvm::InlineCostAnalyzer::ArgInfo, std::allocator<llvm::InlineCostAnalyzer::ArgInfo>>::vector(std::vector<llvm::InlineCostAnalyzer::ArgInfo, std::allocator<llvm::InlineCostAnalyzer::ArgInfo>> const&)"},
    {"_ZN4llvm8DenseMapINS_18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS4_EENS_12DenseMapInfoIS6_EEEES6_NS9_ISB_EESA_E5eraseERKSB_", "llvm::DenseMap<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::erase(llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>> const&)"},
    {"_ZN4llvm8DenseMapINS_18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS4_EENS_12DenseMapInfoIS6_EEEES6_NS9_ISB_EESA_E16FindAndConstructERKSB_", "llvm::DenseMap<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::FindAndConstruct(llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>> const&)"},
    {"_ZN4llvm7InlinerD1Ev", "llvm::Inliner::~Inliner()"},
    {"_ZN4llvm7InlinerD0Ev", "llvm::Inliner::~Inliner()"},
    {"_ZN4llvm8DenseMapINS_18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS4_EENS_12DenseMapInfoIS6_EEEES6_NS9_ISB_EESA_ED2Ev", "llvm::DenseMap<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::~DenseMap()"},
    {"_ZN4llvm8DenseMapINS_18ValueMapCallbackVHIPKNS_8FunctionENS_18InlineCostAnalyzer12FunctionInfoENS_14ValueMapConfigIS4_EENS_12DenseMapInfoIS6_EEEES6_NS9_ISB_EESA_E4initEj", "llvm::DenseMap<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>, llvm::InlineCostAnalyzer::FunctionInfo, llvm::DenseMapInfo<llvm::ValueMapCallbackVH<llvm::Function const*, llvm::InlineCostAnalyzer::FunctionInfo, llvm::ValueMapConfig<llvm::Function const*>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>>, llvm::DenseMapInfo<llvm::InlineCostAnalyzer::FunctionInfo>>::init(unsigned int)"},
    {"_ZN4llvm27initializeSimpleInlinerPassERNS_12PassRegistryE", "llvm::initializeSimpleInlinerPass(llvm::PassRegistry&)"},
    {"_ZN4llvm26createFunctionInliningPassEv", "llvm::createFunctionInliningPass()"},
    {"_ZN4llvm26createFunctionInliningPassEi", "llvm::createFunctionInliningPass(int)"},
    {"_ZN12_GLOBAL__N_113SimpleInlinerD1Ev", "(anonymous namespace)::SimpleInliner::~SimpleInliner()"},
    {"_ZN12_GLOBAL__N_113SimpleInlinerD0Ev", "(anonymous namespace)::SimpleInliner::~SimpleInliner()"},
    {"_ZN12_GLOBAL__N_113SimpleInliner13releaseMemoryEv", "(anonymous namespace)::SimpleInliner::releaseMemory()"},
    {"_ZN12_GLOBAL__N_113SimpleInliner16doInitializationERN4llvm9CallGraphE", "(anonymous namespace)::SimpleInliner::doInitialization(llvm::CallGraph&)"},
    {"_ZN12_GLOBAL__N_113SimpleInliner13getInlineCostEN4llvm8CallSiteE", "(anonymous namespace)::SimpleInliner::getInlineCost(llvm::CallSite)"},
    {"_ZN12_GLOBAL__N_113SimpleInliner20getInlineFudgeFactorEN4llvm8CallSiteE", "(anonymous namespace)::SimpleInliner::getInlineFudgeFactor(llvm::CallSite)"},
    {"_ZN12_GLOBAL__N_113SimpleInliner19resetCachedCostInfoEPN4llvm8FunctionE", "(anonymous namespace)::SimpleInliner::resetCachedCostInfo(llvm::Function*)"},
    {"_ZN12_GLOBAL__N_113SimpleInliner18growCachedCostInfoEPN4llvm8FunctionES3_", "(anonymous namespace)::SimpleInliner::growCachedCostInfo(llvm::Function*, llvm::Function*)"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_113SimpleInlinerEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::SimpleInliner>()"},
    {"_ZN4llvm7InlinerC1ERc", "llvm::Inliner::Inliner(char&)"},
    {"_ZN4llvm7InlinerC2ERc", "llvm::Inliner::Inliner(char&)"},
    {"_ZN4llvm7InlinerC1ERci", "llvm::Inliner::Inliner(char&, int)"},
    {"_ZN4llvm7InlinerC2ERci", "llvm::Inliner::Inliner(char&, int)"},
    {"_ZNK4llvm7Inliner16getAnalysisUsageERNS_13AnalysisUsageE", "llvm::Inliner::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZNK4llvm7Inliner18getInlineThresholdENS_8CallSiteE", "llvm::Inliner::getInlineThreshold(llvm::CallSite) const"},
    {"_ZN4llvm7Inliner12shouldInlineENS_8CallSiteE", "llvm::Inliner::shouldInline(llvm::CallSite)"},
    {"_ZN4llvm7Inliner8runOnSCCERNS_12CallGraphSCCE", "llvm::Inliner::runOnSCC(llvm::CallGraphSCC&)"},
    {"_ZN4llvm7Inliner14doFinalizationERNS_9CallGraphE", "llvm::Inliner::doFinalization(llvm::CallGraph&)"},
    {"_ZN4llvm7Inliner19removeDeadFunctionsERNS_9CallGraphEPNS_11SmallPtrSetIPKNS_8FunctionELj16EEE", "llvm::Inliner::removeDeadFunctions(llvm::CallGraph&, llvm::SmallPtrSet<llvm::Function const*, 16u>*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairINS_8CallSiteEiELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<llvm::CallSite, int>, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIPKNS_9ArrayTypeESt6vectorIPNS_10AllocaInstESaIS6_EENS_12DenseMapInfoIS3_EENS9_IS8_EEE16FindAndConstructERKS3_", "llvm::DenseMap<llvm::ArrayType const*, std::vector<llvm::AllocaInst*, std::allocator<llvm::AllocaInst*>>, llvm::DenseMapInfo<llvm::ArrayType const*>, llvm::DenseMapInfo<std::vector<llvm::AllocaInst*, std::allocator<llvm::AllocaInst*>>>>::FindAndConstruct(llvm::ArrayType const* const&)"},
    {"_ZN4llvm8DenseMapIPKNS_9ArrayTypeESt6vectorIPNS_10AllocaInstESaIS6_EENS_12DenseMapInfoIS3_EENS9_IS8_EEE16InsertIntoBucketERKS3_RKS8_PSt4pairIS3_S8_E", "llvm::DenseMap<llvm::ArrayType const*, std::vector<llvm::AllocaInst*, std::allocator<llvm::AllocaInst*>>, llvm::DenseMapInfo<llvm::ArrayType const*>, llvm::DenseMapInfo<std::vector<llvm::AllocaInst*, std::allocator<llvm::AllocaInst*>>>>::InsertIntoBucket(llvm::ArrayType const* const&, std::vector<llvm::AllocaInst*, std::allocator<llvm::AllocaInst*>> const&, std::pair<llvm::ArrayType const*, std::vector<llvm::AllocaInst*, std::allocator<llvm::AllocaInst*>>>*)"},
    {"_ZN4llvm8DenseMapIPKNS_9ArrayTypeESt6vectorIPNS_10AllocaInstESaIS6_EENS_12DenseMapInfoIS3_EENS9_IS8_EEE4growEj", "llvm::DenseMap<llvm::ArrayType const*, std::vector<llvm::AllocaInst*, std::allocator<llvm::AllocaInst*>>, llvm::DenseMapInfo<llvm::ArrayType const*>, llvm::DenseMapInfo<std::vector<llvm::AllocaInst*, std::allocator<llvm::AllocaInst*>>>>::grow(unsigned int)"},
    {"_ZN4llvm21initializePruneEHPassERNS_12PassRegistryE", "llvm::initializePruneEHPass(llvm::PassRegistry&)"},
    {"_ZN4llvm17createPruneEHPassEv", "llvm::createPruneEHPass()"},
    {"_ZN12_GLOBAL__N_17PruneEHD1Ev", "(anonymous namespace)::PruneEH::~PruneEH()"},
    {"_ZN12_GLOBAL__N_17PruneEHD0Ev", "(anonymous namespace)::PruneEH::~PruneEH()"},
    {"_ZN12_GLOBAL__N_17PruneEH8runOnSCCERN4llvm12CallGraphSCCE", "(anonymous namespace)::PruneEH::runOnSCC(llvm::CallGraphSCC&)"},
    {"_ZN12_GLOBAL__N_17PruneEH16SimplifyFunctionEPN4llvm8FunctionE", "(anonymous namespace)::PruneEH::SimplifyFunction(llvm::Function*)"},
    {"_ZN12_GLOBAL__N_17PruneEH16DeleteBasicBlockEPN4llvm10BasicBlockE", "(anonymous namespace)::PruneEH::DeleteBasicBlock(llvm::BasicBlock*)"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_17PruneEHEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::PruneEH>()"},
    {"_ZNSt6vectorIPN4llvm10BasicBlockESaIS2_EE22_M_initialize_dispatchINS0_12SuccIteratorIPNS0_14TerminatorInstES1_EEEEvT_SA_St12__false_type", "void std::vector<llvm::BasicBlock*, std::allocator<llvm::BasicBlock*>>::_M_initialize_dispatch<llvm::SuccIterator<llvm::TerminatorInst*, llvm::BasicBlock>>(llvm::SuccIterator<llvm::TerminatorInst*, llvm::BasicBlock>, llvm::SuccIterator<llvm::TerminatorInst*, llvm::BasicBlock>, std::__false_type)"},
    {"_ZN4llvm37initializeStripDeadPrototypesPassPassERNS_12PassRegistryE", "llvm::initializeStripDeadPrototypesPassPass(llvm::PassRegistry&)"},
    {"_ZN4llvm29createStripDeadPrototypesPassEv", "llvm::createStripDeadPrototypesPass()"},
    {"_ZN12_GLOBAL__N_123StripDeadPrototypesPassD1Ev", "(anonymous namespace)::StripDeadPrototypesPass::~StripDeadPrototypesPass()"},
    {"_ZN12_GLOBAL__N_123StripDeadPrototypesPassD0Ev", "(anonymous namespace)::StripDeadPrototypesPass::~StripDeadPrototypesPass()"},
    {"_ZN12_GLOBAL__N_123StripDeadPrototypesPass11runOnModuleERN4llvm6ModuleE", "(anonymous namespace)::StripDeadPrototypesPass::runOnModule(llvm::Module&)"},
    {"_ZN4llvm15callDefaultCtorIN12_GLOBAL__N_123StripDeadPrototypesPassEEEPNS_4PassEv", "llvm::Pass* llvm::callDefaultCtor<(anonymous namespace)::StripDeadPrototypesPass>()"},
    {"_ZN4llvm18WriteBitcodeToFileEPKNS_6ModuleERNS_11raw_ostreamE", "llvm::WriteBitcodeToFile(llvm::Module const*, llvm::raw_ostream&)"},
    {"_ZN4llvm20WriteBitcodeToStreamEPKNS_6ModuleERNS_15BitstreamWriterE", "llvm::WriteBitcodeToStream(llvm::Module const*, llvm::BitstreamWriter&)"},
    {"_Z11WriteModulePKN4llvm6ModuleERNS_15BitstreamWriterE", "WriteModule(llvm::Module const*, llvm::BitstreamWriter&)"},
    {"_Z13WriteFunctionRKN4llvm8FunctionERNS_15ValueEnumeratorERNS_15BitstreamWriterE", "WriteFunction(llvm::Function const&, llvm::ValueEnumerator&, llvm::BitstreamWriter&)"},
    {"_Z21WriteValueSymbolTableRKN4llvm16ValueSymbolTableERKNS_15ValueEnumeratorERNS_15BitstreamWriterE", "WriteValueSymbolTable(llvm::ValueSymbolTable const&, llvm::ValueEnumerator const&, llvm::BitstreamWriter&)"},
    {"_Z14WriteConstantsjjRKN4llvm15ValueEnumeratorERNS_15BitstreamWriterEb", "WriteConstants(unsigned int, unsigned int, llvm::ValueEnumerator const&, llvm::BitstreamWriter&, bool)"},
    {"_Z20GetOptimizationFlagsPKN4llvm5ValueE", "GetOptimizationFlags(llvm::Value const*)"},
    {"_Z11WriteMDNodePKN4llvm6MDNodeERKNS_15ValueEnumeratorERNS_15BitstreamWriterERNS_11SmallVectorIyLj64EEE", "WriteMDNode(llvm::MDNode const*, llvm::ValueEnumerator const&, llvm::BitstreamWriter&, llvm::SmallVector<unsigned long long, 64u>&)"},
    {"_Z17WriteStringRecordjRKSsjRN4llvm15BitstreamWriterE", "WriteStringRecord(unsigned int, std::string const&, unsigned int, llvm::BitstreamWriter&)"},
    {"_ZN4llvm15ValueEnumeratorD2Ev", "llvm::ValueEnumerator::~ValueEnumerator()"},
    {"_ZN4llvm15BitstreamWriter10EmitRecordIjEEvjRNS_15SmallVectorImplIT_EEj", "void llvm::BitstreamWriter::EmitRecord<unsigned int>(unsigned int, llvm::SmallVectorImpl<unsigned int>&, unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIjE6insertEPjRKj", "llvm::SmallVectorImpl<unsigned int>::insert(unsigned int*, unsigned int const&)"},
    {"_ZN4llvm15BitstreamWriter24EmitRecordWithAbbrevImplIjEEvjRNS_15SmallVectorImplIT_EENS_9StringRefE", "void llvm::BitstreamWriter::EmitRecordWithAbbrevImpl<unsigned int>(unsigned int, llvm::SmallVectorImpl<unsigned int>&, llvm::StringRef)"},
    {"_ZN4llvm15BitstreamWriter20EmitAbbreviatedFieldIjEEvRKNS_15BitCodeAbbrevOpET_", "void llvm::BitstreamWriter::EmitAbbreviatedField<unsigned int>(llvm::BitCodeAbbrevOp const&, unsigned int)"},
    {"_ZN4llvm15BitstreamWriter19EmitBlockInfoAbbrevEjPNS_13BitCodeAbbrevE", "llvm::BitstreamWriter::EmitBlockInfoAbbrev(unsigned int, llvm::BitCodeAbbrev*)"},
    {"_ZN4llvm15BitstreamWriter15SwitchToBlockIDEj", "llvm::BitstreamWriter::SwitchToBlockID(unsigned int)"},
    {"_ZN4llvm15BitstreamWriter20getOrCreateBlockInfoEj", "llvm::BitstreamWriter::getOrCreateBlockInfo(unsigned int)"},
    {"_ZNSt6vectorIN4llvm15BitstreamWriter9BlockInfoESaIS2_EE9push_backERKS2_", "std::vector<llvm::BitstreamWriter::BlockInfo, std::allocator<llvm::BitstreamWriter::BlockInfo>>::push_back(llvm::BitstreamWriter::BlockInfo const&)"},
    {"_ZNSt6vectorIN4llvm15BitstreamWriter9BlockInfoESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::BitstreamWriter::BlockInfo, std::allocator<llvm::BitstreamWriter::BlockInfo>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::BitstreamWriter::BlockInfo*, std::vector<llvm::BitstreamWriter::BlockInfo, std::allocator<llvm::BitstreamWriter::BlockInfo>>>, llvm::BitstreamWriter::BlockInfo const&)"},
    {"_ZN4llvm23createBitcodeWriterPassERNS_11raw_ostreamE", "llvm::createBitcodeWriterPass(llvm::raw_ostream&)"},
    {"_ZN12_GLOBAL__N_116WriteBitcodePassD1Ev", "(anonymous namespace)::WriteBitcodePass::~WriteBitcodePass()"},
    {"_ZN12_GLOBAL__N_116WriteBitcodePassD0Ev", "(anonymous namespace)::WriteBitcodePass::~WriteBitcodePass()"},
    {"_ZNK12_GLOBAL__N_116WriteBitcodePass11getPassNameEv", "(anonymous namespace)::WriteBitcodePass::getPassName() const"},
    {"_ZN12_GLOBAL__N_116WriteBitcodePass11runOnModuleERN4llvm6ModuleE", "(anonymous namespace)::WriteBitcodePass::runOnModule(llvm::Module&)"},
    {"_ZN4llvm15ValueEnumeratorC1EPKNS_6ModuleE", "llvm::ValueEnumerator::ValueEnumerator(llvm::Module const*)"},
    {"_ZN4llvm15ValueEnumeratorC2EPKNS_6ModuleE", "llvm::ValueEnumerator::ValueEnumerator(llvm::Module const*)"},
    {"_ZN4llvm15ValueEnumerator14EnumerateValueEPKNS_5ValueE", "llvm::ValueEnumerator::EnumerateValue(llvm::Value const*)"},
    {"_ZN4llvm15ValueEnumerator19EnumerateAttributesERKNS_11AttrListPtrE", "llvm::ValueEnumerator::EnumerateAttributes(llvm::AttrListPtr const&)"},
    {"_ZN4llvm15ValueEnumerator24EnumerateTypeSymbolTableERKNS_15TypeSymbolTableE", "llvm::ValueEnumerator::EnumerateTypeSymbolTable(llvm::TypeSymbolTable const&)"},
    {"_ZN4llvm15ValueEnumerator25EnumerateValueSymbolTableERKNS_16ValueSymbolTableE", "llvm::ValueEnumerator::EnumerateValueSymbolTable(llvm::ValueSymbolTable const&)"},
    {"_ZN4llvm15ValueEnumerator22EnumerateNamedMetadataEPKNS_6ModuleE", "llvm::ValueEnumerator::EnumerateNamedMetadata(llvm::Module const*)"},
    {"_ZN4llvm15ValueEnumerator13EnumerateTypeEPKNS_4TypeE", "llvm::ValueEnumerator::EnumerateType(llvm::Type const*)"},
    {"_ZN4llvm15ValueEnumerator20EnumerateOperandTypeEPKNS_5ValueE", "llvm::ValueEnumerator::EnumerateOperandType(llvm::Value const*)"},
    {"_ZN4llvm15ValueEnumerator17EnumerateMetadataEPKNS_5ValueE", "llvm::ValueEnumerator::EnumerateMetadata(llvm::Value const*)"},
    {"_ZN4llvm15ValueEnumerator17OptimizeConstantsEjj", "llvm::ValueEnumerator::OptimizeConstants(unsigned int, unsigned int)"},
    {"_Z18CompareByFrequencyRKSt4pairIPKN4llvm4TypeEjES6_", "CompareByFrequency(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&)"},
    {"_ZNK4llvm15ValueEnumerator16getInstructionIDEPKNS_11InstructionE", "llvm::ValueEnumerator::getInstructionID(llvm::Instruction const*) const"},
    {"_ZN4llvm15ValueEnumerator16setInstructionIDEPKNS_11InstructionE", "llvm::ValueEnumerator::setInstructionID(llvm::Instruction const*)"},
    {"_ZNK4llvm15ValueEnumerator10getValueIDEPKNS_5ValueE", "llvm::ValueEnumerator::getValueID(llvm::Value const*) const"},
    {"_ZN4llvm15ValueEnumerator20EnumerateNamedMDNodeEPKNS_11NamedMDNodeE", "llvm::ValueEnumerator::EnumerateNamedMDNode(llvm::NamedMDNode const*)"},
    {"_ZN4llvm15ValueEnumerator23EnumerateMDNodeOperandsEPKNS_6MDNodeE", "llvm::ValueEnumerator::EnumerateMDNodeOperands(llvm::MDNode const*)"},
    {"_ZN4llvm15ValueEnumerator30EnumerateFunctionLocalMetadataEPKNS_6MDNodeE", "llvm::ValueEnumerator::EnumerateFunctionLocalMetadata(llvm::MDNode const*)"},
    {"_ZN4llvm15ValueEnumerator19incorporateFunctionERKNS_8FunctionE", "llvm::ValueEnumerator::incorporateFunction(llvm::Function const&)"},
    {"_ZN4llvm15ValueEnumerator13purgeFunctionEv", "llvm::ValueEnumerator::purgeFunction()"},
    {"_ZNK4llvm15ValueEnumerator21getGlobalBasicBlockIDEPKNS_10BasicBlockE", "llvm::ValueEnumerator::getGlobalBasicBlockID(llvm::BasicBlock const*) const"},
    {"_ZSt21__inplace_stable_sortIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm5ValueEjESt6vectorIS7_SaIS7_EEEEN12_GLOBAL__N_116CstSortPredicateEEvT_SF_T0_", "void std::__inplace_stable_sort<__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, (anonymous namespace)::CstSortPredicate>(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, (anonymous namespace)::CstSortPredicate)"},
    {"_ZSt22__stable_sort_adaptiveIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm5ValueEjESt6vectorIS7_SaIS7_EEEES8_lN12_GLOBAL__N_116CstSortPredicateEEvT_SF_T0_T1_T2_", "void std::__stable_sort_adaptive<__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, std::pair<llvm::Value const*, unsigned int>*, long, (anonymous namespace)::CstSortPredicate>(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, std::pair<llvm::Value const*, unsigned int>*, long, (anonymous namespace)::CstSortPredicate)"},
    {"_ZSt24__merge_sort_with_bufferIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm5ValueEjESt6vectorIS7_SaIS7_EEEES8_N12_GLOBAL__N_116CstSortPredicateEEvT_SF_T0_T1_", "void std::__merge_sort_with_buffer<__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, std::pair<llvm::Value const*, unsigned int>*, (anonymous namespace)::CstSortPredicate>(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, std::pair<llvm::Value const*, unsigned int>*, (anonymous namespace)::CstSortPredicate)"},
    {"_ZSt16__merge_adaptiveIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm5ValueEjESt6vectorIS7_SaIS7_EEEElS8_N12_GLOBAL__N_116CstSortPredicateEEvT_SF_SF_T0_SG_T1_SG_T2_", "void std::__merge_adaptive<__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, long, std::pair<llvm::Value const*, unsigned int>*, (anonymous namespace)::CstSortPredicate>(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, long, long, std::pair<llvm::Value const*, unsigned int>*, long, (anonymous namespace)::CstSortPredicate)"},
    {"_ZN12_GLOBAL__N_116CstSortPredicateclERKSt4pairIPKN4llvm5ValueEjES8_", "(anonymous namespace)::CstSortPredicate::operator()(std::pair<llvm::Value const*, unsigned int> const&, std::pair<llvm::Value const*, unsigned int> const&)"},
    {"_ZSt5mergeIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm5ValueEjESt6vectorIS7_SaIS7_EEEESC_S8_N12_GLOBAL__N_116CstSortPredicateEET1_T_SG_T0_SH_SF_T2_", "std::pair<llvm::Value const*, unsigned int>* std::merge<__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, std::pair<llvm::Value const*, unsigned int>*, (anonymous namespace)::CstSortPredicate>(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, std::pair<llvm::Value const*, unsigned int>*, (anonymous namespace)::CstSortPredicate)"},
    {"_ZSt16__insertion_sortIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm5ValueEjESt6vectorIS7_SaIS7_EEEEN12_GLOBAL__N_116CstSortPredicateEEvT_SF_T0_", "void std::__insertion_sort<__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, (anonymous namespace)::CstSortPredicate>(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, (anonymous namespace)::CstSortPredicate)"},
    {"_ZSt22__merge_without_bufferIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm5ValueEjESt6vectorIS7_SaIS7_EEEElN12_GLOBAL__N_116CstSortPredicateEEvT_SF_SF_T0_SG_T1_", "void std::__merge_without_buffer<__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, long, (anonymous namespace)::CstSortPredicate>(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, long, long, (anonymous namespace)::CstSortPredicate)"},
    {"_ZNSt6vectorISt4pairIPKN4llvm5ValueEjESaIS5_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS5_S7_EEmRKS5_", "std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>::_M_fill_insert(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, unsigned long, std::pair<llvm::Value const*, unsigned int> const&)"},
    {"_ZNSt6vectorISt4pairIPKN4llvm4TypeEjESaIS5_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS5_S7_EERKS5_", "std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::pair<llvm::Type const*, unsigned int> const&)"},
    {"_ZNSt6vectorISt4pairIPKN4llvm5ValueEjESaIS5_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS5_S7_EERKS5_", "std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, std::pair<llvm::Value const*, unsigned int> const&)"},
    {"_ZSt17__rotate_adaptiveIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm5ValueEjESt6vectorIS7_SaIS7_EEEES8_lET_SD_SD_SD_T1_SE_T0_SE_", "__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>> std::__rotate_adaptive<__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, std::pair<llvm::Value const*, unsigned int>*, long>(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, long, long, std::pair<llvm::Value const*, unsigned int>*, long)"},
    {"_ZSt8__rotateIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm5ValueEjESt6vectorIS7_SaIS7_EEEEEvT_SD_SD_St26random_access_iterator_tag", "void std::__rotate<__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>>(__gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Value const*, unsigned int>*, std::vector<std::pair<llvm::Value const*, unsigned int>, std::allocator<std::pair<llvm::Value const*, unsigned int>>>>, std::random_access_iterator_tag)"},
    {"_ZN4llvm8DenseMapIPKNS_4TypeEjNS_12DenseMapInfoIS3_EENS4_IjEEE16InsertIntoBucketERKS3_RKjPSt4pairIS3_jE", "llvm::DenseMap<llvm::Type const*, unsigned int, llvm::DenseMapInfo<llvm::Type const*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(llvm::Type const* const&, unsigned int const&, std::pair<llvm::Type const*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPKNS_4TypeEjNS_12DenseMapInfoIS3_EENS4_IjEEE4growEj", "llvm::DenseMap<llvm::Type const*, unsigned int, llvm::DenseMapInfo<llvm::Type const*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZSt21__inplace_stable_sortIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm4TypeEjESt6vectorIS7_SaIS7_EEEEPFbRKS7_SE_EEvT_SH_T0_", "void std::__inplace_stable_sort<__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&)>(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&))"},
    {"_ZSt22__stable_sort_adaptiveIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm4TypeEjESt6vectorIS7_SaIS7_EEEES8_lPFbRKS7_SE_EEvT_SH_T0_T1_T2_", "void std::__stable_sort_adaptive<__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::pair<llvm::Type const*, unsigned int>*, long, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&)>(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::pair<llvm::Type const*, unsigned int>*, long, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&))"},
    {"_ZSt24__merge_sort_with_bufferIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm4TypeEjESt6vectorIS7_SaIS7_EEEES8_PFbRKS7_SE_EEvT_SH_T0_T1_", "void std::__merge_sort_with_buffer<__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::pair<llvm::Type const*, unsigned int>*, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&)>(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::pair<llvm::Type const*, unsigned int>*, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&))"},
    {"_ZSt16__merge_adaptiveIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm4TypeEjESt6vectorIS7_SaIS7_EEEElS8_PFbRKS7_SE_EEvT_SH_SH_T0_SI_T1_SI_T2_", "void std::__merge_adaptive<__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, long, std::pair<llvm::Type const*, unsigned int>*, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&)>(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, long, long, std::pair<llvm::Type const*, unsigned int>*, long, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&))"},
    {"_ZSt16__merge_backwardIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm4TypeEjESt6vectorIS7_SaIS7_EEEES8_SC_PFbRKS7_SE_EET1_T_SI_T0_SJ_SH_T2_", "__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>> std::__merge_backward<__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::pair<llvm::Type const*, unsigned int>*, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&)>(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::pair<llvm::Type const*, unsigned int>*, std::pair<llvm::Type const*, unsigned int>*, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&))"},
    {"_ZSt17__rotate_adaptiveIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm4TypeEjESt6vectorIS7_SaIS7_EEEES8_lET_SD_SD_SD_T1_SE_T0_SE_", "__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>> std::__rotate_adaptive<__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::pair<llvm::Type const*, unsigned int>*, long>(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, long, long, std::pair<llvm::Type const*, unsigned int>*, long)"},
    {"_ZSt8__rotateIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm4TypeEjESt6vectorIS7_SaIS7_EEEEEvT_SD_SD_St26random_access_iterator_tag", "void std::__rotate<__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>>(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::random_access_iterator_tag)"},
    {"_ZSt17__merge_sort_loopIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm4TypeEjESt6vectorIS7_SaIS7_EEEES8_lPFbRKS7_SE_EEvT_SH_T0_T1_T2_", "void std::__merge_sort_loop<__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::pair<llvm::Type const*, unsigned int>*, long, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&)>(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, std::pair<llvm::Type const*, unsigned int>*, long, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&))"},
    {"_ZSt17__merge_sort_loopIPSt4pairIPKN4llvm4TypeEjEN9__gnu_cxx17__normal_iteratorIS6_St6vectorIS5_SaIS5_EEEElPFbRKS5_SE_EEvT_SH_T0_T1_T2_", "void std::__merge_sort_loop<std::pair<llvm::Type const*, unsigned int>*, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, long, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&)>(std::pair<llvm::Type const*, unsigned int>*, std::pair<llvm::Type const*, unsigned int>*, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, long, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&))"},
    {"_ZSt16__insertion_sortIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm4TypeEjESt6vectorIS7_SaIS7_EEEEPFbRKS7_SE_EEvT_SH_T0_", "void std::__insertion_sort<__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&)>(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&))"},
    {"_ZSt22__merge_without_bufferIN9__gnu_cxx17__normal_iteratorIPSt4pairIPKN4llvm4TypeEjESt6vectorIS7_SaIS7_EEEElPFbRKS7_SE_EEvT_SH_SH_T0_SI_T1_", "void std::__merge_without_buffer<__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, long, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&)>(__gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Type const*, unsigned int>*, std::vector<std::pair<llvm::Type const*, unsigned int>, std::allocator<std::pair<llvm::Type const*, unsigned int>>>>, long, long, bool (*)(std::pair<llvm::Type const*, unsigned int> const&, std::pair<llvm::Type const*, unsigned int> const&))"},
    {"_ZN4llvm13BitcodeReader9FreeStateEv", "llvm::BitcodeReader::FreeState()"},
    {"_ZN4llvm22BitcodeReaderValueList11AssignValueEPNS_5ValueEj", "llvm::BitcodeReaderValueList::AssignValue(llvm::Value*, unsigned int)"},
    {"_ZN4llvm22BitcodeReaderValueList17getConstantFwdRefEjPKNS_4TypeE", "llvm::BitcodeReaderValueList::getConstantFwdRef(unsigned int, llvm::Type const*)"},
    {"_ZN4llvm22BitcodeReaderValueList14getValueFwdRefEjPKNS_4TypeE", "llvm::BitcodeReaderValueList::getValueFwdRef(unsigned int, llvm::Type const*)"},
    {"_ZN4llvm22BitcodeReaderValueList26ResolveConstantForwardRefsEv", "llvm::BitcodeReaderValueList::ResolveConstantForwardRefs()"},
    {"_ZN4llvm24BitcodeReaderMDValueList11AssignValueEPNS_5ValueEj", "llvm::BitcodeReaderMDValueList::AssignValue(llvm::Value*, unsigned int)"},
    {"_ZN4llvm24BitcodeReaderMDValueList14getValueFwdRefEj", "llvm::BitcodeReaderMDValueList::getValueFwdRef(unsigned int)"},
    {"_ZN4llvm13BitcodeReader11getTypeByIDEjb", "llvm::BitcodeReader::getTypeByID(unsigned int, bool)"},
    {"_ZN4llvm13BitcodeReader19ParseAttributeBlockEv", "llvm::BitcodeReader::ParseAttributeBlock()"},
    {"_ZN4llvm13BitcodeReader14ParseTypeTableEv", "llvm::BitcodeReader::ParseTypeTable()"},
    {"_ZN4llvm13BitcodeReader20ParseTypeSymbolTableEv", "llvm::BitcodeReader::ParseTypeSymbolTable()"},
    {"_ZN4llvm13BitcodeReader21ParseValueSymbolTableEv", "llvm::BitcodeReader::ParseValueSymbolTable()"},
    {"_ZN4llvm13BitcodeReader13ParseMetadataEv", "llvm::BitcodeReader::ParseMetadata()"},
    {"_ZN4llvm13BitcodeReader26ResolveGlobalAndAliasInitsEv", "llvm::BitcodeReader::ResolveGlobalAndAliasInits()"},
    {"_ZN4llvm13BitcodeReader14ParseConstantsEv", "llvm::BitcodeReader::ParseConstants()"},
    {"_Z22GetDecodedBinaryOpcodejPKN4llvm4TypeE", "GetDecodedBinaryOpcode(unsigned int, llvm::Type const*)"},
    {"_ZN4llvm13BitcodeReader27RememberAndSkipFunctionBodyEv", "llvm::BitcodeReader::RememberAndSkipFunctionBody()"},
    {"_ZN4llvm13BitcodeReader11ParseModuleEv", "llvm::BitcodeReader::ParseModule()"},
    {"_ZN4llvm13BitcodeReader16ParseBitcodeIntoEPNS_6ModuleE", "llvm::BitcodeReader::ParseBitcodeInto(llvm::Module*)"},
    {"_ZN4llvm13BitcodeReader17ParseModuleTripleERSs", "llvm::BitcodeReader::ParseModuleTriple(std::string&)"},
    {"_ZN4llvm13BitcodeReader11ParseTripleERSs", "llvm::BitcodeReader::ParseTriple(std::string&)"},
    {"_ZN4llvm13BitcodeReader23ParseMetadataAttachmentEv", "llvm::BitcodeReader::ParseMetadataAttachment()"},
    {"_ZN4llvm13BitcodeReader17ParseFunctionBodyEPNS_8FunctionE", "llvm::BitcodeReader::ParseFunctionBody(llvm::Function*)"},
    {"_ZNK4llvm13BitcodeReader16isMaterializableEPKNS_11GlobalValueE", "llvm::BitcodeReader::isMaterializable(llvm::GlobalValue const*) const"},
    {"_ZN4llvm13BitcodeReader11MaterializeEPNS_11GlobalValueEPSs", "llvm::BitcodeReader::Materialize(llvm::GlobalValue*, std::string*)"},
    {"_ZNK4llvm13BitcodeReader18isDematerializableEPKNS_11GlobalValueE", "llvm::BitcodeReader::isDematerializable(llvm::GlobalValue const*) const"},
    {"_ZN4llvm13BitcodeReader13DematerializeEPNS_11GlobalValueE", "llvm::BitcodeReader::Dematerialize(llvm::GlobalValue*)"},
    {"_ZN4llvm13BitcodeReader17MaterializeModuleEPNS_6ModuleEPSs", "llvm::BitcodeReader::MaterializeModule(llvm::Module*, std::string*)"},
    {"_ZN4llvm20getLazyBitcodeModuleEPNS_12MemoryBufferERNS_11LLVMContextEPSs", "llvm::getLazyBitcodeModule(llvm::MemoryBuffer*, llvm::LLVMContext&, std::string*)"},
    {"_ZN4llvm16ParseBitcodeFileEPNS_12MemoryBufferERNS_11LLVMContextEPSs", "llvm::ParseBitcodeFile(llvm::MemoryBuffer*, llvm::LLVMContext&, std::string*)"},
    {"_ZN4llvm22getBitcodeTargetTripleEPNS_12MemoryBufferERNS_11LLVMContextEPSs", "llvm::getBitcodeTargetTriple(llvm::MemoryBuffer*, llvm::LLVMContext&, std::string*)"},
    {"_ZN4llvm12_GLOBAL__N_119ConstantPlaceHolderD1Ev", "llvm::(anonymous namespace)::ConstantPlaceHolder::~ConstantPlaceHolder()"},
    {"_ZN4llvm12_GLOBAL__N_119ConstantPlaceHolderD0Ev", "llvm::(anonymous namespace)::ConstantPlaceHolder::~ConstantPlaceHolder()"},
    {"_ZN4llvm22BitcodeReaderValueList9push_backEPNS_5ValueE", "llvm::BitcodeReaderValueList::push_back(llvm::Value*)"},
    {"_ZN4llvm22BitcodeReaderValueList6resizeEj", "llvm::BitcodeReaderValueList::resize(unsigned int)"},
    {"_ZN4llvm24BitcodeReaderMDValueList9push_backEPNS_5ValueE", "llvm::BitcodeReaderMDValueList::push_back(llvm::Value*)"},
    {"_ZN4llvm24BitcodeReaderMDValueList6resizeEj", "llvm::BitcodeReaderMDValueList::resize(unsigned int)"},
    {"_ZNSt6vectorIN4llvm12PATypeHolderESaIS1_EE7reserveEm", "std::vector<llvm::PATypeHolder, std::allocator<llvm::PATypeHolder>>::reserve(unsigned long)"},
    {"_ZN4llvm15SmallVectorImplIyE6resizeEj", "llvm::SmallVectorImpl<unsigned long long>::resize(unsigned int)"},
    {"_ZN4llvm22BitcodeReaderValueList8shrinkToEj", "llvm::BitcodeReaderValueList::shrinkTo(unsigned int)"},
    {"_ZN4llvm13BitcodeReader16getValueTypePairERNS_11SmallVectorIyLj64EEERjjRPNS_5ValueE", "llvm::BitcodeReader::getValueTypePair(llvm::SmallVector<unsigned long long, 64u>&, unsigned int&, unsigned int, llvm::Value*&)"},
    {"_ZN4llvm24BitcodeReaderMDValueList8shrinkToEj", "llvm::BitcodeReaderMDValueList::shrinkTo(unsigned int)"},
    {"_ZN4llvm13BitcodeReaderD1Ev", "llvm::BitcodeReader::~BitcodeReader()"},
    {"_ZN4llvm13BitcodeReaderD0Ev", "llvm::BitcodeReader::~BitcodeReader()"},
    {"_ZN4llvm10InvokeInstC2IPPNS_5ValueEEES3_PNS_10BasicBlockES6_T_S7_jRKNS_5TwineEPNS_11InstructionE", "llvm::InvokeInst::InvokeInst<llvm::Value**>(llvm::Value*, llvm::BasicBlock*, llvm::BasicBlock*, llvm::Value**, llvm::Value**, unsigned int, llvm::Twine const&, llvm::Instruction*)"},
    {"_ZN4llvm15InsertValueInstC2IPjEEPNS_5ValueES4_T_S5_RKNS_5TwineEPNS_11InstructionE", "llvm::InsertValueInst::InsertValueInst<unsigned int*>(llvm::Value*, llvm::Value*, unsigned int*, unsigned int*, llvm::Twine const&, llvm::Instruction*)"},
    {"_ZNSt6vectorIPN4llvm10BasicBlockESaIS2_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS2_S4_EEmRKS2_", "std::vector<llvm::BasicBlock*, std::allocator<llvm::BasicBlock*>>::_M_fill_insert(__gnu_cxx::__normal_iterator<llvm::BasicBlock**, std::vector<llvm::BasicBlock*, std::allocator<llvm::BasicBlock*>>>, unsigned long, llvm::BasicBlock* const&)"},
    {"_ZNSt6vectorIPN4llvm8FunctionESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::Function*, std::allocator<llvm::Function*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::Function**, std::vector<llvm::Function*, std::allocator<llvm::Function*>>>, llvm::Function* const&)"},
    {"_ZNSt6vectorISt4pairIPN4llvm8FunctionES3_ESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<std::pair<llvm::Function*, llvm::Function*>, std::allocator<std::pair<llvm::Function*, llvm::Function*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::Function*, llvm::Function*>*, std::vector<std::pair<llvm::Function*, llvm::Function*>, std::allocator<std::pair<llvm::Function*, llvm::Function*>>>>, std::pair<llvm::Function*, llvm::Function*> const&)"},
    {"_ZN4llvm8DenseMapIPNS_8FunctionEyNS_12DenseMapInfoIS2_EENS3_IyEEE16InsertIntoBucketERKS2_RKyPSt4pairIS2_yE", "llvm::DenseMap<llvm::Function*, unsigned long long, llvm::DenseMapInfo<llvm::Function*>, llvm::DenseMapInfo<unsigned long long>>::InsertIntoBucket(llvm::Function* const&, unsigned long long const&, std::pair<llvm::Function*, unsigned long long>*)"},
    {"_ZN4llvm8DenseMapIPNS_8FunctionEyNS_12DenseMapInfoIS2_EENS3_IyEEE4growEj", "llvm::DenseMap<llvm::Function*, unsigned long long, llvm::DenseMapInfo<llvm::Function*>, llvm::DenseMapInfo<unsigned long long>>::grow(unsigned int)"},
    {"_ZNSt6vectorISt4pairIjPN4llvm14GlobalVariableEESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<unsigned int, llvm::GlobalVariable*>*, std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>>>, std::pair<unsigned int, llvm::GlobalVariable*> const&)"},
    {"_ZN4llvm8DenseMapIPNS_8FunctionESt6vectorISt4pairIjPNS_14GlobalVariableEESaIS7_EENS_12DenseMapInfoIS2_EENSA_IS9_EEE16FindAndConstructERKS2_", "llvm::DenseMap<llvm::Function*, std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>>, llvm::DenseMapInfo<llvm::Function*>, llvm::DenseMapInfo<std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>>>>::FindAndConstruct(llvm::Function* const&)"},
    {"_ZN4llvm8DenseMapIPNS_8FunctionESt6vectorISt4pairIjPNS_14GlobalVariableEESaIS7_EENS_12DenseMapInfoIS2_EENSA_IS9_EEE16InsertIntoBucketERKS2_RKS9_PS4_IS2_S9_E", "llvm::DenseMap<llvm::Function*, std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>>, llvm::DenseMapInfo<llvm::Function*>, llvm::DenseMapInfo<std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>>>>::InsertIntoBucket(llvm::Function* const&, std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>> const&, std::pair<llvm::Function*, std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>>>*)"},
    {"_ZN4llvm8DenseMapIPNS_8FunctionESt6vectorISt4pairIjPNS_14GlobalVariableEESaIS7_EENS_12DenseMapInfoIS2_EENSA_IS9_EEE4growEj", "llvm::DenseMap<llvm::Function*, std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>>, llvm::DenseMapInfo<llvm::Function*>, llvm::DenseMapInfo<std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>>>>::grow(unsigned int)"},
    {"_ZNSt6vectorISt4pairIjPN4llvm14GlobalVariableEESaIS4_EEC2ERKS6_", "std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>>::vector(std::vector<std::pair<unsigned int, llvm::GlobalVariable*>, std::allocator<std::pair<unsigned int, llvm::GlobalVariable*>>> const&)"},
    {"_ZNSt6vectorISt4pairIPN4llvm11GlobalAliasEjESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<std::pair<llvm::GlobalAlias*, unsigned int>, std::allocator<std::pair<llvm::GlobalAlias*, unsigned int>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::GlobalAlias*, unsigned int>*, std::vector<std::pair<llvm::GlobalAlias*, unsigned int>, std::allocator<std::pair<llvm::GlobalAlias*, unsigned int>>>>, std::pair<llvm::GlobalAlias*, unsigned int> const&)"},
    {"_ZNSt6vectorISt4pairIPN4llvm14GlobalVariableEjESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<std::pair<llvm::GlobalVariable*, unsigned int>, std::allocator<std::pair<llvm::GlobalVariable*, unsigned int>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::GlobalVariable*, unsigned int>*, std::vector<std::pair<llvm::GlobalVariable*, unsigned int>, std::allocator<std::pair<llvm::GlobalVariable*, unsigned int>>>>, std::pair<llvm::GlobalVariable*, unsigned int> const&)"},
    {"_ZNSt6vectorIN4llvm11AttrListPtrESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<llvm::AttrListPtr, std::allocator<llvm::AttrListPtr>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::AttrListPtr*, std::vector<llvm::AttrListPtr, std::allocator<llvm::AttrListPtr>>>, llvm::AttrListPtr const&)"},
    {"_ZNSt6vectorIN4llvm12PATypeHolderESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<llvm::PATypeHolder, std::allocator<llvm::PATypeHolder>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::PATypeHolder*, std::vector<llvm::PATypeHolder, std::allocator<llvm::PATypeHolder>>>, llvm::PATypeHolder const&)"},
    {"_ZSt16__introsort_loopIN9__gnu_cxx17__normal_iteratorIPSt4pairIPN4llvm8ConstantEjESt6vectorIS6_SaIS6_EEEElEvT_SC_T0_", "void std::__introsort_loop<__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>, long>(__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>, long)"},
    {"_ZSt22__final_insertion_sortIN9__gnu_cxx17__normal_iteratorIPSt4pairIPN4llvm8ConstantEjESt6vectorIS6_SaIS6_EEEEEvT_SC_", "void std::__final_insertion_sort<__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>>(__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>)"},
    {"_ZSt16__insertion_sortIN9__gnu_cxx17__normal_iteratorIPSt4pairIPN4llvm8ConstantEjESt6vectorIS6_SaIS6_EEEEEvT_SC_", "void std::__insertion_sort<__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>>(__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>)"},
    {"_ZSt13__heap_selectIN9__gnu_cxx17__normal_iteratorIPSt4pairIPN4llvm8ConstantEjESt6vectorIS6_SaIS6_EEEEEvT_SC_SC_", "void std::__heap_select<__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>>(__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>)"},
    {"_ZSt13__adjust_heapIN9__gnu_cxx17__normal_iteratorIPSt4pairIPN4llvm8ConstantEjESt6vectorIS6_SaIS6_EEEElS6_EvT_T0_SD_T1_", "void std::__adjust_heap<__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>, long, std::pair<llvm::Constant*, unsigned int>>(__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>, long, long, std::pair<llvm::Constant*, unsigned int>)"},
    {"_ZNSt6vectorISt4pairIPN4llvm8ConstantEjESaIS4_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS4_S6_EERKS4_", "std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::Constant*, unsigned int>*, std::vector<std::pair<llvm::Constant*, unsigned int>, std::allocator<std::pair<llvm::Constant*, unsigned int>>>>, std::pair<llvm::Constant*, unsigned int> const&)"},
    {"_ZN4llvm8DenseMapIjjNS_12DenseMapInfoIjEES2_E16shrink_and_clearEv", "llvm::DenseMap<unsigned int, unsigned int, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<unsigned int>>::shrink_and_clear()"},
    {"_ZN4llvm8DenseMapIPNS_8FunctionEyNS_12DenseMapInfoIS2_EENS3_IyEEE16shrink_and_clearEv", "llvm::DenseMap<llvm::Function*, unsigned long long, llvm::DenseMapInfo<llvm::Function*>, llvm::DenseMapInfo<unsigned long long>>::shrink_and_clear()"},
    {"_ZN4llvm13BitcodeReaderD2Ev", "llvm::BitcodeReader::~BitcodeReader()"},
    {"_ZN4llvm13BitcodeReaderC2EPNS_12MemoryBufferERNS_11LLVMContextE", "llvm::BitcodeReader::BitcodeReader(llvm::MemoryBuffer*, llvm::LLVMContext&)"},
    {"_ZN4llvm14GVMaterializer13DematerializeEPNS_11GlobalValueE", "llvm::GVMaterializer::Dematerialize(llvm::GlobalValue*)"},
    {"_ZNSt6vectorIN4llvm6WeakVHESaIS1_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS1_S3_EEmRKS1_", "std::vector<llvm::WeakVH, std::allocator<llvm::WeakVH>>::_M_fill_insert(__gnu_cxx::__normal_iterator<llvm::WeakVH*, std::vector<llvm::WeakVH, std::allocator<llvm::WeakVH>>>, unsigned long, llvm::WeakVH const&)"},
    {"_ZNSt15__copy_backwardILb0ESt26random_access_iterator_tagE8__copy_bIPN4llvm6WeakVHES5_EET0_T_S7_S6_", "llvm::WeakVH* std::__copy_backward<false, std::random_access_iterator_tag>::__copy_b<llvm::WeakVH*, llvm::WeakVH*>(llvm::WeakVH*, llvm::WeakVH*, llvm::WeakVH*)"},
    {"_ZNSt6vectorIN4llvm6WeakVHESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<llvm::WeakVH, std::allocator<llvm::WeakVH>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::WeakVH*, std::vector<llvm::WeakVH, std::allocator<llvm::WeakVH>>>, llvm::WeakVH const&)"},
    {"_ZNK4llvm7LLLexer5ErrorENS_5SMLocERKNS_5TwineE", "llvm::LLLexer::Error(llvm::SMLoc, llvm::Twine const&) const"},
    {"_ZN4llvm7LLLexer6atoullEPKcS2_", "llvm::LLLexer::atoull(char const*, char const*)"},
    {"_ZN4llvm7LLLexer11HexIntToValEPKcS2_", "llvm::LLLexer::HexIntToVal(char const*, char const*)"},
    {"_ZN4llvm7LLLexer12HexToIntPairEPKcS2_Py", "llvm::LLLexer::HexToIntPair(char const*, char const*, unsigned long long*)"},
    {"_ZN4llvm7LLLexer16FP80HexToIntPairEPKcS2_Py", "llvm::LLLexer::FP80HexToIntPair(char const*, char const*, unsigned long long*)"},
    {"_ZN4llvm7LLLexerC1EPNS_12MemoryBufferERNS_9SourceMgrERNS_12SMDiagnosticERNS_11LLVMContextE", "llvm::LLLexer::LLLexer(llvm::MemoryBuffer*, llvm::SourceMgr&, llvm::SMDiagnostic&, llvm::LLVMContext&)"},
    {"_ZN4llvm7LLLexerC2EPNS_12MemoryBufferERNS_9SourceMgrERNS_12SMDiagnosticERNS_11LLVMContextE", "llvm::LLLexer::LLLexer(llvm::MemoryBuffer*, llvm::SourceMgr&, llvm::SMDiagnostic&, llvm::LLVMContext&)"},
    {"_ZNK4llvm7LLLexer11getFilenameEv", "llvm::LLLexer::getFilename() const"},
    {"_ZN4llvm7LLLexer11getNextCharEv", "llvm::LLLexer::getNextChar()"},
    {"_ZN4llvm7LLLexer8LexTokenEv", "llvm::LLLexer::LexToken()"},
    {"_ZN4llvm7LLLexer13LexIdentifierEv", "llvm::LLLexer::LexIdentifier()"},
    {"_ZN4llvm7LLLexer11LexPositiveEv", "llvm::LLLexer::LexPositive()"},
    {"_ZN4llvm7LLLexer5LexAtEv", "llvm::LLLexer::LexAt()"},
    {"_ZN4llvm7LLLexer10LexPercentEv", "llvm::LLLexer::LexPercent()"},
    {"_ZN4llvm7LLLexer8LexQuoteEv", "llvm::LLLexer::LexQuote()"},
    {"_ZN4llvm7LLLexer15SkipLineCommentEv", "llvm::LLLexer::SkipLineComment()"},
    {"_ZN4llvm7LLLexer10LexExclaimEv", "llvm::LLLexer::LexExclaim()"},
    {"_ZN4llvm7LLLexer18LexDigitOrNegativeEv", "llvm::LLLexer::LexDigitOrNegative()"},
    {"_Z13UnEscapeLexedRSs", "UnEscapeLexed(std::string&)"},
    {"_ZN4llvm7LLLexer5Lex0xEv", "llvm::LLLexer::Lex0x()"},
    {"_ZN4llvm8LLParser3RunEv", "llvm::LLParser::Run()"},
    {"_ZN4llvm8LLParser21ParseTopLevelEntitiesEv", "llvm::LLParser::ParseTopLevelEntities()"},
    {"_ZN4llvm8LLParser19ValidateEndOfModuleEv", "llvm::LLParser::ValidateEndOfModule()"},
    {"_ZN4llvm8LLParser31ResolveForwardRefBlockAddressesEPNS_8FunctionERSt6vectorISt4pairINS_5ValIDEPNS_11GlobalValueEESaIS8_EEPNS0_16PerFunctionStateE", "llvm::LLParser::ResolveForwardRefBlockAddresses(llvm::Function*, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>&, llvm::LLParser::PerFunctionState*)"},
    {"_ZN4llvm8LLParser16PerFunctionState5GetBBERKSsNS_5SMLocE", "llvm::LLParser::PerFunctionState::GetBB(std::string const&, llvm::SMLoc)"},
    {"_ZN4llvm8LLParser16PerFunctionState5GetBBEjNS_5SMLocE", "llvm::LLParser::PerFunctionState::GetBB(unsigned int, llvm::SMLoc)"},
    {"_ZN4llvm8LLParser12ParseDeclareEv", "llvm::LLParser::ParseDeclare()"},
    {"_ZN4llvm8LLParser11ParseDefineEv", "llvm::LLParser::ParseDefine()"},
    {"_ZN4llvm8LLParser14ParseModuleAsmEv", "llvm::LLParser::ParseModuleAsm()"},
    {"_ZN4llvm8LLParser21ParseTargetDefinitionEv", "llvm::LLParser::ParseTargetDefinition()"},
    {"_ZN4llvm8LLParser12ParseDepLibsEv", "llvm::LLParser::ParseDepLibs()"},
    {"_ZN4llvm8LLParser16ParseUnnamedTypeEv", "llvm::LLParser::ParseUnnamedType()"},
    {"_ZN4llvm8LLParser14ParseNamedTypeEv", "llvm::LLParser::ParseNamedType()"},
    {"_ZN4llvm8LLParser18ParseUnnamedGlobalEv", "llvm::LLParser::ParseUnnamedGlobal()"},
    {"_ZN4llvm8LLParser16ParseNamedGlobalEv", "llvm::LLParser::ParseNamedGlobal()"},
    {"_ZN4llvm8LLParser23ParseStandaloneMetadataEv", "llvm::LLParser::ParseStandaloneMetadata()"},
    {"_ZN4llvm8LLParser18ParseNamedMetadataEv", "llvm::LLParser::ParseNamedMetadata()"},
    {"_ZN4llvm8LLParser23ParseOptionalVisibilityERj", "llvm::LLParser::ParseOptionalVisibility(unsigned int&)"},
    {"_ZN4llvm8LLParser11ParseGlobalERKSsNS_5SMLocEjbj", "llvm::LLParser::ParseGlobal(std::string const&, llvm::SMLoc, unsigned int, bool, unsigned int)"},
    {"_ZN4llvm8LLParser10ParseTokenENS_5lltok4KindEPKc", "llvm::LLParser::ParseToken(llvm::lltok::Kind, char const*)"},
    {"_ZN4llvm8LLParser19ParseStringConstantERSs", "llvm::LLParser::ParseStringConstant(std::string&)"},
    {"_ZN4llvm8LLParser9ParseTypeERNS_12PATypeHolderEb", "llvm::LLParser::ParseType(llvm::PATypeHolder&, bool)"},
    {"_ZN4llvm8LLParser19ParseFunctionHeaderERPNS_8FunctionEb", "llvm::LLParser::ParseFunctionHeader(llvm::Function*&, bool)"},
    {"_ZN4llvm8LLParser17ParseFunctionBodyERNS_8FunctionE", "llvm::LLParser::ParseFunctionBody(llvm::Function&)"},
    {"_ZN4llvm8LLParser15ParseGlobalTypeERb", "llvm::LLParser::ParseGlobalType(bool&)"},
    {"_ZN4llvm8LLParser20ParseOptionalLinkageERjRb", "llvm::LLParser::ParseOptionalLinkage(unsigned int&, bool&)"},
    {"_ZN4llvm8LLParser10ParseAliasERKSsNS_5SMLocEj", "llvm::LLParser::ParseAlias(std::string const&, llvm::SMLoc, unsigned int)"},
    {"_ZN4llvm8LLParser13ParseMDStringERPNS_8MDStringE", "llvm::LLParser::ParseMDString(llvm::MDString*&)"},
    {"_ZN4llvm8LLParser13ParseMDNodeIDERPNS_6MDNodeERj", "llvm::LLParser::ParseMDNodeID(llvm::MDNode*&, unsigned int&)"},
    {"_ZN4llvm8LLParser11ParseUInt32ERj", "llvm::LLParser::ParseUInt32(unsigned int&)"},
    {"_ZN4llvm8LLParser13ParseMDNodeIDERPNS_6MDNodeE", "llvm::LLParser::ParseMDNodeID(llvm::MDNode*&)"},
    {"_ZN4llvm8LLParser17ParseMDNodeVectorERNS_15SmallVectorImplIPNS_5ValueEEEPNS0_16PerFunctionStateE", "llvm::LLParser::ParseMDNodeVector(llvm::SmallVectorImpl<llvm::Value*>&, llvm::LLParser::PerFunctionState*)"},
    {"_ZN4llvm8LLParser23ParseGlobalTypeAndValueERPNS_8ConstantE", "llvm::LLParser::ParseGlobalTypeAndValue(llvm::Constant*&)"},
    {"_ZN4llvm8LLParser10ParseValIDERNS_5ValIDEPNS0_16PerFunctionStateE", "llvm::LLParser::ParseValID(llvm::ValID&, llvm::LLParser::PerFunctionState*)"},
    {"_ZN4llvm8LLParser22ParseOptionalAddrSpaceERj", "llvm::LLParser::ParseOptionalAddrSpace(unsigned int&)"},
    {"_ZN4llvm8LLParser16ParseGlobalValueEPKNS_4TypeERPNS_8ConstantE", "llvm::LLParser::ParseGlobalValue(llvm::Type const*, llvm::Constant*&)"},
    {"_ZN4llvm8LLParser22ParseOptionalAlignmentERj", "llvm::LLParser::ParseOptionalAlignment(unsigned int&)"},
    {"_ZN4llvm8LLParser12GetGlobalValERKSsPKNS_4TypeENS_5SMLocE", "llvm::LLParser::GetGlobalVal(std::string const&, llvm::Type const*, llvm::SMLoc)"},
    {"_ZN4llvm8LLParser12GetGlobalValEjPKNS_4TypeENS_5SMLocE", "llvm::LLParser::GetGlobalVal(unsigned int, llvm::Type const*, llvm::SMLoc)"},
    {"_ZN4llvm8LLParser18ParseOptionalAttrsERjj", "llvm::LLParser::ParseOptionalAttrs(unsigned int&, unsigned int)"},
    {"_ZN4llvm8LLParser27ParseOptionalStackAlignmentERj", "llvm::LLParser::ParseOptionalStackAlignment(unsigned int&)"},
    {"_ZN4llvm8LLParser24ParseOptionalCallingConvERNS_11CallingConv2IDE", "llvm::LLParser::ParseOptionalCallingConv(llvm::CallingConv::ID&)"},
    {"_ZN4llvm8LLParser24ParseInstructionMetadataEPNS_11InstructionEPNS0_16PerFunctionStateE", "llvm::LLParser::ParseInstructionMetadata(llvm::Instruction*, llvm::LLParser::PerFunctionState*)"},
    {"_ZN4llvm8LLParser22ParseMetadataListValueERNS_5ValIDEPNS0_16PerFunctionStateE", "llvm::LLParser::ParseMetadataListValue(llvm::ValID&, llvm::LLParser::PerFunctionState*)"},
    {"_ZN4llvm8LLParser23ParseOptionalCommaAlignERjRb", "llvm::LLParser::ParseOptionalCommaAlign(unsigned int&, bool&)"},
    {"_ZN4llvm8LLParser14ParseIndexListERNS_15SmallVectorImplIjEERb", "llvm::LLParser::ParseIndexList(llvm::SmallVectorImpl<unsigned int>&, bool&)"},
    {"_ZN4llvm8LLParser12ParseTypeRecERNS_12PATypeHolderE", "llvm::LLParser::ParseTypeRec(llvm::PATypeHolder&)"},
    {"_ZN4llvm8LLParser12HandleUpRefsEPKNS_4TypeE", "llvm::LLParser::HandleUpRefs(llvm::Type const*)"},
    {"_ZN4llvm8LLParser15ParseStructTypeERNS_12PATypeHolderEb", "llvm::LLParser::ParseStructType(llvm::PATypeHolder&, bool)"},
    {"_ZN4llvm8LLParser20ParseArrayVectorTypeERNS_12PATypeHolderEb", "llvm::LLParser::ParseArrayVectorType(llvm::PATypeHolder&, bool)"},
    {"_ZN4llvm8LLParser17ParseFunctionTypeERNS_12PATypeHolderE", "llvm::LLParser::ParseFunctionType(llvm::PATypeHolder&)"},
    {"_ZN4llvm8LLParser18ParseParameterListERNS_15SmallVectorImplINS0_9ParamInfoEEERNS0_16PerFunctionStateE", "llvm::LLParser::ParseParameterList(llvm::SmallVectorImpl<llvm::LLParser::ParamInfo>&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser10ParseValueEPKNS_4TypeERPNS_5ValueERNS0_16PerFunctionStateE", "llvm::LLParser::ParseValue(llvm::Type const*, llvm::Value*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser17ParseArgumentListERSt6vectorINS0_7ArgInfoESaIS2_EERbb", "llvm::LLParser::ParseArgumentList(std::vector<llvm::LLParser::ArgInfo, std::allocator<llvm::LLParser::ArgInfo>>&, bool&, bool)"},
    {"_ZN4llvm8LLParser16PerFunctionStateC1ERS0_RNS_8FunctionEi", "llvm::LLParser::PerFunctionState::PerFunctionState(llvm::LLParser&, llvm::Function&, int)"},
    {"_ZN4llvm8LLParser16PerFunctionStateC2ERS0_RNS_8FunctionEi", "llvm::LLParser::PerFunctionState::PerFunctionState(llvm::LLParser&, llvm::Function&, int)"},
    {"_ZN4llvm8LLParser16PerFunctionStateD1Ev", "llvm::LLParser::PerFunctionState::~PerFunctionState()"},
    {"_ZN4llvm8LLParser16PerFunctionStateD2Ev", "llvm::LLParser::PerFunctionState::~PerFunctionState()"},
    {"_ZN4llvm8LLParser16PerFunctionState14FinishFunctionEv", "llvm::LLParser::PerFunctionState::FinishFunction()"},
    {"_ZN4llvm8LLParser16PerFunctionState6GetValERKSsPKNS_4TypeENS_5SMLocE", "llvm::LLParser::PerFunctionState::GetVal(std::string const&, llvm::Type const*, llvm::SMLoc)"},
    {"_ZN4llvm8LLParser16PerFunctionState6GetValEjPKNS_4TypeENS_5SMLocE", "llvm::LLParser::PerFunctionState::GetVal(unsigned int, llvm::Type const*, llvm::SMLoc)"},
    {"_ZN4llvm8LLParser16PerFunctionState11SetInstNameEiRKSsNS_5SMLocEPNS_11InstructionE", "llvm::LLParser::PerFunctionState::SetInstName(int, std::string const&, llvm::SMLoc, llvm::Instruction*)"},
    {"_ZN4llvm8LLParser16PerFunctionState8DefineBBERKSsNS_5SMLocE", "llvm::LLParser::PerFunctionState::DefineBB(std::string const&, llvm::SMLoc)"},
    {"_ZN4llvm8LLParser18ParseMetadataValueERNS_5ValIDEPNS0_16PerFunctionStateE", "llvm::LLParser::ParseMetadataValue(llvm::ValID&, llvm::LLParser::PerFunctionState*)"},
    {"_ZN4llvm8LLParser22ParseGlobalValueVectorERNS_15SmallVectorImplIPNS_8ConstantEEE", "llvm::LLParser::ParseGlobalValueVector(llvm::SmallVectorImpl<llvm::Constant*>&)"},
    {"_ZN4llvm8LLParser17ParseCmpPredicateERjj", "llvm::LLParser::ParseCmpPredicate(unsigned int&, unsigned int)"},
    {"_ZN4llvm8LLParser19ConvertValIDToValueEPKNS_4TypeERNS_5ValIDERPNS_5ValueEPNS0_16PerFunctionStateE", "llvm::LLParser::ConvertValIDToValue(llvm::Type const*, llvm::ValID&, llvm::Value*&, llvm::LLParser::PerFunctionState*)"},
    {"_ZN4llvm8LLParser17ParseTypeAndValueERPNS_5ValueERNS0_16PerFunctionStateE", "llvm::LLParser::ParseTypeAndValue(llvm::Value*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser22ParseTypeAndBasicBlockERPNS_10BasicBlockERNS_5SMLocERNS0_16PerFunctionStateE", "llvm::LLParser::ParseTypeAndBasicBlock(llvm::BasicBlock*&, llvm::SMLoc&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser15ParseBasicBlockERNS0_16PerFunctionStateE", "llvm::LLParser::ParseBasicBlock(llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser16ParseInstructionERPNS_11InstructionEPNS_10BasicBlockERNS0_16PerFunctionStateE", "llvm::LLParser::ParseInstruction(llvm::Instruction*&, llvm::BasicBlock*, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser8ParseRetERPNS_11InstructionEPNS_10BasicBlockERNS0_16PerFunctionStateE", "llvm::LLParser::ParseRet(llvm::Instruction*&, llvm::BasicBlock*, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser7ParseBrERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseBr(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser11ParseSwitchERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseSwitch(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser15ParseIndirectBrERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseIndirectBr(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser11ParseInvokeERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseInvoke(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser15ParseArithmeticERPNS_11InstructionERNS0_16PerFunctionStateEjj", "llvm::LLParser::ParseArithmetic(llvm::Instruction*&, llvm::LLParser::PerFunctionState&, unsigned int, unsigned int)"},
    {"_ZN4llvm8LLParser12ParseLogicalERPNS_11InstructionERNS0_16PerFunctionStateEj", "llvm::LLParser::ParseLogical(llvm::Instruction*&, llvm::LLParser::PerFunctionState&, unsigned int)"},
    {"_ZN4llvm8LLParser12ParseCompareERPNS_11InstructionERNS0_16PerFunctionStateEj", "llvm::LLParser::ParseCompare(llvm::Instruction*&, llvm::LLParser::PerFunctionState&, unsigned int)"},
    {"_ZN4llvm8LLParser9ParseCastERPNS_11InstructionERNS0_16PerFunctionStateEj", "llvm::LLParser::ParseCast(llvm::Instruction*&, llvm::LLParser::PerFunctionState&, unsigned int)"},
    {"_ZN4llvm8LLParser11ParseSelectERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseSelect(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser11ParseVA_ArgERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseVA_Arg(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser19ParseExtractElementERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseExtractElement(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser18ParseInsertElementERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseInsertElement(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser18ParseShuffleVectorERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseShuffleVector(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser8ParsePHIERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParsePHI(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser9ParseCallERPNS_11InstructionERNS0_16PerFunctionStateEb", "llvm::LLParser::ParseCall(llvm::Instruction*&, llvm::LLParser::PerFunctionState&, bool)"},
    {"_ZN4llvm8LLParser10ParseAllocERPNS_11InstructionERNS0_16PerFunctionStateEPNS_10BasicBlockEb", "llvm::LLParser::ParseAlloc(llvm::Instruction*&, llvm::LLParser::PerFunctionState&, llvm::BasicBlock*, bool)"},
    {"_ZN4llvm8LLParser9ParseFreeERPNS_11InstructionERNS0_16PerFunctionStateEPNS_10BasicBlockE", "llvm::LLParser::ParseFree(llvm::Instruction*&, llvm::LLParser::PerFunctionState&, llvm::BasicBlock*)"},
    {"_ZN4llvm8LLParser9ParseLoadERPNS_11InstructionERNS0_16PerFunctionStateEb", "llvm::LLParser::ParseLoad(llvm::Instruction*&, llvm::LLParser::PerFunctionState&, bool)"},
    {"_ZN4llvm8LLParser10ParseStoreERPNS_11InstructionERNS0_16PerFunctionStateEb", "llvm::LLParser::ParseStore(llvm::Instruction*&, llvm::LLParser::PerFunctionState&, bool)"},
    {"_ZN4llvm8LLParser14ParseGetResultERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseGetResult(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser18ParseGetElementPtrERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseGetElementPtr(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser17ParseExtractValueERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseExtractValue(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8LLParser16ParseInsertValueERPNS_11InstructionERNS0_16PerFunctionStateE", "llvm::LLParser::ParseInsertValue(llvm::Instruction*&, llvm::LLParser::PerFunctionState&)"},
    {"_ZN4llvm8DenseMapIPNS_11InstructionESt6vectorINS_8LLParser5MDRefESaIS5_EENS_12DenseMapInfoIS2_EENS8_IS7_EEE5clearEv", "llvm::DenseMap<llvm::Instruction*, std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>, llvm::DenseMapInfo<llvm::Instruction*>, llvm::DenseMapInfo<std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>>>::clear()"},
    {"_ZNSt3mapIjSt4pairIN4llvm10TrackingVHINS1_6MDNodeEEENS1_5SMLocEESt4lessIjESaIS0_IKjS6_EEEixERS9_", "std::map<unsigned int, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>>::operator[](unsigned int const&)"},
    {"_ZNSt3mapISsSt4pairIPN4llvm11GlobalValueENS1_5SMLocEESt4lessISsESaIS0_IKSsS5_EEEixERS8_", "std::map<std::string, std::pair<llvm::GlobalValue*, llvm::SMLoc>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::operator[](std::string const&)"},
    {"_ZNSt3mapISsSt4pairIPN4llvm5ValueENS1_5SMLocEESt4lessISsESaIS0_IKSsS5_EEEixERS8_", "std::map<std::string, std::pair<llvm::Value*, llvm::SMLoc>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>>::operator[](std::string const&)"},
    {"_ZNSt3mapIN4llvm5ValIDESt6vectorISt4pairIS1_PNS0_11GlobalValueEESaIS6_EESt4lessIS1_ESaIS3_IKS1_S8_EEEixERSB_", "std::map<llvm::ValID, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>, std::less<llvm::ValID>, std::allocator<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>>::operator[](llvm::ValID const&)"},
    {"_ZNSt4pairIN4llvm5ValIDEPNS0_11GlobalValueEEC2IS1_PNS0_14GlobalVariableEEERKS_IT_T0_E", "std::pair<llvm::ValID, llvm::GlobalValue*>::pair<llvm::ValID, llvm::GlobalVariable*>(std::pair<llvm::ValID, llvm::GlobalVariable*> const&)"},
    {"_ZNSt4pairIN4llvm5ValIDEPNS0_14GlobalVariableEEC2ERKS1_RKS3_", "std::pair<llvm::ValID, llvm::GlobalVariable*>::pair(llvm::ValID const&, llvm::GlobalVariable* const&)"},
    {"_ZN9__gnu_cxx13new_allocatorISt4pairIN4llvm5ValIDEPNS2_11GlobalValueEEE9constructEPS6_RKS6_", "__gnu_cxx::new_allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>::construct(std::pair<llvm::ValID, llvm::GlobalValue*>*, std::pair<llvm::ValID, llvm::GlobalValue*> const&)"},
    {"_ZNSt6vectorISt4pairIN4llvm5ValIDEPNS1_11GlobalValueEESaIS5_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS5_S7_EERKS5_", "std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::ValID, llvm::GlobalValue*>*, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>, std::pair<llvm::ValID, llvm::GlobalValue*> const&)"},
    {"_ZNSt4pairIN4llvm5ValIDEPNS0_11GlobalValueEEaSERKS4_", "std::pair<llvm::ValID, llvm::GlobalValue*>::operator=(std::pair<llvm::ValID, llvm::GlobalValue*> const&)"},
    {"_ZSt24__uninitialized_copy_auxIPSt4pairIN4llvm5ValIDEPNS1_11GlobalValueEES6_ET0_T_S8_S7_St12__false_type", "std::pair<llvm::ValID, llvm::GlobalValue*>* std::__uninitialized_copy_aux<std::pair<llvm::ValID, llvm::GlobalValue*>*, std::pair<llvm::ValID, llvm::GlobalValue*>*>(std::pair<llvm::ValID, llvm::GlobalValue*>*, std::pair<llvm::ValID, llvm::GlobalValue*>*, std::pair<llvm::ValID, llvm::GlobalValue*>*, std::__false_type)"},
    {"_ZNSt4pairIKN4llvm5ValIDESt6vectorIS_IS1_PNS0_11GlobalValueEESaIS6_EEEC2ERS2_RKS8_", "std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>::pair(llvm::ValID const&, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>> const&)"},
    {"_ZSt24__uninitialized_copy_auxIN9__gnu_cxx17__normal_iteratorIPKSt4pairIN4llvm5ValIDEPNS3_11GlobalValueEESt6vectorIS7_SaIS7_EEEEPS7_ET0_T_SG_SF_St12__false_type", "std::pair<llvm::ValID, llvm::GlobalValue*>* std::__uninitialized_copy_aux<__gnu_cxx::__normal_iterator<std::pair<llvm::ValID, llvm::GlobalValue*> const*, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>, std::pair<llvm::ValID, llvm::GlobalValue*>*>(__gnu_cxx::__normal_iterator<std::pair<llvm::ValID, llvm::GlobalValue*> const*, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>, __gnu_cxx::__normal_iterator<std::pair<llvm::ValID, llvm::GlobalValue*> const*, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>, std::pair<llvm::ValID, llvm::GlobalValue*>*, std::__false_type)"},
    {"_ZNSt8_Rb_treeIN4llvm5ValIDESt4pairIKS1_St6vectorIS2_IS1_PNS0_11GlobalValueEESaIS7_EEESt10_Select1stISA_ESt4lessIS1_ESaISA_EE16_M_insert_uniqueESt17_Rb_tree_iteratorISA_ERKSA_", "std::_Rb_tree<llvm::ValID, std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>, std::_Select1st<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>, std::less<llvm::ValID>, std::allocator<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>, std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>> const&)"},
    {"_ZNSt8_Rb_treeIN4llvm5ValIDESt4pairIKS1_St6vectorIS2_IS1_PNS0_11GlobalValueEESaIS7_EEESt10_Select1stISA_ESt4lessIS1_ESaISA_EE9_M_insertEPSt18_Rb_tree_node_baseSI_RKSA_", "std::_Rb_tree<llvm::ValID, std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>, std::_Select1st<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>, std::less<llvm::ValID>, std::allocator<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>> const&)"},
    {"_ZNSt8_Rb_treeIN4llvm5ValIDESt4pairIKS1_St6vectorIS2_IS1_PNS0_11GlobalValueEESaIS7_EEESt10_Select1stISA_ESt4lessIS1_ESaISA_EE16_M_insert_uniqueERKSA_", "std::_Rb_tree<llvm::ValID, std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>, std::_Select1st<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>, std::less<llvm::ValID>, std::allocator<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>>::_M_insert_unique(std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>> const&)"},
    {"_ZNSt4pairIKN4llvm5ValIDESt6vectorIS_IS1_PNS0_11GlobalValueEESaIS6_EEEC2ERKS9_", "std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>::pair(std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE11equal_rangeERS1_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>>::equal_range(std::string const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE5eraseESt17_Rb_tree_iteratorIS7_ESF_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>>::erase(std::_Rb_tree_iterator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::_Rb_tree_iterator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE8_M_eraseEPSt13_Rb_tree_nodeIS7_E", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>>::_M_erase(std::_Rb_tree_node<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>*)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessIjESaIS7_EE5eraseESt17_Rb_tree_iteratorIS7_ESF_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>>::erase(std::_Rb_tree_iterator<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::_Rb_tree_iterator<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessIjESaIS7_EE8_M_eraseEPSt13_Rb_tree_nodeIS7_E", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>>::_M_erase(std::_Rb_tree_node<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>*)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessIjESaIS7_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS7_ERKS7_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessIjESaIS7_EE16_M_insert_uniqueERKS7_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>>>>::_M_insert_unique(std::pair<unsigned int const, std::pair<llvm::Value*, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS7_ERKS7_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE9_M_insertEPSt18_Rb_tree_node_baseSF_RKS7_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE16_M_insert_uniqueERKS7_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>>::_M_insert_unique(std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm5ValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE4findERS1_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::Value*, llvm::SMLoc>>>>::find(std::string const&)"},
    {"_ZNSt8_Rb_treeIN4llvm5ValIDESt4pairIKS1_St6vectorIS2_IS1_PNS0_11GlobalValueEESaIS7_EEESt10_Select1stISA_ESt4lessIS1_ESaISA_EE4findERS3_", "std::_Rb_tree<llvm::ValID, std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>, std::_Select1st<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>, std::less<llvm::ValID>, std::allocator<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>>::find(llvm::ValID const&)"},
    {"_ZNSt6vectorIN4llvm8LLParser7ArgInfoESaIS2_EED2Ev", "std::vector<llvm::LLParser::ArgInfo, std::allocator<llvm::LLParser::ArgInfo>>::~vector()"},
    {"_ZNSt6vectorIN4llvm8LLParser7ArgInfoESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::LLParser::ArgInfo, std::allocator<llvm::LLParser::ArgInfo>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::LLParser::ArgInfo*, std::vector<llvm::LLParser::ArgInfo, std::allocator<llvm::LLParser::ArgInfo>>>, llvm::LLParser::ArgInfo const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_8LLParser9ParamInfoELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::LLParser::ParamInfo, false>::grow(unsigned long)"},
    {"_ZNSt6vectorIN4llvm8LLParser11UpRefRecordESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::LLParser::UpRefRecord, std::allocator<llvm::LLParser::UpRefRecord>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::LLParser::UpRefRecord*, std::vector<llvm::LLParser::UpRefRecord, std::allocator<llvm::LLParser::UpRefRecord>>>, llvm::LLParser::UpRefRecord const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IN4llvm12PATypeHolderENS2_5SMLocEEESt10_Select1stIS6_ESt4lessIjESaIS6_EE16_M_insert_uniqueERKS6_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>>::_M_insert_unique(std::pair<unsigned int const, std::pair<llvm::PATypeHolder, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IN4llvm12PATypeHolderENS2_5SMLocEEESt10_Select1stIS6_ESt4lessISsESaIS6_EE16_M_insert_uniqueERKS6_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>>::_M_insert_unique(std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IN4llvm12PATypeHolderENS2_5SMLocEEESt10_Select1stIS6_ESt4lessISsESaIS6_EE9_M_insertEPSt18_Rb_tree_node_baseSE_RKS6_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>> const&)"},
    {"_ZSt6__findIPN4llvm12PATypeHandleEPKNS0_4TypeEET_S6_S6_RKT0_St26random_access_iterator_tag", "llvm::PATypeHandle* std::__find<llvm::PATypeHandle*, llvm::Type const*>(llvm::PATypeHandle*, llvm::PATypeHandle*, llvm::Type const* const&, std::random_access_iterator_tag)"},
    {"_ZNSt6vectorIN4llvm8LLParser5MDRefESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::LLParser::MDRef*, std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>>, llvm::LLParser::MDRef const&)"},
    {"_ZN4llvm8DenseMapIPNS_11InstructionESt6vectorINS_8LLParser5MDRefESaIS5_EENS_12DenseMapInfoIS2_EENS8_IS7_EEE16FindAndConstructERKS2_", "llvm::DenseMap<llvm::Instruction*, std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>, llvm::DenseMapInfo<llvm::Instruction*>, llvm::DenseMapInfo<std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>>>::FindAndConstruct(llvm::Instruction* const&)"},
    {"_ZN4llvm8DenseMapIPNS_11InstructionESt6vectorINS_8LLParser5MDRefESaIS5_EENS_12DenseMapInfoIS2_EENS8_IS7_EEE16InsertIntoBucketERKS2_RKS7_PSt4pairIS2_S7_E", "llvm::DenseMap<llvm::Instruction*, std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>, llvm::DenseMapInfo<llvm::Instruction*>, llvm::DenseMapInfo<std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>>>::InsertIntoBucket(llvm::Instruction* const&, std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>> const&, std::pair<llvm::Instruction*, std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>>*)"},
    {"_ZN4llvm8DenseMapIPNS_11InstructionESt6vectorINS_8LLParser5MDRefESaIS5_EENS_12DenseMapInfoIS2_EENS8_IS7_EEE4growEj", "llvm::DenseMap<llvm::Instruction*, std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>, llvm::DenseMapInfo<llvm::Instruction*>, llvm::DenseMapInfo<std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>>>::grow(unsigned int)"},
    {"_ZNSt6vectorIN4llvm8LLParser5MDRefESaIS2_EEC2ERKS4_", "std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>::vector(std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IPN4llvm11GlobalValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessIjESaIS7_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS7_ERKS7_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IPN4llvm11GlobalValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessIjESaIS7_EE16_M_insert_uniqueERKS7_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::_M_insert_unique(std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm11GlobalValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS7_ERKS7_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm11GlobalValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE9_M_insertEPSt18_Rb_tree_node_baseSF_RKS7_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm11GlobalValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE16_M_insert_uniqueERKS7_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::_M_insert_unique(std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>> const&)"},
    {"_ZNSt6vectorIPN4llvm11GlobalValueESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::GlobalValue*, std::allocator<llvm::GlobalValue*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::GlobalValue**, std::vector<llvm::GlobalValue*, std::allocator<llvm::GlobalValue*>>>, llvm::GlobalValue* const&)"},
    {"_ZN4llvm6iplistINS_14GlobalVariableENS_12ilist_traitsIS1_EEE8transferENS_14ilist_iteratorIS1_EERS4_S6_S6_", "llvm::iplist<llvm::GlobalVariable, llvm::ilist_traits<llvm::GlobalVariable>>::transfer(llvm::ilist_iterator<llvm::GlobalVariable>, llvm::iplist<llvm::GlobalVariable, llvm::ilist_traits<llvm::GlobalVariable>>&, llvm::ilist_iterator<llvm::GlobalVariable>, llvm::ilist_iterator<llvm::GlobalVariable>)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm11GlobalValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE11equal_rangeERS1_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::equal_range(std::string const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm11GlobalValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE5eraseESt17_Rb_tree_iteratorIS7_ESF_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::erase(std::_Rb_tree_iterator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::_Rb_tree_iterator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm11GlobalValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE4findERS1_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::find(std::string const&)"},
    {"_ZNSt6vectorIN4llvm10TrackingVHINS0_6MDNodeEEESaIS3_EE14_M_fill_insertEN9__gnu_cxx17__normal_iteratorIPS3_S5_EEmRKS3_", "std::vector<llvm::TrackingVH<llvm::MDNode>, std::allocator<llvm::TrackingVH<llvm::MDNode>>>::_M_fill_insert(__gnu_cxx::__normal_iterator<llvm::TrackingVH<llvm::MDNode>*, std::vector<llvm::TrackingVH<llvm::MDNode>, std::allocator<llvm::TrackingVH<llvm::MDNode>>>>, unsigned long, llvm::TrackingVH<llvm::MDNode> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IN4llvm10TrackingVHINS2_6MDNodeEEENS2_5SMLocEEESt10_Select1stIS8_ESt4lessIjESaIS8_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS8_ERKS8_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>, std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IN4llvm10TrackingVHINS2_6MDNodeEEENS2_5SMLocEEESt10_Select1stIS8_ESt4lessIjESaIS8_EE9_M_insertEPSt18_Rb_tree_node_baseSG_RKS8_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IN4llvm10TrackingVHINS2_6MDNodeEEENS2_5SMLocEEESt10_Select1stIS8_ESt4lessIjESaIS8_EE16_M_insert_uniqueERKS8_", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>>::_M_insert_unique(std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IN4llvm12PATypeHolderENS2_5SMLocEEESt10_Select1stIS6_ESt4lessISsESaIS6_EE4findERS1_", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>>::find(std::string const&)"},
    {"_ZN4llvm8DenseMapIPNS_11InstructionESt6vectorINS_8LLParser5MDRefESaIS5_EENS_12DenseMapInfoIS2_EENS8_IS7_EEE16shrink_and_clearEv", "llvm::DenseMap<llvm::Instruction*, std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>, llvm::DenseMapInfo<llvm::Instruction*>, llvm::DenseMapInfo<std::vector<llvm::LLParser::MDRef, std::allocator<llvm::LLParser::MDRef>>>>::shrink_and_clear()"},
    {"_ZN4llvm13ParseAssemblyEPNS_12MemoryBufferEPNS_6ModuleERNS_12SMDiagnosticERNS_11LLVMContextE", "llvm::ParseAssembly(llvm::MemoryBuffer*, llvm::Module*, llvm::SMDiagnostic&, llvm::LLVMContext&)"},
    {"_ZN4llvm17ParseAssemblyFileERKSsRNS_12SMDiagnosticERNS_11LLVMContextE", "llvm::ParseAssemblyFile(std::string const&, llvm::SMDiagnostic&, llvm::LLVMContext&)"},
    {"_ZN4llvm19ParseAssemblyStringEPKcPNS_6ModuleERNS_12SMDiagnosticERNS_11LLVMContextE", "llvm::ParseAssemblyString(char const*, llvm::Module*, llvm::SMDiagnostic&, llvm::LLVMContext&)"},
    {"_ZN4llvm8LLParserD2Ev", "llvm::LLParser::~LLParser()"},
    {"_ZN4llvm7LLLexerD2Ev", "llvm::LLLexer::~LLLexer()"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IN4llvm12PATypeHolderENS2_5SMLocEEESt10_Select1stIS6_ESt4lessISsESaIS6_EE8_M_eraseEPSt13_Rb_tree_nodeIS6_E", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>>::_M_erase(std::_Rb_tree_node<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>*)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IN4llvm12PATypeHolderENS2_5SMLocEEESt10_Select1stIS6_ESt4lessISsESaIS6_EE15_M_destroy_nodeEPSt13_Rb_tree_nodeIS6_E", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>>::_M_destroy_node(std::_Rb_tree_node<std::pair<std::string const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>*)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IN4llvm12PATypeHolderENS2_5SMLocEEESt10_Select1stIS6_ESt4lessIjESaIS6_EE8_M_eraseEPSt13_Rb_tree_nodeIS6_E", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>>::_M_erase(std::_Rb_tree_node<std::pair<unsigned int const, std::pair<llvm::PATypeHolder, llvm::SMLoc>>>*)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IN4llvm10TrackingVHINS2_6MDNodeEEENS2_5SMLocEEESt10_Select1stIS8_ESt4lessIjESaIS8_EE8_M_eraseEPSt13_Rb_tree_nodeIS8_E", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>>::_M_erase(std::_Rb_tree_node<std::pair<unsigned int const, std::pair<llvm::TrackingVH<llvm::MDNode>, llvm::SMLoc>>>*)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsS0_IPN4llvm11GlobalValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessISsESaIS7_EE8_M_eraseEPSt13_Rb_tree_nodeIS7_E", "std::_Rb_tree<std::string, std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>, std::_Select1st<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::less<std::string>, std::allocator<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::_M_erase(std::_Rb_tree_node<std::pair<std::string const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>*)"},
    {"_ZNSt8_Rb_treeIjSt4pairIKjS0_IPN4llvm11GlobalValueENS2_5SMLocEEESt10_Select1stIS7_ESt4lessIjESaIS7_EE8_M_eraseEPSt13_Rb_tree_nodeIS7_E", "std::_Rb_tree<unsigned int, std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>, std::_Select1st<std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>, std::less<unsigned int>, std::allocator<std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>>::_M_erase(std::_Rb_tree_node<std::pair<unsigned int const, std::pair<llvm::GlobalValue*, llvm::SMLoc>>>*)"},
    {"_ZNSt8_Rb_treeIN4llvm5ValIDESt4pairIKS1_St6vectorIS2_IS1_PNS0_11GlobalValueEESaIS7_EEESt10_Select1stISA_ESt4lessIS1_ESaISA_EE8_M_eraseEPSt13_Rb_tree_nodeISA_E", "std::_Rb_tree<llvm::ValID, std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>, std::_Select1st<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>, std::less<llvm::ValID>, std::allocator<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>>::_M_erase(std::_Rb_tree_node<std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>>*)"},
    {"_ZNSt4pairIKN4llvm5ValIDESt6vectorIS_IS1_PNS0_11GlobalValueEESaIS6_EEED2Ev", "std::pair<llvm::ValID const, std::vector<std::pair<llvm::ValID, llvm::GlobalValue*>, std::allocator<std::pair<llvm::ValID, llvm::GlobalValue*>>>>::~pair()"},
    {"_ZSt13__destroy_auxIPSt4pairIN4llvm5ValIDEPNS1_11GlobalValueEEEvT_S7_St12__false_type", "void std::__destroy_aux<std::pair<llvm::ValID, llvm::GlobalValue*>*>(std::pair<llvm::ValID, llvm::GlobalValue*>*, std::pair<llvm::ValID, llvm::GlobalValue*>*, std::__false_type)"},
    {"_ZN4llvm8LLParserC2EPNS_12MemoryBufferERNS_9SourceMgrERNS_12SMDiagnosticEPNS_6ModuleE", "llvm::LLParser::LLParser(llvm::MemoryBuffer*, llvm::SourceMgr&, llvm::SMDiagnostic&, llvm::Module*)"},
    {"_ZN4llvm16RegisterAsmLexerIN12_GLOBAL__N_111X86AsmLexerEE9AllocatorERKNS_6TargetERKNS_9MCAsmInfoE", "llvm::RegisterAsmLexer<(anonymous namespace)::X86AsmLexer>::Allocator(llvm::Target const&, llvm::MCAsmInfo const&)"},
    {"_ZN12_GLOBAL__N_111X86AsmLexer8LexTokenEv", "(anonymous namespace)::X86AsmLexer::LexToken()"},
    {"_ZN12_GLOBAL__N_111X86AsmLexerD1Ev", "(anonymous namespace)::X86AsmLexer::~X86AsmLexer()"},
    {"_ZN12_GLOBAL__N_111X86AsmLexerD0Ev", "(anonymous namespace)::X86AsmLexer::~X86AsmLexer()"},
    {"_Z17MatchRegisterNameN4llvm9StringRefE", "MatchRegisterName(llvm::StringRef)"},
    {"_ZN4llvm17RegisterAsmParserIN12_GLOBAL__N_118X86_64ATTAsmParserEE9AllocatorERKNS_6TargetERNS_11MCAsmParserERNS_13TargetMachineE", "llvm::RegisterAsmParser<(anonymous namespace)::X86_64ATTAsmParser>::Allocator(llvm::Target const&, llvm::MCAsmParser&, llvm::TargetMachine&)"},
    {"_ZN12_GLOBAL__N_118X86_64ATTAsmParserD1Ev", "(anonymous namespace)::X86_64ATTAsmParser::~X86_64ATTAsmParser()"},
    {"_ZN12_GLOBAL__N_118X86_64ATTAsmParserD0Ev", "(anonymous namespace)::X86_64ATTAsmParser::~X86_64ATTAsmParser()"},
    {"_ZN12_GLOBAL__N_115X86ATTAsmParser13ParseRegisterERjRN4llvm5SMLocES4_", "(anonymous namespace)::X86ATTAsmParser::ParseRegister(unsigned int&, llvm::SMLoc&, llvm::SMLoc&)"},
    {"_ZN12_GLOBAL__N_115X86ATTAsmParser16ParseInstructionEN4llvm9StringRefENS1_5SMLocERNS1_15SmallVectorImplIPNS1_18MCParsedAsmOperandEEE", "(anonymous namespace)::X86ATTAsmParser::ParseInstruction(llvm::StringRef, llvm::SMLoc, llvm::SmallVectorImpl<llvm::MCParsedAsmOperand*>&)"},
    {"_ZN12_GLOBAL__N_115X86ATTAsmParser14ParseDirectiveEN4llvm8AsmTokenE", "(anonymous namespace)::X86ATTAsmParser::ParseDirective(llvm::AsmToken)"},
    {"_ZN12_GLOBAL__N_115X86ATTAsmParser23MatchAndEmitInstructionEN4llvm5SMLocERNS1_15SmallVectorImplIPNS1_18MCParsedAsmOperandEEERNS1_10MCStreamerE", "(anonymous namespace)::X86ATTAsmParser::MatchAndEmitInstruction(llvm::SMLoc, llvm::SmallVectorImpl<llvm::MCParsedAsmOperand*>&, llvm::MCStreamer&)"},
    {"_ZN12_GLOBAL__N_115X86ATTAsmParser20MatchInstructionImplERKN4llvm15SmallVectorImplIPNS1_18MCParsedAsmOperandEEERNS1_6MCInstERj", "(anonymous namespace)::X86ATTAsmParser::MatchInstructionImpl(llvm::SmallVectorImpl<llvm::MCParsedAsmOperand*> const&, llvm::MCInst&, unsigned int&)"},
    {"_ZN12_GLOBAL__N_115X86ATTAsmParser15ConvertToMCInstEjRN4llvm6MCInstEjRKNS1_15SmallVectorImplIPNS1_18MCParsedAsmOperandEEE", "(anonymous namespace)::X86ATTAsmParser::ConvertToMCInst(unsigned int, llvm::MCInst&, unsigned int, llvm::SmallVectorImpl<llvm::MCParsedAsmOperand*> const&)"},
    {"_ZNK12_GLOBAL__N_110X86Operand14addMemOperandsERN4llvm6MCInstEj", "(anonymous namespace)::X86Operand::addMemOperands(llvm::MCInst&, unsigned int) const"},
    {"_ZNK12_GLOBAL__N_110X86Operand7addExprERN4llvm6MCInstEPKNS1_6MCExprE", "(anonymous namespace)::X86Operand::addExpr(llvm::MCInst&, llvm::MCExpr const*) const"},
    {"_ZN12_GLOBAL__N_110X86OperandD1Ev", "(anonymous namespace)::X86Operand::~X86Operand()"},
    {"_ZN12_GLOBAL__N_110X86OperandD0Ev", "(anonymous namespace)::X86Operand::~X86Operand()"},
    {"_ZNK12_GLOBAL__N_110X86Operand11getStartLocEv", "(anonymous namespace)::X86Operand::getStartLoc() const"},
    {"_ZNK12_GLOBAL__N_110X86Operand9getEndLocEv", "(anonymous namespace)::X86Operand::getEndLoc() const"},
    {"_ZNK12_GLOBAL__N_110X86Operand4dumpERN4llvm11raw_ostreamE", "(anonymous namespace)::X86Operand::dump(llvm::raw_ostream&) const"},
    {"_ZN12_GLOBAL__N_115X86ATTAsmParser12ParseOperandEv", "(anonymous namespace)::X86ATTAsmParser::ParseOperand()"},
    {"_Z17MatchRegisterNameN4llvm9StringRefE", "MatchRegisterName(llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_115X86ATTAsmParser15ParseMemOperandEjN4llvm5SMLocE", "(anonymous namespace)::X86ATTAsmParser::ParseMemOperand(unsigned int, llvm::SMLoc)"},
    {"_ZN12_GLOBAL__N_115X86ATTAsmParserD1Ev", "(anonymous namespace)::X86ATTAsmParser::~X86ATTAsmParser()"},
    {"_ZN12_GLOBAL__N_115X86ATTAsmParserD0Ev", "(anonymous namespace)::X86ATTAsmParser::~X86ATTAsmParser()"},
    {"_ZN4llvm17RegisterAsmParserIN12_GLOBAL__N_118X86_32ATTAsmParserEE9AllocatorERKNS_6TargetERNS_11MCAsmParserERNS_13TargetMachineE", "llvm::RegisterAsmParser<(anonymous namespace)::X86_32ATTAsmParser>::Allocator(llvm::Target const&, llvm::MCAsmParser&, llvm::TargetMachine&)"},
    {"_ZN12_GLOBAL__N_118X86_32ATTAsmParserD1Ev", "(anonymous namespace)::X86_32ATTAsmParser::~X86_32ATTAsmParser()"},
    {"_ZN12_GLOBAL__N_118X86_32ATTAsmParserD0Ev", "(anonymous namespace)::X86_32ATTAsmParser::~X86_32ATTAsmParser()"},
    {"_ZN4llvm22createSSEDomainFixPassEv", "llvm::createSSEDomainFixPass()"},
    {"_ZN12_GLOBAL__N_116SSEDomainFixPassD1Ev", "(anonymous namespace)::SSEDomainFixPass::~SSEDomainFixPass()"},
    {"_ZN12_GLOBAL__N_116SSEDomainFixPassD0Ev", "(anonymous namespace)::SSEDomainFixPass::~SSEDomainFixPass()"},
    {"_ZNK12_GLOBAL__N_116SSEDomainFixPass11getPassNameEv", "(anonymous namespace)::SSEDomainFixPass::getPassName() const"},
    {"_ZNK12_GLOBAL__N_116SSEDomainFixPass16getAnalysisUsageERN4llvm13AnalysisUsageE", "(anonymous namespace)::SSEDomainFixPass::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_116SSEDomainFixPass20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::SSEDomainFixPass::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN12_GLOBAL__N_116SSEDomainFixPass14visitHardInstrEPN4llvm12MachineInstrEj", "(anonymous namespace)::SSEDomainFixPass::visitHardInstr(llvm::MachineInstr*, unsigned int)"},
    {"_ZN4llvm24SpecificBumpPtrAllocatorIN12_GLOBAL__N_111DomainValueEE10DestroyAllEv", "llvm::SpecificBumpPtrAllocator<(anonymous namespace)::DomainValue>::DestroyAll()"},
    {"_ZN12_GLOBAL__N_116SSEDomainFixPass8CollapseEPNS_11DomainValueEj", "(anonymous namespace)::SSEDomainFixPass::Collapse((anonymous namespace)::DomainValue*, unsigned int)"},
    {"_ZN12_GLOBAL__N_116SSEDomainFixPass10SetLiveRegEiPNS_11DomainValueE", "(anonymous namespace)::SSEDomainFixPass::SetLiveReg(int, (anonymous namespace)::DomainValue*)"},
    {"_ZN12_GLOBAL__N_116SSEDomainFixPass5ForceEij", "(anonymous namespace)::SSEDomainFixPass::Force(int, unsigned int)"},
    {"_ZN12_GLOBAL__N_116SSEDomainFixPass5MergeEPNS_11DomainValueES2_", "(anonymous namespace)::SSEDomainFixPass::Merge((anonymous namespace)::DomainValue*, (anonymous namespace)::DomainValue*)"},
    {"_ZN4llvm12df_ext_beginIPNS_17MachineBasicBlockENS_11SmallPtrSetIS2_Lj16EEEEENS_15df_ext_iteratorIT_T0_EERKS6_RS7_", "llvm::df_ext_iterator<llvm::MachineBasicBlock*, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 16u>> llvm::df_ext_begin<llvm::MachineBasicBlock*, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 16u>>(llvm::MachineBasicBlock* const&, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 16u>&)"},
    {"_ZN4llvm11df_iteratorIPNS_17MachineBasicBlockENS_11SmallPtrSetIS2_Lj16EEELb1ENS_11GraphTraitsIS2_EEE6toNextEv", "llvm::df_iterator<llvm::MachineBasicBlock*, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 16u>, true, llvm::GraphTraits<llvm::MachineBasicBlock*>>::toNext()"},
    {"_ZNSt6vectorISt4pairIN4llvm14PointerIntPairIPNS1_17MachineBasicBlockELj1EjNS1_21PointerLikeTypeTraitsIS4_EEEEN9__gnu_cxx17__normal_iteratorIPS4_S_IS4_SaIS4_EEEEESaISE_EE13_M_insert_auxENS9_IPSE_SG_EERKSE_", "std::vector<std::pair<llvm::PointerIntPair<llvm::MachineBasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::MachineBasicBlock*>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>>, std::allocator<std::pair<llvm::PointerIntPair<llvm::MachineBasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::MachineBasicBlock*>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::PointerIntPair<llvm::MachineBasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::MachineBasicBlock*>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>>*, std::vector<std::pair<llvm::PointerIntPair<llvm::MachineBasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::MachineBasicBlock*>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>>, std::allocator<std::pair<llvm::PointerIntPair<llvm::MachineBasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::MachineBasicBlock*>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>>>>>, std::pair<llvm::PointerIntPair<llvm::MachineBasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::MachineBasicBlock*>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>> const&)"},
    {"_ZNSt6vectorISt4pairIN4llvm14PointerIntPairIPNS1_17MachineBasicBlockELj1EjNS1_21PointerLikeTypeTraitsIS4_EEEEN9__gnu_cxx17__normal_iteratorIPS4_S_IS4_SaIS4_EEEEESaISE_EEC2ERKSG_", "std::vector<std::pair<llvm::PointerIntPair<llvm::MachineBasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::MachineBasicBlock*>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>>, std::allocator<std::pair<llvm::PointerIntPair<llvm::MachineBasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::MachineBasicBlock*>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>>>>::vector(std::vector<std::pair<llvm::PointerIntPair<llvm::MachineBasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::MachineBasicBlock*>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>>, std::allocator<std::pair<llvm::PointerIntPair<llvm::MachineBasicBlock*, 1u, unsigned int, llvm::PointerLikeTypeTraits<llvm::MachineBasicBlock*>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>>>> const&)"},
    {"_ZN4llvm11df_iteratorIPNS_17MachineBasicBlockENS_11SmallPtrSetIS2_Lj16EEELb1ENS_11GraphTraitsIS2_EEEC2ES2_RS4_", "llvm::df_iterator<llvm::MachineBasicBlock*, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 16u>, true, llvm::GraphTraits<llvm::MachineBasicBlock*>>::df_iterator(llvm::MachineBasicBlock*, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 16u>&)"},
    {"_ZN4llvm22createX86_32AsmBackendERKNS_6TargetERKSs", "llvm::createX86_32AsmBackend(llvm::Target const&, std::string const&)"},
    {"_ZN4llvm22createX86_64AsmBackendERKNS_6TargetERKSs", "llvm::createX86_64AsmBackend(llvm::Target const&, std::string const&)"},
    {"_ZN12_GLOBAL__N_119ELFX86_64AsmBackendD1Ev", "(anonymous namespace)::ELFX86_64AsmBackend::~ELFX86_64AsmBackend()"},
    {"_ZN12_GLOBAL__N_119ELFX86_64AsmBackendD0Ev", "(anonymous namespace)::ELFX86_64AsmBackend::~ELFX86_64AsmBackend()"},
    {"_ZNK12_GLOBAL__N_119ELFX86_64AsmBackend18createObjectWriterERN4llvm11raw_ostreamE", "(anonymous namespace)::ELFX86_64AsmBackend::createObjectWriter(llvm::raw_ostream&) const"},
    {"_ZNK12_GLOBAL__N_116ELFX86AsmBackend25doesSectionRequireSymbolsERKN4llvm9MCSectionE", "(anonymous namespace)::ELFX86AsmBackend::doesSectionRequireSymbols(llvm::MCSection const&) const"},
    {"_ZNK12_GLOBAL__N_113X86AsmBackend16getNumFixupKindsEv", "(anonymous namespace)::X86AsmBackend::getNumFixupKinds() const"},
    {"_ZNK12_GLOBAL__N_113X86AsmBackend16getFixupKindInfoEN4llvm11MCFixupKindE", "(anonymous namespace)::X86AsmBackend::getFixupKindInfo(llvm::MCFixupKind) const"},
    {"_ZNK12_GLOBAL__N_113X86AsmBackend10ApplyFixupERKN4llvm7MCFixupEPcjy", "(anonymous namespace)::X86AsmBackend::ApplyFixup(llvm::MCFixup const&, char*, unsigned int, unsigned long long) const"},
    {"_ZNK12_GLOBAL__N_113X86AsmBackend17MayNeedRelaxationERKN4llvm6MCInstE", "(anonymous namespace)::X86AsmBackend::MayNeedRelaxation(llvm::MCInst const&) const"},
    {"_ZNK12_GLOBAL__N_113X86AsmBackend16RelaxInstructionERKN4llvm6MCInstERS2_", "(anonymous namespace)::X86AsmBackend::RelaxInstruction(llvm::MCInst const&, llvm::MCInst&) const"},
    {"_ZNK12_GLOBAL__N_113X86AsmBackend12WriteNopDataEyPN4llvm14MCObjectWriterE", "(anonymous namespace)::X86AsmBackend::WriteNopData(unsigned long long, llvm::MCObjectWriter*) const"},
    {"_ZN12_GLOBAL__N_118X86ELFObjectWriterD1Ev", "(anonymous namespace)::X86ELFObjectWriter::~X86ELFObjectWriter()"},
    {"_ZN12_GLOBAL__N_118X86ELFObjectWriterD0Ev", "(anonymous namespace)::X86ELFObjectWriter::~X86ELFObjectWriter()"},
    {"_ZN12_GLOBAL__N_116ELFX86AsmBackendD1Ev", "(anonymous namespace)::ELFX86AsmBackend::~ELFX86AsmBackend()"},
    {"_ZN12_GLOBAL__N_116ELFX86AsmBackendD0Ev", "(anonymous namespace)::ELFX86AsmBackend::~ELFX86AsmBackend()"},
    {"_ZN12_GLOBAL__N_113X86AsmBackendD1Ev", "(anonymous namespace)::X86AsmBackend::~X86AsmBackend()"},
    {"_ZN12_GLOBAL__N_113X86AsmBackendD0Ev", "(anonymous namespace)::X86AsmBackend::~X86AsmBackend()"},
    {"_ZN12_GLOBAL__N_122DarwinX86_64AsmBackendD1Ev", "(anonymous namespace)::DarwinX86_64AsmBackend::~DarwinX86_64AsmBackend()"},
    {"_ZN12_GLOBAL__N_122DarwinX86_64AsmBackendD0Ev", "(anonymous namespace)::DarwinX86_64AsmBackend::~DarwinX86_64AsmBackend()"},
    {"_ZNK12_GLOBAL__N_122DarwinX86_64AsmBackend18createObjectWriterERN4llvm11raw_ostreamE", "(anonymous namespace)::DarwinX86_64AsmBackend::createObjectWriter(llvm::raw_ostream&) const"},
    {"_ZNK12_GLOBAL__N_122DarwinX86_64AsmBackend25doesSectionRequireSymbolsERKN4llvm9MCSectionE", "(anonymous namespace)::DarwinX86_64AsmBackend::doesSectionRequireSymbols(llvm::MCSection const&) const"},
    {"_ZNK12_GLOBAL__N_122DarwinX86_64AsmBackend19isSectionAtomizableERKN4llvm9MCSectionE", "(anonymous namespace)::DarwinX86_64AsmBackend::isSectionAtomizable(llvm::MCSection const&) const"},
    {"_ZN12_GLOBAL__N_119DarwinX86AsmBackendD1Ev", "(anonymous namespace)::DarwinX86AsmBackend::~DarwinX86AsmBackend()"},
    {"_ZN12_GLOBAL__N_119DarwinX86AsmBackendD0Ev", "(anonymous namespace)::DarwinX86AsmBackend::~DarwinX86AsmBackend()"},
    {"_ZN12_GLOBAL__N_119ELFX86_32AsmBackendD1Ev", "(anonymous namespace)::ELFX86_32AsmBackend::~ELFX86_32AsmBackend()"},
    {"_ZN12_GLOBAL__N_119ELFX86_32AsmBackendD0Ev", "(anonymous namespace)::ELFX86_32AsmBackend::~ELFX86_32AsmBackend()"},
    {"_ZNK12_GLOBAL__N_119ELFX86_32AsmBackend18createObjectWriterERN4llvm11raw_ostreamE", "(anonymous namespace)::ELFX86_32AsmBackend::createObjectWriter(llvm::raw_ostream&) const"},
    {"_ZN12_GLOBAL__N_120WindowsX86AsmBackendD1Ev", "(anonymous namespace)::WindowsX86AsmBackend::~WindowsX86AsmBackend()"},
    {"_ZN12_GLOBAL__N_120WindowsX86AsmBackendD0Ev", "(anonymous namespace)::WindowsX86AsmBackend::~WindowsX86AsmBackend()"},
    {"_ZNK12_GLOBAL__N_120WindowsX86AsmBackend18createObjectWriterERN4llvm11raw_ostreamE", "(anonymous namespace)::WindowsX86AsmBackend::createObjectWriter(llvm::raw_ostream&) const"},
    {"_ZN12_GLOBAL__N_122DarwinX86_32AsmBackendD1Ev", "(anonymous namespace)::DarwinX86_32AsmBackend::~DarwinX86_32AsmBackend()"},
    {"_ZN12_GLOBAL__N_122DarwinX86_32AsmBackendD0Ev", "(anonymous namespace)::DarwinX86_32AsmBackend::~DarwinX86_32AsmBackend()"},
    {"_ZNK12_GLOBAL__N_122DarwinX86_32AsmBackend18createObjectWriterERN4llvm11raw_ostreamE", "(anonymous namespace)::DarwinX86_32AsmBackend::createObjectWriter(llvm::raw_ostream&) const"},
    {"_ZNK4llvm16TargetAsmBackend19isSectionAtomizableERKNS_9MCSectionE", "llvm::TargetAsmBackend::isSectionAtomizable(llvm::MCSection const&) const"},
    {"_ZN4llvm16TargetAsmBackend19HandleAssemblerFlagENS_15MCAssemblerFlagE", "llvm::TargetAsmBackend::HandleAssemblerFlag(llvm::MCAssemblerFlag)"},
    {"_ZN4llvm15SmallVectorImplINS_9MCOperandEEaSERKS2_", "llvm::SmallVectorImpl<llvm::MCOperand>::operator=(llvm::SmallVectorImpl<llvm::MCOperand> const&)"},
    {"_ZNK4llvm16TargetAsmBackend25doesSectionRequireSymbolsERKNS_9MCSectionE", "llvm::TargetAsmBackend::doesSectionRequireSymbols(llvm::MCSection const&) const"},
    {"_ZN4llvm13X86AsmPrinter20runOnMachineFunctionERNS_15MachineFunctionE", "llvm::X86AsmPrinter::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN4llvm13X86AsmPrinter18printSymbolOperandERKNS_14MachineOperandERNS_11raw_ostreamE", "llvm::X86AsmPrinter::printSymbolOperand(llvm::MachineOperand const&, llvm::raw_ostream&)"},
    {"_ZN4llvm13X86AsmPrinter15print_pcrel_immEPKNS_12MachineInstrEjRNS_11raw_ostreamE", "llvm::X86AsmPrinter::print_pcrel_imm(llvm::MachineInstr const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm13X86AsmPrinter12printOperandEPKNS_12MachineInstrEjRNS_11raw_ostreamEPKc", "llvm::X86AsmPrinter::printOperand(llvm::MachineInstr const*, unsigned int, llvm::raw_ostream&, char const*)"},
    {"_ZN4llvm13X86AsmPrinter10printSSECCEPKNS_12MachineInstrEjRNS_11raw_ostreamE", "llvm::X86AsmPrinter::printSSECC(llvm::MachineInstr const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm13X86AsmPrinter20printLeaMemReferenceEPKNS_12MachineInstrEjRNS_11raw_ostreamEPKc", "llvm::X86AsmPrinter::printLeaMemReference(llvm::MachineInstr const*, unsigned int, llvm::raw_ostream&, char const*)"},
    {"_ZN4llvm13X86AsmPrinter17printMemReferenceEPKNS_12MachineInstrEjRNS_11raw_ostreamEPKc", "llvm::X86AsmPrinter::printMemReference(llvm::MachineInstr const*, unsigned int, llvm::raw_ostream&, char const*)"},
    {"_ZN4llvm13X86AsmPrinter13printPICLabelEPKNS_12MachineInstrEjRNS_11raw_ostreamE", "llvm::X86AsmPrinter::printPICLabel(llvm::MachineInstr const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm13X86AsmPrinter17printAsmMRegisterERKNS_14MachineOperandEcRNS_11raw_ostreamE", "llvm::X86AsmPrinter::printAsmMRegister(llvm::MachineOperand const&, char, llvm::raw_ostream&)"},
    {"_ZN4llvm13X86AsmPrinter15PrintAsmOperandEPKNS_12MachineInstrEjjPKcRNS_11raw_ostreamE", "llvm::X86AsmPrinter::PrintAsmOperand(llvm::MachineInstr const*, unsigned int, unsigned int, char const*, llvm::raw_ostream&)"},
    {"_ZN4llvm13X86AsmPrinter21PrintAsmMemoryOperandEPKNS_12MachineInstrEjjPKcRNS_11raw_ostreamE", "llvm::X86AsmPrinter::PrintAsmMemoryOperand(llvm::MachineInstr const*, unsigned int, unsigned int, char const*, llvm::raw_ostream&)"},
    {"_ZN4llvm13X86AsmPrinter18EmitStartOfAsmFileERNS_6ModuleE", "llvm::X86AsmPrinter::EmitStartOfAsmFile(llvm::Module&)"},
    {"_ZN4llvm13X86AsmPrinter16EmitEndOfAsmFileERNS_6ModuleE", "llvm::X86AsmPrinter::EmitEndOfAsmFile(llvm::Module&)"},
    {"_ZNK4llvm13X86AsmPrinter21getDebugValueLocationEPKNS_12MachineInstrE", "llvm::X86AsmPrinter::getDebugValueLocation(llvm::MachineInstr const*) const"},
    {"_ZN4llvm13X86AsmPrinter22PrintDebugValueCommentEPKNS_12MachineInstrERNS_11raw_ostreamE", "llvm::X86AsmPrinter::PrintDebugValueComment(llvm::MachineInstr const*, llvm::raw_ostream&)"},
    {"_Z22createX86MCInstPrinterRKN4llvm6TargetEjRKNS_9MCAsmInfoE", "createX86MCInstPrinter(llvm::Target const&, unsigned int, llvm::MCAsmInfo const&)"},
    {"_ZNK4llvm12X86Subtarget12isTargetCOFFEv", "llvm::X86Subtarget::isTargetCOFF() const"},
    {"_ZNK4llvm12X86Subtarget11isTargetELFEv", "llvm::X86Subtarget::isTargetELF() const"},
    {"_ZN4llvm7DIScopeD1Ev", "llvm::DIScope::~DIScope()"},
    {"_ZN4llvm12DISubprogramD1Ev", "llvm::DISubprogram::~DISubprogram()"},
    {"_ZN4llvm13X86AsmPrinterD1Ev", "llvm::X86AsmPrinter::~X86AsmPrinter()"},
    {"_ZN4llvm13X86AsmPrinterD0Ev", "llvm::X86AsmPrinter::~X86AsmPrinter()"},
    {"_ZNK4llvm13X86AsmPrinter11getPassNameEv", "llvm::X86AsmPrinter::getPassName() const"},
    {"_ZN4llvm10AsmPrinter14getISAEncodingEv", "llvm::AsmPrinter::getISAEncoding()"},
    {"_ZN4llvm18RegisterAsmPrinterINS_13X86AsmPrinterEE9AllocatorERNS_13TargetMachineERNS_10MCStreamerE", "llvm::RegisterAsmPrinter<llvm::X86AsmPrinter>::Allocator(llvm::TargetMachine&, llvm::MCStreamer&)"},
    {"_ZNSt6vectorIPKN4llvm8MCSymbolESaIS3_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS3_S5_EERKS3_", "std::vector<llvm::MCSymbol const*, std::allocator<llvm::MCSymbol const*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::MCSymbol const**, std::vector<llvm::MCSymbol const*, std::allocator<llvm::MCSymbol const*>>>, llvm::MCSymbol const* const&)"},
    {"_ZN4llvm12DISubprogramD0Ev", "llvm::DISubprogram::~DISubprogram()"},
    {"_ZN4llvm7DIScopeD0Ev", "llvm::DIScope::~DIScope()"},
    {"_ZN4llvm24X86COFFMachineModuleInfoD0Ev", "llvm::X86COFFMachineModuleInfo::~X86COFFMachineModuleInfo()"},
    {"_ZN4llvm24X86COFFMachineModuleInfoD1Ev", "llvm::X86COFFMachineModuleInfo::~X86COFFMachineModuleInfo()"},
    {"_ZN4llvm24X86COFFMachineModuleInfoD2Ev", "llvm::X86COFFMachineModuleInfo::~X86COFFMachineModuleInfo()"},
    {"_ZN4llvm27createX86JITCodeEmitterPassERNS_16X86TargetMachineERNS_14JITCodeEmitterE", "llvm::createX86JITCodeEmitterPass(llvm::X86TargetMachine&, llvm::JITCodeEmitter&)"},
    {"_ZN12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEED1Ev", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::~Emitter()"},
    {"_ZN12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEED0Ev", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::~Emitter()"},
    {"_ZNK12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEE11getPassNameEv", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::getPassName() const"},
    {"_ZNK12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEE16getAnalysisUsageERNS1_13AnalysisUsageE", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEE20runOnMachineFunctionERNS1_15MachineFunctionE", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEE15emitInstructionERNS1_12MachineInstrEPKNS1_15TargetInstrDescE", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::emitInstruction(llvm::MachineInstr&, llvm::TargetInstrDesc const*)"},
    {"_ZN12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEE17emitGlobalAddressEPKNS1_11GlobalValueEjllb", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::emitGlobalAddress(llvm::GlobalValue const*, unsigned int, long, long, bool)"},
    {"_ZN12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEE25emitExternalSymbolAddressEPKcj", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::emitExternalSymbolAddress(char const*, unsigned int)"},
    {"_ZN12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEE20emitJumpTableAddressEjjl", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::emitJumpTableAddress(unsigned int, unsigned int, long)"},
    {"_ZN12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEE20emitConstPoolAddressEjjll", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::emitConstPoolAddress(unsigned int, unsigned int, long, long)"},
    {"_ZN12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEE16emitMemModRMByteERKNS1_12MachineInstrEjjl", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::emitMemModRMByte(llvm::MachineInstr const&, unsigned int, unsigned int, long)"},
    {"_ZN12_GLOBAL__N_17EmitterIN4llvm14JITCodeEmitterEE21emitDisplacementFieldEPKNS1_14MachineOperandEilb", "(anonymous namespace)::Emitter<llvm::JITCodeEmitter>::emitDisplacementField(llvm::MachineOperand const*, int, long, bool)"},
    {"_ZN4llvm16X86ELFWriterInfoC1Ebb", "llvm::X86ELFWriterInfo::X86ELFWriterInfo(bool, bool)"},
    {"_ZN4llvm16X86ELFWriterInfoC2Ebb", "llvm::X86ELFWriterInfo::X86ELFWriterInfo(bool, bool)"},
    {"_ZN4llvm16X86ELFWriterInfoD0Ev", "llvm::X86ELFWriterInfo::~X86ELFWriterInfo()"},
    {"_ZN4llvm16X86ELFWriterInfoD1Ev", "llvm::X86ELFWriterInfo::~X86ELFWriterInfo()"},
    {"_ZN4llvm16X86ELFWriterInfoD2Ev", "llvm::X86ELFWriterInfo::~X86ELFWriterInfo()"},
    {"_ZNK4llvm16X86ELFWriterInfo17getRelocationTypeEj", "llvm::X86ELFWriterInfo::getRelocationType(unsigned int) const"},
    {"_ZNK4llvm16X86ELFWriterInfo24getDefaultAddendForRelTyEjl", "llvm::X86ELFWriterInfo::getDefaultAddendForRelTy(unsigned int, long) const"},
    {"_ZNK4llvm16X86ELFWriterInfo19getRelocationTySizeEj", "llvm::X86ELFWriterInfo::getRelocationTySize(unsigned int) const"},
    {"_ZNK4llvm16X86ELFWriterInfo15isPCRelativeRelEj", "llvm::X86ELFWriterInfo::isPCRelativeRel(unsigned int) const"},
    {"_ZNK4llvm16X86ELFWriterInfo28getAbsoluteLabelMachineRelTyEv", "llvm::X86ELFWriterInfo::getAbsoluteLabelMachineRelTy() const"},
    {"_ZNK4llvm16X86ELFWriterInfo17computeRelocationEjjj", "llvm::X86ELFWriterInfo::computeRelocation(unsigned int, unsigned int, unsigned int) const"},
    {"_ZNK4llvm16X86ELFWriterInfo19hasRelocationAddendEv", "llvm::X86ELFWriterInfo::hasRelocationAddend() const"},
    {"_ZN4llvm3X8614createFastISelERNS_20FunctionLoweringInfoE", "llvm::X86::createFastISel(llvm::FunctionLoweringInfo&)"},
    {"_ZN12_GLOBAL__N_111X86FastISel13TryToFoldLoadEPN4llvm12MachineInstrEjPKNS1_8LoadInstE", "(anonymous namespace)::X86FastISel::TryToFoldLoad(llvm::MachineInstr*, unsigned int, llvm::LoadInst const*)"},
    {"_ZN12_GLOBAL__N_111X86FastISelD1Ev", "(anonymous namespace)::X86FastISel::~X86FastISel()"},
    {"_ZN12_GLOBAL__N_111X86FastISelD0Ev", "(anonymous namespace)::X86FastISel::~X86FastISel()"},
    {"_ZN12_GLOBAL__N_111X86FastISel23TargetSelectInstructionEPKN4llvm11InstructionE", "(anonymous namespace)::X86FastISel::TargetSelectInstruction(llvm::Instruction const*)"},
    {"_ZN12_GLOBAL__N_111X86FastISel10FastEmit_rEN4llvm3MVTES2_jjb", "(anonymous namespace)::X86FastISel::FastEmit_r(llvm::MVT, llvm::MVT, unsigned int, unsigned int, bool)"},
    {"_ZN12_GLOBAL__N_111X86FastISel11FastEmit_rrEN4llvm3MVTES2_jjbjb", "(anonymous namespace)::X86FastISel::FastEmit_rr(llvm::MVT, llvm::MVT, unsigned int, unsigned int, bool, unsigned int, bool)"},
    {"_ZN12_GLOBAL__N_111X86FastISel11FastEmit_riEN4llvm3MVTES2_jjby", "(anonymous namespace)::X86FastISel::FastEmit_ri(llvm::MVT, llvm::MVT, unsigned int, unsigned int, bool, unsigned long long)"},
    {"_ZN12_GLOBAL__N_111X86FastISel10FastEmit_iEN4llvm3MVTES2_jy", "(anonymous namespace)::X86FastISel::FastEmit_i(llvm::MVT, llvm::MVT, unsigned int, unsigned long long)"},
    {"_ZN12_GLOBAL__N_111X86FastISel25TargetMaterializeConstantEPKN4llvm8ConstantE", "(anonymous namespace)::X86FastISel::TargetMaterializeConstant(llvm::Constant const*)"},
    {"_ZN12_GLOBAL__N_111X86FastISel23TargetMaterializeAllocaEPKN4llvm10AllocaInstE", "(anonymous namespace)::X86FastISel::TargetMaterializeAlloca(llvm::AllocaInst const*)"},
    {"_ZN12_GLOBAL__N_111X86FastISel16X86SelectAddressEPKN4llvm5ValueERNS1_14X86AddressModeE", "(anonymous namespace)::X86FastISel::X86SelectAddress(llvm::Value const*, llvm::X86AddressMode&)"},
    {"_ZN4llvm14addFullAddressERKNS_19MachineInstrBuilderERKNS_14X86AddressModeE", "llvm::addFullAddress(llvm::MachineInstrBuilder const&, llvm::X86AddressMode const&)"},
    {"_ZN12_GLOBAL__N_111X86FastISel13X86SelectZExtEPKN4llvm11InstructionE", "(anonymous namespace)::X86FastISel::X86SelectZExt(llvm::Instruction const*)"},
    {"_ZN12_GLOBAL__N_111X86FastISel14X86SelectTruncEPKN4llvm11InstructionE", "(anonymous namespace)::X86FastISel::X86SelectTrunc(llvm::Instruction const*)"},
    {"_Z6CC_X86jN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_X86(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZN12_GLOBAL__N_111X86FastISel16X86FastEmitStoreEN4llvm3EVTEPKNS1_5ValueERKNS1_14X86AddressModeE", "(anonymous namespace)::X86FastISel::X86FastEmitStore(llvm::EVT, llvm::Value const*, llvm::X86AddressMode const&)"},
    {"_ZN12_GLOBAL__N_111X86FastISel16X86FastEmitStoreEN4llvm3EVTEjRKNS1_14X86AddressModeE", "(anonymous namespace)::X86FastISel::X86FastEmitStore(llvm::EVT, unsigned int, llvm::X86AddressMode const&)"},
    {"_Z9RetCC_X86jN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_X86(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZN4llvm17addFrameReferenceERKNS_19MachineInstrBuilderEii", "llvm::addFrameReference(llvm::MachineInstrBuilder const&, int, int)"},
    {"_Z15RetCC_X86CommonjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_X86Common(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z14RetCC_X86_64_CjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_X86_64_C(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z16CC_X86_32_CommonjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_X86_32_Common(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZN12_GLOBAL__N_111X86FastISel18X86FastEmitCompareEPKN4llvm5ValueES4_NS1_3EVTE", "(anonymous namespace)::X86FastISel::X86FastEmitCompare(llvm::Value const*, llvm::Value const*, llvm::EVT)"},
    {"_ZN4llvm14X86AddressMode14getFullAddressERNS_15SmallVectorImplINS_14MachineOperandEEE", "llvm::X86AddressMode::getFullAddress(llvm::SmallVectorImpl<llvm::MachineOperand>&)"},
    {"_ZN4llvm36createX86FloatingPointStackifierPassEv", "llvm::createX86FloatingPointStackifierPass()"},
    {"_ZN12_GLOBAL__N_13FPSD1Ev", "(anonymous namespace)::FPS::~FPS()"},
    {"_ZN12_GLOBAL__N_13FPSD0Ev", "(anonymous namespace)::FPS::~FPS()"},
    {"_ZNK12_GLOBAL__N_13FPS11getPassNameEv", "(anonymous namespace)::FPS::getPassName() const"},
    {"_ZNK12_GLOBAL__N_13FPS16getAnalysisUsageERN4llvm13AnalysisUsageE", "(anonymous namespace)::FPS::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_13FPS20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::FPS::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN12_GLOBAL__N_13FPS17processBasicBlockERN4llvm15MachineFunctionERNS1_17MachineBasicBlockE", "(anonymous namespace)::FPS::processBasicBlock(llvm::MachineFunction&, llvm::MachineBasicBlock&)"},
    {"_ZN12_GLOBAL__N_13FPS14adjustLiveRegsEjN4llvm14ilist_iteratorINS1_12MachineInstrEEE", "(anonymous namespace)::FPS::adjustLiveRegs(unsigned int, llvm::ilist_iterator<llvm::MachineInstr>)"},
    {"_ZN12_GLOBAL__N_13FPS9moveToTopEjN4llvm14ilist_iteratorINS1_12MachineInstrEEE", "(anonymous namespace)::FPS::moveToTop(unsigned int, llvm::ilist_iterator<llvm::MachineInstr>)"},
    {"_ZN12_GLOBAL__N_13FPS13popStackAfterERN4llvm14ilist_iteratorINS1_12MachineInstrEEE", "(anonymous namespace)::FPS::popStackAfter(llvm::ilist_iterator<llvm::MachineInstr>&)"},
    {"_ZN12_GLOBAL__N_13FPS19freeStackSlotBeforeEN4llvm14ilist_iteratorINS1_12MachineInstrEEEj", "(anonymous namespace)::FPS::freeStackSlotBefore(llvm::ilist_iterator<llvm::MachineInstr>, unsigned int)"},
    {"_ZN12_GLOBAL__N_13FPS14duplicateToTopEjjPN4llvm12MachineInstrE", "(anonymous namespace)::FPS::duplicateToTop(unsigned int, unsigned int, llvm::MachineInstr*)"},
    {"_ZN4llvm12df_ext_beginIPNS_17MachineBasicBlockENS_11SmallPtrSetIS2_Lj8EEEEENS_15df_ext_iteratorIT_T0_EERKS6_RS7_", "llvm::df_ext_iterator<llvm::MachineBasicBlock*, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 8u>> llvm::df_ext_begin<llvm::MachineBasicBlock*, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 8u>>(llvm::MachineBasicBlock* const&, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 8u>&)"},
    {"_ZN4llvm11df_iteratorIPNS_17MachineBasicBlockENS_11SmallPtrSetIS2_Lj8EEELb1ENS_11GraphTraitsIS2_EEE6toNextEv", "llvm::df_iterator<llvm::MachineBasicBlock*, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 8u>, true, llvm::GraphTraits<llvm::MachineBasicBlock*>>::toNext()"},
    {"_ZN4llvm11df_iteratorIPNS_17MachineBasicBlockENS_11SmallPtrSetIS2_Lj8EEELb1ENS_11GraphTraitsIS2_EEEC2ES2_RS4_", "llvm::df_iterator<llvm::MachineBasicBlock*, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 8u>, true, llvm::GraphTraits<llvm::MachineBasicBlock*>>::df_iterator(llvm::MachineBasicBlock*, llvm::SmallPtrSet<llvm::MachineBasicBlock*, 8u>&)"},
    {"_ZNK4llvm16X86FrameLowering20hasReservedCallFrameERKNS_15MachineFunctionE", "llvm::X86FrameLowering::hasReservedCallFrame(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm16X86FrameLowering5hasFPERKNS_15MachineFunctionE", "llvm::X86FrameLowering::hasFP(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm16X86FrameLowering25emitCalleeSavedFrameMovesERNS_15MachineFunctionEPNS_8MCSymbolEj", "llvm::X86FrameLowering::emitCalleeSavedFrameMoves(llvm::MachineFunction&, llvm::MCSymbol*, unsigned int) const"},
    {"_ZNK4llvm16X86FrameLowering12emitPrologueERNS_15MachineFunctionE", "llvm::X86FrameLowering::emitPrologue(llvm::MachineFunction&) const"},
    {"_Z14mergeSPUpdatesRN4llvm17MachineBasicBlockERNS_14ilist_iteratorINS_12MachineInstrEEEjb", "mergeSPUpdates(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>&, unsigned int, bool)"},
    {"_Z12emitSPUpdateRN4llvm17MachineBasicBlockERNS_14ilist_iteratorINS_12MachineInstrEEEjxbRKNS_15TargetInstrInfoERKNS_18TargetRegisterInfoE", "emitSPUpdate(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>&, unsigned int, long long, bool, llvm::TargetInstrInfo const&, llvm::TargetRegisterInfo const&)"},
    {"_ZNK4llvm16X86FrameLowering12emitEpilogueERNS_15MachineFunctionERNS_17MachineBasicBlockE", "llvm::X86FrameLowering::emitEpilogue(llvm::MachineFunction&, llvm::MachineBasicBlock&) const"},
    {"_ZNK4llvm16X86FrameLowering20getInitialFrameStateERSt6vectorINS_11MachineMoveESaIS2_EE", "llvm::X86FrameLowering::getInitialFrameState(std::vector<llvm::MachineMove, std::allocator<llvm::MachineMove>>&) const"},
    {"_ZNK4llvm16X86FrameLowering19getFrameIndexOffsetERKNS_15MachineFunctionEi", "llvm::X86FrameLowering::getFrameIndexOffset(llvm::MachineFunction const&, int) const"},
    {"_ZNK4llvm16X86FrameLowering25spillCalleeSavedRegistersERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERKSt6vectorINS_15CalleeSavedInfoESaIS7_EEPKNS_18TargetRegisterInfoE", "llvm::X86FrameLowering::spillCalleeSavedRegisters(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, std::vector<llvm::CalleeSavedInfo, std::allocator<llvm::CalleeSavedInfo>> const&, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm16X86FrameLowering27restoreCalleeSavedRegistersERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERKSt6vectorINS_15CalleeSavedInfoESaIS7_EEPKNS_18TargetRegisterInfoE", "llvm::X86FrameLowering::restoreCalleeSavedRegisters(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, std::vector<llvm::CalleeSavedInfo, std::allocator<llvm::CalleeSavedInfo>> const&, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm16X86FrameLowering36processFunctionBeforeCalleeSavedScanERNS_15MachineFunctionEPNS_12RegScavengerE", "llvm::X86FrameLowering::processFunctionBeforeCalleeSavedScan(llvm::MachineFunction&, llvm::RegScavenger*) const"},
    {"_ZNK4llvm12X86Subtarget13isTargetWin32Ev", "llvm::X86Subtarget::isTargetWin32() const"},
    {"_ZNSt6vectorIN4llvm11MachineMoveESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<llvm::MachineMove, std::allocator<llvm::MachineMove>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::MachineMove*, std::vector<llvm::MachineMove, std::allocator<llvm::MachineMove>>>, llvm::MachineMove const&)"},
    {"_ZN4llvm8SmallSetIjLj8EE6insertERKj", "llvm::SmallSet<unsigned int, 8u>::insert(unsigned int const&)"},
    {"_ZN4llvm16createX86ISelDagERNS_16X86TargetMachineENS_10CodeGenOpt5LevelE", "llvm::createX86ISelDag(llvm::X86TargetMachine&, llvm::CodeGenOpt::Level)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISelD1Ev", "(anonymous namespace)::X86DAGToDAGISel::~X86DAGToDAGISel()"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISelD0Ev", "(anonymous namespace)::X86DAGToDAGISel::~X86DAGToDAGISel()"},
    {"_ZNK12_GLOBAL__N_115X86DAGToDAGISel11getPassNameEv", "(anonymous namespace)::X86DAGToDAGISel::getPassName() const"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel21EmitFunctionEntryCodeEv", "(anonymous namespace)::X86DAGToDAGISel::EmitFunctionEntryCode()"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel17PreprocessISelDAGEv", "(anonymous namespace)::X86DAGToDAGISel::PreprocessISelDAG()"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel6SelectEPN4llvm6SDNodeE", "(anonymous namespace)::X86DAGToDAGISel::Select(llvm::SDNode*)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel28SelectInlineAsmMemoryOperandERKN4llvm7SDValueEcRSt6vectorIS2_SaIS2_EE", "(anonymous namespace)::X86DAGToDAGISel::SelectInlineAsmMemoryOperand(llvm::SDValue const&, char, std::vector<llvm::SDValue, std::allocator<llvm::SDValue>>&)"},
    {"_ZNK12_GLOBAL__N_115X86DAGToDAGISel18IsProfitableToFoldEN4llvm7SDValueEPNS1_6SDNodeES4_", "(anonymous namespace)::X86DAGToDAGISel::IsProfitableToFold(llvm::SDValue, llvm::SDNode*, llvm::SDNode*) const"},
    {"_ZNK12_GLOBAL__N_115X86DAGToDAGISel21CheckPatternPredicateEj", "(anonymous namespace)::X86DAGToDAGISel::CheckPatternPredicate(unsigned int) const"},
    {"_ZNK12_GLOBAL__N_115X86DAGToDAGISel18CheckNodePredicateEPN4llvm6SDNodeEj", "(anonymous namespace)::X86DAGToDAGISel::CheckNodePredicate(llvm::SDNode*, unsigned int) const"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel19CheckComplexPatternEPN4llvm6SDNodeES3_NS1_7SDValueEjRNS1_15SmallVectorImplISt4pairIS4_S3_EEE", "(anonymous namespace)::X86DAGToDAGISel::CheckComplexPattern(llvm::SDNode*, llvm::SDNode*, llvm::SDValue, unsigned int, llvm::SmallVectorImpl<std::pair<llvm::SDValue, llvm::SDNode*>>&)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel14RunSDNodeXFormEN4llvm7SDValueEj", "(anonymous namespace)::X86DAGToDAGISel::RunSDNodeXForm(llvm::SDValue, unsigned int)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel10SelectAddrEPN4llvm6SDNodeENS1_7SDValueERS4_S5_S5_S5_S5_", "(anonymous namespace)::X86DAGToDAGISel::SelectAddr(llvm::SDNode*, llvm::SDValue, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel19SelectScalarSSELoadEPN4llvm6SDNodeENS1_7SDValueERS4_S5_S5_S5_S5_S5_", "(anonymous namespace)::X86DAGToDAGISel::SelectScalarSSELoad(llvm::SDNode*, llvm::SDValue, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel13SelectLEAAddrEN4llvm7SDValueERS2_S3_S3_S3_S3_", "(anonymous namespace)::X86DAGToDAGISel::SelectLEAAddr(llvm::SDValue, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel17SelectTLSADDRAddrEN4llvm7SDValueERS2_S3_S3_S3_S3_", "(anonymous namespace)::X86DAGToDAGISel::SelectTLSADDRAddr(llvm::SDValue, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel18getAddressOperandsERNS_18X86ISelAddressModeERN4llvm7SDValueES5_S5_S5_S5_", "(anonymous namespace)::X86DAGToDAGISel::getAddressOperands((anonymous namespace)::X86ISelAddressMode&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel12MatchAddressEN4llvm7SDValueERNS_18X86ISelAddressModeE", "(anonymous namespace)::X86DAGToDAGISel::MatchAddress(llvm::SDValue, (anonymous namespace)::X86ISelAddressMode&)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel23MatchAddressRecursivelyEN4llvm7SDValueERNS_18X86ISelAddressModeEj", "(anonymous namespace)::X86DAGToDAGISel::MatchAddressRecursively(llvm::SDValue, (anonymous namespace)::X86ISelAddressMode&, unsigned int)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel14SelectAtomic64EPN4llvm6SDNodeEj", "(anonymous namespace)::X86DAGToDAGISel::SelectAtomic64(llvm::SDNode*, unsigned int)"},
    {"_ZN12_GLOBAL__N_115X86DAGToDAGISel11TryFoldLoadEPN4llvm6SDNodeENS1_7SDValueERS4_S5_S5_S5_S5_", "(anonymous namespace)::X86DAGToDAGISel::TryFoldLoad(llvm::SDNode*, llvm::SDValue, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN4llvm17X86TargetLoweringC1ERNS_16X86TargetMachineE", "llvm::X86TargetLowering::X86TargetLowering(llvm::X86TargetMachine&)"},
    {"_ZN4llvm17X86TargetLoweringC2ERNS_16X86TargetMachineE", "llvm::X86TargetLowering::X86TargetLowering(llvm::X86TargetMachine&)"},
    {"_ZNK4llvm17X86TargetLowering18getSetCCResultTypeENS_3EVTE", "llvm::X86TargetLowering::getSetCCResultType(llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering21getByValTypeAlignmentEPKNS_4TypeE", "llvm::X86TargetLowering::getByValTypeAlignment(llvm::Type const*) const"},
    {"_Z16getMaxByValAlignPKN4llvm4TypeERj", "getMaxByValAlign(llvm::Type const*, unsigned int&)"},
    {"_ZNK4llvm17X86TargetLowering19getOptimalMemOpTypeEyjjbbRNS_15MachineFunctionE", "llvm::X86TargetLowering::getOptimalMemOpType(unsigned long long, unsigned int, unsigned int, bool, bool, llvm::MachineFunction&) const"},
    {"_ZNK4llvm17X86TargetLowering20getJumpTableEncodingEv", "llvm::X86TargetLowering::getJumpTableEncoding() const"},
    {"_ZNK4llvm17X86TargetLowering25LowerCustomJumpTableEntryEPKNS_20MachineJumpTableInfoEPKNS_17MachineBasicBlockEjRNS_9MCContextE", "llvm::X86TargetLowering::LowerCustomJumpTableEntry(llvm::MachineJumpTableInfo const*, llvm::MachineBasicBlock const*, unsigned int, llvm::MCContext&) const"},
    {"_ZNK4llvm17X86TargetLowering24getPICJumpTableRelocBaseENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::getPICJumpTableRelocBase(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering28getPICJumpTableRelocBaseExprEPKNS_15MachineFunctionEjRNS_9MCContextE", "llvm::X86TargetLowering::getPICJumpTableRelocBaseExpr(llvm::MachineFunction const*, unsigned int, llvm::MCContext&) const"},
    {"_ZNK4llvm17X86TargetLowering20getFunctionAlignmentEPKNS_8FunctionE", "llvm::X86TargetLowering::getFunctionAlignment(llvm::Function const*) const"},
    {"_ZNK4llvm17X86TargetLowering23findRepresentativeClassENS_3EVTE", "llvm::X86TargetLowering::findRepresentativeClass(llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering19getRegPressureLimitEPKNS_19TargetRegisterClassERNS_15MachineFunctionE", "llvm::X86TargetLowering::getRegPressureLimit(llvm::TargetRegisterClass const*, llvm::MachineFunction&) const"},
    {"_ZNK4llvm17X86TargetLowering22getStackCookieLocationERjS1_", "llvm::X86TargetLowering::getStackCookieLocation(unsigned int&, unsigned int&) const"},
    {"_ZNK4llvm17X86TargetLowering14CanLowerReturnENS_11CallingConv2IDEbRKNS_15SmallVectorImplINS_3ISD9OutputArgEEERNS_11LLVMContextE", "llvm::X86TargetLowering::CanLowerReturn(llvm::CallingConv::ID, bool, llvm::SmallVectorImpl<llvm::ISD::OutputArg> const&, llvm::LLVMContext&) const"},
    {"_Z9RetCC_X86jN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_X86(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZNK4llvm17X86TargetLowering11LowerReturnENS_7SDValueENS_11CallingConv2IDEbRKNS_15SmallVectorImplINS_3ISD9OutputArgEEERKNS4_IS1_EENS_8DebugLocERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerReturn(llvm::SDValue, llvm::CallingConv::ID, bool, llvm::SmallVectorImpl<llvm::ISD::OutputArg> const&, llvm::SmallVectorImpl<llvm::SDValue> const&, llvm::DebugLoc, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering18isUsedByReturnOnlyEPNS_6SDNodeE", "llvm::X86TargetLowering::isUsedByReturnOnly(llvm::SDNode*) const"},
    {"_ZNK4llvm17X86TargetLowering15LowerCallResultENS_7SDValueES1_NS_11CallingConv2IDEbRKNS_15SmallVectorImplINS_3ISD8InputArgEEENS_8DebugLocERNS_12SelectionDAGERNS4_IS1_EE", "llvm::X86TargetLowering::LowerCallResult(llvm::SDValue, llvm::SDValue, llvm::CallingConv::ID, bool, llvm::SmallVectorImpl<llvm::ISD::InputArg> const&, llvm::DebugLoc, llvm::SelectionDAG&, llvm::SmallVectorImpl<llvm::SDValue>&) const"},
    {"_ZNK4llvm17X86TargetLowering16LowerMemArgumentENS_7SDValueENS_11CallingConv2IDERKNS_15SmallVectorImplINS_3ISD8InputArgEEENS_8DebugLocERNS_12SelectionDAGERKNS_11CCValAssignEPNS_16MachineFrameInfoEj", "llvm::X86TargetLowering::LowerMemArgument(llvm::SDValue, llvm::CallingConv::ID, llvm::SmallVectorImpl<llvm::ISD::InputArg> const&, llvm::DebugLoc, llvm::SelectionDAG&, llvm::CCValAssign const&, llvm::MachineFrameInfo*, unsigned int) const"},
    {"_ZNK4llvm17X86TargetLowering20LowerFormalArgumentsENS_7SDValueENS_11CallingConv2IDEbRKNS_15SmallVectorImplINS_3ISD8InputArgEEENS_8DebugLocERNS_12SelectionDAGERNS4_IS1_EE", "llvm::X86TargetLowering::LowerFormalArguments(llvm::SDValue, llvm::CallingConv::ID, bool, llvm::SmallVectorImpl<llvm::ISD::InputArg> const&, llvm::DebugLoc, llvm::SelectionDAG&, llvm::SmallVectorImpl<llvm::SDValue>&) const"},
    {"_Z6CC_X86jN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_X86(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZNK4llvm17X86TargetLowering27GetAlignedArgumentStackSizeEjRNS_12SelectionDAGE", "llvm::X86TargetLowering::GetAlignedArgumentStackSize(unsigned int, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering16LowerMemOpCallToENS_7SDValueES1_S1_NS_8DebugLocERNS_12SelectionDAGERKNS_11CCValAssignENS_3ISD10ArgFlagsTyE", "llvm::X86TargetLowering::LowerMemOpCallTo(llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::DebugLoc, llvm::SelectionDAG&, llvm::CCValAssign const&, llvm::ISD::ArgFlagsTy) const"},
    {"_ZNK4llvm17X86TargetLowering23EmitTailCallLoadRetAddrERNS_12SelectionDAGERNS_7SDValueES3_bbiNS_8DebugLocE", "llvm::X86TargetLowering::EmitTailCallLoadRetAddr(llvm::SelectionDAG&, llvm::SDValue&, llvm::SDValue, bool, bool, int, llvm::DebugLoc) const"},
    {"_ZNK4llvm17X86TargetLowering26getReturnAddressFrameIndexERNS_12SelectionDAGE", "llvm::X86TargetLowering::getReturnAddressFrameIndex(llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering9LowerCallENS_7SDValueES1_NS_11CallingConv2IDEbRbRKNS_15SmallVectorImplINS_3ISD9OutputArgEEERKNS5_IS1_EERKNS5_INS6_8InputArgEEENS_8DebugLocERNS_12SelectionDAGERSB_", "llvm::X86TargetLowering::LowerCall(llvm::SDValue, llvm::SDValue, llvm::CallingConv::ID, bool, bool&, llvm::SmallVectorImpl<llvm::ISD::OutputArg> const&, llvm::SmallVectorImpl<llvm::SDValue> const&, llvm::SmallVectorImpl<llvm::ISD::InputArg> const&, llvm::DebugLoc, llvm::SelectionDAG&, llvm::SmallVectorImpl<llvm::SDValue>&) const"},
    {"_ZNK4llvm17X86TargetLowering33IsEligibleForTailCallOptimizationENS_7SDValueENS_11CallingConv2IDEbbbRKNS_15SmallVectorImplINS_3ISD9OutputArgEEERKNS4_IS1_EERKNS4_INS5_8InputArgEEERNS_12SelectionDAGE", "llvm::X86TargetLowering::IsEligibleForTailCallOptimization(llvm::SDValue, llvm::CallingConv::ID, bool, bool, bool, llvm::SmallVectorImpl<llvm::ISD::OutputArg> const&, llvm::SmallVectorImpl<llvm::SDValue> const&, llvm::SmallVectorImpl<llvm::ISD::InputArg> const&, llvm::SelectionDAG&) const"},
    {"_Z7getMOVLRN4llvm12SelectionDAGENS_8DebugLocENS_3EVTENS_7SDValueES4_", "getMOVL(llvm::SelectionDAG&, llvm::DebugLoc, llvm::EVT, llvm::SDValue, llvm::SDValue)"},
    {"_ZNK4llvm17X86TargetLowering18LowerGlobalAddressENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerGlobalAddress(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering19LowerExternalSymbolENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerExternalSymbol(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering14createFastISelERNS_20FunctionLoweringInfoE", "llvm::X86TargetLowering::createFastISel(llvm::FunctionLoweringInfo&) const"},
    {"_ZN4llvm3X8628isOffsetSuitableForCodeModelExNS_9CodeModel5ModelEb", "llvm::X86::isOffsetSuitableForCodeModel(long long, llvm::CodeModel::Model, bool)"},
    {"_ZNK4llvm17X86TargetLowering12isFPImmLegalERKNS_7APFloatENS_3EVTE", "llvm::X86TargetLowering::isFPImmLegal(llvm::APFloat const&, llvm::EVT) const"},
    {"_ZN4llvm3X8612isPSHUFDMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isPSHUFDMask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8613isPSHUFHWMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isPSHUFHWMask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8613isPSHUFLWMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isPSHUFLWMask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8613isPALIGNRMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isPALIGNRMask(llvm::ShuffleVectorSDNode*)"},
    {"_Z13isPALIGNRMaskRKN4llvm15SmallVectorImplIiEENS_3EVTEb", "isPALIGNRMask(llvm::SmallVectorImpl<int> const&, llvm::EVT, bool)"},
    {"_ZN4llvm3X8611isSHUFPMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isSHUFPMask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8613isMOVHLPSMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isMOVHLPSMask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8622isMOVHLPS_v_undef_MaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isMOVHLPS_v_undef_Mask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8611isMOVLPMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isMOVLPMask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8613isMOVLHPSMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isMOVLHPSMask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8612isUNPCKLMaskEPNS_19ShuffleVectorSDNodeEb", "llvm::X86::isUNPCKLMask(llvm::ShuffleVectorSDNode*, bool)"},
    {"_ZN4llvm3X8612isUNPCKHMaskEPNS_19ShuffleVectorSDNodeEb", "llvm::X86::isUNPCKHMask(llvm::ShuffleVectorSDNode*, bool)"},
    {"_ZN4llvm3X8621isUNPCKL_v_undef_MaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isUNPCKL_v_undef_Mask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8621isUNPCKH_v_undef_MaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isUNPCKH_v_undef_Mask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8610isMOVLMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isMOVLMask(llvm::ShuffleVectorSDNode*)"},
    {"_Z10isMOVLMaskRKN4llvm15SmallVectorImplIiEENS_3EVTE", "isMOVLMask(llvm::SmallVectorImpl<int> const&, llvm::EVT)"},
    {"_ZN4llvm3X8614isMOVSHDUPMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isMOVSHDUPMask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8614isMOVSLDUPMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isMOVSLDUPMask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8613isMOVDDUPMaskEPNS_19ShuffleVectorSDNodeE", "llvm::X86::isMOVDDUPMask(llvm::ShuffleVectorSDNode*)"},
    {"_ZN4llvm3X8619isVEXTRACTF128IndexEPNS_6SDNodeE", "llvm::X86::isVEXTRACTF128Index(llvm::SDNode*)"},
    {"_ZN4llvm3X8618isVINSERTF128IndexEPNS_6SDNodeE", "llvm::X86::isVINSERTF128Index(llvm::SDNode*)"},
    {"_ZN4llvm3X8623getShuffleSHUFImmediateEPNS_6SDNodeE", "llvm::X86::getShuffleSHUFImmediate(llvm::SDNode*)"},
    {"_ZN4llvm3X8626getShufflePSHUFHWImmediateEPNS_6SDNodeE", "llvm::X86::getShufflePSHUFHWImmediate(llvm::SDNode*)"},
    {"_ZN4llvm3X8626getShufflePSHUFLWImmediateEPNS_6SDNodeE", "llvm::X86::getShufflePSHUFLWImmediate(llvm::SDNode*)"},
    {"_ZN4llvm3X8626getShufflePALIGNRImmediateEPNS_6SDNodeE", "llvm::X86::getShufflePALIGNRImmediate(llvm::SDNode*)"},
    {"_ZN4llvm3X8631getExtractVEXTRACTF128ImmediateEPNS_6SDNodeE", "llvm::X86::getExtractVEXTRACTF128Immediate(llvm::SDNode*)"},
    {"_ZN4llvm3X8629getInsertVINSERTF128ImmediateEPNS_6SDNodeE", "llvm::X86::getInsertVINSERTF128Immediate(llvm::SDNode*)"},
    {"_ZN4llvm3X8610isZeroNodeENS_7SDValueE", "llvm::X86::isZeroNode(llvm::SDValue)"},
    {"_Z19getShuffleScalarEltPN4llvm6SDNodeEiRNS_12SelectionDAGEj", "getShuffleScalarElt(llvm::SDNode*, int, llvm::SelectionDAG&, unsigned int)"},
    {"_ZNK4llvm17X86TargetLowering22LowerAsSplatVectorLoadENS_7SDValueENS_3EVTENS_8DebugLocERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerAsSplatVectorLoad(llvm::SDValue, llvm::EVT, llvm::DebugLoc, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering17LowerBUILD_VECTORENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerBUILD_VECTOR(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_Z13getZeroVectorN4llvm3EVTEbRNS_12SelectionDAGENS_8DebugLocE", "getZeroVector(llvm::EVT, bool, llvm::SelectionDAG&, llvm::DebugLoc)"},
    {"_Z27getShuffleVectorZeroOrUndefN4llvm7SDValueEjbbRNS_12SelectionDAGE", "getShuffleVectorZeroOrUndef(llvm::SDValue, unsigned int, bool, bool, llvm::SelectionDAG&)"},
    {"_Z10getUnpacklRN4llvm12SelectionDAGENS_8DebugLocENS_3EVTENS_7SDValueES4_", "getUnpackl(llvm::SelectionDAG&, llvm::DebugLoc, llvm::EVT, llvm::SDValue, llvm::SDValue)"},
    {"_Z24EltsFromConsecutiveLoadsN4llvm3EVTERNS_15SmallVectorImplINS_7SDValueEEERNS_8DebugLocERNS_12SelectionDAGE", "EltsFromConsecutiveLoads(llvm::EVT, llvm::SmallVectorImpl<llvm::SDValue>&, llvm::DebugLoc&, llvm::SelectionDAG&)"},
    {"_ZNK4llvm17X86TargetLowering19LowerCONCAT_VECTORSENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerCONCAT_VECTORS(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering24LowerVECTOR_SHUFFLEv8i16ENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerVECTOR_SHUFFLEv8i16(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering19LowerVECTOR_SHUFFLEENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerVECTOR_SHUFFLE(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_Z12getVZextMovLN4llvm3EVTES0_NS_7SDValueERNS_12SelectionDAGEPKNS_12X86SubtargetENS_8DebugLocE", "getVZextMovL(llvm::EVT, llvm::EVT, llvm::SDValue, llvm::SelectionDAG&, llvm::X86Subtarget const*, llvm::DebugLoc)"},
    {"_Z20CommuteVectorShufflePN4llvm19ShuffleVectorSDNodeERNS_12SelectionDAGE", "CommuteVectorShuffle(llvm::ShuffleVectorSDNode*, llvm::SelectionDAG&)"},
    {"_ZNK4llvm17X86TargetLowering28LowerEXTRACT_VECTOR_ELT_SSE4ENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerEXTRACT_VECTOR_ELT_SSE4(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering23LowerEXTRACT_VECTOR_ELTENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerEXTRACT_VECTOR_ELT(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering27LowerINSERT_VECTOR_ELT_SSE4ENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerINSERT_VECTOR_ELT_SSE4(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering22LowerINSERT_VECTOR_ELTENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerINSERT_VECTOR_ELT(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_Z19Extract128BitVectorN4llvm7SDValueES0_RNS_12SelectionDAGENS_8DebugLocE", "Extract128BitVector(llvm::SDValue, llvm::SDValue, llvm::SelectionDAG&, llvm::DebugLoc)"},
    {"_Z18Insert128BitVectorN4llvm7SDValueES0_S0_RNS_12SelectionDAGENS_8DebugLocE", "Insert128BitVector(llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::SelectionDAG&, llvm::DebugLoc)"},
    {"_ZNK4llvm17X86TargetLowering21LowerSCALAR_TO_VECTORENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerSCALAR_TO_VECTOR(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering22LowerEXTRACT_SUBVECTORENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerEXTRACT_SUBVECTOR(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering21LowerINSERT_SUBVECTORENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerINSERT_SUBVECTOR(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering17LowerConstantPoolENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerConstantPool(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering14LowerJumpTableENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerJumpTable(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering17LowerBlockAddressENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerBlockAddress(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering18LowerGlobalAddressEPKNS_11GlobalValueENS_8DebugLocExRNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerGlobalAddress(llvm::GlobalValue const*, llvm::DebugLoc, long long, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering21LowerGlobalTLSAddressENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerGlobalTLSAddress(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering10LowerShiftENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerShift(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering15LowerSINT_TO_FPENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerSINT_TO_FP(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering9BuildFILDENS_7SDValueENS_3EVTES1_S1_RNS_12SelectionDAGE", "llvm::X86TargetLowering::BuildFILD(llvm::SDValue, llvm::EVT, llvm::SDValue, llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering19LowerUINT_TO_FP_i64ENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerUINT_TO_FP_i64(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering19LowerUINT_TO_FP_i32ENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerUINT_TO_FP_i32(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering15LowerUINT_TO_FPENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerUINT_TO_FP(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering15FP_TO_INTHelperENS_7SDValueERNS_12SelectionDAGEb", "llvm::X86TargetLowering::FP_TO_INTHelper(llvm::SDValue, llvm::SelectionDAG&, bool) const"},
    {"_ZNK4llvm17X86TargetLowering15LowerFP_TO_SINTENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerFP_TO_SINT(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering15LowerFP_TO_UINTENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerFP_TO_UINT(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering9LowerFABSENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerFABS(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering9LowerFNEGENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerFNEG(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering14LowerFCOPYSIGNENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerFCOPYSIGN(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering8EmitTestENS_7SDValueEjRNS_12SelectionDAGE", "llvm::X86TargetLowering::EmitTest(llvm::SDValue, unsigned int, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering7EmitCmpENS_7SDValueES1_jRNS_12SelectionDAGE", "llvm::X86TargetLowering::EmitCmp(llvm::SDValue, llvm::SDValue, unsigned int, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering9LowerToBTENS_7SDValueENS_3ISD8CondCodeENS_8DebugLocERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerToBT(llvm::SDValue, llvm::ISD::CondCode, llvm::DebugLoc, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering10LowerSETCCENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerSETCC(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_Z14TranslateX86CCN4llvm3ISD8CondCodeEbRNS_7SDValueES3_RNS_12SelectionDAGE", "TranslateX86CC(llvm::ISD::CondCode, bool, llvm::SDValue&, llvm::SDValue&, llvm::SelectionDAG&)"},
    {"_ZNK4llvm17X86TargetLowering11LowerVSETCCENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerVSETCC(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering11LowerSELECTENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerSELECT(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering11LowerBRCONDENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerBRCOND(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering23LowerDYNAMIC_STACKALLOCENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerDYNAMIC_STACKALLOC(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering12LowerVASTARTENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerVASTART(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering10LowerVAARGENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerVAARG(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering11LowerVACOPYENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerVACOPY(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering23LowerINTRINSIC_WO_CHAINENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerINTRINSIC_WO_CHAIN(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering15LowerRETURNADDRENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerRETURNADDR(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering14LowerFRAMEADDRENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerFRAMEADDR(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering25LowerFRAME_TO_ARGS_OFFSETENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerFRAME_TO_ARGS_OFFSET(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering14LowerEH_RETURNENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerEH_RETURN(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering15LowerTRAMPOLINEENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerTRAMPOLINE(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering16LowerFLT_ROUNDS_ENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerFLT_ROUNDS_(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering9LowerCTLZENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerCTLZ(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering9LowerCTTZENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerCTTZ(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering14LowerMUL_V2I64ENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerMUL_V2I64(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering8LowerSHLENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerSHL(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering10LowerXALUOENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerXALUO(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering15LowerMEMBARRIERENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerMEMBARRIER(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering13LowerCMP_SWAPENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerCMP_SWAP(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering21LowerREADCYCLECOUNTERENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerREADCYCLECOUNTER(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering12LowerBITCASTENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerBITCAST(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering13LowerLOAD_SUBENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerLOAD_SUB(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering14LowerOperationENS_7SDValueERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerOperation(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering23ReplaceATOMIC_BINARY_64EPNS_6SDNodeERNS_15SmallVectorImplINS_7SDValueEEERNS_12SelectionDAGEj", "llvm::X86TargetLowering::ReplaceATOMIC_BINARY_64(llvm::SDNode*, llvm::SmallVectorImpl<llvm::SDValue>&, llvm::SelectionDAG&, unsigned int) const"},
    {"_ZNK4llvm17X86TargetLowering18ReplaceNodeResultsEPNS_6SDNodeERNS_15SmallVectorImplINS_7SDValueEEERNS_12SelectionDAGE", "llvm::X86TargetLowering::ReplaceNodeResults(llvm::SDNode*, llvm::SmallVectorImpl<llvm::SDValue>&, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering17getTargetNodeNameEj", "llvm::X86TargetLowering::getTargetNodeName(unsigned int) const"},
    {"_ZNK4llvm17X86TargetLowering21isLegalAddressingModeERKNS_14TargetLowering8AddrModeEPKNS_4TypeE", "llvm::X86TargetLowering::isLegalAddressingMode(llvm::TargetLowering::AddrMode const&, llvm::Type const*) const"},
    {"_ZNK4llvm17X86TargetLowering14isTruncateFreeEPKNS_4TypeES3_", "llvm::X86TargetLowering::isTruncateFree(llvm::Type const*, llvm::Type const*) const"},
    {"_ZNK4llvm17X86TargetLowering14isTruncateFreeENS_3EVTES1_", "llvm::X86TargetLowering::isTruncateFree(llvm::EVT, llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering10isZExtFreeEPKNS_4TypeES3_", "llvm::X86TargetLowering::isZExtFree(llvm::Type const*, llvm::Type const*) const"},
    {"_ZNK4llvm17X86TargetLowering10isZExtFreeENS_3EVTES1_", "llvm::X86TargetLowering::isZExtFree(llvm::EVT, llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering21isNarrowingProfitableENS_3EVTES1_", "llvm::X86TargetLowering::isNarrowingProfitable(llvm::EVT, llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering18isShuffleMaskLegalERKNS_15SmallVectorImplIiEENS_3EVTE", "llvm::X86TargetLowering::isShuffleMaskLegal(llvm::SmallVectorImpl<int> const&, llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering22isVectorClearMaskLegalERKNS_15SmallVectorImplIiEENS_3EVTE", "llvm::X86TargetLowering::isVectorClearMaskLegal(llvm::SmallVectorImpl<int> const&, llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering35EmitAtomicBitwiseWithCustomInserterEPNS_12MachineInstrEPNS_17MachineBasicBlockEjjjjjjPNS_19TargetRegisterClassEb", "llvm::X86TargetLowering::EmitAtomicBitwiseWithCustomInserter(llvm::MachineInstr*, llvm::MachineBasicBlock*, unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, llvm::TargetRegisterClass*, bool) const"},
    {"_ZNK4llvm17X86TargetLowering35EmitAtomicBit6432WithCustomInserterEPNS_12MachineInstrEPNS_17MachineBasicBlockEjjjjb", "llvm::X86TargetLowering::EmitAtomicBit6432WithCustomInserter(llvm::MachineInstr*, llvm::MachineBasicBlock*, unsigned int, unsigned int, unsigned int, unsigned int, bool) const"},
    {"_ZNK4llvm17X86TargetLowering34EmitAtomicMinMaxWithCustomInserterEPNS_12MachineInstrEPNS_17MachineBasicBlockEj", "llvm::X86TargetLowering::EmitAtomicMinMaxWithCustomInserter(llvm::MachineInstr*, llvm::MachineBasicBlock*, unsigned int) const"},
    {"_ZNK4llvm17X86TargetLowering8EmitPCMPEPNS_12MachineInstrEPNS_17MachineBasicBlockEjb", "llvm::X86TargetLowering::EmitPCMP(llvm::MachineInstr*, llvm::MachineBasicBlock*, unsigned int, bool) const"},
    {"_ZNK4llvm17X86TargetLowering11EmitMonitorEPNS_12MachineInstrEPNS_17MachineBasicBlockE", "llvm::X86TargetLowering::EmitMonitor(llvm::MachineInstr*, llvm::MachineBasicBlock*) const"},
    {"_ZNK4llvm17X86TargetLowering9EmitMwaitEPNS_12MachineInstrEPNS_17MachineBasicBlockE", "llvm::X86TargetLowering::EmitMwait(llvm::MachineInstr*, llvm::MachineBasicBlock*) const"},
    {"_ZNK4llvm17X86TargetLowering29EmitVAARG64WithCustomInserterEPNS_12MachineInstrEPNS_17MachineBasicBlockE", "llvm::X86TargetLowering::EmitVAARG64WithCustomInserter(llvm::MachineInstr*, llvm::MachineBasicBlock*) const"},
    {"_ZNK4llvm17X86TargetLowering40EmitVAStartSaveXMMRegsWithCustomInserterEPNS_12MachineInstrEPNS_17MachineBasicBlockE", "llvm::X86TargetLowering::EmitVAStartSaveXMMRegsWithCustomInserter(llvm::MachineInstr*, llvm::MachineBasicBlock*) const"},
    {"_ZNK4llvm17X86TargetLowering17EmitLoweredSelectEPNS_12MachineInstrEPNS_17MachineBasicBlockE", "llvm::X86TargetLowering::EmitLoweredSelect(llvm::MachineInstr*, llvm::MachineBasicBlock*) const"},
    {"_ZNK4llvm17X86TargetLowering20EmitLoweredWinAllocaEPNS_12MachineInstrEPNS_17MachineBasicBlockE", "llvm::X86TargetLowering::EmitLoweredWinAlloca(llvm::MachineInstr*, llvm::MachineBasicBlock*) const"},
    {"_ZNK4llvm17X86TargetLowering18EmitLoweredTLSCallEPNS_12MachineInstrEPNS_17MachineBasicBlockE", "llvm::X86TargetLowering::EmitLoweredTLSCall(llvm::MachineInstr*, llvm::MachineBasicBlock*) const"},
    {"_ZNK4llvm17X86TargetLowering27EmitInstrWithCustomInserterEPNS_12MachineInstrEPNS_17MachineBasicBlockE", "llvm::X86TargetLowering::EmitInstrWithCustomInserter(llvm::MachineInstr*, llvm::MachineBasicBlock*) const"},
    {"_ZN4llvm17addFrameReferenceERKNS_19MachineInstrBuilderEii", "llvm::addFrameReference(llvm::MachineInstrBuilder const&, int, int)"},
    {"_ZNK4llvm17X86TargetLowering30computeMaskedBitsForTargetNodeENS_7SDValueERKNS_5APIntERS2_S5_RKNS_12SelectionDAGEj", "llvm::X86TargetLowering::computeMaskedBitsForTargetNode(llvm::SDValue, llvm::APInt const&, llvm::APInt&, llvm::APInt&, llvm::SelectionDAG const&, unsigned int) const"},
    {"_ZNK4llvm17X86TargetLowering31ComputeNumSignBitsForTargetNodeENS_7SDValueEj", "llvm::X86TargetLowering::ComputeNumSignBitsForTargetNode(llvm::SDValue, unsigned int) const"},
    {"_ZNK4llvm17X86TargetLowering14isGAPlusOffsetEPNS_6SDNodeERPKNS_11GlobalValueERx", "llvm::X86TargetLowering::isGAPlusOffset(llvm::SDNode*, llvm::GlobalValue const*&, long long&) const"},
    {"_ZNK4llvm17X86TargetLowering17PerformDAGCombineEPNS_6SDNodeERNS_14TargetLowering15DAGCombinerInfoE", "llvm::X86TargetLowering::PerformDAGCombine(llvm::SDNode*, llvm::TargetLowering::DAGCombinerInfo&) const"},
    {"_ZNK4llvm17X86TargetLowering20isTypeDesirableForOpEjNS_3EVTE", "llvm::X86TargetLowering::isTypeDesirableForOp(unsigned int, llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering22IsDesirableToPromoteOpENS_7SDValueERNS_3EVTE", "llvm::X86TargetLowering::IsDesirableToPromoteOp(llvm::SDValue, llvm::EVT&) const"},
    {"_ZNK4llvm17X86TargetLowering15ExpandInlineAsmEPNS_8CallInstE", "llvm::X86TargetLowering::ExpandInlineAsm(llvm::CallInst*) const"},
    {"_ZNK4llvm17X86TargetLowering17getConstraintTypeERKSs", "llvm::X86TargetLowering::getConstraintType(std::string const&) const"},
    {"_ZNK4llvm17X86TargetLowering30getSingleConstraintMatchWeightERNS_14TargetLowering14AsmOperandInfoEPKc", "llvm::X86TargetLowering::getSingleConstraintMatchWeight(llvm::TargetLowering::AsmOperandInfo&, char const*) const"},
    {"_ZNK4llvm17X86TargetLowering16LowerXConstraintENS_3EVTE", "llvm::X86TargetLowering::LowerXConstraint(llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering28LowerAsmOperandForConstraintENS_7SDValueEcRSt6vectorIS1_SaIS1_EERNS_12SelectionDAGE", "llvm::X86TargetLowering::LowerAsmOperandForConstraint(llvm::SDValue, char, std::vector<llvm::SDValue, std::allocator<llvm::SDValue>>&, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17X86TargetLowering33getRegClassForInlineAsmConstraintERKSsNS_3EVTE", "llvm::X86TargetLowering::getRegClassForInlineAsmConstraint(std::string const&, llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering28getRegForInlineAsmConstraintERKSsNS_3EVTE", "llvm::X86TargetLowering::getRegForInlineAsmConstraint(std::string const&, llvm::EVT) const"},
    {"_Z10GetTLSADDRRN4llvm12SelectionDAGENS_7SDValueEPNS_19GlobalAddressSDNodeEPS2_NS_3EVTEjh", "GetTLSADDR(llvm::SelectionDAG&, llvm::SDValue, llvm::GlobalAddressSDNode*, llvm::SDValue*, llvm::EVT, unsigned int, unsigned char)"},
    {"_Z17MayFoldVectorLoadN4llvm7SDValueE", "MayFoldVectorLoad(llvm::SDValue)"},
    {"_Z24RewriteAsNarrowerShufflePN4llvm19ShuffleVectorSDNodeERNS_12SelectionDAGENS_8DebugLocE", "RewriteAsNarrowerShuffle(llvm::ShuffleVectorSDNode*, llvm::SelectionDAG&, llvm::DebugLoc)"},
    {"_Z16CC_X86_32_CommonjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_X86_32_Common(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z15RetCC_X86CommonjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_X86Common(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z14RetCC_X86_64_CjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_X86_64_C(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZN4llvm15SmallVectorImplINS_7SDValueEE6resizeEj", "llvm::SmallVectorImpl<llvm::SDValue>::resize(unsigned int)"},
    {"_ZN4llvm8SmallSetINS_7SDValueELj8EE6insertERKS1_", "llvm::SmallSet<llvm::SDValue, 8u>::insert(llvm::SDValue const&)"},
    {"_ZN4llvm5APInt10getBitsSetEjjj", "llvm::APInt::getBitsSet(unsigned int, unsigned int, unsigned int)"},
    {"_ZNK4llvm3EVT6bitsLTES0_", "llvm::EVT::bitsLT(llvm::EVT) const"},
    {"_ZNK4llvm19MachineInstrBuilder7addDispERKNS_14MachineOperandEx", "llvm::MachineInstrBuilder::addDisp(llvm::MachineOperand const&, long long) const"},
    {"_ZN4llvm5APInt14getHighBitsSetEjj", "llvm::APInt::getHighBitsSet(unsigned int, unsigned int)"},
    {"_ZN4llvm11SmallVectorIjLj4EEC2EjRKj", "llvm::SmallVector<unsigned int, 4u>::SmallVector(unsigned int, unsigned int const&)"},
    {"_ZNSt8_Rb_treeIN4llvm7SDValueES1_St9_IdentityIS1_ESt4lessIS1_ESaIS1_EE16_M_insert_uniqueERKS1_", "std::_Rb_tree<llvm::SDValue, llvm::SDValue, std::_Identity<llvm::SDValue>, std::less<llvm::SDValue>, std::allocator<llvm::SDValue>>::_M_insert_unique(llvm::SDValue const&)"},
    {"_ZNSt6vectorIN4llvm9InlineAsm14ConstraintInfoESaIS2_EED2Ev", "std::vector<llvm::InlineAsm::ConstraintInfo, std::allocator<llvm::InlineAsm::ConstraintInfo>>::~vector()"},
    {"_ZNSt6vectorIN4llvm9InlineAsm17SubConstraintInfoESaIS2_EED2Ev", "std::vector<llvm::InlineAsm::SubConstraintInfo, std::allocator<llvm::InlineAsm::SubConstraintInfo>>::~vector()"},
    {"_ZN4llvm5APInt13getLowBitsSetEjj", "llvm::APInt::getLowBitsSet(unsigned int, unsigned int)"},
    {"_ZNK4llvm5APIntplEy", "llvm::APInt::operator+(unsigned long long) const"},
    {"_ZN4llvm5APInt17getSignedMinValueEj", "llvm::APInt::getSignedMinValue(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplISt4pairIiiEE6resizeEj", "llvm::SmallVectorImpl<std::pair<int, int>>::resize(unsigned int)"},
    {"_ZN4llvm11SmallVectorIiLj8EEC2EjRKi", "llvm::SmallVector<int, 8u>::SmallVector(unsigned int, int const&)"},
    {"_ZNSt8_Rb_treeIN4llvm7SDValueES1_St9_IdentityIS1_ESt4lessIS1_ESaIS1_EE8_M_eraseEPSt13_Rb_tree_nodeIS1_E", "std::_Rb_tree<llvm::SDValue, llvm::SDValue, std::_Identity<llvm::SDValue>, std::less<llvm::SDValue>, std::allocator<llvm::SDValue>>::_M_erase(std::_Rb_tree_node<llvm::SDValue>*)"},
    {"_ZNSt6vectorIN4llvm7APFloatESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<llvm::APFloat, std::allocator<llvm::APFloat>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::APFloat*, std::vector<llvm::APFloat, std::allocator<llvm::APFloat>>>, llvm::APFloat const&)"},
    {"_ZN4llvm28TargetLoweringObjectFileCOFFD1Ev", "llvm::TargetLoweringObjectFileCOFF::~TargetLoweringObjectFileCOFF()"},
    {"_ZN4llvm28TargetLoweringObjectFileCOFFD0Ev", "llvm::TargetLoweringObjectFileCOFF::~TargetLoweringObjectFileCOFF()"},
    {"_ZNK4llvm28TargetLoweringObjectFileCOFF17getDrectveSectionEv", "llvm::TargetLoweringObjectFileCOFF::getDrectveSection() const"},
    {"_ZN4llvm12X86InstrInfoC1ERNS_16X86TargetMachineE", "llvm::X86InstrInfo::X86InstrInfo(llvm::X86TargetMachine&)"},
    {"_ZN4llvm12X86InstrInfoC2ERNS_16X86TargetMachineE", "llvm::X86InstrInfo::X86InstrInfo(llvm::X86TargetMachine&)"},
    {"_ZNK4llvm12X86InstrInfo21isCoalescableExtInstrERKNS_12MachineInstrERjS4_S4_", "llvm::X86InstrInfo::isCoalescableExtInstr(llvm::MachineInstr const&, unsigned int&, unsigned int&, unsigned int&) const"},
    {"_ZNK4llvm12X86InstrInfo14isFrameOperandEPKNS_12MachineInstrEjRi", "llvm::X86InstrInfo::isFrameOperand(llvm::MachineInstr const*, unsigned int, int&) const"},
    {"_ZNK4llvm12X86InstrInfo19isLoadFromStackSlotEPKNS_12MachineInstrERi", "llvm::X86InstrInfo::isLoadFromStackSlot(llvm::MachineInstr const*, int&) const"},
    {"_ZNK4llvm12X86InstrInfo25isLoadFromStackSlotPostFEEPKNS_12MachineInstrERi", "llvm::X86InstrInfo::isLoadFromStackSlotPostFE(llvm::MachineInstr const*, int&) const"},
    {"_ZNK4llvm12X86InstrInfo20hasLoadFromStackSlotEPKNS_12MachineInstrERPKNS_17MachineMemOperandERi", "llvm::X86InstrInfo::hasLoadFromStackSlot(llvm::MachineInstr const*, llvm::MachineMemOperand const*&, int&) const"},
    {"_ZNK4llvm12X86InstrInfo18isStoreToStackSlotEPKNS_12MachineInstrERi", "llvm::X86InstrInfo::isStoreToStackSlot(llvm::MachineInstr const*, int&) const"},
    {"_ZNK4llvm12X86InstrInfo24isStoreToStackSlotPostFEEPKNS_12MachineInstrERi", "llvm::X86InstrInfo::isStoreToStackSlotPostFE(llvm::MachineInstr const*, int&) const"},
    {"_ZNK4llvm12X86InstrInfo19hasStoreToStackSlotEPKNS_12MachineInstrERPKNS_17MachineMemOperandERi", "llvm::X86InstrInfo::hasStoreToStackSlot(llvm::MachineInstr const*, llvm::MachineMemOperand const*&, int&) const"},
    {"_ZNK4llvm12X86InstrInfo33isReallyTriviallyReMaterializableEPKNS_12MachineInstrEPNS_13AliasAnalysisE", "llvm::X86InstrInfo::isReallyTriviallyReMaterializable(llvm::MachineInstr const*, llvm::AliasAnalysis*) const"},
    {"_ZNK4llvm12X86InstrInfo13reMaterializeERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEEjjPKS4_RKNS_18TargetRegisterInfoE", "llvm::X86InstrInfo::reMaterialize(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, unsigned int, llvm::MachineInstr const*, llvm::TargetRegisterInfo const&) const"},
    {"_ZNK4llvm12X86InstrInfo28convertToThreeAddressWithLEAEjRNS_14ilist_iteratorINS_17MachineBasicBlockEEERNS1_INS_12MachineInstrEEEPNS_13LiveVariablesE", "llvm::X86InstrInfo::convertToThreeAddressWithLEA(unsigned int, llvm::ilist_iterator<llvm::MachineBasicBlock>&, llvm::ilist_iterator<llvm::MachineInstr>&, llvm::LiveVariables*) const"},
    {"_ZNK4llvm12X86InstrInfo21convertToThreeAddressERNS_14ilist_iteratorINS_17MachineBasicBlockEEERNS1_INS_12MachineInstrEEEPNS_13LiveVariablesE", "llvm::X86InstrInfo::convertToThreeAddress(llvm::ilist_iterator<llvm::MachineBasicBlock>&, llvm::ilist_iterator<llvm::MachineInstr>&, llvm::LiveVariables*) const"},
    {"_ZNK4llvm12X86InstrInfo18commuteInstructionEPNS_12MachineInstrEb", "llvm::X86InstrInfo::commuteInstruction(llvm::MachineInstr*, bool) const"},
    {"_ZN4llvm3X8621GetCondBranchFromCondENS0_8CondCodeE", "llvm::X86::GetCondBranchFromCond(llvm::X86::CondCode)"},
    {"_ZN4llvm3X8626GetOppositeBranchConditionENS0_8CondCodeE", "llvm::X86::GetOppositeBranchCondition(llvm::X86::CondCode)"},
    {"_ZNK4llvm12X86InstrInfo24isUnpredicatedTerminatorEPKNS_12MachineInstrE", "llvm::X86InstrInfo::isUnpredicatedTerminator(llvm::MachineInstr const*) const"},
    {"_ZNK4llvm12X86InstrInfo13analyzeBranchERNS_17MachineBasicBlockERPS1_S4_RNS_15SmallVectorImplINS_14MachineOperandEEEb", "llvm::X86InstrInfo::analyzeBranch(llvm::MachineBasicBlock&, llvm::MachineBasicBlock*&, llvm::MachineBasicBlock*&, llvm::SmallVectorImpl<llvm::MachineOperand>&, bool) const"},
    {"_ZNK4llvm12X86InstrInfo12removeBranchERNS_17MachineBasicBlockE", "llvm::X86InstrInfo::removeBranch(llvm::MachineBasicBlock&) const"},
    {"_ZNK4llvm12X86InstrInfo12insertBranchERNS_17MachineBasicBlockEPS1_S3_RKNS_15SmallVectorImplINS_14MachineOperandEEENS_8DebugLocE", "llvm::X86InstrInfo::insertBranch(llvm::MachineBasicBlock&, llvm::MachineBasicBlock*, llvm::MachineBasicBlock*, llvm::SmallVectorImpl<llvm::MachineOperand> const&, llvm::DebugLoc) const"},
    {"_ZNK4llvm12X86InstrInfo11copyPhysRegERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEENS_8DebugLocEjjb", "llvm::X86InstrInfo::copyPhysReg(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, llvm::DebugLoc, unsigned int, unsigned int, bool) const"},
    {"_ZNK4llvm12X86InstrInfo19storeRegToStackSlotERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEEjbiPKNS_19TargetRegisterClassEPKNS_18TargetRegisterInfoE", "llvm::X86InstrInfo::storeRegToStackSlot(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, bool, int, llvm::TargetRegisterClass const*, llvm::TargetRegisterInfo const*) const"},
    {"_ZN4llvm17addFrameReferenceERKNS_19MachineInstrBuilderEii", "llvm::addFrameReference(llvm::MachineInstrBuilder const&, int, int)"},
    {"_ZNK4llvm12X86InstrInfo14storeRegToAddrERNS_15MachineFunctionEjbRNS_15SmallVectorImplINS_14MachineOperandEEEPKNS_19TargetRegisterClassEPPNS_17MachineMemOperandESC_RNS3_IPNS_12MachineInstrEEE", "llvm::X86InstrInfo::storeRegToAddr(llvm::MachineFunction&, unsigned int, bool, llvm::SmallVectorImpl<llvm::MachineOperand>&, llvm::TargetRegisterClass const*, llvm::MachineMemOperand**, llvm::MachineMemOperand**, llvm::SmallVectorImpl<llvm::MachineInstr*>&) const"},
    {"_ZNK4llvm12X86InstrInfo20loadRegFromStackSlotERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEEjiPKNS_19TargetRegisterClassEPKNS_18TargetRegisterInfoE", "llvm::X86InstrInfo::loadRegFromStackSlot(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, int, llvm::TargetRegisterClass const*, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm12X86InstrInfo15loadRegFromAddrERNS_15MachineFunctionEjRNS_15SmallVectorImplINS_14MachineOperandEEEPKNS_19TargetRegisterClassEPPNS_17MachineMemOperandESC_RNS3_IPNS_12MachineInstrEEE", "llvm::X86InstrInfo::loadRegFromAddr(llvm::MachineFunction&, unsigned int, llvm::SmallVectorImpl<llvm::MachineOperand>&, llvm::TargetRegisterClass const*, llvm::MachineMemOperand**, llvm::MachineMemOperand**, llvm::SmallVectorImpl<llvm::MachineInstr*>&) const"},
    {"_ZNK4llvm12X86InstrInfo24emitFrameIndexDebugValueERNS_15MachineFunctionEiyPKNS_6MDNodeENS_8DebugLocE", "llvm::X86InstrInfo::emitFrameIndexDebugValue(llvm::MachineFunction&, int, unsigned long long, llvm::MDNode const*, llvm::DebugLoc) const"},
    {"_ZNK4llvm12X86InstrInfo21foldMemoryOperandImplERNS_15MachineFunctionEPNS_12MachineInstrEjRKNS_15SmallVectorImplINS_14MachineOperandEEEjj", "llvm::X86InstrInfo::foldMemoryOperandImpl(llvm::MachineFunction&, llvm::MachineInstr*, unsigned int, llvm::SmallVectorImpl<llvm::MachineOperand> const&, unsigned int, unsigned int) const"},
    {"_Z10MakeM0InstRKN4llvm15TargetInstrInfoEjRKNS_15SmallVectorImplINS_14MachineOperandEEEPNS_12MachineInstrE", "MakeM0Inst(llvm::TargetInstrInfo const&, unsigned int, llvm::SmallVectorImpl<llvm::MachineOperand> const&, llvm::MachineInstr*)"},
    {"_ZNK4llvm12X86InstrInfo21foldMemoryOperandImplERNS_15MachineFunctionEPNS_12MachineInstrERKNS_15SmallVectorImplIjEEi", "llvm::X86InstrInfo::foldMemoryOperandImpl(llvm::MachineFunction&, llvm::MachineInstr*, llvm::SmallVectorImpl<unsigned int> const&, int) const"},
    {"_ZNK4llvm12X86InstrInfo21foldMemoryOperandImplERNS_15MachineFunctionEPNS_12MachineInstrERKNS_15SmallVectorImplIjEES4_", "llvm::X86InstrInfo::foldMemoryOperandImpl(llvm::MachineFunction&, llvm::MachineInstr*, llvm::SmallVectorImpl<unsigned int> const&, llvm::MachineInstr*) const"},
    {"_ZNK4llvm12X86InstrInfo20canFoldMemoryOperandEPKNS_12MachineInstrERKNS_15SmallVectorImplIjEE", "llvm::X86InstrInfo::canFoldMemoryOperand(llvm::MachineInstr const*, llvm::SmallVectorImpl<unsigned int> const&) const"},
    {"_ZNK4llvm12X86InstrInfo19unfoldMemoryOperandERNS_15MachineFunctionEPNS_12MachineInstrEjbbRNS_15SmallVectorImplIS4_EE", "llvm::X86InstrInfo::unfoldMemoryOperand(llvm::MachineFunction&, llvm::MachineInstr*, unsigned int, bool, bool, llvm::SmallVectorImpl<llvm::MachineInstr*>&) const"},
    {"_ZNK4llvm12X86InstrInfo19unfoldMemoryOperandERNS_12SelectionDAGEPNS_6SDNodeERNS_15SmallVectorImplIS4_EE", "llvm::X86InstrInfo::unfoldMemoryOperand(llvm::SelectionDAG&, llvm::SDNode*, llvm::SmallVectorImpl<llvm::SDNode*>&) const"},
    {"_ZNK4llvm12X86InstrInfo26getOpcodeAfterMemoryUnfoldEjbbPj", "llvm::X86InstrInfo::getOpcodeAfterMemoryUnfold(unsigned int, bool, bool, unsigned int*) const"},
    {"_ZNK4llvm12X86InstrInfo23areLoadsFromSameBasePtrEPNS_6SDNodeES2_RxS3_", "llvm::X86InstrInfo::areLoadsFromSameBasePtr(llvm::SDNode*, llvm::SDNode*, long long&, long long&) const"},
    {"_ZNK4llvm12X86InstrInfo23shouldScheduleLoadsNearEPNS_6SDNodeES2_xxj", "llvm::X86InstrInfo::shouldScheduleLoadsNear(llvm::SDNode*, llvm::SDNode*, long long, long long, unsigned int) const"},
    {"_ZNK4llvm12X86InstrInfo22ReverseBranchConditionERNS_15SmallVectorImplINS_14MachineOperandEEE", "llvm::X86InstrInfo::ReverseBranchCondition(llvm::SmallVectorImpl<llvm::MachineOperand>&) const"},
    {"_ZNK4llvm12X86InstrInfo24isSafeToMoveRegClassDefsEPKNS_19TargetRegisterClassE", "llvm::X86InstrInfo::isSafeToMoveRegClassDefs(llvm::TargetRegisterClass const*) const"},
    {"_ZN4llvm12X86InstrInfo19isX86_64ExtendedRegEj", "llvm::X86InstrInfo::isX86_64ExtendedReg(unsigned int)"},
    {"_ZNK4llvm12X86InstrInfo16getGlobalBaseRegEPNS_15MachineFunctionE", "llvm::X86InstrInfo::getGlobalBaseReg(llvm::MachineFunction*) const"},
    {"_ZNK4llvm12X86InstrInfo12GetSSEDomainEPKNS_12MachineInstrE", "llvm::X86InstrInfo::GetSSEDomain(llvm::MachineInstr const*) const"},
    {"_ZNK4llvm12X86InstrInfo12SetSSEDomainEPNS_12MachineInstrEj", "llvm::X86InstrInfo::SetSSEDomain(llvm::MachineInstr*, unsigned int) const"},
    {"_ZNK4llvm12X86InstrInfo21getNoopForMachoTargetERNS_6MCInstE", "llvm::X86InstrInfo::getNoopForMachoTarget(llvm::MCInst&) const"},
    {"_ZNK4llvm12X86InstrInfo21hasHighOperandLatencyEPKNS_18InstrItineraryDataEPKNS_19MachineRegisterInfoEPKNS_12MachineInstrEjS9_j", "llvm::X86InstrInfo::hasHighOperandLatency(llvm::InstrItineraryData const*, llvm::MachineRegisterInfo const*, llvm::MachineInstr const*, unsigned int, llvm::MachineInstr const*, unsigned int) const"},
    {"_ZN4llvm23createGlobalBaseRegPassEv", "llvm::createGlobalBaseRegPass()"},
    {"_ZN12_GLOBAL__N_14CGBRD1Ev", "(anonymous namespace)::CGBR::~CGBR()"},
    {"_ZN12_GLOBAL__N_14CGBRD0Ev", "(anonymous namespace)::CGBR::~CGBR()"},
    {"_ZNK12_GLOBAL__N_14CGBR11getPassNameEv", "(anonymous namespace)::CGBR::getPassName() const"},
    {"_ZNK12_GLOBAL__N_14CGBR16getAnalysisUsageERN4llvm13AnalysisUsageE", "(anonymous namespace)::CGBR::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_14CGBR20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::CGBR::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_Z21getLoadStoreRegOpcodejPKN4llvm19TargetRegisterClassEbRKNS_13TargetMachineEb", "getLoadStoreRegOpcode(unsigned int, llvm::TargetRegisterClass const*, bool, llvm::TargetMachine const&, bool)"},
    {"_ZN4llvm22X86MachineFunctionInfoD1Ev", "llvm::X86MachineFunctionInfo::~X86MachineFunctionInfo()"},
    {"_ZN4llvm22X86MachineFunctionInfoD0Ev", "llvm::X86MachineFunctionInfo::~X86MachineFunctionInfo()"},
    {"_ZNSt6vectorIN4llvm3EVTESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<llvm::EVT, std::allocator<llvm::EVT>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::EVT*, std::vector<llvm::EVT, std::allocator<llvm::EVT>>>, llvm::EVT const&)"},
    {"_ZNSt6vectorIN4llvm7SDValueESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<llvm::SDValue, std::allocator<llvm::SDValue>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::SDValue*, std::vector<llvm::SDValue, std::allocator<llvm::SDValue>>>, llvm::SDValue const&)"},
    {"_ZN4llvm8DenseMapIjSt4pairIjjENS_12DenseMapInfoIjEENS3_IS2_EEE16InsertIntoBucketERKjRKS2_PS1_IjS2_E", "llvm::DenseMap<unsigned int, std::pair<unsigned int, unsigned int>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<std::pair<unsigned int, unsigned int>>>::InsertIntoBucket(unsigned int const&, std::pair<unsigned int, unsigned int> const&, std::pair<unsigned int, std::pair<unsigned int, unsigned int>>*)"},
    {"_ZN4llvm8DenseMapIjSt4pairIjjENS_12DenseMapInfoIjEENS3_IS2_EEE4growEj", "llvm::DenseMap<unsigned int, std::pair<unsigned int, unsigned int>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<std::pair<unsigned int, unsigned int>>>::grow(unsigned int)"},
    {"_ZNSt6vectorIPN4llvm12MachineInstrESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::MachineInstr*, std::allocator<llvm::MachineInstr*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::MachineInstr**, std::vector<llvm::MachineInstr*, std::allocator<llvm::MachineInstr*>>>, llvm::MachineInstr* const&)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_14MachineOperandELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::MachineOperand, false>::grow(unsigned long)"},
    {"_ZN4llvm19MachineFunctionPassD1Ev", "llvm::MachineFunctionPass::~MachineFunctionPass()"},
    {"_ZN4llvm19MachineFunctionPassD0Ev", "llvm::MachineFunctionPass::~MachineFunctionPass()"},
    {"_ZN4llvm12FunctionPassD1Ev", "llvm::FunctionPass::~FunctionPass()"},
    {"_ZN4llvm12FunctionPassD0Ev", "llvm::FunctionPass::~FunctionPass()"},
    {"_ZN4llvm10X86JITInfo29replaceMachineCodeForFunctionEPvS1_", "llvm::X86JITInfo::replaceMachineCodeForFunction(void*, void*)"},
    {"_ZN4llvm10X86JITInfo23getLazyResolverFunctionEPFPvS1_E", "llvm::X86JITInfo::getLazyResolverFunction(void* (*)(void*))"},
    {"_ZN4llvm10X86JITInfoC1ERNS_16X86TargetMachineE", "llvm::X86JITInfo::X86JITInfo(llvm::X86TargetMachine&)"},
    {"_ZN4llvm10X86JITInfoC2ERNS_16X86TargetMachineE", "llvm::X86JITInfo::X86JITInfo(llvm::X86TargetMachine&)"},
    {"_ZN4llvm10X86JITInfo26emitGlobalValueIndirectSymEPKNS_11GlobalValueEPvRNS_14JITCodeEmitterE", "llvm::X86JITInfo::emitGlobalValueIndirectSym(llvm::GlobalValue const*, void*, llvm::JITCodeEmitter&)"},
    {"_ZN4llvm10X86JITInfo13getStubLayoutEv", "llvm::X86JITInfo::getStubLayout()"},
    {"_ZN4llvm10X86JITInfo16emitFunctionStubEPKNS_8FunctionEPvRNS_14JITCodeEmitterE", "llvm::X86JITInfo::emitFunctionStub(llvm::Function const*, void*, llvm::JITCodeEmitter&)"},
    {"_ZN4llvm10X86JITInfo20getPICJumpTableEntryEmm", "llvm::X86JITInfo::getPICJumpTableEntry(unsigned long, unsigned long)"},
    {"_ZN4llvm10X86JITInfo8relocateEPvPNS_17MachineRelocationEjPh", "llvm::X86JITInfo::relocate(void*, llvm::MachineRelocation*, unsigned int, unsigned char*)"},
    {"_ZN4llvm10X86JITInfo25allocateThreadLocalMemoryEm", "llvm::X86JITInfo::allocateThreadLocalMemory(unsigned long)"},
    {"_ZN4llvm18X86MCAsmInfoDarwinC1ERKNS_6TripleE", "llvm::X86MCAsmInfoDarwin::X86MCAsmInfoDarwin(llvm::Triple const&)"},
    {"_ZN4llvm18X86MCAsmInfoDarwinC2ERKNS_6TripleE", "llvm::X86MCAsmInfoDarwin::X86MCAsmInfoDarwin(llvm::Triple const&)"},
    {"_ZN4llvm15X86ELFMCAsmInfoC1ERKNS_6TripleE", "llvm::X86ELFMCAsmInfo::X86ELFMCAsmInfo(llvm::Triple const&)"},
    {"_ZN4llvm15X86ELFMCAsmInfoC2ERKNS_6TripleE", "llvm::X86ELFMCAsmInfo::X86ELFMCAsmInfo(llvm::Triple const&)"},
    {"_ZNK4llvm15X86ELFMCAsmInfo28getNonexecutableStackSectionERNS_9MCContextE", "llvm::X86ELFMCAsmInfo::getNonexecutableStackSection(llvm::MCContext&) const"},
    {"_ZN4llvm16X86MCAsmInfoCOFFC1ERKNS_6TripleE", "llvm::X86MCAsmInfoCOFF::X86MCAsmInfoCOFF(llvm::Triple const&)"},
    {"_ZN4llvm16X86MCAsmInfoCOFFC2ERKNS_6TripleE", "llvm::X86MCAsmInfoCOFF::X86MCAsmInfoCOFF(llvm::Triple const&)"},
    {"_ZN4llvm2cl3optI17AsmWriterFlavorTyLb0ENS0_6parserIS2_EEED1Ev", "llvm::cl::opt<AsmWriterFlavorTy, false, llvm::cl::parser<AsmWriterFlavorTy>>::~opt()"},
    {"_ZNK4llvm9MCAsmInfo18getDataASDirectiveEjj", "llvm::MCAsmInfo::getDataASDirective(unsigned int, unsigned int) const"},
    {"_ZN4llvm15X86ELFMCAsmInfoD1Ev", "llvm::X86ELFMCAsmInfo::~X86ELFMCAsmInfo()"},
    {"_ZN4llvm15X86ELFMCAsmInfoD0Ev", "llvm::X86ELFMCAsmInfo::~X86ELFMCAsmInfo()"},
    {"_ZN4llvm16X86MCAsmInfoCOFFD1Ev", "llvm::X86MCAsmInfoCOFF::~X86MCAsmInfoCOFF()"},
    {"_ZN4llvm16X86MCAsmInfoCOFFD0Ev", "llvm::X86MCAsmInfoCOFF::~X86MCAsmInfoCOFF()"},
    {"_ZNK4llvm9MCAsmInfo28getNonexecutableStackSectionERNS_9MCContextE", "llvm::MCAsmInfo::getNonexecutableStackSection(llvm::MCContext&) const"},
    {"_ZN4llvm18X86MCAsmInfoDarwinD1Ev", "llvm::X86MCAsmInfoDarwin::~X86MCAsmInfoDarwin()"},
    {"_ZN4llvm18X86MCAsmInfoDarwinD0Ev", "llvm::X86MCAsmInfoDarwin::~X86MCAsmInfoDarwin()"},
    {"_ZN4llvm15MCAsmInfoDarwinD1Ev", "llvm::MCAsmInfoDarwin::~MCAsmInfoDarwin()"},
    {"_ZN4llvm15MCAsmInfoDarwinD0Ev", "llvm::MCAsmInfoDarwin::~MCAsmInfoDarwin()"},
    {"_ZN4llvm13MCAsmInfoCOFFD1Ev", "llvm::MCAsmInfoCOFF::~MCAsmInfoCOFF()"},
    {"_ZN4llvm13MCAsmInfoCOFFD0Ev", "llvm::MCAsmInfoCOFF::~MCAsmInfoCOFF()"},
    {"_ZN4llvm2cl3optI17AsmWriterFlavorTyLb0ENS0_6parserIS2_EEE16handleOccurrenceEjNS_9StringRefES6_", "llvm::cl::opt<AsmWriterFlavorTy, false, llvm::cl::parser<AsmWriterFlavorTy>>::handleOccurrence(unsigned int, llvm::StringRef, llvm::StringRef)"},
    {"_ZNK4llvm2cl3optI17AsmWriterFlavorTyLb0ENS0_6parserIS2_EEE27getValueExpectedFlagDefaultEv", "llvm::cl::opt<AsmWriterFlavorTy, false, llvm::cl::parser<AsmWriterFlavorTy>>::getValueExpectedFlagDefault() const"},
    {"_ZNK4llvm2cl3optI17AsmWriterFlavorTyLb0ENS0_6parserIS2_EEE14getOptionWidthEv", "llvm::cl::opt<AsmWriterFlavorTy, false, llvm::cl::parser<AsmWriterFlavorTy>>::getOptionWidth() const"},
    {"_ZNK4llvm2cl3optI17AsmWriterFlavorTyLb0ENS0_6parserIS2_EEE15printOptionInfoEm", "llvm::cl::opt<AsmWriterFlavorTy, false, llvm::cl::parser<AsmWriterFlavorTy>>::printOptionInfo(unsigned long) const"},
    {"_ZN4llvm2cl3optI17AsmWriterFlavorTyLb0ENS0_6parserIS2_EEE19getExtraOptionNamesERNS_15SmallVectorImplIPKcEE", "llvm::cl::opt<AsmWriterFlavorTy, false, llvm::cl::parser<AsmWriterFlavorTy>>::getExtraOptionNames(llvm::SmallVectorImpl<char const*>&)"},
    {"_ZN4llvm2cl3optI17AsmWriterFlavorTyLb0ENS0_6parserIS2_EEED0Ev", "llvm::cl::opt<AsmWriterFlavorTy, false, llvm::cl::parser<AsmWriterFlavorTy>>::~opt()"},
    {"_ZN4llvm2cl6parserI17AsmWriterFlavorTyE5parseERNS0_6OptionENS_9StringRefES6_RS2_", "llvm::cl::parser<AsmWriterFlavorTy>::parse(llvm::cl::Option&, llvm::StringRef, llvm::StringRef, AsmWriterFlavorTy&)"},
    {"_ZNK4llvm2cl11ValuesClassIiE5applyINS0_3optI17AsmWriterFlavorTyLb0ENS0_6parserIS5_EEEEEEvRT_", "void llvm::cl::ValuesClass<int>::apply<llvm::cl::opt<AsmWriterFlavorTy, false, llvm::cl::parser<AsmWriterFlavorTy>>>(llvm::cl::opt<AsmWriterFlavorTy, false, llvm::cl::parser<AsmWriterFlavorTy>>&) const"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_2cl6parserI17AsmWriterFlavorTyE10OptionInfoELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::cl::parser<AsmWriterFlavorTy>::OptionInfo, false>::grow(unsigned long)"},
    {"_ZN4llvm2cl6parserI17AsmWriterFlavorTyED1Ev", "llvm::cl::parser<AsmWriterFlavorTy>::~parser()"},
    {"_ZN4llvm2cl6parserI17AsmWriterFlavorTyED0Ev", "llvm::cl::parser<AsmWriterFlavorTy>::~parser()"},
    {"_ZNK4llvm2cl6parserI17AsmWriterFlavorTyE13getNumOptionsEv", "llvm::cl::parser<AsmWriterFlavorTy>::getNumOptions() const"},
    {"_ZNK4llvm2cl6parserI17AsmWriterFlavorTyE9getOptionEj", "llvm::cl::parser<AsmWriterFlavorTy>::getOption(unsigned int) const"},
    {"_ZNK4llvm2cl6parserI17AsmWriterFlavorTyE14getDescriptionEj", "llvm::cl::parser<AsmWriterFlavorTy>::getDescription(unsigned int) const"},
    {"_ZN4llvm25createX86_32MCCodeEmitterERKNS_6TargetERNS_13TargetMachineERNS_9MCContextE", "llvm::createX86_32MCCodeEmitter(llvm::Target const&, llvm::TargetMachine&, llvm::MCContext&)"},
    {"_ZN4llvm25createX86_64MCCodeEmitterERKNS_6TargetERNS_13TargetMachineERNS_9MCContextE", "llvm::createX86_64MCCodeEmitter(llvm::Target const&, llvm::TargetMachine&, llvm::MCContext&)"},
    {"_ZN12_GLOBAL__N_116X86MCCodeEmitterD1Ev", "(anonymous namespace)::X86MCCodeEmitter::~X86MCCodeEmitter()"},
    {"_ZN12_GLOBAL__N_116X86MCCodeEmitterD0Ev", "(anonymous namespace)::X86MCCodeEmitter::~X86MCCodeEmitter()"},
    {"_ZNK12_GLOBAL__N_116X86MCCodeEmitter17EncodeInstructionERKN4llvm6MCInstERNS1_11raw_ostreamERNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::X86MCCodeEmitter::EncodeInstruction(llvm::MCInst const&, llvm::raw_ostream&, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116X86MCCodeEmitter13EmitImmediateERKN4llvm9MCOperandEjNS1_11MCFixupKindERjRNS1_11raw_ostreamERNS1_15SmallVectorImplINS1_7MCFixupEEEi", "(anonymous namespace)::X86MCCodeEmitter::EmitImmediate(llvm::MCOperand const&, unsigned int, llvm::MCFixupKind, unsigned int&, llvm::raw_ostream&, llvm::SmallVectorImpl<llvm::MCFixup>&, int) const"},
    {"_ZNK12_GLOBAL__N_116X86MCCodeEmitter16EmitMemModRMByteERKN4llvm6MCInstEjjyRjRNS1_11raw_ostreamERNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::X86MCCodeEmitter::EmitMemModRMByte(llvm::MCInst const&, unsigned int, unsigned int, unsigned long long, unsigned int&, llvm::raw_ostream&, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116X86MCCodeEmitter25EmitSegmentOverridePrefixEyRjiRKN4llvm6MCInstERNS2_11raw_ostreamE", "(anonymous namespace)::X86MCCodeEmitter::EmitSegmentOverridePrefix(unsigned long long, unsigned int&, int, llvm::MCInst const&, llvm::raw_ostream&) const"},
    {"_ZN4llvm14X86MCInstLowerC1EPNS_7ManglerERKNS_15MachineFunctionERNS_13X86AsmPrinterE", "llvm::X86MCInstLower::X86MCInstLower(llvm::Mangler*, llvm::MachineFunction const&, llvm::X86AsmPrinter&)"},
    {"_ZN4llvm14X86MCInstLowerC2EPNS_7ManglerERKNS_15MachineFunctionERNS_13X86AsmPrinterE", "llvm::X86MCInstLower::X86MCInstLower(llvm::Mangler*, llvm::MachineFunction const&, llvm::X86AsmPrinter&)"},
    {"_ZNK4llvm14X86MCInstLower11getMachOMMIEv", "llvm::X86MCInstLower::getMachOMMI() const"},
    {"_ZNK4llvm14X86MCInstLower20GetSymbolFromOperandERKNS_14MachineOperandE", "llvm::X86MCInstLower::GetSymbolFromOperand(llvm::MachineOperand const&) const"},
    {"_ZNK4llvm14X86MCInstLower18LowerSymbolOperandERKNS_14MachineOperandEPNS_8MCSymbolE", "llvm::X86MCInstLower::LowerSymbolOperand(llvm::MachineOperand const&, llvm::MCSymbol*) const"},
    {"_ZNK4llvm14X86MCInstLower5LowerEPKNS_12MachineInstrERNS_6MCInstE", "llvm::X86MCInstLower::Lower(llvm::MachineInstr const*, llvm::MCInst&) const"},
    {"_Z21SimplifyShortMoveFormRN4llvm13X86AsmPrinterERNS_6MCInstEj", "SimplifyShortMoveForm(llvm::X86AsmPrinter&, llvm::MCInst&, unsigned int)"},
    {"_Z20SimplifyShortImmFormRN4llvm6MCInstEj", "SimplifyShortImmForm(llvm::MCInst&, unsigned int)"},
    {"_ZN4llvm13X86AsmPrinter15EmitInstructionEPKNS_12MachineInstrE", "llvm::X86AsmPrinter::EmitInstruction(llvm::MachineInstr const*)"},
    {"_ZN4llvm15SmallVectorImplIcE6insertIPKcEEPcS5_T_S6_", "char* llvm::SmallVectorImpl<char>::insert<char const*>(char*, char const*, char const*)"},
    {"_ZN4llvm25createX86MachObjectWriterERNS_11raw_ostreamEbjj", "llvm::createX86MachObjectWriter(llvm::raw_ostream&, bool, unsigned int, unsigned int)"},
    {"_ZN12_GLOBAL__N_119X86MachObjectWriterD1Ev", "(anonymous namespace)::X86MachObjectWriter::~X86MachObjectWriter()"},
    {"_ZN12_GLOBAL__N_119X86MachObjectWriterD0Ev", "(anonymous namespace)::X86MachObjectWriter::~X86MachObjectWriter()"},
    {"_ZN4llvm15X86RegisterInfoC1ERNS_16X86TargetMachineERKNS_15TargetInstrInfoE", "llvm::X86RegisterInfo::X86RegisterInfo(llvm::X86TargetMachine&, llvm::TargetInstrInfo const&)"},
    {"_ZN4llvm15X86RegisterInfoC2ERNS_16X86TargetMachineERKNS_15TargetInstrInfoE", "llvm::X86RegisterInfo::X86RegisterInfo(llvm::X86TargetMachine&, llvm::TargetInstrInfo const&)"},
    {"_ZN4llvm18X86GenRegisterInfoC2Eii", "llvm::X86GenRegisterInfo::X86GenRegisterInfo(int, int)"},
    {"_ZNK4llvm15X86RegisterInfo14getDwarfRegNumEjb", "llvm::X86RegisterInfo::getDwarfRegNum(unsigned int, bool) const"},
    {"_ZNK4llvm18X86GenRegisterInfo18getDwarfRegNumFullEjj", "llvm::X86GenRegisterInfo::getDwarfRegNumFull(unsigned int, unsigned int) const"},
    {"_ZN4llvm15X86RegisterInfo12getX86RegNumEj", "llvm::X86RegisterInfo::getX86RegNum(unsigned int)"},
    {"_ZNK4llvm15X86RegisterInfo24getMatchingSuperRegClassEPKNS_19TargetRegisterClassES3_j", "llvm::X86RegisterInfo::getMatchingSuperRegClass(llvm::TargetRegisterClass const*, llvm::TargetRegisterClass const*, unsigned int) const"},
    {"_ZNK4llvm15X86RegisterInfo18getPointerRegClassEj", "llvm::X86RegisterInfo::getPointerRegClass(unsigned int) const"},
    {"_ZNK4llvm15X86RegisterInfo20getCrossCopyRegClassEPKNS_19TargetRegisterClassE", "llvm::X86RegisterInfo::getCrossCopyRegClass(llvm::TargetRegisterClass const*) const"},
    {"_ZNK4llvm15X86RegisterInfo18getCalleeSavedRegsEPKNS_15MachineFunctionE", "llvm::X86RegisterInfo::getCalleeSavedRegs(llvm::MachineFunction const*) const"},
    {"_ZNK4llvm15X86RegisterInfo15getReservedRegsERKNS_15MachineFunctionE", "llvm::X86RegisterInfo::getReservedRegs(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm15X86RegisterInfo15canRealignStackERKNS_15MachineFunctionE", "llvm::X86RegisterInfo::canRealignStack(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm15X86RegisterInfo21needsStackRealignmentERKNS_15MachineFunctionE", "llvm::X86RegisterInfo::needsStackRealignment(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm15X86RegisterInfo20hasReservedSpillSlotERKNS_15MachineFunctionEjRi", "llvm::X86RegisterInfo::hasReservedSpillSlot(llvm::MachineFunction const&, unsigned int, int&) const"},
    {"_ZNK4llvm15X86RegisterInfo29eliminateCallFramePseudoInstrERNS_15MachineFunctionERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEE", "llvm::X86RegisterInfo::eliminateCallFramePseudoInstr(llvm::MachineFunction&, llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>) const"},
    {"_ZNK4llvm15X86RegisterInfo19eliminateFrameIndexENS_14ilist_iteratorINS_12MachineInstrEEEiPNS_12RegScavengerE", "llvm::X86RegisterInfo::eliminateFrameIndex(llvm::ilist_iterator<llvm::MachineInstr>, int, llvm::RegScavenger*) const"},
    {"_ZNK4llvm15X86RegisterInfo13getRARegisterEv", "llvm::X86RegisterInfo::getRARegister() const"},
    {"_ZNK4llvm15X86RegisterInfo16getFrameRegisterERKNS_15MachineFunctionE", "llvm::X86RegisterInfo::getFrameRegister(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm15X86RegisterInfo22getEHExceptionRegisterEv", "llvm::X86RegisterInfo::getEHExceptionRegister() const"},
    {"_ZNK4llvm15X86RegisterInfo20getEHHandlerRegisterEv", "llvm::X86RegisterInfo::getEHHandlerRegister() const"},
    {"_ZN4llvm22getX86SubSuperRegisterEjNS_3EVTEb", "llvm::getX86SubSuperRegister(unsigned int, llvm::EVT, bool)"},
    {"_ZN4llvm3X868CCRClassC1Ev", "llvm::X86::CCRClass::CCRClass()"},
    {"_ZN4llvm3X8616CONTROL_REGClassC1Ev", "llvm::X86::CONTROL_REGClass::CONTROL_REGClass()"},
    {"_ZN4llvm3X8614DEBUG_REGClassC1Ev", "llvm::X86::DEBUG_REGClass::DEBUG_REGClass()"},
    {"_ZN4llvm3X869FR32ClassC1Ev", "llvm::X86::FR32Class::FR32Class()"},
    {"_ZN4llvm3X869FR64ClassC1Ev", "llvm::X86::FR64Class::FR64Class()"},
    {"_ZN4llvm3X869GR16ClassC1Ev", "llvm::X86::GR16Class::GR16Class()"},
    {"_ZN4llvm3X8614GR16_ABCDClassC1Ev", "llvm::X86::GR16_ABCDClass::GR16_ABCDClass()"},
    {"_ZN4llvm3X8615GR16_NOREXClassC1Ev", "llvm::X86::GR16_NOREXClass::GR16_NOREXClass()"},
    {"_ZN4llvm3X869GR32ClassC1Ev", "llvm::X86::GR32Class::GR32Class()"},
    {"_ZN4llvm3X8614GR32_ABCDClassC1Ev", "llvm::X86::GR32_ABCDClass::GR32_ABCDClass()"},
    {"_ZN4llvm3X8612GR32_ADClassC1Ev", "llvm::X86::GR32_ADClass::GR32_ADClass()"},
    {"_ZN4llvm3X8615GR32_NOREXClassC1Ev", "llvm::X86::GR32_NOREXClass::GR32_NOREXClass()"},
    {"_ZN4llvm3X8614GR32_NOSPClassC1Ev", "llvm::X86::GR32_NOSPClass::GR32_NOSPClass()"},
    {"_ZN4llvm3X8612GR32_TCClassC1Ev", "llvm::X86::GR32_TCClass::GR32_TCClass()"},
    {"_ZN4llvm3X869GR64ClassC1Ev", "llvm::X86::GR64Class::GR64Class()"},
    {"_ZN4llvm3X8614GR64_ABCDClassC1Ev", "llvm::X86::GR64_ABCDClass::GR64_ABCDClass()"},
    {"_ZN4llvm3X8615GR64_NOREXClassC1Ev", "llvm::X86::GR64_NOREXClass::GR64_NOREXClass()"},
    {"_ZN4llvm3X8620GR64_NOREX_NOSPClassC1Ev", "llvm::X86::GR64_NOREX_NOSPClass::GR64_NOREX_NOSPClass()"},
    {"_ZN4llvm3X8614GR64_NOSPClassC1Ev", "llvm::X86::GR64_NOSPClass::GR64_NOSPClass()"},
    {"_ZN4llvm3X8612GR64_TCClassC1Ev", "llvm::X86::GR64_TCClass::GR64_TCClass()"},
    {"_ZN4llvm3X8615GR64_TCW64ClassC1Ev", "llvm::X86::GR64_TCW64Class::GR64_TCW64Class()"},
    {"_ZN4llvm3X868GR8ClassC1Ev", "llvm::X86::GR8Class::GR8Class()"},
    {"_ZN4llvm3X8615GR8_ABCD_HClassC1Ev", "llvm::X86::GR8_ABCD_HClass::GR8_ABCD_HClass()"},
    {"_ZN4llvm3X8615GR8_ABCD_LClassC1Ev", "llvm::X86::GR8_ABCD_LClass::GR8_ABCD_LClass()"},
    {"_ZN4llvm3X8614GR8_NOREXClassC1Ev", "llvm::X86::GR8_NOREXClass::GR8_NOREXClass()"},
    {"_ZN4llvm3X8610RFP32ClassC1Ev", "llvm::X86::RFP32Class::RFP32Class()"},
    {"_ZN4llvm3X8610RFP64ClassC1Ev", "llvm::X86::RFP64Class::RFP64Class()"},
    {"_ZN4llvm3X8610RFP80ClassC1Ev", "llvm::X86::RFP80Class::RFP80Class()"},
    {"_ZN4llvm3X868RSTClassC1Ev", "llvm::X86::RSTClass::RSTClass()"},
    {"_ZN4llvm3X8616SEGMENT_REGClassC1Ev", "llvm::X86::SEGMENT_REGClass::SEGMENT_REGClass()"},
    {"_ZN4llvm3X8610VR128ClassC1Ev", "llvm::X86::VR128Class::VR128Class()"},
    {"_ZN4llvm3X8610VR256ClassC1Ev", "llvm::X86::VR256Class::VR256Class()"},
    {"_ZN4llvm3X869VR64ClassC1Ev", "llvm::X86::VR64Class::VR64Class()"},
    {"_ZNK4llvm3X868CCRClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::CCRClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X868CCRClassC2Ev", "llvm::X86::CCRClass::CCRClass()"},
    {"_ZN4llvm3X8616CONTROL_REGClassC2Ev", "llvm::X86::CONTROL_REGClass::CONTROL_REGClass()"},
    {"_ZN4llvm3X8614DEBUG_REGClassC2Ev", "llvm::X86::DEBUG_REGClass::DEBUG_REGClass()"},
    {"_ZNK4llvm3X869FR32Class20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::FR32Class::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X869FR32ClassC2Ev", "llvm::X86::FR32Class::FR32Class()"},
    {"_ZNK4llvm3X869FR64Class20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::FR64Class::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X869FR64ClassC2Ev", "llvm::X86::FR64Class::FR64Class()"},
    {"_ZNK4llvm3X869GR16Class22allocation_order_beginERKNS_15MachineFunctionE", "llvm::X86::GR16Class::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3X869GR16Class20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR16Class::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X869GR16ClassC2Ev", "llvm::X86::GR16Class::GR16Class()"},
    {"_ZN4llvm3X8614GR16_ABCDClassC2Ev", "llvm::X86::GR16_ABCDClass::GR16_ABCDClass()"},
    {"_ZNK4llvm3X8615GR16_NOREXClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR16_NOREXClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X8615GR16_NOREXClassC2Ev", "llvm::X86::GR16_NOREXClass::GR16_NOREXClass()"},
    {"_ZNK4llvm3X869GR32Class22allocation_order_beginERKNS_15MachineFunctionE", "llvm::X86::GR32Class::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3X869GR32Class20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR32Class::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X869GR32ClassC2Ev", "llvm::X86::GR32Class::GR32Class()"},
    {"_ZN4llvm3X8614GR32_ABCDClassC2Ev", "llvm::X86::GR32_ABCDClass::GR32_ABCDClass()"},
    {"_ZN4llvm3X8612GR32_ADClassC2Ev", "llvm::X86::GR32_ADClass::GR32_ADClass()"},
    {"_ZNK4llvm3X8615GR32_NOREXClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR32_NOREXClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X8615GR32_NOREXClassC2Ev", "llvm::X86::GR32_NOREXClass::GR32_NOREXClass()"},
    {"_ZNK4llvm3X8614GR32_NOSPClass22allocation_order_beginERKNS_15MachineFunctionE", "llvm::X86::GR32_NOSPClass::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3X8614GR32_NOSPClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR32_NOSPClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X8614GR32_NOSPClassC2Ev", "llvm::X86::GR32_NOSPClass::GR32_NOSPClass()"},
    {"_ZN4llvm3X8612GR32_TCClassC2Ev", "llvm::X86::GR32_TCClass::GR32_TCClass()"},
    {"_ZNK4llvm3X869GR64Class20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR64Class::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X869GR64ClassC2Ev", "llvm::X86::GR64Class::GR64Class()"},
    {"_ZN4llvm3X8614GR64_ABCDClassC2Ev", "llvm::X86::GR64_ABCDClass::GR64_ABCDClass()"},
    {"_ZNK4llvm3X8615GR64_NOREXClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR64_NOREXClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X8615GR64_NOREXClassC2Ev", "llvm::X86::GR64_NOREXClass::GR64_NOREXClass()"},
    {"_ZNK4llvm3X8620GR64_NOREX_NOSPClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR64_NOREX_NOSPClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X8620GR64_NOREX_NOSPClassC2Ev", "llvm::X86::GR64_NOREX_NOSPClass::GR64_NOREX_NOSPClass()"},
    {"_ZNK4llvm3X8614GR64_NOSPClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR64_NOSPClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X8614GR64_NOSPClassC2Ev", "llvm::X86::GR64_NOSPClass::GR64_NOSPClass()"},
    {"_ZN4llvm3X8612GR64_TCClassC2Ev", "llvm::X86::GR64_TCClass::GR64_TCClass()"},
    {"_ZN4llvm3X8615GR64_TCW64ClassC2Ev", "llvm::X86::GR64_TCW64Class::GR64_TCW64Class()"},
    {"_ZNK4llvm3X868GR8Class22allocation_order_beginERKNS_15MachineFunctionE", "llvm::X86::GR8Class::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3X868GR8Class20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR8Class::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X868GR8ClassC2Ev", "llvm::X86::GR8Class::GR8Class()"},
    {"_ZN4llvm3X8615GR8_ABCD_HClassC2Ev", "llvm::X86::GR8_ABCD_HClass::GR8_ABCD_HClass()"},
    {"_ZN4llvm3X8615GR8_ABCD_LClassC2Ev", "llvm::X86::GR8_ABCD_LClass::GR8_ABCD_LClass()"},
    {"_ZNK4llvm3X8614GR8_NOREXClass22allocation_order_beginERKNS_15MachineFunctionE", "llvm::X86::GR8_NOREXClass::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3X8614GR8_NOREXClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::GR8_NOREXClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X8614GR8_NOREXClassC2Ev", "llvm::X86::GR8_NOREXClass::GR8_NOREXClass()"},
    {"_ZN4llvm3X8610RFP32ClassC2Ev", "llvm::X86::RFP32Class::RFP32Class()"},
    {"_ZN4llvm3X8610RFP64ClassC2Ev", "llvm::X86::RFP64Class::RFP64Class()"},
    {"_ZN4llvm3X8610RFP80ClassC2Ev", "llvm::X86::RFP80Class::RFP80Class()"},
    {"_ZNK4llvm3X868RSTClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::RSTClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X868RSTClassC2Ev", "llvm::X86::RSTClass::RSTClass()"},
    {"_ZN4llvm3X8616SEGMENT_REGClassC2Ev", "llvm::X86::SEGMENT_REGClass::SEGMENT_REGClass()"},
    {"_ZNK4llvm3X8610VR128Class20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::VR128Class::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X8610VR128ClassC2Ev", "llvm::X86::VR128Class::VR128Class()"},
    {"_ZNK4llvm3X8610VR256Class20allocation_order_endERKNS_15MachineFunctionE", "llvm::X86::VR256Class::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3X8610VR256ClassC2Ev", "llvm::X86::VR256Class::VR256Class()"},
    {"_ZN4llvm3X869VR64ClassC2Ev", "llvm::X86::VR64Class::VR64Class()"},
    {"_ZNK4llvm18X86GenRegisterInfo9getSubRegEjj", "llvm::X86GenRegisterInfo::getSubReg(unsigned int, unsigned int) const"},
    {"_ZNK4llvm18X86GenRegisterInfo14getSubRegIndexEjj", "llvm::X86GenRegisterInfo::getSubRegIndex(unsigned int, unsigned int) const"},
    {"_ZNK4llvm18X86GenRegisterInfo20composeSubRegIndicesEjj", "llvm::X86GenRegisterInfo::composeSubRegIndices(unsigned int, unsigned int) const"},
    {"_ZN4llvm18X86GenRegisterInfoC1Eii", "llvm::X86GenRegisterInfo::X86GenRegisterInfo(int, int)"},
    {"_ZN4llvm39createX86MaxStackAlignmentHeuristicPassEv", "llvm::createX86MaxStackAlignmentHeuristicPass()"},
    {"_ZN12_GLOBAL__N_14MSAHD1Ev", "(anonymous namespace)::MSAH::~MSAH()"},
    {"_ZN12_GLOBAL__N_14MSAHD0Ev", "(anonymous namespace)::MSAH::~MSAH()"},
    {"_ZNK12_GLOBAL__N_14MSAH11getPassNameEv", "(anonymous namespace)::MSAH::getPassName() const"},
    {"_ZNK12_GLOBAL__N_14MSAH16getAnalysisUsageERN4llvm13AnalysisUsageE", "(anonymous namespace)::MSAH::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_14MSAH20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::MSAH::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN4llvm3X868CCRClassD1Ev", "llvm::X86::CCRClass::~CCRClass()"},
    {"_ZN4llvm3X8616CONTROL_REGClassD1Ev", "llvm::X86::CONTROL_REGClass::~CONTROL_REGClass()"},
    {"_ZN4llvm3X8614DEBUG_REGClassD1Ev", "llvm::X86::DEBUG_REGClass::~DEBUG_REGClass()"},
    {"_ZN4llvm3X869FR32ClassD1Ev", "llvm::X86::FR32Class::~FR32Class()"},
    {"_ZN4llvm3X869FR64ClassD1Ev", "llvm::X86::FR64Class::~FR64Class()"},
    {"_ZN4llvm3X869GR16ClassD1Ev", "llvm::X86::GR16Class::~GR16Class()"},
    {"_ZN4llvm3X8614GR16_ABCDClassD1Ev", "llvm::X86::GR16_ABCDClass::~GR16_ABCDClass()"},
    {"_ZN4llvm3X8615GR16_NOREXClassD1Ev", "llvm::X86::GR16_NOREXClass::~GR16_NOREXClass()"},
    {"_ZN4llvm3X869GR32ClassD1Ev", "llvm::X86::GR32Class::~GR32Class()"},
    {"_ZN4llvm3X8614GR32_ABCDClassD1Ev", "llvm::X86::GR32_ABCDClass::~GR32_ABCDClass()"},
    {"_ZN4llvm3X8612GR32_ADClassD1Ev", "llvm::X86::GR32_ADClass::~GR32_ADClass()"},
    {"_ZN4llvm3X8615GR32_NOREXClassD1Ev", "llvm::X86::GR32_NOREXClass::~GR32_NOREXClass()"},
    {"_ZN4llvm3X8614GR32_NOSPClassD1Ev", "llvm::X86::GR32_NOSPClass::~GR32_NOSPClass()"},
    {"_ZN4llvm3X8612GR32_TCClassD1Ev", "llvm::X86::GR32_TCClass::~GR32_TCClass()"},
    {"_ZN4llvm3X869GR64ClassD1Ev", "llvm::X86::GR64Class::~GR64Class()"},
    {"_ZN4llvm3X8614GR64_ABCDClassD1Ev", "llvm::X86::GR64_ABCDClass::~GR64_ABCDClass()"},
    {"_ZN4llvm3X8615GR64_NOREXClassD1Ev", "llvm::X86::GR64_NOREXClass::~GR64_NOREXClass()"},
    {"_ZN4llvm3X8620GR64_NOREX_NOSPClassD1Ev", "llvm::X86::GR64_NOREX_NOSPClass::~GR64_NOREX_NOSPClass()"},
    {"_ZN4llvm3X8614GR64_NOSPClassD1Ev", "llvm::X86::GR64_NOSPClass::~GR64_NOSPClass()"},
    {"_ZN4llvm3X8612GR64_TCClassD1Ev", "llvm::X86::GR64_TCClass::~GR64_TCClass()"},
    {"_ZN4llvm3X8615GR64_TCW64ClassD1Ev", "llvm::X86::GR64_TCW64Class::~GR64_TCW64Class()"},
    {"_ZN4llvm3X868GR8ClassD1Ev", "llvm::X86::GR8Class::~GR8Class()"},
    {"_ZN4llvm3X8615GR8_ABCD_HClassD1Ev", "llvm::X86::GR8_ABCD_HClass::~GR8_ABCD_HClass()"},
    {"_ZN4llvm3X8615GR8_ABCD_LClassD1Ev", "llvm::X86::GR8_ABCD_LClass::~GR8_ABCD_LClass()"},
    {"_ZN4llvm3X8614GR8_NOREXClassD1Ev", "llvm::X86::GR8_NOREXClass::~GR8_NOREXClass()"},
    {"_ZN4llvm3X8610RFP32ClassD1Ev", "llvm::X86::RFP32Class::~RFP32Class()"},
    {"_ZN4llvm3X8610RFP64ClassD1Ev", "llvm::X86::RFP64Class::~RFP64Class()"},
    {"_ZN4llvm3X8610RFP80ClassD1Ev", "llvm::X86::RFP80Class::~RFP80Class()"},
    {"_ZN4llvm3X868RSTClassD1Ev", "llvm::X86::RSTClass::~RSTClass()"},
    {"_ZN4llvm3X8616SEGMENT_REGClassD1Ev", "llvm::X86::SEGMENT_REGClass::~SEGMENT_REGClass()"},
    {"_ZN4llvm3X8610VR128ClassD1Ev", "llvm::X86::VR128Class::~VR128Class()"},
    {"_ZN4llvm3X8610VR256ClassD1Ev", "llvm::X86::VR256Class::~VR256Class()"},
    {"_ZN4llvm3X869VR64ClassD1Ev", "llvm::X86::VR64Class::~VR64Class()"},
    {"_ZN4llvm3X868CCRClassD0Ev", "llvm::X86::CCRClass::~CCRClass()"},
    {"_ZN4llvm3X869FR32ClassD0Ev", "llvm::X86::FR32Class::~FR32Class()"},
    {"_ZN4llvm3X869FR64ClassD0Ev", "llvm::X86::FR64Class::~FR64Class()"},
    {"_ZN4llvm3X869GR16ClassD0Ev", "llvm::X86::GR16Class::~GR16Class()"},
    {"_ZN4llvm3X8615GR16_NOREXClassD0Ev", "llvm::X86::GR16_NOREXClass::~GR16_NOREXClass()"},
    {"_ZN4llvm3X869GR32ClassD0Ev", "llvm::X86::GR32Class::~GR32Class()"},
    {"_ZN4llvm3X8615GR32_NOREXClassD0Ev", "llvm::X86::GR32_NOREXClass::~GR32_NOREXClass()"},
    {"_ZN4llvm3X8614GR32_NOSPClassD0Ev", "llvm::X86::GR32_NOSPClass::~GR32_NOSPClass()"},
    {"_ZN4llvm3X869GR64ClassD0Ev", "llvm::X86::GR64Class::~GR64Class()"},
    {"_ZN4llvm3X8615GR64_NOREXClassD0Ev", "llvm::X86::GR64_NOREXClass::~GR64_NOREXClass()"},
    {"_ZN4llvm3X8620GR64_NOREX_NOSPClassD0Ev", "llvm::X86::GR64_NOREX_NOSPClass::~GR64_NOREX_NOSPClass()"},
    {"_ZN4llvm3X8614GR64_NOSPClassD0Ev", "llvm::X86::GR64_NOSPClass::~GR64_NOSPClass()"},
    {"_ZN4llvm3X868GR8ClassD0Ev", "llvm::X86::GR8Class::~GR8Class()"},
    {"_ZN4llvm3X8614GR8_NOREXClassD0Ev", "llvm::X86::GR8_NOREXClass::~GR8_NOREXClass()"},
    {"_ZN4llvm3X868RSTClassD0Ev", "llvm::X86::RSTClass::~RSTClass()"},
    {"_ZN4llvm3X8610VR128ClassD0Ev", "llvm::X86::VR128Class::~VR128Class()"},
    {"_ZN4llvm3X8610VR256ClassD0Ev", "llvm::X86::VR256Class::~VR256Class()"},
    {"_ZN4llvm3X869VR64ClassD0Ev", "llvm::X86::VR64Class::~VR64Class()"},
    {"_ZN4llvm3X8616SEGMENT_REGClassD0Ev", "llvm::X86::SEGMENT_REGClass::~SEGMENT_REGClass()"},
    {"_ZN4llvm3X8610RFP80ClassD0Ev", "llvm::X86::RFP80Class::~RFP80Class()"},
    {"_ZN4llvm3X8610RFP64ClassD0Ev", "llvm::X86::RFP64Class::~RFP64Class()"},
    {"_ZN4llvm3X8610RFP32ClassD0Ev", "llvm::X86::RFP32Class::~RFP32Class()"},
    {"_ZN4llvm3X8615GR8_ABCD_LClassD0Ev", "llvm::X86::GR8_ABCD_LClass::~GR8_ABCD_LClass()"},
    {"_ZN4llvm3X8615GR8_ABCD_HClassD0Ev", "llvm::X86::GR8_ABCD_HClass::~GR8_ABCD_HClass()"},
    {"_ZN4llvm3X8615GR64_TCW64ClassD0Ev", "llvm::X86::GR64_TCW64Class::~GR64_TCW64Class()"},
    {"_ZN4llvm3X8612GR64_TCClassD0Ev", "llvm::X86::GR64_TCClass::~GR64_TCClass()"},
    {"_ZN4llvm3X8614GR64_ABCDClassD0Ev", "llvm::X86::GR64_ABCDClass::~GR64_ABCDClass()"},
    {"_ZN4llvm3X8612GR32_TCClassD0Ev", "llvm::X86::GR32_TCClass::~GR32_TCClass()"},
    {"_ZN4llvm3X8612GR32_ADClassD0Ev", "llvm::X86::GR32_ADClass::~GR32_ADClass()"},
    {"_ZN4llvm3X8614GR32_ABCDClassD0Ev", "llvm::X86::GR32_ABCDClass::~GR32_ABCDClass()"},
    {"_ZN4llvm3X8614GR16_ABCDClassD0Ev", "llvm::X86::GR16_ABCDClass::~GR16_ABCDClass()"},
    {"_ZN4llvm3X8614DEBUG_REGClassD0Ev", "llvm::X86::DEBUG_REGClass::~DEBUG_REGClass()"},
    {"_ZN4llvm3X8616CONTROL_REGClassD0Ev", "llvm::X86::CONTROL_REGClass::~CONTROL_REGClass()"},
    {"_ZN4llvm19X86SelectionDAGInfoC1ERKNS_16X86TargetMachineE", "llvm::X86SelectionDAGInfo::X86SelectionDAGInfo(llvm::X86TargetMachine const&)"},
    {"_ZN4llvm19X86SelectionDAGInfoC2ERKNS_16X86TargetMachineE", "llvm::X86SelectionDAGInfo::X86SelectionDAGInfo(llvm::X86TargetMachine const&)"},
    {"_ZN4llvm19X86SelectionDAGInfoD0Ev", "llvm::X86SelectionDAGInfo::~X86SelectionDAGInfo()"},
    {"_ZN4llvm19X86SelectionDAGInfoD1Ev", "llvm::X86SelectionDAGInfo::~X86SelectionDAGInfo()"},
    {"_ZN4llvm19X86SelectionDAGInfoD2Ev", "llvm::X86SelectionDAGInfo::~X86SelectionDAGInfo()"},
    {"_ZNK4llvm19X86SelectionDAGInfo23EmitTargetCodeForMemsetERNS_12SelectionDAGENS_8DebugLocENS_7SDValueES4_S4_S4_jbNS_18MachinePointerInfoE", "llvm::X86SelectionDAGInfo::EmitTargetCodeForMemset(llvm::SelectionDAG&, llvm::DebugLoc, llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::SDValue, unsigned int, bool, llvm::MachinePointerInfo) const"},
    {"_ZNK4llvm19X86SelectionDAGInfo23EmitTargetCodeForMemcpyERNS_12SelectionDAGENS_8DebugLocENS_7SDValueES4_S4_S4_jbbNS_18MachinePointerInfoES5_", "llvm::X86SelectionDAGInfo::EmitTargetCodeForMemcpy(llvm::SelectionDAG&, llvm::DebugLoc, llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::SDValue, unsigned int, bool, bool, llvm::MachinePointerInfo, llvm::MachinePointerInfo) const"},
    {"_ZNK4llvm3EVT6bitsGTES0_", "llvm::EVT::bitsGT(llvm::EVT) const"},
    {"_ZN4llvm12X86Subtarget22ParseSubtargetFeaturesERKSsS2_", "llvm::X86Subtarget::ParseSubtargetFeatures(std::string const&, std::string const&)"},
    {"_ZNK4llvm12X86Subtarget29ClassifyBlockAddressReferenceEv", "llvm::X86Subtarget::ClassifyBlockAddressReference() const"},
    {"_ZNK4llvm12X86Subtarget23ClassifyGlobalReferenceEPKNS_11GlobalValueERKNS_13TargetMachineE", "llvm::X86Subtarget::ClassifyGlobalReference(llvm::GlobalValue const*, llvm::TargetMachine const&) const"},
    {"_ZNK4llvm12X86Subtarget13getBZeroEntryEv", "llvm::X86Subtarget::getBZeroEntry() const"},
    {"_ZNK4llvm12X86Subtarget26IsLegalToCallImmediateAddrERKNS_13TargetMachineE", "llvm::X86Subtarget::IsLegalToCallImmediateAddr(llvm::TargetMachine const&) const"},
    {"_ZNK4llvm12X86Subtarget24getSpecialAddressLatencyEv", "llvm::X86Subtarget::getSpecialAddressLatency() const"},
    {"_ZN4llvm12X86Subtarget27AutoDetectSubtargetFeaturesEv", "llvm::X86Subtarget::AutoDetectSubtargetFeatures()"},
    {"_ZN4llvm12X86SubtargetC1ERKSsS2_b", "llvm::X86Subtarget::X86Subtarget(std::string const&, std::string const&, bool)"},
    {"_ZN4llvm12X86SubtargetC2ERKSsS2_b", "llvm::X86Subtarget::X86Subtarget(std::string const&, std::string const&, bool)"},
    {"_ZNK4llvm12X86Subtarget11IsCalleePopEbNS_11CallingConv2IDE", "llvm::X86Subtarget::IsCalleePop(bool, llvm::CallingConv::ID) const"},
    {"_Z15createMCAsmInfoRKN4llvm6TargetENS_9StringRefE", "createMCAsmInfo(llvm::Target const&, llvm::StringRef)"},
    {"_Z16createMCStreamerRKN4llvm6TargetERKSsRNS_9MCContextERNS_16TargetAsmBackendERNS_11raw_ostreamEPNS_13MCCodeEmitterEbb", "createMCStreamer(llvm::Target const&, std::string const&, llvm::MCContext&, llvm::TargetAsmBackend&, llvm::raw_ostream&, llvm::MCCodeEmitter*, bool, bool)"},
    {"_ZN4llvm19X86_32TargetMachineC1ERKNS_6TargetERKSsS5_", "llvm::X86_32TargetMachine::X86_32TargetMachine(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZN4llvm19X86_32TargetMachineC2ERKNS_6TargetERKSsS5_", "llvm::X86_32TargetMachine::X86_32TargetMachine(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZN4llvm16X86TargetMachineC2ERKNS_6TargetERKSsS5_b", "llvm::X86TargetMachine::X86TargetMachine(llvm::Target const&, std::string const&, std::string const&, bool)"},
    {"_ZN4llvm19X86_64TargetMachineC1ERKNS_6TargetERKSsS5_", "llvm::X86_64TargetMachine::X86_64TargetMachine(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZN4llvm19X86_64TargetMachineC2ERKNS_6TargetERKSsS5_", "llvm::X86_64TargetMachine::X86_64TargetMachine(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZN4llvm16X86TargetMachineC1ERKNS_6TargetERKSsS5_b", "llvm::X86TargetMachine::X86TargetMachine(llvm::Target const&, std::string const&, std::string const&, bool)"},
    {"_ZN4llvm16X86TargetMachine15addInstSelectorERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::X86TargetMachine::addInstSelector(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm16X86TargetMachine14addPreRegAllocERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::X86TargetMachine::addPreRegAlloc(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm16X86TargetMachine15addPostRegAllocERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::X86TargetMachine::addPostRegAlloc(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm16X86TargetMachine14addPreEmitPassERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::X86TargetMachine::addPreEmitPass(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm16X86TargetMachine14addCodeEmitterERNS_15PassManagerBaseENS_10CodeGenOpt5LevelERNS_14JITCodeEmitterE", "llvm::X86TargetMachine::addCodeEmitter(llvm::PassManagerBase&, llvm::CodeGenOpt::Level, llvm::JITCodeEmitter&)"},
    {"_ZN4llvm16X86TargetMachine21setCodeModelForStaticEv", "llvm::X86TargetMachine::setCodeModelForStatic()"},
    {"_ZN4llvm16X86TargetMachine18setCodeModelForJITEv", "llvm::X86TargetMachine::setCodeModelForJIT()"},
    {"_ZNK4llvm12X86Subtarget13isTargetWin64Ev", "llvm::X86Subtarget::isTargetWin64() const"},
    {"_ZNK4llvm16X86TargetMachine16getSubtargetImplEv", "llvm::X86TargetMachine::getSubtargetImpl() const"},
    {"_ZN4llvm16X86TargetMachineD1Ev", "llvm::X86TargetMachine::~X86TargetMachine()"},
    {"_ZN4llvm16X86TargetMachineD0Ev", "llvm::X86TargetMachine::~X86TargetMachine()"},
    {"_ZNK4llvm16X86TargetMachine12getInstrInfoEv", "llvm::X86TargetMachine::getInstrInfo() const"},
    {"_ZNK4llvm16X86TargetMachine16getFrameLoweringEv", "llvm::X86TargetMachine::getFrameLowering() const"},
    {"_ZNK4llvm16X86TargetMachine17getTargetLoweringEv", "llvm::X86TargetMachine::getTargetLowering() const"},
    {"_ZNK4llvm16X86TargetMachine19getSelectionDAGInfoEv", "llvm::X86TargetMachine::getSelectionDAGInfo() const"},
    {"_ZNK4llvm16X86TargetMachine15getRegisterInfoEv", "llvm::X86TargetMachine::getRegisterInfo() const"},
    {"_ZN4llvm16X86TargetMachine10getJITInfoEv", "llvm::X86TargetMachine::getJITInfo()"},
    {"_ZNK4llvm16X86TargetMachine16getELFWriterInfoEv", "llvm::X86TargetMachine::getELFWriterInfo() const"},
    {"_ZN4llvm19X86_64TargetMachineD1Ev", "llvm::X86_64TargetMachine::~X86_64TargetMachine()"},
    {"_ZN4llvm19X86_64TargetMachineD0Ev", "llvm::X86_64TargetMachine::~X86_64TargetMachine()"},
    {"_ZNK4llvm19X86_64TargetMachine12getInstrInfoEv", "llvm::X86_64TargetMachine::getInstrInfo() const"},
    {"_ZNK4llvm19X86_64TargetMachine17getTargetLoweringEv", "llvm::X86_64TargetMachine::getTargetLowering() const"},
    {"_ZNK4llvm19X86_64TargetMachine19getSelectionDAGInfoEv", "llvm::X86_64TargetMachine::getSelectionDAGInfo() const"},
    {"_ZNK4llvm19X86_64TargetMachine13getDataLayoutEv", "llvm::X86_64TargetMachine::getDataLayout() const"},
    {"_ZN4llvm19X86_64TargetMachine10getJITInfoEv", "llvm::X86_64TargetMachine::getJITInfo()"},
    {"_ZN4llvm19X86_32TargetMachineD1Ev", "llvm::X86_32TargetMachine::~X86_32TargetMachine()"},
    {"_ZN4llvm19X86_32TargetMachineD0Ev", "llvm::X86_32TargetMachine::~X86_32TargetMachine()"},
    {"_ZNK4llvm19X86_32TargetMachine12getInstrInfoEv", "llvm::X86_32TargetMachine::getInstrInfo() const"},
    {"_ZNK4llvm19X86_32TargetMachine17getTargetLoweringEv", "llvm::X86_32TargetMachine::getTargetLowering() const"},
    {"_ZNK4llvm19X86_32TargetMachine19getSelectionDAGInfoEv", "llvm::X86_32TargetMachine::getSelectionDAGInfo() const"},
    {"_ZNK4llvm19X86_32TargetMachine13getDataLayoutEv", "llvm::X86_32TargetMachine::getDataLayout() const"},
    {"_ZN4llvm19X86_32TargetMachine10getJITInfoEv", "llvm::X86_32TargetMachine::getJITInfo()"},
    {"_ZN4llvm19X86_32TargetMachineD2Ev", "llvm::X86_32TargetMachine::~X86_32TargetMachine()"},
    {"_ZN4llvm10X86JITInfoD1Ev", "llvm::X86JITInfo::~X86JITInfo()"},
    {"_ZN4llvm17X86TargetLoweringD1Ev", "llvm::X86TargetLowering::~X86TargetLowering()"},
    {"_ZN4llvm12X86InstrInfoD1Ev", "llvm::X86InstrInfo::~X86InstrInfo()"},
    {"_ZN4llvm16X86TargetMachineD2Ev", "llvm::X86TargetMachine::~X86TargetMachine()"},
    {"_ZN4llvm16X86FrameLoweringD1Ev", "llvm::X86FrameLowering::~X86FrameLowering()"},
    {"_ZN4llvm12X86SubtargetD1Ev", "llvm::X86Subtarget::~X86Subtarget()"},
    {"_ZN4llvm12X86SubtargetD0Ev", "llvm::X86Subtarget::~X86Subtarget()"},
    {"_ZN4llvm16X86FrameLoweringD0Ev", "llvm::X86FrameLowering::~X86FrameLowering()"},
    {"_ZN4llvm15X86RegisterInfoD1Ev", "llvm::X86RegisterInfo::~X86RegisterInfo()"},
    {"_ZN4llvm12X86InstrInfoD0Ev", "llvm::X86InstrInfo::~X86InstrInfo()"},
    {"_ZNK4llvm12X86InstrInfo15getRegisterInfoEv", "llvm::X86InstrInfo::getRegisterInfo() const"},
    {"_ZN4llvm15X86RegisterInfoD0Ev", "llvm::X86RegisterInfo::~X86RegisterInfo()"},
    {"_ZN4llvm18X86GenRegisterInfoD1Ev", "llvm::X86GenRegisterInfo::~X86GenRegisterInfo()"},
    {"_ZN4llvm18X86GenRegisterInfoD0Ev", "llvm::X86GenRegisterInfo::~X86GenRegisterInfo()"},
    {"_ZNK4llvm18X86GenRegisterInfo21needsStackRealignmentERKNS_15MachineFunctionE", "llvm::X86GenRegisterInfo::needsStackRealignment(llvm::MachineFunction const&) const"},
    {"_ZN4llvm17X86TargetLoweringD0Ev", "llvm::X86TargetLowering::~X86TargetLowering()"},
    {"_ZNK4llvm14TargetLowering23getSchedulingPreferenceEPNS_6SDNodeE", "llvm::TargetLowering::getSchedulingPreference(llvm::SDNode*) const"},
    {"_ZNK4llvm14TargetLowering14getRegClassForENS_3EVTE", "llvm::TargetLowering::getRegClassFor(llvm::EVT) const"},
    {"_ZNK4llvm14TargetLowering18getTgtMemIntrinsicERNS0_13IntrinsicInfoERKNS_8CallInstEj", "llvm::TargetLowering::getTgtMemIntrinsic(llvm::TargetLowering::IntrinsicInfo&, llvm::CallInst const&, unsigned int) const"},
    {"_ZNK4llvm17X86TargetLowering22ShouldShrinkFPConstantENS_3EVTE", "llvm::X86TargetLowering::ShouldShrinkFPConstant(llvm::EVT) const"},
    {"_ZNK4llvm17X86TargetLowering29allowsUnalignedMemoryAccessesENS_3EVTE", "llvm::X86TargetLowering::allowsUnalignedMemoryAccesses(llvm::EVT) const"},
    {"_ZNK4llvm14TargetLowering25getPreIndexedAddressPartsEPNS_6SDNodeERNS_7SDValueES4_RNS_3ISD14MemIndexedModeERNS_12SelectionDAGE", "llvm::TargetLowering::getPreIndexedAddressParts(llvm::SDNode*, llvm::SDValue&, llvm::SDValue&, llvm::ISD::MemIndexedMode&, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm14TargetLowering26getPostIndexedAddressPartsEPNS_6SDNodeES2_RNS_7SDValueES4_RNS_3ISD14MemIndexedModeERNS_12SelectionDAGE", "llvm::TargetLowering::getPostIndexedAddressParts(llvm::SDNode*, llvm::SDNode*, llvm::SDValue&, llvm::SDValue&, llvm::ISD::MemIndexedMode&, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm14TargetLowering22getMaximalGlobalOffsetEv", "llvm::TargetLowering::getMaximalGlobalOffset() const"},
    {"_ZNK4llvm14TargetLowering33isDesirableToTransformToIntegerOpEjNS_3EVTE", "llvm::TargetLowering::isDesirableToTransformToIntegerOp(unsigned int, llvm::EVT) const"},
    {"_ZNK4llvm14TargetLowering20isLegalICmpImmediateEx", "llvm::TargetLowering::isLegalICmpImmediate(long long) const"},
    {"_ZN4llvm10X86JITInfoD0Ev", "llvm::X86JITInfo::~X86JITInfo()"},
    {"_ZN4llvm19X86_64TargetMachineD2Ev", "llvm::X86_64TargetMachine::~X86_64TargetMachine()"},
    {"_ZN4llvm21RegisterTargetMachineINS_19X86_64TargetMachineEE9AllocatorERKNS_6TargetERKSsS7_", "llvm::RegisterTargetMachine<llvm::X86_64TargetMachine>::Allocator(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZN4llvm21RegisterTargetMachineINS_19X86_32TargetMachineEE9AllocatorERKNS_6TargetERKSsS7_", "llvm::RegisterTargetMachine<llvm::X86_32TargetMachine>::Allocator(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZNK4llvm27X8664_MachoTargetObjectFile30getExprForDwarfGlobalReferenceEPKNS_11GlobalValueEPNS_7ManglerEPNS_17MachineModuleInfoEjRNS_10MCStreamerE", "llvm::X8664_MachoTargetObjectFile::getExprForDwarfGlobalReference(llvm::GlobalValue const*, llvm::Mangler*, llvm::MachineModuleInfo*, unsigned int, llvm::MCStreamer&) const"},
    {"_ZNK4llvm25X8632_ELFTargetObjectFile22getPersonalityEncodingEv", "llvm::X8632_ELFTargetObjectFile::getPersonalityEncoding() const"},
    {"_ZNK4llvm25X8632_ELFTargetObjectFile15getLSDAEncodingEv", "llvm::X8632_ELFTargetObjectFile::getLSDAEncoding() const"},
    {"_ZNK4llvm25X8632_ELFTargetObjectFile14getFDEEncodingEv", "llvm::X8632_ELFTargetObjectFile::getFDEEncoding() const"},
    {"_ZNK4llvm25X8632_ELFTargetObjectFile16getTTypeEncodingEv", "llvm::X8632_ELFTargetObjectFile::getTTypeEncoding() const"},
    {"_ZNK4llvm25X8664_ELFTargetObjectFile22getPersonalityEncodingEv", "llvm::X8664_ELFTargetObjectFile::getPersonalityEncoding() const"},
    {"_ZNK4llvm25X8664_ELFTargetObjectFile15getLSDAEncodingEv", "llvm::X8664_ELFTargetObjectFile::getLSDAEncoding() const"},
    {"_ZNK4llvm25X8664_ELFTargetObjectFile14getFDEEncodingEv", "llvm::X8664_ELFTargetObjectFile::getFDEEncoding() const"},
    {"_ZNK4llvm25X8664_ELFTargetObjectFile16getTTypeEncodingEv", "llvm::X8664_ELFTargetObjectFile::getTTypeEncoding() const"},
    {"_ZN4llvm25X8632_ELFTargetObjectFileD1Ev", "llvm::X8632_ELFTargetObjectFile::~X8632_ELFTargetObjectFile()"},
    {"_ZN4llvm25X8632_ELFTargetObjectFileD0Ev", "llvm::X8632_ELFTargetObjectFile::~X8632_ELFTargetObjectFile()"},
    {"_ZN4llvm25X8664_ELFTargetObjectFileD1Ev", "llvm::X8664_ELFTargetObjectFile::~X8664_ELFTargetObjectFile()"},
    {"_ZN4llvm25X8664_ELFTargetObjectFileD0Ev", "llvm::X8664_ELFTargetObjectFile::~X8664_ELFTargetObjectFile()"},
    {"_ZN4llvm27X8664_MachoTargetObjectFileD1Ev", "llvm::X8664_MachoTargetObjectFile::~X8664_MachoTargetObjectFile()"},
    {"_ZN4llvm27X8664_MachoTargetObjectFileD0Ev", "llvm::X8664_MachoTargetObjectFile::~X8664_MachoTargetObjectFile()"},
    {"_ZN4llvm17X86ATTInstPrinter16printInstructionEPKNS_6MCInstERNS_11raw_ostreamE", "llvm::X86ATTInstPrinter::printInstruction(llvm::MCInst const*, llvm::raw_ostream&)"},
    {"_ZN4llvm17X86ATTInstPrinter12printOperandEPKNS_6MCInstEjRNS_11raw_ostreamE", "llvm::X86ATTInstPrinter::printOperand(llvm::MCInst const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm17X86ATTInstPrinter15print_pcrel_immEPKNS_6MCInstEjRNS_11raw_ostreamE", "llvm::X86ATTInstPrinter::print_pcrel_imm(llvm::MCInst const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm17X86ATTInstPrinter10printSSECCEPKNS_6MCInstEjRNS_11raw_ostreamE", "llvm::X86ATTInstPrinter::printSSECC(llvm::MCInst const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm17X86ATTInstPrinter15getRegisterNameEj", "llvm::X86ATTInstPrinter::getRegisterName(unsigned int)"},
    {"_ZN4llvm17X86ATTInstPrinter18getInstructionNameEj", "llvm::X86ATTInstPrinter::getInstructionName(unsigned int)"},
    {"_ZN4llvm17X86ATTInstPrinter9printInstEPKNS_6MCInstERNS_11raw_ostreamE", "llvm::X86ATTInstPrinter::printInst(llvm::MCInst const*, llvm::raw_ostream&)"},
    {"_ZNK4llvm17X86ATTInstPrinter13getOpcodeNameEj", "llvm::X86ATTInstPrinter::getOpcodeName(unsigned int) const"},
    {"_ZN4llvm17X86ATTInstPrinter17printMemReferenceEPKNS_6MCInstEjRNS_11raw_ostreamE", "llvm::X86ATTInstPrinter::printMemReference(llvm::MCInst const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm17X86ATTInstPrinterD1Ev", "llvm::X86ATTInstPrinter::~X86ATTInstPrinter()"},
    {"_ZN4llvm17X86ATTInstPrinterD0Ev", "llvm::X86ATTInstPrinter::~X86ATTInstPrinter()"},
    {"_ZN4llvm22EmitAnyX86InstCommentsEPKNS_6MCInstERNS_11raw_ostreamEPFPKcjE", "llvm::EmitAnyX86InstComments(llvm::MCInst const*, llvm::raw_ostream&, char const* (*)(unsigned int))"},
    {"_Z16DecodeSHUFPSMaskjjRN4llvm15SmallVectorImplIjEE", "DecodeSHUFPSMask(unsigned int, unsigned int, llvm::SmallVectorImpl<unsigned int>&)"},
    {"_ZN4llvm19X86IntelInstPrinter16printInstructionEPKNS_6MCInstERNS_11raw_ostreamE", "llvm::X86IntelInstPrinter::printInstruction(llvm::MCInst const*, llvm::raw_ostream&)"},
    {"_ZN4llvm19X86IntelInstPrinter12printOperandEPKNS_6MCInstEjRNS_11raw_ostreamE", "llvm::X86IntelInstPrinter::printOperand(llvm::MCInst const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm19X86IntelInstPrinter15print_pcrel_immEPKNS_6MCInstEjRNS_11raw_ostreamE", "llvm::X86IntelInstPrinter::print_pcrel_imm(llvm::MCInst const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm19X86IntelInstPrinter10printSSECCEPKNS_6MCInstEjRNS_11raw_ostreamE", "llvm::X86IntelInstPrinter::printSSECC(llvm::MCInst const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm19X86IntelInstPrinter15getRegisterNameEj", "llvm::X86IntelInstPrinter::getRegisterName(unsigned int)"},
    {"_ZN4llvm19X86IntelInstPrinter18getInstructionNameEj", "llvm::X86IntelInstPrinter::getInstructionName(unsigned int)"},
    {"_ZN4llvm19X86IntelInstPrinter9printInstEPKNS_6MCInstERNS_11raw_ostreamE", "llvm::X86IntelInstPrinter::printInst(llvm::MCInst const*, llvm::raw_ostream&)"},
    {"_ZNK4llvm19X86IntelInstPrinter13getOpcodeNameEj", "llvm::X86IntelInstPrinter::getOpcodeName(unsigned int) const"},
    {"_ZN4llvm19X86IntelInstPrinter17printMemReferenceEPKNS_6MCInstEjRNS_11raw_ostreamE", "llvm::X86IntelInstPrinter::printMemReference(llvm::MCInst const*, unsigned int, llvm::raw_ostream&)"},
    {"_ZN4llvm19X86IntelInstPrinterD1Ev", "llvm::X86IntelInstPrinter::~X86IntelInstPrinter()"},
    {"_ZN4llvm19X86IntelInstPrinterD0Ev", "llvm::X86IntelInstPrinter::~X86IntelInstPrinter()"},
    {"_ZN4llvm14RegisterTargetILNS_6Triple8ArchTypeE16ELb1EE21getTripleMatchQualityERKSs", "llvm::RegisterTarget<(llvm::Triple::ArchType)16, true>::getTripleMatchQuality(std::string const&)"},
    {"_ZN4llvm14RegisterTargetILNS_6Triple8ArchTypeE15ELb1EE21getTripleMatchQualityERKSs", "llvm::RegisterTarget<(llvm::Triple::ArchType)15, true>::getTripleMatchQuality(std::string const&)"},
    {"_ZN4llvm16RegisterAsmLexerIN12_GLOBAL__N_113ThumbAsmLexerEE9AllocatorERKNS_6TargetERKNS_9MCAsmInfoE", "llvm::RegisterAsmLexer<(anonymous namespace)::ThumbAsmLexer>::Allocator(llvm::Target const&, llvm::MCAsmInfo const&)"},
    {"_ZN12_GLOBAL__N_115ARMBaseAsmLexer15InitRegisterMapEPKN4llvm18TargetRegisterInfoE", "(anonymous namespace)::ARMBaseAsmLexer::InitRegisterMap(llvm::TargetRegisterInfo const*)"},
    {"_ZN12_GLOBAL__N_115ARMBaseAsmLexer8LexTokenEv", "(anonymous namespace)::ARMBaseAsmLexer::LexToken()"},
    {"_ZN12_GLOBAL__N_113ThumbAsmLexerD1Ev", "(anonymous namespace)::ThumbAsmLexer::~ThumbAsmLexer()"},
    {"_ZN12_GLOBAL__N_113ThumbAsmLexerD0Ev", "(anonymous namespace)::ThumbAsmLexer::~ThumbAsmLexer()"},
    {"_ZN12_GLOBAL__N_115ARMBaseAsmLexerD1Ev", "(anonymous namespace)::ARMBaseAsmLexer::~ARMBaseAsmLexer()"},
    {"_ZN12_GLOBAL__N_115ARMBaseAsmLexerD0Ev", "(anonymous namespace)::ARMBaseAsmLexer::~ARMBaseAsmLexer()"},
    {"_ZN4llvm16RegisterAsmLexerIN12_GLOBAL__N_111ARMAsmLexerEE9AllocatorERKNS_6TargetERKNS_9MCAsmInfoE", "llvm::RegisterAsmLexer<(anonymous namespace)::ARMAsmLexer>::Allocator(llvm::Target const&, llvm::MCAsmInfo const&)"},
    {"_ZN12_GLOBAL__N_111ARMAsmLexerD1Ev", "(anonymous namespace)::ARMAsmLexer::~ARMAsmLexer()"},
    {"_ZN12_GLOBAL__N_111ARMAsmLexerD0Ev", "(anonymous namespace)::ARMAsmLexer::~ARMAsmLexer()"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsjESt10_Select1stIS2_ESt4lessISsESaIS2_EE8_M_eraseEPSt13_Rb_tree_nodeIS2_E", "std::_Rb_tree<std::string, std::pair<std::string const, unsigned int>, std::_Select1st<std::pair<std::string const, unsigned int>>, std::less<std::string>, std::allocator<std::pair<std::string const, unsigned int>>>::_M_erase(std::_Rb_tree_node<std::pair<std::string const, unsigned int>>*)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsjESt10_Select1stIS2_ESt4lessISsESaIS2_EE4findERS1_", "std::_Rb_tree<std::string, std::pair<std::string const, unsigned int>, std::_Select1st<std::pair<std::string const, unsigned int>>, std::less<std::string>, std::allocator<std::pair<std::string const, unsigned int>>>::find(std::string const&)"},
    {"_ZNSt3mapISsjSt4lessISsESaISt4pairIKSsjEEEixERS3_", "std::map<std::string, unsigned int, std::less<std::string>, std::allocator<std::pair<std::string const, unsigned int>>>::operator[](std::string const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsjESt10_Select1stIS2_ESt4lessISsESaIS2_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS2_ERKS2_", "std::_Rb_tree<std::string, std::pair<std::string const, unsigned int>, std::_Select1st<std::pair<std::string const, unsigned int>>, std::less<std::string>, std::allocator<std::pair<std::string const, unsigned int>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<std::string const, unsigned int>>, std::pair<std::string const, unsigned int> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsjESt10_Select1stIS2_ESt4lessISsESaIS2_EE9_M_insertEPSt18_Rb_tree_node_baseSA_RKS2_", "std::_Rb_tree<std::string, std::pair<std::string const, unsigned int>, std::_Select1st<std::pair<std::string const, unsigned int>>, std::less<std::string>, std::allocator<std::pair<std::string const, unsigned int>>>::_M_insert(std::_Rb_tree_node_base*, std::_Rb_tree_node_base*, std::pair<std::string const, unsigned int> const&)"},
    {"_ZNSt8_Rb_treeISsSt4pairIKSsjESt10_Select1stIS2_ESt4lessISsESaIS2_EE16_M_insert_uniqueERKS2_", "std::_Rb_tree<std::string, std::pair<std::string const, unsigned int>, std::_Select1st<std::pair<std::string const, unsigned int>>, std::less<std::string>, std::allocator<std::pair<std::string const, unsigned int>>>::_M_insert_unique(std::pair<std::string const, unsigned int> const&)"},
    {"_ZN4llvm17RegisterAsmParserIN12_GLOBAL__N_112ARMAsmParserEE9AllocatorERKNS_6TargetERNS_11MCAsmParserERNS_13TargetMachineE", "llvm::RegisterAsmParser<(anonymous namespace)::ARMAsmParser>::Allocator(llvm::Target const&, llvm::MCAsmParser&, llvm::TargetMachine&)"},
    {"_ZN12_GLOBAL__N_112ARMAsmParserD1Ev", "(anonymous namespace)::ARMAsmParser::~ARMAsmParser()"},
    {"_ZN12_GLOBAL__N_112ARMAsmParserD0Ev", "(anonymous namespace)::ARMAsmParser::~ARMAsmParser()"},
    {"_ZN12_GLOBAL__N_112ARMAsmParser13ParseRegisterERjRN4llvm5SMLocES4_", "(anonymous namespace)::ARMAsmParser::ParseRegister(unsigned int&, llvm::SMLoc&, llvm::SMLoc&)"},
    {"_ZN12_GLOBAL__N_112ARMAsmParser16ParseInstructionEN4llvm9StringRefENS1_5SMLocERNS1_15SmallVectorImplIPNS1_18MCParsedAsmOperandEEE", "(anonymous namespace)::ARMAsmParser::ParseInstruction(llvm::StringRef, llvm::SMLoc, llvm::SmallVectorImpl<llvm::MCParsedAsmOperand*>&)"},
    {"_ZN12_GLOBAL__N_112ARMAsmParser14ParseDirectiveEN4llvm8AsmTokenE", "(anonymous namespace)::ARMAsmParser::ParseDirective(llvm::AsmToken)"},
    {"_ZN12_GLOBAL__N_112ARMAsmParser23MatchAndEmitInstructionEN4llvm5SMLocERNS1_15SmallVectorImplIPNS1_18MCParsedAsmOperandEEERNS1_10MCStreamerE", "(anonymous namespace)::ARMAsmParser::MatchAndEmitInstruction(llvm::SMLoc, llvm::SmallVectorImpl<llvm::MCParsedAsmOperand*>&, llvm::MCStreamer&)"},
    {"_ZN12_GLOBAL__N_112ARMAsmParser20MatchInstructionImplERKN4llvm15SmallVectorImplIPNS1_18MCParsedAsmOperandEEERNS1_6MCInstERj", "(anonymous namespace)::ARMAsmParser::MatchInstructionImpl(llvm::SmallVectorImpl<llvm::MCParsedAsmOperand*> const&, llvm::MCInst&, unsigned int&)"},
    {"_ZN12_GLOBAL__N_110ARMOperandD1Ev", "(anonymous namespace)::ARMOperand::~ARMOperand()"},
    {"_ZN12_GLOBAL__N_110ARMOperandD0Ev", "(anonymous namespace)::ARMOperand::~ARMOperand()"},
    {"_ZNK12_GLOBAL__N_110ARMOperand11getStartLocEv", "(anonymous namespace)::ARMOperand::getStartLoc() const"},
    {"_ZNK12_GLOBAL__N_110ARMOperand9getEndLocEv", "(anonymous namespace)::ARMOperand::getEndLoc() const"},
    {"_ZNK12_GLOBAL__N_110ARMOperand4dumpERN4llvm11raw_ostreamE", "(anonymous namespace)::ARMOperand::dump(llvm::raw_ostream&) const"},
    {"_ZN12_GLOBAL__N_112ARMAsmParser15ConvertToMCInstEjRN4llvm6MCInstEjRKNS1_15SmallVectorImplIPNS1_18MCParsedAsmOperandEEE", "(anonymous namespace)::ARMAsmParser::ConvertToMCInst(unsigned int, llvm::MCInst&, unsigned int, llvm::SmallVectorImpl<llvm::MCParsedAsmOperand*> const&)"},
    {"_ZNK12_GLOBAL__N_110ARMOperand19addCondCodeOperandsERN4llvm6MCInstEj", "(anonymous namespace)::ARMOperand::addCondCodeOperands(llvm::MCInst&, unsigned int) const"},
    {"_ZNK12_GLOBAL__N_110ARMOperand14addImmOperandsERN4llvm6MCInstEj", "(anonymous namespace)::ARMOperand::addImmOperands(llvm::MCInst&, unsigned int) const"},
    {"_ZNK12_GLOBAL__N_110ARMOperand19addMemMode5OperandsERN4llvm6MCInstEj", "(anonymous namespace)::ARMOperand::addMemMode5Operands(llvm::MCInst&, unsigned int) const"},
    {"_ZN12_GLOBAL__N_112ARMAsmParser12ParseOperandERN4llvm15SmallVectorImplIPNS1_18MCParsedAsmOperandEEENS1_9StringRefE", "(anonymous namespace)::ARMAsmParser::ParseOperand(llvm::SmallVectorImpl<llvm::MCParsedAsmOperand*>&, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_112ARMAsmParser16TryParseRegisterEv", "(anonymous namespace)::ARMAsmParser::TryParseRegister()"},
    {"_ZN4llvm25array_pod_sort_comparatorIjEEiPKvS2_", "int llvm::array_pod_sort_comparator<unsigned int>(void const*, void const*)"},
    {"_ZN12_GLOBAL__N_112ARMAsmParser20ParseMemoryOffsetRegERbS1_R9ShiftTypeRPKN4llvm6MCExprES8_S1_RiRNS4_5SMLocE", "(anonymous namespace)::ARMAsmParser::ParseMemoryOffsetReg(bool&, bool&, ShiftType&, llvm::MCExpr const*&, llvm::MCExpr const*&, bool&, int&, llvm::SMLoc&)"},
    {"_ZN4llvm15SmallVectorImplIPNS_18MCParsedAsmOperandEE6insertEPS2_RKS2_", "llvm::SmallVectorImpl<llvm::MCParsedAsmOperand*>::insert(llvm::MCParsedAsmOperand**, llvm::MCParsedAsmOperand* const&)"},
    {"_ZN4llvm18MCParsedAsmOperandD1Ev", "llvm::MCParsedAsmOperand::~MCParsedAsmOperand()"},
    {"_ZN4llvm18MCParsedAsmOperandD0Ev", "llvm::MCParsedAsmOperand::~MCParsedAsmOperand()"},
    {"_ZN4llvm8DenseMapIjbNS_12DenseMapInfoIjEENS1_IbEEE16InsertIntoBucketERKjRKbPSt4pairIjbE", "llvm::DenseMap<unsigned int, bool, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<bool>>::InsertIntoBucket(unsigned int const&, bool const&, std::pair<unsigned int, bool>*)"},
    {"_ZN4llvm8DenseMapIjbNS_12DenseMapInfoIjEENS1_IbEEE4growEj", "llvm::DenseMap<unsigned int, bool, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<bool>>::grow(unsigned int)"},
    {"_ZN4llvm23SmallVectorTemplateBaseISt4pairIjNS_5SMLocEELb0EE4growEm", "llvm::SmallVectorTemplateBase<std::pair<unsigned int, llvm::SMLoc>, false>::grow(unsigned long)"},
    {"_ZN4llvm19createARMAsmBackendERKNS_6TargetERKSs", "llvm::createARMAsmBackend(llvm::Target const&, std::string const&)"},
    {"_ZN12_GLOBAL__N_116ELFARMAsmBackendD1Ev", "(anonymous namespace)::ELFARMAsmBackend::~ELFARMAsmBackend()"},
    {"_ZN12_GLOBAL__N_116ELFARMAsmBackendD0Ev", "(anonymous namespace)::ELFARMAsmBackend::~ELFARMAsmBackend()"},
    {"_ZNK12_GLOBAL__N_116ELFARMAsmBackend18createObjectWriterERN4llvm11raw_ostreamE", "(anonymous namespace)::ELFARMAsmBackend::createObjectWriter(llvm::raw_ostream&) const"},
    {"_ZNK12_GLOBAL__N_113ARMAsmBackend16getNumFixupKindsEv", "(anonymous namespace)::ARMAsmBackend::getNumFixupKinds() const"},
    {"_ZNK12_GLOBAL__N_113ARMAsmBackend16getFixupKindInfoEN4llvm11MCFixupKindE", "(anonymous namespace)::ARMAsmBackend::getFixupKindInfo(llvm::MCFixupKind) const"},
    {"_ZNK12_GLOBAL__N_116ELFARMAsmBackend10ApplyFixupERKN4llvm7MCFixupEPcjy", "(anonymous namespace)::ELFARMAsmBackend::ApplyFixup(llvm::MCFixup const&, char*, unsigned int, unsigned long long) const"},
    {"_ZNK12_GLOBAL__N_113ARMAsmBackend17MayNeedRelaxationERKN4llvm6MCInstE", "(anonymous namespace)::ARMAsmBackend::MayNeedRelaxation(llvm::MCInst const&) const"},
    {"_ZNK12_GLOBAL__N_113ARMAsmBackend16RelaxInstructionERKN4llvm6MCInstERS2_", "(anonymous namespace)::ARMAsmBackend::RelaxInstruction(llvm::MCInst const&, llvm::MCInst&) const"},
    {"_ZNK12_GLOBAL__N_113ARMAsmBackend12WriteNopDataEyPN4llvm14MCObjectWriterE", "(anonymous namespace)::ARMAsmBackend::WriteNopData(unsigned long long, llvm::MCObjectWriter*) const"},
    {"_ZN12_GLOBAL__N_113ARMAsmBackend19HandleAssemblerFlagEN4llvm15MCAssemblerFlagE", "(anonymous namespace)::ARMAsmBackend::HandleAssemblerFlag(llvm::MCAssemblerFlag)"},
    {"_Z16adjustFixupValuejy", "adjustFixupValue(unsigned int, unsigned long long)"},
    {"_ZN12_GLOBAL__N_118ARMELFObjectWriterD1Ev", "(anonymous namespace)::ARMELFObjectWriter::~ARMELFObjectWriter()"},
    {"_ZN12_GLOBAL__N_118ARMELFObjectWriterD0Ev", "(anonymous namespace)::ARMELFObjectWriter::~ARMELFObjectWriter()"},
    {"_ZN12_GLOBAL__N_113ARMAsmBackendD1Ev", "(anonymous namespace)::ARMAsmBackend::~ARMAsmBackend()"},
    {"_ZN12_GLOBAL__N_113ARMAsmBackendD0Ev", "(anonymous namespace)::ARMAsmBackend::~ARMAsmBackend()"},
    {"_ZN12_GLOBAL__N_119DarwinARMAsmBackendD1Ev", "(anonymous namespace)::DarwinARMAsmBackend::~DarwinARMAsmBackend()"},
    {"_ZN12_GLOBAL__N_119DarwinARMAsmBackendD0Ev", "(anonymous namespace)::DarwinARMAsmBackend::~DarwinARMAsmBackend()"},
    {"_ZNK12_GLOBAL__N_119DarwinARMAsmBackend18createObjectWriterERN4llvm11raw_ostreamE", "(anonymous namespace)::DarwinARMAsmBackend::createObjectWriter(llvm::raw_ostream&) const"},
    {"_ZNK12_GLOBAL__N_119DarwinARMAsmBackend25doesSectionRequireSymbolsERKN4llvm9MCSectionE", "(anonymous namespace)::DarwinARMAsmBackend::doesSectionRequireSymbols(llvm::MCSection const&) const"},
    {"_ZNK12_GLOBAL__N_119DarwinARMAsmBackend10ApplyFixupERKN4llvm7MCFixupEPcjy", "(anonymous namespace)::DarwinARMAsmBackend::ApplyFixup(llvm::MCFixup const&, char*, unsigned int, unsigned long long) const"},
    {"_ZN12_GLOBAL__N_119ARMMachObjectWriterD1Ev", "(anonymous namespace)::ARMMachObjectWriter::~ARMMachObjectWriter()"},
    {"_ZN12_GLOBAL__N_119ARMMachObjectWriterD0Ev", "(anonymous namespace)::ARMMachObjectWriter::~ARMMachObjectWriter()"},
    {"_ZN4llvm14MCObjectWriter7Write16Et", "llvm::MCObjectWriter::Write16(unsigned short)"},
    {"_ZN4llvm14MCObjectWriter9WriteLE32Ej", "llvm::MCObjectWriter::WriteLE32(unsigned int)"},
    {"_ZN4llvm14MCObjectWriter9WriteBE32Ej", "llvm::MCObjectWriter::WriteBE32(unsigned int)"},
    {"_ZNK4llvm13ARMAsmPrinter21getDebugValueLocationEPKNS_12MachineInstrE", "llvm::ARMAsmPrinter::getDebugValueLocation(llvm::MachineInstr const*) const"},
    {"_ZN4llvm13ARMAsmPrinter22EmitFunctionEntryLabelEv", "llvm::ARMAsmPrinter::EmitFunctionEntryLabel()"},
    {"_ZN4llvm13ARMAsmPrinter20runOnMachineFunctionERNS_15MachineFunctionE", "llvm::ARMAsmPrinter::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN4llvm13ARMAsmPrinter12printOperandEPKNS_12MachineInstrEiRNS_11raw_ostreamEPKc", "llvm::ARMAsmPrinter::printOperand(llvm::MachineInstr const*, int, llvm::raw_ostream&, char const*)"},
    {"_ZNK4llvm13ARMAsmPrinter27GetARMSetPICJumpTableLabel2EjjPKNS_17MachineBasicBlockE", "llvm::ARMAsmPrinter::GetARMSetPICJumpTableLabel2(unsigned int, unsigned int, llvm::MachineBasicBlock const*) const"},
    {"_ZNK4llvm13ARMAsmPrinter27GetARMJTIPICJumpTableLabel2Ejj", "llvm::ARMAsmPrinter::GetARMJTIPICJumpTableLabel2(unsigned int, unsigned int) const"},
    {"_ZNK4llvm13ARMAsmPrinter17GetARMSJLJEHLabelEv", "llvm::ARMAsmPrinter::GetARMSJLJEHLabel() const"},
    {"_ZN4llvm13ARMAsmPrinter15PrintAsmOperandEPKNS_12MachineInstrEjjPKcRNS_11raw_ostreamE", "llvm::ARMAsmPrinter::PrintAsmOperand(llvm::MachineInstr const*, unsigned int, unsigned int, char const*, llvm::raw_ostream&)"},
    {"_ZN4llvm13ARMAsmPrinter21PrintAsmMemoryOperandEPKNS_12MachineInstrEjjPKcRNS_11raw_ostreamE", "llvm::ARMAsmPrinter::PrintAsmMemoryOperand(llvm::MachineInstr const*, unsigned int, unsigned int, char const*, llvm::raw_ostream&)"},
    {"_ZN4llvm13ARMAsmPrinter18EmitStartOfAsmFileERNS_6ModuleE", "llvm::ARMAsmPrinter::EmitStartOfAsmFile(llvm::Module&)"},
    {"_ZN4llvm13ARMAsmPrinter14emitAttributesEv", "llvm::ARMAsmPrinter::emitAttributes()"},
    {"_ZN4llvm13ARMAsmPrinter16EmitEndOfAsmFileERNS_6ModuleE", "llvm::ARMAsmPrinter::EmitEndOfAsmFile(llvm::Module&)"},
    {"_ZN4llvm13ARMAsmPrinter23emitARMAttributeSectionEv", "llvm::ARMAsmPrinter::emitARMAttributeSection()"},
    {"_ZN4llvm13ARMAsmPrinter14GetARMGVSymbolEPKNS_11GlobalValueE", "llvm::ARMAsmPrinter::GetARMGVSymbol(llvm::GlobalValue const*)"},
    {"_ZN4llvm13ARMAsmPrinter28EmitMachineConstantPoolValueEPNS_24MachineConstantPoolValueE", "llvm::ARMAsmPrinter::EmitMachineConstantPoolValue(llvm::MachineConstantPoolValue*)"},
    {"_Z11getPICLabelPKcjjRN4llvm9MCContextE", "getPICLabel(char const*, unsigned int, unsigned int, llvm::MCContext&)"},
    {"_ZN4llvm13ARMAsmPrinter13EmitJumpTableEPKNS_12MachineInstrE", "llvm::ARMAsmPrinter::EmitJumpTable(llvm::MachineInstr const*)"},
    {"_ZN4llvm13ARMAsmPrinter14EmitJump2TableEPKNS_12MachineInstrE", "llvm::ARMAsmPrinter::EmitJump2Table(llvm::MachineInstr const*)"},
    {"_ZN4llvm13ARMAsmPrinter22PrintDebugValueCommentEPKNS_12MachineInstrERNS_11raw_ostreamE", "llvm::ARMAsmPrinter::PrintDebugValueComment(llvm::MachineInstr const*, llvm::raw_ostream&)"},
    {"_ZN4llvm13ARMAsmPrinter22EmitPatchedInstructionEPKNS_12MachineInstrEj", "llvm::ARMAsmPrinter::EmitPatchedInstruction(llvm::MachineInstr const*, unsigned int)"},
    {"_ZN4llvm13ARMAsmPrinter15EmitInstructionEPKNS_12MachineInstrE", "llvm::ARMAsmPrinter::EmitInstruction(llvm::MachineInstr const*)"},
    {"_Z19populateADROperandsRN4llvm6MCInstEjPKNS_8MCSymbolEjjRNS_9MCContextE", "populateADROperands(llvm::MCInst&, unsigned int, llvm::MCSymbol const*, unsigned int, unsigned int, llvm::MCContext&)"},
    {"_Z22createARMMCInstPrinterRKN4llvm6TargetEjRKNS_9MCAsmInfoE", "createARMMCInstPrinter(llvm::Target const&, unsigned int, llvm::MCAsmInfo const&)"},
    {"_ZN12_GLOBAL__N_122ObjectAttributeEmitter17MaybeSwitchVendorEN4llvm9StringRefE", "(anonymous namespace)::ObjectAttributeEmitter::MaybeSwitchVendor(llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_122ObjectAttributeEmitter13EmitAttributeEjj", "(anonymous namespace)::ObjectAttributeEmitter::EmitAttribute(unsigned int, unsigned int)"},
    {"_ZN12_GLOBAL__N_122ObjectAttributeEmitter17EmitTextAttributeEjN4llvm9StringRefE", "(anonymous namespace)::ObjectAttributeEmitter::EmitTextAttribute(unsigned int, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_122ObjectAttributeEmitter6FinishEv", "(anonymous namespace)::ObjectAttributeEmitter::Finish()"},
    {"_ZN12_GLOBAL__N_122ObjectAttributeEmitterD1Ev", "(anonymous namespace)::ObjectAttributeEmitter::~ObjectAttributeEmitter()"},
    {"_ZN12_GLOBAL__N_122ObjectAttributeEmitterD0Ev", "(anonymous namespace)::ObjectAttributeEmitter::~ObjectAttributeEmitter()"},
    {"_ZN12_GLOBAL__N_116AttributeEmitterD1Ev", "(anonymous namespace)::AttributeEmitter::~AttributeEmitter()"},
    {"_ZN12_GLOBAL__N_116AttributeEmitterD0Ev", "(anonymous namespace)::AttributeEmitter::~AttributeEmitter()"},
    {"_ZN12_GLOBAL__N_119AsmAttributeEmitter17MaybeSwitchVendorEN4llvm9StringRefE", "(anonymous namespace)::AsmAttributeEmitter::MaybeSwitchVendor(llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_119AsmAttributeEmitter13EmitAttributeEjj", "(anonymous namespace)::AsmAttributeEmitter::EmitAttribute(unsigned int, unsigned int)"},
    {"_ZN12_GLOBAL__N_119AsmAttributeEmitter17EmitTextAttributeEjN4llvm9StringRefE", "(anonymous namespace)::AsmAttributeEmitter::EmitTextAttribute(unsigned int, llvm::StringRef)"},
    {"_ZN12_GLOBAL__N_119AsmAttributeEmitter6FinishEv", "(anonymous namespace)::AsmAttributeEmitter::Finish()"},
    {"_ZN12_GLOBAL__N_119AsmAttributeEmitterD1Ev", "(anonymous namespace)::AsmAttributeEmitter::~AsmAttributeEmitter()"},
    {"_ZN12_GLOBAL__N_119AsmAttributeEmitterD0Ev", "(anonymous namespace)::AsmAttributeEmitter::~AsmAttributeEmitter()"},
    {"_ZNSt6vectorISt4pairIPN4llvm8MCSymbolENS1_14PointerIntPairIS3_Lj1EbNS1_21PointerLikeTypeTraitsIS3_EEEEESaIS8_EEaSERKSA_", "std::vector<std::pair<llvm::MCSymbol*, llvm::PointerIntPair<llvm::MCSymbol*, 1u, bool, llvm::PointerLikeTypeTraits<llvm::MCSymbol*>>>, std::allocator<std::pair<llvm::MCSymbol*, llvm::PointerIntPair<llvm::MCSymbol*, 1u, bool, llvm::PointerLikeTypeTraits<llvm::MCSymbol*>>>>>::operator=(std::vector<std::pair<llvm::MCSymbol*, llvm::PointerIntPair<llvm::MCSymbol*, 1u, bool, llvm::PointerLikeTypeTraits<llvm::MCSymbol*>>>, std::allocator<std::pair<llvm::MCSymbol*, llvm::PointerIntPair<llvm::MCSymbol*, 1u, bool, llvm::PointerLikeTypeTraits<llvm::MCSymbol*>>>>> const&)"},
    {"_ZN4llvm13ARMAsmPrinterD1Ev", "llvm::ARMAsmPrinter::~ARMAsmPrinter()"},
    {"_ZN4llvm13ARMAsmPrinterD0Ev", "llvm::ARMAsmPrinter::~ARMAsmPrinter()"},
    {"_ZNK4llvm13ARMAsmPrinter11getPassNameEv", "llvm::ARMAsmPrinter::getPassName() const"},
    {"_ZNK4llvm4Pass9getPassIDEv", "llvm::Pass::getPassID() const"},
    {"_ZN4llvm13ARMAsmPrinter16EmitConstantPoolEv", "llvm::ARMAsmPrinter::EmitConstantPool()"},
    {"_ZN4llvm10AsmPrinter21EmitFunctionBodyStartEv", "llvm::AsmPrinter::EmitFunctionBodyStart()"},
    {"_ZN4llvm10AsmPrinter19EmitFunctionBodyEndEv", "llvm::AsmPrinter::EmitFunctionBodyEnd()"},
    {"_ZN4llvm13ARMAsmPrinter14getISAEncodingEv", "llvm::ARMAsmPrinter::getISAEncoding()"},
    {"_ZN4llvm18RegisterAsmPrinterINS_13ARMAsmPrinterEE9AllocatorERNS_13TargetMachineERNS_10MCStreamerE", "llvm::RegisterAsmPrinter<llvm::ARMAsmPrinter>::Allocator(llvm::TargetMachine&, llvm::MCStreamer&)"},
    {"_ZN4llvm22MachineModuleInfoMachOC2ERKNS_17MachineModuleInfoE", "llvm::MachineModuleInfoMachO::MachineModuleInfoMachO(llvm::MachineModuleInfo const&)"},
    {"_ZN4llvm15ARMFunctionInfoC2ERNS_15MachineFunctionE", "llvm::ARMFunctionInfo::ARMFunctionInfo(llvm::MachineFunction&)"},
    {"_ZN4llvm15ARMFunctionInfoD1Ev", "llvm::ARMFunctionInfo::~ARMFunctionInfo()"},
    {"_ZN4llvm15ARMFunctionInfoD0Ev", "llvm::ARMFunctionInfo::~ARMFunctionInfo()"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_9MCOperandELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::MCOperand, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIPNS_8MCSymbolENS_14PointerIntPairIS2_Lj1EbNS_21PointerLikeTypeTraitsIS2_EEEENS_12DenseMapInfoIS2_EENS7_IS6_EEE16InsertIntoBucketERKS2_RKS6_PSt4pairIS2_S6_E", "llvm::DenseMap<llvm::MCSymbol*, llvm::PointerIntPair<llvm::MCSymbol*, 1u, bool, llvm::PointerLikeTypeTraits<llvm::MCSymbol*>>, llvm::DenseMapInfo<llvm::MCSymbol*>, llvm::DenseMapInfo<llvm::PointerIntPair<llvm::MCSymbol*, 1u, bool, llvm::PointerLikeTypeTraits<llvm::MCSymbol*>>>>::InsertIntoBucket(llvm::MCSymbol* const&, llvm::PointerIntPair<llvm::MCSymbol*, 1u, bool, llvm::PointerLikeTypeTraits<llvm::MCSymbol*>> const&, std::pair<llvm::MCSymbol*, llvm::PointerIntPair<llvm::MCSymbol*, 1u, bool, llvm::PointerLikeTypeTraits<llvm::MCSymbol*>>>*)"},
    {"_ZN4llvm8DenseMapIPNS_8MCSymbolENS_14PointerIntPairIS2_Lj1EbNS_21PointerLikeTypeTraitsIS2_EEEENS_12DenseMapInfoIS2_EENS7_IS6_EEE4growEj", "llvm::DenseMap<llvm::MCSymbol*, llvm::PointerIntPair<llvm::MCSymbol*, 1u, bool, llvm::PointerLikeTypeTraits<llvm::MCSymbol*>>, llvm::DenseMapInfo<llvm::MCSymbol*>, llvm::DenseMapInfo<llvm::PointerIntPair<llvm::MCSymbol*, 1u, bool, llvm::PointerLikeTypeTraits<llvm::MCSymbol*>>>>::grow(unsigned int)"},
    {"_ZN4llvm16ARMBaseInstrInfoC1ERKNS_12ARMSubtargetE", "llvm::ARMBaseInstrInfo::ARMBaseInstrInfo(llvm::ARMSubtarget const&)"},
    {"_ZN4llvm16ARMBaseInstrInfoC2ERKNS_12ARMSubtargetE", "llvm::ARMBaseInstrInfo::ARMBaseInstrInfo(llvm::ARMSubtarget const&)"},
    {"_ZNK4llvm16ARMBaseInstrInfo28CreateTargetHazardRecognizerEPKNS_13TargetMachineEPKNS_11ScheduleDAGE", "llvm::ARMBaseInstrInfo::CreateTargetHazardRecognizer(llvm::TargetMachine const*, llvm::ScheduleDAG const*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo34CreateTargetPostRAHazardRecognizerEPKNS_18InstrItineraryDataEPKNS_11ScheduleDAGE", "llvm::ARMBaseInstrInfo::CreateTargetPostRAHazardRecognizer(llvm::InstrItineraryData const*, llvm::ScheduleDAG const*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo21convertToThreeAddressERNS_14ilist_iteratorINS_17MachineBasicBlockEEERNS1_INS_12MachineInstrEEEPNS_13LiveVariablesE", "llvm::ARMBaseInstrInfo::convertToThreeAddress(llvm::ilist_iterator<llvm::MachineBasicBlock>&, llvm::ilist_iterator<llvm::MachineInstr>&, llvm::LiveVariables*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo13analyzeBranchERNS_17MachineBasicBlockERPS1_S4_RNS_15SmallVectorImplINS_14MachineOperandEEEb", "llvm::ARMBaseInstrInfo::analyzeBranch(llvm::MachineBasicBlock&, llvm::MachineBasicBlock*&, llvm::MachineBasicBlock*&, llvm::SmallVectorImpl<llvm::MachineOperand>&, bool) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo12removeBranchERNS_17MachineBasicBlockE", "llvm::ARMBaseInstrInfo::removeBranch(llvm::MachineBasicBlock&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo12insertBranchERNS_17MachineBasicBlockEPS1_S3_RKNS_15SmallVectorImplINS_14MachineOperandEEENS_8DebugLocE", "llvm::ARMBaseInstrInfo::insertBranch(llvm::MachineBasicBlock&, llvm::MachineBasicBlock*, llvm::MachineBasicBlock*, llvm::SmallVectorImpl<llvm::MachineOperand> const&, llvm::DebugLoc) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo22ReverseBranchConditionERNS_15SmallVectorImplINS_14MachineOperandEEE", "llvm::ARMBaseInstrInfo::ReverseBranchCondition(llvm::SmallVectorImpl<llvm::MachineOperand>&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo20PredicateInstructionEPNS_12MachineInstrERKNS_15SmallVectorImplINS_14MachineOperandEEE", "llvm::ARMBaseInstrInfo::PredicateInstruction(llvm::MachineInstr*, llvm::SmallVectorImpl<llvm::MachineOperand> const&) const"},
    {"_ZN4llvm27getMatchingCondBranchOpcodeEi", "llvm::getMatchingCondBranchOpcode(int)"},
    {"_ZNK4llvm16ARMBaseInstrInfo17SubsumesPredicateERKNS_15SmallVectorImplINS_14MachineOperandEEES5_", "llvm::ARMBaseInstrInfo::SubsumesPredicate(llvm::SmallVectorImpl<llvm::MachineOperand> const&, llvm::SmallVectorImpl<llvm::MachineOperand> const&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo16DefinesPredicateEPNS_12MachineInstrERSt6vectorINS_14MachineOperandESaIS4_EE", "llvm::ARMBaseInstrInfo::DefinesPredicate(llvm::MachineInstr*, std::vector<llvm::MachineOperand, std::allocator<llvm::MachineOperand>>&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo12isPredicableEPNS_12MachineInstrE", "llvm::ARMBaseInstrInfo::isPredicable(llvm::MachineInstr*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo18GetInstSizeInBytesEPKNS_12MachineInstrE", "llvm::ARMBaseInstrInfo::GetInstSizeInBytes(llvm::MachineInstr const*) const"},
    {"_Z15getNumJTEntriesRKSt6vectorIN4llvm21MachineJumpTableEntryESaIS1_EEj", "getNumJTEntries(std::vector<llvm::MachineJumpTableEntry, std::allocator<llvm::MachineJumpTableEntry>> const&, unsigned int)"},
    {"_ZNK4llvm16ARMBaseInstrInfo11copyPhysRegERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEENS_8DebugLocEjjb", "llvm::ARMBaseInstrInfo::copyPhysReg(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, llvm::DebugLoc, unsigned int, unsigned int, bool) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo19storeRegToStackSlotERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEEjbiPKNS_19TargetRegisterClassEPKNS_18TargetRegisterInfoE", "llvm::ARMBaseInstrInfo::storeRegToStackSlot(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, bool, int, llvm::TargetRegisterClass const*, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo18isStoreToStackSlotEPKNS_12MachineInstrERi", "llvm::ARMBaseInstrInfo::isStoreToStackSlot(llvm::MachineInstr const*, int&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo20loadRegFromStackSlotERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEEjiPKNS_19TargetRegisterClassEPKNS_18TargetRegisterInfoE", "llvm::ARMBaseInstrInfo::loadRegFromStackSlot(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, int, llvm::TargetRegisterClass const*, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo19isLoadFromStackSlotEPKNS_12MachineInstrERi", "llvm::ARMBaseInstrInfo::isLoadFromStackSlot(llvm::MachineInstr const*, int&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo24emitFrameIndexDebugValueERNS_15MachineFunctionEiyPKNS_6MDNodeENS_8DebugLocE", "llvm::ARMBaseInstrInfo::emitFrameIndexDebugValue(llvm::MachineFunction&, int, unsigned long long, llvm::MDNode const*, llvm::DebugLoc) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo13reMaterializeERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEEjjPKS4_RKNS_18TargetRegisterInfoE", "llvm::ARMBaseInstrInfo::reMaterialize(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, unsigned int, llvm::MachineInstr const*, llvm::TargetRegisterInfo const&) const"},
    {"_Z12duplicateCPVRN4llvm15MachineFunctionERj", "duplicateCPV(llvm::MachineFunction&, unsigned int&)"},
    {"_ZNK4llvm16ARMBaseInstrInfo9duplicateEPNS_12MachineInstrERNS_15MachineFunctionE", "llvm::ARMBaseInstrInfo::duplicate(llvm::MachineInstr*, llvm::MachineFunction&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo16produceSameValueEPKNS_12MachineInstrES3_PKNS_19MachineRegisterInfoE", "llvm::ARMBaseInstrInfo::produceSameValue(llvm::MachineInstr const*, llvm::MachineInstr const*, llvm::MachineRegisterInfo const*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo23areLoadsFromSameBasePtrEPNS_6SDNodeES2_RxS3_", "llvm::ARMBaseInstrInfo::areLoadsFromSameBasePtr(llvm::SDNode*, llvm::SDNode*, long long&, long long&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo23shouldScheduleLoadsNearEPNS_6SDNodeES2_xxj", "llvm::ARMBaseInstrInfo::shouldScheduleLoadsNear(llvm::SDNode*, llvm::SDNode*, long long, long long, unsigned int) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo20isSchedulingBoundaryEPKNS_12MachineInstrEPKNS_17MachineBasicBlockERKNS_15MachineFunctionE", "llvm::ARMBaseInstrInfo::isSchedulingBoundary(llvm::MachineInstr const*, llvm::MachineBasicBlock const*, llvm::MachineFunction const&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo19isProfitableToIfCvtERNS_17MachineBasicBlockEjjff", "llvm::ARMBaseInstrInfo::isProfitableToIfCvt(llvm::MachineBasicBlock&, unsigned int, unsigned int, float, float) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo19isProfitableToIfCvtERNS_17MachineBasicBlockEjjS2_jjff", "llvm::ARMBaseInstrInfo::isProfitableToIfCvt(llvm::MachineBasicBlock&, unsigned int, unsigned int, llvm::MachineBasicBlock&, unsigned int, unsigned int, float, float) const"},
    {"_ZN4llvm17getInstrPredicateEPKNS_12MachineInstrERj", "llvm::getInstrPredicate(llvm::MachineInstr const*, unsigned int&)"},
    {"_ZN4llvm23emitARMRegPlusImmediateERNS_17MachineBasicBlockERNS_14ilist_iteratorINS_12MachineInstrEEENS_8DebugLocEjjiNS_5ARMCC9CondCodesEjRKNS_16ARMBaseInstrInfoE", "llvm::emitARMRegPlusImmediate(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>&, llvm::DebugLoc, unsigned int, unsigned int, int, llvm::ARMCC::CondCodes, unsigned int, llvm::ARMBaseInstrInfo const&)"},
    {"_ZN4llvm20rewriteARMFrameIndexERNS_12MachineInstrEjjRiRKNS_16ARMBaseInstrInfoE", "llvm::rewriteARMFrameIndex(llvm::MachineInstr&, unsigned int, unsigned int, int&, llvm::ARMBaseInstrInfo const&)"},
    {"_ZNK4llvm16ARMBaseInstrInfo14AnalyzeCompareEPKNS_12MachineInstrERjRiS5_", "llvm::ARMBaseInstrInfo::AnalyzeCompare(llvm::MachineInstr const*, unsigned int&, int&, int&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo20OptimizeCompareInstrEPNS_12MachineInstrEjiiPKNS_19MachineRegisterInfoE", "llvm::ARMBaseInstrInfo::OptimizeCompareInstr(llvm::MachineInstr*, unsigned int, int, int, llvm::MachineRegisterInfo const*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo13FoldImmediateEPNS_12MachineInstrES2_jPNS_19MachineRegisterInfoE", "llvm::ARMBaseInstrInfo::FoldImmediate(llvm::MachineInstr*, llvm::MachineInstr*, unsigned int, llvm::MachineRegisterInfo*) const"},
    {"_ZN4llvm6ARM_AM22getT2SOImmTwoPartFirstEj", "llvm::ARM_AM::getT2SOImmTwoPartFirst(unsigned int)"},
    {"_ZNK4llvm16ARMBaseInstrInfo14getNumMicroOpsEPKNS_18InstrItineraryDataEPKNS_12MachineInstrE", "llvm::ARMBaseInstrInfo::getNumMicroOps(llvm::InstrItineraryData const*, llvm::MachineInstr const*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo15getVLDMDefCycleEPKNS_18InstrItineraryDataERKNS_15TargetInstrDescEjjj", "llvm::ARMBaseInstrInfo::getVLDMDefCycle(llvm::InstrItineraryData const*, llvm::TargetInstrDesc const&, unsigned int, unsigned int, unsigned int) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo14getLDMDefCycleEPKNS_18InstrItineraryDataERKNS_15TargetInstrDescEjjj", "llvm::ARMBaseInstrInfo::getLDMDefCycle(llvm::InstrItineraryData const*, llvm::TargetInstrDesc const&, unsigned int, unsigned int, unsigned int) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo15getVSTMUseCycleEPKNS_18InstrItineraryDataERKNS_15TargetInstrDescEjjj", "llvm::ARMBaseInstrInfo::getVSTMUseCycle(llvm::InstrItineraryData const*, llvm::TargetInstrDesc const&, unsigned int, unsigned int, unsigned int) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo14getSTMUseCycleEPKNS_18InstrItineraryDataERKNS_15TargetInstrDescEjjj", "llvm::ARMBaseInstrInfo::getSTMUseCycle(llvm::InstrItineraryData const*, llvm::TargetInstrDesc const&, unsigned int, unsigned int, unsigned int) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo17getOperandLatencyEPKNS_18InstrItineraryDataERKNS_15TargetInstrDescEjjS6_jj", "llvm::ARMBaseInstrInfo::getOperandLatency(llvm::InstrItineraryData const*, llvm::TargetInstrDesc const&, unsigned int, unsigned int, llvm::TargetInstrDesc const&, unsigned int, unsigned int) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo17getOperandLatencyEPKNS_18InstrItineraryDataEPKNS_12MachineInstrEjS6_j", "llvm::ARMBaseInstrInfo::getOperandLatency(llvm::InstrItineraryData const*, llvm::MachineInstr const*, unsigned int, llvm::MachineInstr const*, unsigned int) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo17getOperandLatencyEPKNS_18InstrItineraryDataEPNS_6SDNodeEjS5_j", "llvm::ARMBaseInstrInfo::getOperandLatency(llvm::InstrItineraryData const*, llvm::SDNode*, unsigned int, llvm::SDNode*, unsigned int) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo15getInstrLatencyEPKNS_18InstrItineraryDataEPKNS_12MachineInstrEPj", "llvm::ARMBaseInstrInfo::getInstrLatency(llvm::InstrItineraryData const*, llvm::MachineInstr const*, unsigned int*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo15getInstrLatencyEPKNS_18InstrItineraryDataEPNS_6SDNodeE", "llvm::ARMBaseInstrInfo::getInstrLatency(llvm::InstrItineraryData const*, llvm::SDNode*) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo21hasHighOperandLatencyEPKNS_18InstrItineraryDataEPKNS_19MachineRegisterInfoEPKNS_12MachineInstrEjS9_j", "llvm::ARMBaseInstrInfo::hasHighOperandLatency(llvm::InstrItineraryData const*, llvm::MachineRegisterInfo const*, llvm::MachineInstr const*, unsigned int, llvm::MachineInstr const*, unsigned int) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo16hasLowDefLatencyEPKNS_18InstrItineraryDataEPKNS_12MachineInstrEj", "llvm::ARMBaseInstrInfo::hasLowDefLatency(llvm::InstrItineraryData const*, llvm::MachineInstr const*, unsigned int) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo18isFpMLxInstructionEjRjS1_RbS2_", "llvm::ARMBaseInstrInfo::isFpMLxInstruction(unsigned int, unsigned int&, unsigned int&, bool&, bool&) const"},
    {"_ZN4llvm8DenseMapIjjNS_12DenseMapInfoIjEES2_E6insertERKSt4pairIjjE", "llvm::DenseMap<unsigned int, unsigned int, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<unsigned int>>::insert(std::pair<unsigned int, unsigned int> const&)"},
    {"_ZN4llvm8SmallSetIjLj16EE6insertERKj", "llvm::SmallSet<unsigned int, 16u>::insert(unsigned int const&)"},
    {"_ZN4llvm13LiveVariables7VarInfo10removeKillEPNS_12MachineInstrE", "llvm::LiveVariables::VarInfo::removeKill(llvm::MachineInstr*)"},
    {"_ZNSt6vectorIN4llvm14MachineOperandESaIS1_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS1_S3_EERKS1_", "std::vector<llvm::MachineOperand, std::allocator<llvm::MachineOperand>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::MachineOperand*, std::vector<llvm::MachineOperand, std::allocator<llvm::MachineOperand>>>, llvm::MachineOperand const&)"},
    {"_ZNSt8_Rb_treeIjjSt9_IdentityIjESt4lessIjESaIjEE16_M_insert_uniqueERKj", "std::_Rb_tree<unsigned int, unsigned int, std::_Identity<unsigned int>, std::less<unsigned int>, std::allocator<unsigned int>>::_M_insert_unique(unsigned int const&)"},
    {"_ZSt6__findIN9__gnu_cxx17__normal_iteratorIPPN4llvm12MachineInstrESt6vectorIS4_SaIS4_EEEES4_ET_SA_SA_RKT0_St26random_access_iterator_tag", "__gnu_cxx::__normal_iterator<llvm::MachineInstr**, std::vector<llvm::MachineInstr*, std::allocator<llvm::MachineInstr*>>> std::__find<__gnu_cxx::__normal_iterator<llvm::MachineInstr**, std::vector<llvm::MachineInstr*, std::allocator<llvm::MachineInstr*>>>, llvm::MachineInstr*>(__gnu_cxx::__normal_iterator<llvm::MachineInstr**, std::vector<llvm::MachineInstr*, std::allocator<llvm::MachineInstr*>>>, __gnu_cxx::__normal_iterator<llvm::MachineInstr**, std::vector<llvm::MachineInstr*, std::allocator<llvm::MachineInstr*>>>, llvm::MachineInstr* const&, std::random_access_iterator_tag)"},
    {"_ZN4llvm24ScheduleHazardRecognizer8EmitNoopEv", "llvm::ScheduleHazardRecognizer::EmitNoop()"},
    {"_ZN4llvm19ARMBaseRegisterInfoC1ERKNS_16ARMBaseInstrInfoERKNS_12ARMSubtargetE", "llvm::ARMBaseRegisterInfo::ARMBaseRegisterInfo(llvm::ARMBaseInstrInfo const&, llvm::ARMSubtarget const&)"},
    {"_ZN4llvm19ARMBaseRegisterInfoC2ERKNS_16ARMBaseInstrInfoERKNS_12ARMSubtargetE", "llvm::ARMBaseRegisterInfo::ARMBaseRegisterInfo(llvm::ARMBaseInstrInfo const&, llvm::ARMSubtarget const&)"},
    {"_ZN4llvm18ARMGenRegisterInfoC2Eii", "llvm::ARMGenRegisterInfo::ARMGenRegisterInfo(int, int)"},
    {"_ZNK4llvm19ARMBaseRegisterInfo18getCalleeSavedRegsEPKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::getCalleeSavedRegs(llvm::MachineFunction const*) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo15getReservedRegsERKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::getReservedRegs(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo14hasBasePointerERKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::hasBasePointer(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo13isReservedRegERKNS_15MachineFunctionEj", "llvm::ARMBaseRegisterInfo::isReservedReg(llvm::MachineFunction const&, unsigned int) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo24getMatchingSuperRegClassEPKNS_19TargetRegisterClassES3_j", "llvm::ARMBaseRegisterInfo::getMatchingSuperRegClass(llvm::TargetRegisterClass const*, llvm::TargetRegisterClass const*, unsigned int) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo23canCombineSubRegIndicesEPKNS_19TargetRegisterClassERNS_15SmallVectorImplIjEERj", "llvm::ARMBaseRegisterInfo::canCombineSubRegIndices(llvm::TargetRegisterClass const*, llvm::SmallVectorImpl<unsigned int>&, unsigned int&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo18getPointerRegClassEj", "llvm::ARMBaseRegisterInfo::getPointerRegClass(unsigned int) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo18getAllocationOrderEPKNS_19TargetRegisterClassEjjRKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::getAllocationOrder(llvm::TargetRegisterClass const*, unsigned int, unsigned int, llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo19getRegisterPairEvenEjRKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::getRegisterPairEven(unsigned int, llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo18getRegisterPairOddEjRKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::getRegisterPairOdd(unsigned int, llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo19ResolveRegAllocHintEjjRKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::ResolveRegAllocHint(unsigned int, unsigned int, llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo18UpdateRegAllocHintEjjRNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::UpdateRegAllocHint(unsigned int, unsigned int, llvm::MachineFunction&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo15canRealignStackERKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::canRealignStack(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo21needsStackRealignmentERKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::needsStackRealignment(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo20cannotEliminateFrameERKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::cannotEliminateFrame(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo13getRARegisterEv", "llvm::ARMBaseRegisterInfo::getRARegister() const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo16getFrameRegisterERKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::getFrameRegister(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo22getEHExceptionRegisterEv", "llvm::ARMBaseRegisterInfo::getEHExceptionRegister() const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo20getEHHandlerRegisterEv", "llvm::ARMBaseRegisterInfo::getEHHandlerRegister() const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo14getDwarfRegNumEjb", "llvm::ARMBaseRegisterInfo::getDwarfRegNum(unsigned int, bool) const"},
    {"_ZNK4llvm18ARMGenRegisterInfo18getDwarfRegNumFullEjj", "llvm::ARMGenRegisterInfo::getDwarfRegNumFull(unsigned int, unsigned int) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo17emitLoadConstPoolERNS_17MachineBasicBlockERNS_14ilist_iteratorINS_12MachineInstrEEENS_8DebugLocEjjiNS_5ARMCC9CondCodesEj", "llvm::ARMBaseRegisterInfo::emitLoadConstPool(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>&, llvm::DebugLoc, unsigned int, unsigned int, int, llvm::ARMCC::CondCodes, unsigned int) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo26requiresRegisterScavengingERKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::requiresRegisterScavenging(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo28requiresFrameIndexScavengingERKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::requiresFrameIndexScavenging(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo28requiresVirtualBaseRegistersERKNS_15MachineFunctionE", "llvm::ARMBaseRegisterInfo::requiresVirtualBaseRegisters(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo29eliminateCallFramePseudoInstrERNS_15MachineFunctionERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEE", "llvm::ARMBaseRegisterInfo::eliminateCallFramePseudoInstr(llvm::MachineFunction&, llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo24getFrameIndexInstrOffsetEPKNS_12MachineInstrEi", "llvm::ARMBaseRegisterInfo::getFrameIndexInstrOffset(llvm::MachineInstr const*, int) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo17needsFrameBaseRegEPNS_12MachineInstrEx", "llvm::ARMBaseRegisterInfo::needsFrameBaseReg(llvm::MachineInstr*, long long) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo28materializeFrameBaseRegisterEPNS_17MachineBasicBlockEjix", "llvm::ARMBaseRegisterInfo::materializeFrameBaseRegister(llvm::MachineBasicBlock*, unsigned int, int, long long) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo17resolveFrameIndexENS_14ilist_iteratorINS_12MachineInstrEEEjx", "llvm::ARMBaseRegisterInfo::resolveFrameIndex(llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, long long) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo18isFrameOffsetLegalEPKNS_12MachineInstrEx", "llvm::ARMBaseRegisterInfo::isFrameOffsetLegal(llvm::MachineInstr const*, long long) const"},
    {"_ZNK4llvm19ARMBaseRegisterInfo19eliminateFrameIndexENS_14ilist_iteratorINS_12MachineInstrEEEiPNS_12RegScavengerE", "llvm::ARMBaseRegisterInfo::eliminateFrameIndex(llvm::ilist_iterator<llvm::MachineInstr>, int, llvm::RegScavenger*) const"},
    {"_ZN4llvm3ARM8CCRClassC1Ev", "llvm::ARM::CCRClass::CCRClass()"},
    {"_ZN4llvm3ARM8DPRClassC1Ev", "llvm::ARM::DPRClass::DPRClass()"},
    {"_ZN4llvm3ARM10DPR_8ClassC1Ev", "llvm::ARM::DPR_8Class::DPR_8Class()"},
    {"_ZN4llvm3ARM13DPR_VFP2ClassC1Ev", "llvm::ARM::DPR_VFP2Class::DPR_VFP2Class()"},
    {"_ZN4llvm3ARM8GPRClassC1Ev", "llvm::ARM::GPRClass::GPRClass()"},
    {"_ZN4llvm3ARM8QPRClassC1Ev", "llvm::ARM::QPRClass::QPRClass()"},
    {"_ZN4llvm3ARM10QPR_8ClassC1Ev", "llvm::ARM::QPR_8Class::QPR_8Class()"},
    {"_ZN4llvm3ARM13QPR_VFP2ClassC1Ev", "llvm::ARM::QPR_VFP2Class::QPR_VFP2Class()"},
    {"_ZN4llvm3ARM9QQPRClassC1Ev", "llvm::ARM::QQPRClass::QQPRClass()"},
    {"_ZN4llvm3ARM14QQPR_VFP2ClassC1Ev", "llvm::ARM::QQPR_VFP2Class::QQPR_VFP2Class()"},
    {"_ZN4llvm3ARM11QQQQPRClassC1Ev", "llvm::ARM::QQQQPRClass::QQQQPRClass()"},
    {"_ZN4llvm3ARM8SPRClassC1Ev", "llvm::ARM::SPRClass::SPRClass()"},
    {"_ZN4llvm3ARM10SPR_8ClassC1Ev", "llvm::ARM::SPR_8Class::SPR_8Class()"},
    {"_ZN4llvm3ARM9rGPRClassC1Ev", "llvm::ARM::rGPRClass::rGPRClass()"},
    {"_ZN4llvm3ARM9tGPRClassC1Ev", "llvm::ARM::tGPRClass::tGPRClass()"},
    {"_ZN4llvm3ARM10tcGPRClassC1Ev", "llvm::ARM::tcGPRClass::tcGPRClass()"},
    {"_ZN4llvm3ARM8CCRClassC2Ev", "llvm::ARM::CCRClass::CCRClass()"},
    {"_ZNK4llvm3ARM8DPRClass22allocation_order_beginERKNS_15MachineFunctionE", "llvm::ARM::DPRClass::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3ARM8DPRClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::ARM::DPRClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3ARM8DPRClassC2Ev", "llvm::ARM::DPRClass::DPRClass()"},
    {"_ZN4llvm3ARM10DPR_8ClassC2Ev", "llvm::ARM::DPR_8Class::DPR_8Class()"},
    {"_ZN4llvm3ARM13DPR_VFP2ClassC2Ev", "llvm::ARM::DPR_VFP2Class::DPR_VFP2Class()"},
    {"_ZNK4llvm3ARM8GPRClass22allocation_order_beginERKNS_15MachineFunctionE", "llvm::ARM::GPRClass::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3ARM8GPRClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::ARM::GPRClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3ARM8GPRClassC2Ev", "llvm::ARM::GPRClass::GPRClass()"},
    {"_ZNK4llvm3ARM8QPRClass22allocation_order_beginERKNS_15MachineFunctionE", "llvm::ARM::QPRClass::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3ARM8QPRClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::ARM::QPRClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3ARM8QPRClassC2Ev", "llvm::ARM::QPRClass::QPRClass()"},
    {"_ZN4llvm3ARM10QPR_8ClassC2Ev", "llvm::ARM::QPR_8Class::QPR_8Class()"},
    {"_ZN4llvm3ARM13QPR_VFP2ClassC2Ev", "llvm::ARM::QPR_VFP2Class::QPR_VFP2Class()"},
    {"_ZNK4llvm3ARM9QQPRClass22allocation_order_beginERKNS_15MachineFunctionE", "llvm::ARM::QQPRClass::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3ARM9QQPRClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::ARM::QQPRClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3ARM9QQPRClassC2Ev", "llvm::ARM::QQPRClass::QQPRClass()"},
    {"_ZN4llvm3ARM14QQPR_VFP2ClassC2Ev", "llvm::ARM::QQPR_VFP2Class::QQPR_VFP2Class()"},
    {"_ZNK4llvm3ARM11QQQQPRClass22allocation_order_beginERKNS_15MachineFunctionE", "llvm::ARM::QQQQPRClass::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3ARM11QQQQPRClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::ARM::QQQQPRClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3ARM11QQQQPRClassC2Ev", "llvm::ARM::QQQQPRClass::QQQQPRClass()"},
    {"_ZN4llvm3ARM8SPRClassC2Ev", "llvm::ARM::SPRClass::SPRClass()"},
    {"_ZN4llvm3ARM10SPR_8ClassC2Ev", "llvm::ARM::SPR_8Class::SPR_8Class()"},
    {"_ZNK4llvm3ARM9rGPRClass22allocation_order_beginERKNS_15MachineFunctionE", "llvm::ARM::rGPRClass::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3ARM9rGPRClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::ARM::rGPRClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3ARM9rGPRClassC2Ev", "llvm::ARM::rGPRClass::rGPRClass()"},
    {"_ZN4llvm3ARM9tGPRClassC2Ev", "llvm::ARM::tGPRClass::tGPRClass()"},
    {"_ZNK4llvm3ARM10tcGPRClass22allocation_order_beginERKNS_15MachineFunctionE", "llvm::ARM::tcGPRClass::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm3ARM10tcGPRClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::ARM::tcGPRClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3ARM10tcGPRClassC2Ev", "llvm::ARM::tcGPRClass::tcGPRClass()"},
    {"_ZNK4llvm18ARMGenRegisterInfo9getSubRegEjj", "llvm::ARMGenRegisterInfo::getSubReg(unsigned int, unsigned int) const"},
    {"_ZNK4llvm18ARMGenRegisterInfo14getSubRegIndexEjj", "llvm::ARMGenRegisterInfo::getSubRegIndex(unsigned int, unsigned int) const"},
    {"_ZNK4llvm18ARMGenRegisterInfo20composeSubRegIndicesEjj", "llvm::ARMGenRegisterInfo::composeSubRegIndices(unsigned int, unsigned int) const"},
    {"_ZN4llvm18ARMGenRegisterInfoC1Eii", "llvm::ARMGenRegisterInfo::ARMGenRegisterInfo(int, int)"},
    {"_ZN4llvm3ARM8CCRClassD1Ev", "llvm::ARM::CCRClass::~CCRClass()"},
    {"_ZN4llvm3ARM8DPRClassD1Ev", "llvm::ARM::DPRClass::~DPRClass()"},
    {"_ZN4llvm3ARM10DPR_8ClassD1Ev", "llvm::ARM::DPR_8Class::~DPR_8Class()"},
    {"_ZN4llvm3ARM13DPR_VFP2ClassD1Ev", "llvm::ARM::DPR_VFP2Class::~DPR_VFP2Class()"},
    {"_ZN4llvm3ARM8GPRClassD1Ev", "llvm::ARM::GPRClass::~GPRClass()"},
    {"_ZN4llvm3ARM8QPRClassD1Ev", "llvm::ARM::QPRClass::~QPRClass()"},
    {"_ZN4llvm3ARM10QPR_8ClassD1Ev", "llvm::ARM::QPR_8Class::~QPR_8Class()"},
    {"_ZN4llvm3ARM13QPR_VFP2ClassD1Ev", "llvm::ARM::QPR_VFP2Class::~QPR_VFP2Class()"},
    {"_ZN4llvm3ARM9QQPRClassD1Ev", "llvm::ARM::QQPRClass::~QQPRClass()"},
    {"_ZN4llvm3ARM14QQPR_VFP2ClassD1Ev", "llvm::ARM::QQPR_VFP2Class::~QQPR_VFP2Class()"},
    {"_ZN4llvm3ARM11QQQQPRClassD1Ev", "llvm::ARM::QQQQPRClass::~QQQQPRClass()"},
    {"_ZN4llvm3ARM8SPRClassD1Ev", "llvm::ARM::SPRClass::~SPRClass()"},
    {"_ZN4llvm3ARM10SPR_8ClassD1Ev", "llvm::ARM::SPR_8Class::~SPR_8Class()"},
    {"_ZN4llvm3ARM9rGPRClassD1Ev", "llvm::ARM::rGPRClass::~rGPRClass()"},
    {"_ZN4llvm3ARM9tGPRClassD1Ev", "llvm::ARM::tGPRClass::~tGPRClass()"},
    {"_ZN4llvm3ARM10tcGPRClassD1Ev", "llvm::ARM::tcGPRClass::~tcGPRClass()"},
    {"_ZN4llvm19TargetRegisterClassC2EjPKcPKNS_3EVTEPKPKS0_S9_S9_S9_jjiPKjSB_", "llvm::TargetRegisterClass::TargetRegisterClass(unsigned int, char const*, llvm::EVT const*, llvm::TargetRegisterClass const* const*, llvm::TargetRegisterClass const* const*, llvm::TargetRegisterClass const* const*, llvm::TargetRegisterClass const* const*, unsigned int, unsigned int, int, unsigned int const*, unsigned int const*)"},
    {"_ZN4llvm3ARM8DPRClassD0Ev", "llvm::ARM::DPRClass::~DPRClass()"},
    {"_ZN4llvm3ARM8GPRClassD0Ev", "llvm::ARM::GPRClass::~GPRClass()"},
    {"_ZN4llvm3ARM8QPRClassD0Ev", "llvm::ARM::QPRClass::~QPRClass()"},
    {"_ZN4llvm3ARM9QQPRClassD0Ev", "llvm::ARM::QQPRClass::~QQPRClass()"},
    {"_ZN4llvm3ARM11QQQQPRClassD0Ev", "llvm::ARM::QQQQPRClass::~QQQQPRClass()"},
    {"_ZN4llvm3ARM9rGPRClassD0Ev", "llvm::ARM::rGPRClass::~rGPRClass()"},
    {"_ZN4llvm3ARM10tcGPRClassD0Ev", "llvm::ARM::tcGPRClass::~tcGPRClass()"},
    {"_ZN4llvm3ARM9tGPRClassD0Ev", "llvm::ARM::tGPRClass::~tGPRClass()"},
    {"_ZNK4llvm19TargetRegisterClass22allocation_order_beginERKNS_15MachineFunctionE", "llvm::TargetRegisterClass::allocation_order_begin(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19TargetRegisterClass20allocation_order_endERKNS_15MachineFunctionE", "llvm::TargetRegisterClass::allocation_order_end(llvm::MachineFunction const&) const"},
    {"_ZN4llvm3ARM10SPR_8ClassD0Ev", "llvm::ARM::SPR_8Class::~SPR_8Class()"},
    {"_ZN4llvm3ARM8SPRClassD0Ev", "llvm::ARM::SPRClass::~SPRClass()"},
    {"_ZN4llvm3ARM14QQPR_VFP2ClassD0Ev", "llvm::ARM::QQPR_VFP2Class::~QQPR_VFP2Class()"},
    {"_ZN4llvm3ARM13QPR_VFP2ClassD0Ev", "llvm::ARM::QPR_VFP2Class::~QPR_VFP2Class()"},
    {"_ZN4llvm3ARM10QPR_8ClassD0Ev", "llvm::ARM::QPR_8Class::~QPR_8Class()"},
    {"_ZN4llvm3ARM13DPR_VFP2ClassD0Ev", "llvm::ARM::DPR_VFP2Class::~DPR_VFP2Class()"},
    {"_ZN4llvm3ARM10DPR_8ClassD0Ev", "llvm::ARM::DPR_8Class::~DPR_8Class()"},
    {"_ZN4llvm3ARM8CCRClassD0Ev", "llvm::ARM::CCRClass::~CCRClass()"},
    {"_ZN4llvm19TargetRegisterClassD1Ev", "llvm::TargetRegisterClass::~TargetRegisterClass()"},
    {"_ZN4llvm19TargetRegisterClassD0Ev", "llvm::TargetRegisterClass::~TargetRegisterClass()"},
    {"_ZN4llvm27createARMJITCodeEmitterPassERNS_20ARMBaseTargetMachineERNS_14JITCodeEmitterE", "llvm::createARMJITCodeEmitterPass(llvm::ARMBaseTargetMachine&, llvm::JITCodeEmitter&)"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitterD1Ev", "(anonymous namespace)::ARMCodeEmitter::~ARMCodeEmitter()"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitterD0Ev", "(anonymous namespace)::ARMCodeEmitter::~ARMCodeEmitter()"},
    {"_ZNK12_GLOBAL__N_114ARMCodeEmitter11getPassNameEv", "(anonymous namespace)::ARMCodeEmitter::getPassName() const"},
    {"_ZNK12_GLOBAL__N_114ARMCodeEmitter16getAnalysisUsageERN4llvm13AnalysisUsageE", "(anonymous namespace)::ARMCodeEmitter::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitter20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::ARMCodeEmitter::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitter15emitInstructionERKN4llvm12MachineInstrE", "(anonymous namespace)::ARMCodeEmitter::emitInstruction(llvm::MachineInstr const&)"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitter25emitLEApcrelJTInstructionERKN4llvm12MachineInstrE", "(anonymous namespace)::ARMCodeEmitter::emitLEApcrelJTInstruction(llvm::MachineInstr const&)"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitter29emitDataProcessingInstructionERKN4llvm12MachineInstrEjj", "(anonymous namespace)::ARMCodeEmitter::emitDataProcessingInstruction(llvm::MachineInstr const&, unsigned int, unsigned int)"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitter24emitLoadStoreInstructionERKN4llvm12MachineInstrEjj", "(anonymous namespace)::ARMCodeEmitter::emitLoadStoreInstruction(llvm::MachineInstr const&, unsigned int, unsigned int)"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitter28emitMiscLoadStoreInstructionERKN4llvm12MachineInstrEj", "(anonymous namespace)::ARMCodeEmitter::emitMiscLoadStoreInstruction(llvm::MachineInstr const&, unsigned int)"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitter25emitMiscBranchInstructionERKN4llvm12MachineInstrE", "(anonymous namespace)::ARMCodeEmitter::emitMiscBranchInstruction(llvm::MachineInstr const&)"},
    {"_ZNK12_GLOBAL__N_114ARMCodeEmitter21getBinaryCodeForInstrERKN4llvm12MachineInstrE", "(anonymous namespace)::ARMCodeEmitter::getBinaryCodeForInstr(llvm::MachineInstr const&) const"},
    {"_Z12encodeNEONRdRKN4llvm12MachineInstrEj", "encodeNEONRd(llvm::MachineInstr const&, unsigned int)"},
    {"_Z12encodeNEONRnRKN4llvm12MachineInstrEj", "encodeNEONRn(llvm::MachineInstr const&, unsigned int)"},
    {"_Z12encodeNEONRmRKN4llvm12MachineInstrEj", "encodeNEONRm(llvm::MachineInstr const&, unsigned int)"},
    {"_ZNK12_GLOBAL__N_114ARMCodeEmitter17getMachineOpValueERKN4llvm12MachineInstrERKNS1_14MachineOperandE", "(anonymous namespace)::ARMCodeEmitter::getMachineOpValue(llvm::MachineInstr const&, llvm::MachineOperand const&) const"},
    {"_ZNK12_GLOBAL__N_114ARMCodeEmitter23getAddrModeImm12OpValueERKN4llvm12MachineInstrEj", "(anonymous namespace)::ARMCodeEmitter::getAddrModeImm12OpValue(llvm::MachineInstr const&, unsigned int) const"},
    {"_ZNK12_GLOBAL__N_114ARMCodeEmitter19getAddrMode5OpValueERKN4llvm12MachineInstrEj", "(anonymous namespace)::ARMCodeEmitter::getAddrMode5OpValue(llvm::MachineInstr const&, unsigned int) const"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitter19emitInlineJumpTableEj", "(anonymous namespace)::ARMCodeEmitter::emitInlineJumpTable(unsigned int)"},
    {"_ZN12_GLOBAL__N_114ARMCodeEmitter14getMovi32ValueERKN4llvm12MachineInstrERKNS1_14MachineOperandEj", "(anonymous namespace)::ARMCodeEmitter::getMovi32Value(llvm::MachineInstr const&, llvm::MachineOperand const&, unsigned int)"},
    {"_ZN4llvm8DenseMapIjlNS_12DenseMapInfoIjEENS1_IlEEE6insertERKSt4pairIjlE", "llvm::DenseMap<unsigned int, long, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<long>>::insert(std::pair<unsigned int, long> const&)"},
    {"_ZN4llvm8DenseMapIjlNS_12DenseMapInfoIjEENS1_IlEEE16InsertIntoBucketERKjRKlPSt4pairIjlE", "llvm::DenseMap<unsigned int, long, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<long>>::InsertIntoBucket(unsigned int const&, long const&, std::pair<unsigned int, long>*)"},
    {"_ZN4llvm8DenseMapIjlNS_12DenseMapInfoIjEENS1_IlEEE4growEj", "llvm::DenseMap<unsigned int, long, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<long>>::grow(unsigned int)"},
    {"_ZN4llvm15SmallVectorImplIlE6resizeEj", "llvm::SmallVectorImpl<long>::resize(unsigned int)"},
    {"_ZN4llvm27createARMConstantIslandPassEv", "llvm::createARMConstantIslandPass()"},
    {"_ZN12_GLOBAL__N_118ARMConstantIslandsD1Ev", "(anonymous namespace)::ARMConstantIslands::~ARMConstantIslands()"},
    {"_ZN12_GLOBAL__N_118ARMConstantIslandsD0Ev", "(anonymous namespace)::ARMConstantIslands::~ARMConstantIslands()"},
    {"_ZNK12_GLOBAL__N_118ARMConstantIslands11getPassNameEv", "(anonymous namespace)::ARMConstantIslands::getPassName() const"},
    {"_ZN12_GLOBAL__N_118ARMConstantIslands20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::ARMConstantIslands::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN12_GLOBAL__N_118ARMConstantIslands12CPEIsInRangeEPN4llvm12MachineInstrEjS3_jbb", "(anonymous namespace)::ARMConstantIslands::CPEIsInRange(llvm::MachineInstr*, unsigned int, llvm::MachineInstr*, unsigned int, bool, bool)"},
    {"_ZN12_GLOBAL__N_118ARMConstantIslands20AdjustBBOffsetsAfterEPN4llvm17MachineBasicBlockEi", "(anonymous namespace)::ARMConstantIslands::AdjustBBOffsetsAfter(llvm::MachineBasicBlock*, int)"},
    {"_ZN12_GLOBAL__N_118ARMConstantIslands21SplitBlockBeforeInstrEPN4llvm12MachineInstrE", "(anonymous namespace)::ARMConstantIslands::SplitBlockBeforeInstr(llvm::MachineInstr*)"},
    {"_ZNSt6vectorIN12_GLOBAL__N_118ARMConstantIslands9ImmBranchESaIS2_EE9push_backERKS2_", "std::vector<(anonymous namespace)::ARMConstantIslands::ImmBranch, std::allocator<(anonymous namespace)::ARMConstantIslands::ImmBranch>>::push_back((anonymous namespace)::ARMConstantIslands::ImmBranch const&)"},
    {"_ZN12_GLOBAL__N_118ARMConstantIslands17DecrementOldEntryEjPN4llvm12MachineInstrE", "(anonymous namespace)::ARMConstantIslands::DecrementOldEntry(unsigned int, llvm::MachineInstr*)"},
    {"_ZNSt6vectorIN12_GLOBAL__N_118ARMConstantIslands7CPEntryESaIS2_EE9push_backERKS2_", "std::vector<(anonymous namespace)::ARMConstantIslands::CPEntry, std::allocator<(anonymous namespace)::ARMConstantIslands::CPEntry>>::push_back((anonymous namespace)::ARMConstantIslands::CPEntry const&)"},
    {"_ZNSt6vectorIN12_GLOBAL__N_118ARMConstantIslands7CPEntryESaIS2_EEC1ERKS4_", "std::vector<(anonymous namespace)::ARMConstantIslands::CPEntry, std::allocator<(anonymous namespace)::ARMConstantIslands::CPEntry>>::vector(std::vector<(anonymous namespace)::ARMConstantIslands::CPEntry, std::allocator<(anonymous namespace)::ARMConstantIslands::CPEntry>> const&)"},
    {"_ZNSt6vectorIPN4llvm17MachineBasicBlockESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>, llvm::MachineBasicBlock* const&)"},
    {"_ZSt6__findIN9__gnu_cxx17__normal_iteratorIPPN4llvm17MachineBasicBlockESt6vectorIS4_SaIS4_EEEES4_ET_SA_SA_RKT0_St26random_access_iterator_tag", "__gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>> std::__find<__gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>, llvm::MachineBasicBlock*>(__gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>, __gnu_cxx::__normal_iterator<llvm::MachineBasicBlock**, std::vector<llvm::MachineBasicBlock*, std::allocator<llvm::MachineBasicBlock*>>>, llvm::MachineBasicBlock* const&, std::random_access_iterator_tag)"},
    {"_ZN4llvm20ARMConstantPoolValueC1EPKNS_8ConstantEjNS_5ARMCP9ARMCPKindEhNS4_13ARMCPModifierEb", "llvm::ARMConstantPoolValue::ARMConstantPoolValue(llvm::Constant const*, unsigned int, llvm::ARMCP::ARMCPKind, unsigned char, llvm::ARMCP::ARMCPModifier, bool)"},
    {"_ZN4llvm20ARMConstantPoolValueC2EPKNS_8ConstantEjNS_5ARMCP9ARMCPKindEhNS4_13ARMCPModifierEb", "llvm::ARMConstantPoolValue::ARMConstantPoolValue(llvm::Constant const*, unsigned int, llvm::ARMCP::ARMCPKind, unsigned char, llvm::ARMCP::ARMCPModifier, bool)"},
    {"_ZN4llvm20ARMConstantPoolValueC1ERNS_11LLVMContextEPKcjhNS_5ARMCP13ARMCPModifierEb", "llvm::ARMConstantPoolValue::ARMConstantPoolValue(llvm::LLVMContext&, char const*, unsigned int, unsigned char, llvm::ARMCP::ARMCPModifier, bool)"},
    {"_ZN4llvm20ARMConstantPoolValueC2ERNS_11LLVMContextEPKcjhNS_5ARMCP13ARMCPModifierEb", "llvm::ARMConstantPoolValue::ARMConstantPoolValue(llvm::LLVMContext&, char const*, unsigned int, unsigned char, llvm::ARMCP::ARMCPModifier, bool)"},
    {"_ZN4llvm20ARMConstantPoolValueC1EPKNS_11GlobalValueENS_5ARMCP13ARMCPModifierE", "llvm::ARMConstantPoolValue::ARMConstantPoolValue(llvm::GlobalValue const*, llvm::ARMCP::ARMCPModifier)"},
    {"_ZN4llvm20ARMConstantPoolValueC2EPKNS_11GlobalValueENS_5ARMCP13ARMCPModifierE", "llvm::ARMConstantPoolValue::ARMConstantPoolValue(llvm::GlobalValue const*, llvm::ARMCP::ARMCPModifier)"},
    {"_ZNK4llvm20ARMConstantPoolValue5getGVEv", "llvm::ARMConstantPoolValue::getGV() const"},
    {"_ZNK4llvm20ARMConstantPoolValue15getBlockAddressEv", "llvm::ARMConstantPoolValue::getBlockAddress() const"},
    {"_ZN4llvm20ARMConstantPoolValue25getExistingMachineCPValueEPNS_19MachineConstantPoolEj", "llvm::ARMConstantPoolValue::getExistingMachineCPValue(llvm::MachineConstantPool*, unsigned int)"},
    {"_ZN4llvm20ARMConstantPoolValueD0Ev", "llvm::ARMConstantPoolValue::~ARMConstantPoolValue()"},
    {"_ZN4llvm20ARMConstantPoolValueD1Ev", "llvm::ARMConstantPoolValue::~ARMConstantPoolValue()"},
    {"_ZN4llvm20ARMConstantPoolValueD2Ev", "llvm::ARMConstantPoolValue::~ARMConstantPoolValue()"},
    {"_ZN4llvm20ARMConstantPoolValue20AddSelectionDAGCSEIdERNS_16FoldingSetNodeIDE", "llvm::ARMConstantPoolValue::AddSelectionDAGCSEId(llvm::FoldingSetNodeID&)"},
    {"_ZN4llvm20ARMConstantPoolValue12hasSameValueEPS0_", "llvm::ARMConstantPoolValue::hasSameValue(llvm::ARMConstantPoolValue*)"},
    {"_ZNK4llvm20ARMConstantPoolValue4dumpEv", "llvm::ARMConstantPoolValue::dump() const"},
    {"_ZNK4llvm20ARMConstantPoolValue5printERNS_11raw_ostreamE", "llvm::ARMConstantPoolValue::print(llvm::raw_ostream&) const"},
    {"_ZNK4llvm20ARMConstantPoolValue17getRelocationInfoEv", "llvm::ARMConstantPoolValue::getRelocationInfo() const"},
    {"_ZNSt6vectorIN4llvm24MachineConstantPoolEntryESaIS1_EEC2ERKS3_", "std::vector<llvm::MachineConstantPoolEntry, std::allocator<llvm::MachineConstantPoolEntry>>::vector(std::vector<llvm::MachineConstantPoolEntry, std::allocator<llvm::MachineConstantPoolEntry>> const&)"},
    {"_ZN4llvm24MachineConstantPoolValueD1Ev", "llvm::MachineConstantPoolValue::~MachineConstantPoolValue()"},
    {"_ZN4llvm24MachineConstantPoolValueD0Ev", "llvm::MachineConstantPoolValue::~MachineConstantPoolValue()"},
    {"_ZN4llvm16ARMELFWriterInfoC1ERNS_13TargetMachineE", "llvm::ARMELFWriterInfo::ARMELFWriterInfo(llvm::TargetMachine&)"},
    {"_ZN4llvm16ARMELFWriterInfoC2ERNS_13TargetMachineE", "llvm::ARMELFWriterInfo::ARMELFWriterInfo(llvm::TargetMachine&)"},
    {"_ZN4llvm16ARMELFWriterInfoD0Ev", "llvm::ARMELFWriterInfo::~ARMELFWriterInfo()"},
    {"_ZN4llvm16ARMELFWriterInfoD1Ev", "llvm::ARMELFWriterInfo::~ARMELFWriterInfo()"},
    {"_ZN4llvm16ARMELFWriterInfoD2Ev", "llvm::ARMELFWriterInfo::~ARMELFWriterInfo()"},
    {"_ZNK4llvm16ARMELFWriterInfo17getRelocationTypeEj", "llvm::ARMELFWriterInfo::getRelocationType(unsigned int) const"},
    {"_ZNK4llvm16ARMELFWriterInfo24getDefaultAddendForRelTyEjl", "llvm::ARMELFWriterInfo::getDefaultAddendForRelTy(unsigned int, long) const"},
    {"_ZNK4llvm16ARMELFWriterInfo19getRelocationTySizeEj", "llvm::ARMELFWriterInfo::getRelocationTySize(unsigned int) const"},
    {"_ZNK4llvm16ARMELFWriterInfo15isPCRelativeRelEj", "llvm::ARMELFWriterInfo::isPCRelativeRel(unsigned int) const"},
    {"_ZNK4llvm16ARMELFWriterInfo28getAbsoluteLabelMachineRelTyEv", "llvm::ARMELFWriterInfo::getAbsoluteLabelMachineRelTy() const"},
    {"_ZNK4llvm16ARMELFWriterInfo17computeRelocationEjjj", "llvm::ARMELFWriterInfo::computeRelocation(unsigned int, unsigned int, unsigned int) const"},
    {"_ZNK4llvm16ARMELFWriterInfo19hasRelocationAddendEv", "llvm::ARMELFWriterInfo::hasRelocationAddend() const"},
    {"_ZN4llvm25createARMExpandPseudoPassEv", "llvm::createARMExpandPseudoPass()"},
    {"_ZN12_GLOBAL__N_115ARMExpandPseudoD1Ev", "(anonymous namespace)::ARMExpandPseudo::~ARMExpandPseudo()"},
    {"_ZN12_GLOBAL__N_115ARMExpandPseudoD0Ev", "(anonymous namespace)::ARMExpandPseudo::~ARMExpandPseudo()"},
    {"_ZNK12_GLOBAL__N_115ARMExpandPseudo11getPassNameEv", "(anonymous namespace)::ARMExpandPseudo::getPassName() const"},
    {"_ZN12_GLOBAL__N_115ARMExpandPseudo20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::ARMExpandPseudo::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN12_GLOBAL__N_115ARMExpandPseudo8ExpandMIERN4llvm17MachineBasicBlockENS1_14ilist_iteratorINS1_12MachineInstrEEE", "(anonymous namespace)::ARMExpandPseudo::ExpandMI(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>)"},
    {"_ZN12_GLOBAL__N_115ARMExpandPseudo10ExpandVTBLERN4llvm14ilist_iteratorINS1_12MachineInstrEEEjbj", "(anonymous namespace)::ARMExpandPseudo::ExpandVTBL(llvm::ilist_iterator<llvm::MachineInstr>&, unsigned int, bool, unsigned int)"},
    {"_Z11GetDSubRegsjN12_GLOBAL__N_114NEONRegSpacingEPKN4llvm18TargetRegisterInfoERjS5_S5_S5_", "GetDSubRegs(unsigned int, (anonymous namespace)::NEONRegSpacing, llvm::TargetRegisterInfo const*, unsigned int&, unsigned int&, unsigned int&, unsigned int&)"},
    {"_ZN4llvm3ARM14createFastISelERNS_20FunctionLoweringInfoE", "llvm::ARM::createFastISel(llvm::FunctionLoweringInfo&)"},
    {"_ZN12_GLOBAL__N_111ARMFastISelD1Ev", "(anonymous namespace)::ARMFastISel::~ARMFastISel()"},
    {"_ZN12_GLOBAL__N_111ARMFastISelD0Ev", "(anonymous namespace)::ARMFastISel::~ARMFastISel()"},
    {"_ZN12_GLOBAL__N_111ARMFastISel23TargetSelectInstructionEPKN4llvm11InstructionE", "(anonymous namespace)::ARMFastISel::TargetSelectInstruction(llvm::Instruction const*)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel10FastEmit_rEN4llvm3MVTES2_jjb", "(anonymous namespace)::ARMFastISel::FastEmit_r(llvm::MVT, llvm::MVT, unsigned int, unsigned int, bool)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel11FastEmit_rrEN4llvm3MVTES2_jjbjb", "(anonymous namespace)::ARMFastISel::FastEmit_rr(llvm::MVT, llvm::MVT, unsigned int, unsigned int, bool, unsigned int, bool)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel11FastEmit_riEN4llvm3MVTES2_jjby", "(anonymous namespace)::ARMFastISel::FastEmit_ri(llvm::MVT, llvm::MVT, unsigned int, unsigned int, bool, unsigned long long)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel10FastEmit_iEN4llvm3MVTES2_jy", "(anonymous namespace)::ARMFastISel::FastEmit_i(llvm::MVT, llvm::MVT, unsigned int, unsigned long long)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel25TargetMaterializeConstantEPKN4llvm8ConstantE", "(anonymous namespace)::ARMFastISel::TargetMaterializeConstant(llvm::Constant const*)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel23TargetMaterializeAllocaEPKN4llvm10AllocaInstE", "(anonymous namespace)::ARMFastISel::TargetMaterializeAlloca(llvm::AllocaInst const*)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel13FastEmitInst_EjPKN4llvm19TargetRegisterClassE", "(anonymous namespace)::ARMFastISel::FastEmitInst_(unsigned int, llvm::TargetRegisterClass const*)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel14FastEmitInst_rEjPKN4llvm19TargetRegisterClassEjb", "(anonymous namespace)::ARMFastISel::FastEmitInst_r(unsigned int, llvm::TargetRegisterClass const*, unsigned int, bool)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel15FastEmitInst_rrEjPKN4llvm19TargetRegisterClassEjbjb", "(anonymous namespace)::ARMFastISel::FastEmitInst_rr(unsigned int, llvm::TargetRegisterClass const*, unsigned int, bool, unsigned int, bool)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel15FastEmitInst_riEjPKN4llvm19TargetRegisterClassEjby", "(anonymous namespace)::ARMFastISel::FastEmitInst_ri(unsigned int, llvm::TargetRegisterClass const*, unsigned int, bool, unsigned long long)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel15FastEmitInst_rfEjPKN4llvm19TargetRegisterClassEjbPKNS1_10ConstantFPE", "(anonymous namespace)::ARMFastISel::FastEmitInst_rf(unsigned int, llvm::TargetRegisterClass const*, unsigned int, bool, llvm::ConstantFP const*)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel14FastEmitInst_iEjPKN4llvm19TargetRegisterClassEy", "(anonymous namespace)::ARMFastISel::FastEmitInst_i(unsigned int, llvm::TargetRegisterClass const*, unsigned long long)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel16FastEmitInst_rriEjPKN4llvm19TargetRegisterClassEjbjby", "(anonymous namespace)::ARMFastISel::FastEmitInst_rri(unsigned int, llvm::TargetRegisterClass const*, unsigned int, bool, unsigned int, bool, unsigned long long)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel26FastEmitInst_extractsubregEN4llvm3MVTEjbj", "(anonymous namespace)::ARMFastISel::FastEmitInst_extractsubreg(llvm::MVT, unsigned int, bool, unsigned int)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel15AddOptionalDefsERKN4llvm19MachineInstrBuilderE", "(anonymous namespace)::ARMFastISel::AddOptionalDefs(llvm::MachineInstrBuilder const&)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel16ARMMaterializeGVEPKN4llvm11GlobalValueENS1_3EVTE", "(anonymous namespace)::ARMFastISel::ARMMaterializeGV(llvm::GlobalValue const*, llvm::EVT)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel14SelectBinaryOpEPKN4llvm11InstructionEj", "(anonymous namespace)::ARMFastISel::SelectBinaryOp(llvm::Instruction const*, unsigned int)"},
    {"_Z19RetCC_ARM_AAPCS_VFPjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_ARM_AAPCS_VFP(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z16CC_ARM_AAPCS_VFPjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_ARM_AAPCS_VFP(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z15RetCC_ARM_AAPCSjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_ARM_AAPCS(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z12CC_ARM_AAPCSjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_ARM_AAPCS(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z14RetCC_ARM_APCSjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_ARM_APCS(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z11CC_ARM_APCSjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_ARM_APCS(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZN4llvm13f64AssignAPCSERjRNS_3MVTES2_RNS_11CCValAssign7LocInfoERNS_7CCStateEb", "llvm::f64AssignAPCS(unsigned int&, llvm::MVT&, llvm::MVT&, llvm::CCValAssign::LocInfo&, llvm::CCState&, bool)"},
    {"_ZN4llvm12f64RetAssignERjRNS_3MVTES2_RNS_11CCValAssign7LocInfoERNS_7CCStateE", "llvm::f64RetAssign(unsigned int&, llvm::MVT&, llvm::MVT&, llvm::CCValAssign::LocInfo&, llvm::CCState&)"},
    {"_Z19CC_ARM_AAPCS_CommonjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_ARM_AAPCS_Common(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZN4llvm14f64AssignAAPCSERjRNS_3MVTES2_RNS_11CCValAssign7LocInfoERNS_7CCStateEb", "llvm::f64AssignAAPCS(unsigned int&, llvm::MVT&, llvm::MVT&, llvm::CCValAssign::LocInfo&, llvm::CCState&, bool)"},
    {"_Z22RetCC_ARM_AAPCS_CommonjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_ARM_AAPCS_Common(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel15ProcessCallArgsERN4llvm15SmallVectorImplIPNS1_5ValueEEERNS2_IjEERNS2_INS1_3MVTEEERNS2_INS1_3ISD10ArgFlagsTyEEES8_NS1_11CallingConv2IDERj", "(anonymous namespace)::ARMFastISel::ProcessCallArgs(llvm::SmallVectorImpl<llvm::Value*>&, llvm::SmallVectorImpl<unsigned int>&, llvm::SmallVectorImpl<llvm::MVT>&, llvm::SmallVectorImpl<llvm::ISD::ArgFlagsTy>&, llvm::SmallVectorImpl<unsigned int>&, llvm::CallingConv::ID, unsigned int&)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel10FinishCallEN4llvm3MVTERNS1_15SmallVectorImplIjEEPKNS1_11InstructionENS1_11CallingConv2IDERj", "(anonymous namespace)::ARMFastISel::FinishCall(llvm::MVT, llvm::SmallVectorImpl<unsigned int>&, llvm::Instruction const*, llvm::CallingConv::ID, unsigned int&)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel12ARMEmitStoreEN4llvm3EVTEjRNS_7AddressE", "(anonymous namespace)::ARMFastISel::ARMEmitStore(llvm::EVT, unsigned int, (anonymous namespace)::Address&)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel18ARMSimplifyAddressERNS_7AddressEN4llvm3EVTE", "(anonymous namespace)::ARMFastISel::ARMSimplifyAddress((anonymous namespace)::Address&, llvm::EVT)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel20AddLoadStoreOperandsEN4llvm3EVTERNS_7AddressERKNS1_19MachineInstrBuilderE", "(anonymous namespace)::ARMFastISel::AddLoadStoreOperands(llvm::EVT, (anonymous namespace)::Address&, llvm::MachineInstrBuilder const&)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel14ARMEmitLibcallEPKN4llvm11InstructionENS1_5RTLIB7LibcallE", "(anonymous namespace)::ARMFastISel::ARMEmitLibcall(llvm::Instruction const*, llvm::RTLIB::Libcall)"},
    {"_ZN12_GLOBAL__N_111ARMFastISel17ARMComputeAddressEPKN4llvm5ValueERNS_7AddressE", "(anonymous namespace)::ARMFastISel::ARMComputeAddress(llvm::Value const*, (anonymous namespace)::Address&)"},
    {"_ZN4llvm8FastISel13TryToFoldLoadEPNS_12MachineInstrEjPKNS_8LoadInstE", "llvm::FastISel::TryToFoldLoad(llvm::MachineInstr*, unsigned int, llvm::LoadInst const*)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_3ISD10ArgFlagsTyELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::ISD::ArgFlagsTy, false>::grow(unsigned long)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_3MVTELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::MVT, false>::grow(unsigned long)"},
    {"_ZNK4llvm16ARMFrameLowering5hasFPERKNS_15MachineFunctionE", "llvm::ARMFrameLowering::hasFP(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm16ARMFrameLowering20hasReservedCallFrameERKNS_15MachineFunctionE", "llvm::ARMFrameLowering::hasReservedCallFrame(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm16ARMFrameLowering27canSimplifyCallFramePseudosERKNS_15MachineFunctionE", "llvm::ARMFrameLowering::canSimplifyCallFramePseudos(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm16ARMFrameLowering12emitPrologueERNS_15MachineFunctionE", "llvm::ARMFrameLowering::emitPrologue(llvm::MachineFunction&) const"},
    {"_ZNK4llvm16ARMFrameLowering12emitEpilogueERNS_15MachineFunctionERNS_17MachineBasicBlockE", "llvm::ARMFrameLowering::emitEpilogue(llvm::MachineFunction&, llvm::MachineBasicBlock&) const"},
    {"_ZNK4llvm16ARMFrameLowering22getFrameIndexReferenceERKNS_15MachineFunctionEiRj", "llvm::ARMFrameLowering::getFrameIndexReference(llvm::MachineFunction const&, int, unsigned int&) const"},
    {"_ZNK4llvm16ARMFrameLowering26ResolveFrameIndexReferenceERKNS_15MachineFunctionEiRji", "llvm::ARMFrameLowering::ResolveFrameIndexReference(llvm::MachineFunction const&, int, unsigned int&, int) const"},
    {"_ZNK4llvm16ARMFrameLowering19getFrameIndexOffsetERKNS_15MachineFunctionEi", "llvm::ARMFrameLowering::getFrameIndexOffset(llvm::MachineFunction const&, int) const"},
    {"_ZNK4llvm16ARMFrameLowering12emitPushInstERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERKSt6vectorINS_15CalleeSavedInfoESaIS7_EEjjbPFbjbE", "llvm::ARMFrameLowering::emitPushInst(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, std::vector<llvm::CalleeSavedInfo, std::allocator<llvm::CalleeSavedInfo>> const&, unsigned int, unsigned int, bool, bool (*)(unsigned int, bool)) const"},
    {"_ZNK4llvm16ARMFrameLowering11emitPopInstERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERKSt6vectorINS_15CalleeSavedInfoESaIS7_EEjjbbPFbjbE", "llvm::ARMFrameLowering::emitPopInst(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, std::vector<llvm::CalleeSavedInfo, std::allocator<llvm::CalleeSavedInfo>> const&, unsigned int, unsigned int, bool, bool, bool (*)(unsigned int, bool)) const"},
    {"_ZNK4llvm16ARMFrameLowering25spillCalleeSavedRegistersERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERKSt6vectorINS_15CalleeSavedInfoESaIS7_EEPKNS_18TargetRegisterInfoE", "llvm::ARMFrameLowering::spillCalleeSavedRegisters(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, std::vector<llvm::CalleeSavedInfo, std::allocator<llvm::CalleeSavedInfo>> const&, llvm::TargetRegisterInfo const*) const"},
    {"_ZN4llvm18isARMArea1RegisterEjb", "llvm::isARMArea1Register(unsigned int, bool)"},
    {"_ZN4llvm18isARMArea2RegisterEjb", "llvm::isARMArea2Register(unsigned int, bool)"},
    {"_ZN4llvm18isARMArea3RegisterEjb", "llvm::isARMArea3Register(unsigned int, bool)"},
    {"_ZNK4llvm16ARMFrameLowering27restoreCalleeSavedRegistersERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERKSt6vectorINS_15CalleeSavedInfoESaIS7_EEPKNS_18TargetRegisterInfoE", "llvm::ARMFrameLowering::restoreCalleeSavedRegisters(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, std::vector<llvm::CalleeSavedInfo, std::allocator<llvm::CalleeSavedInfo>> const&, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm16ARMFrameLowering36processFunctionBeforeCalleeSavedScanERNS_15MachineFunctionEPNS_12RegScavengerE", "llvm::ARMFrameLowering::processFunctionBeforeCalleeSavedScan(llvm::MachineFunction&, llvm::RegScavenger*) const"},
    {"_ZSt6__findIPjjET_S1_S1_RKT0_St26random_access_iterator_tag", "unsigned int* std::__find<unsigned int*, unsigned int>(unsigned int*, unsigned int*, unsigned int const&, std::random_access_iterator_tag)"},
    {"_ZNSt6vectorIN4llvm16MachineFrameInfo11StackObjectESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::MachineFrameInfo::StackObject, std::allocator<llvm::MachineFrameInfo::StackObject>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::MachineFrameInfo::StackObject*, std::vector<llvm::MachineFrameInfo::StackObject, std::allocator<llvm::MachineFrameInfo::StackObject>>>, llvm::MachineFrameInfo::StackObject const&)"},
    {"_ZN4llvm24createARMGlobalMergePassEPKNS_14TargetLoweringE", "llvm::createARMGlobalMergePass(llvm::TargetLowering const*)"},
    {"_ZN12_GLOBAL__N_114ARMGlobalMergeD1Ev", "(anonymous namespace)::ARMGlobalMerge::~ARMGlobalMerge()"},
    {"_ZN12_GLOBAL__N_114ARMGlobalMergeD0Ev", "(anonymous namespace)::ARMGlobalMerge::~ARMGlobalMerge()"},
    {"_ZNK12_GLOBAL__N_114ARMGlobalMerge11getPassNameEv", "(anonymous namespace)::ARMGlobalMerge::getPassName() const"},
    {"_ZNK12_GLOBAL__N_114ARMGlobalMerge16getAnalysisUsageERN4llvm13AnalysisUsageE", "(anonymous namespace)::ARMGlobalMerge::getAnalysisUsage(llvm::AnalysisUsage&) const"},
    {"_ZN12_GLOBAL__N_114ARMGlobalMerge16doInitializationERN4llvm6ModuleE", "(anonymous namespace)::ARMGlobalMerge::doInitialization(llvm::Module&)"},
    {"_ZN12_GLOBAL__N_114ARMGlobalMerge13runOnFunctionERN4llvm8FunctionE", "(anonymous namespace)::ARMGlobalMerge::runOnFunction(llvm::Function&)"},
    {"_ZNK12_GLOBAL__N_114ARMGlobalMerge7doMergeERN4llvm15SmallVectorImplIPNS1_14GlobalVariableEEERNS1_6ModuleEb", "(anonymous namespace)::ARMGlobalMerge::doMerge(llvm::SmallVectorImpl<llvm::GlobalVariable*>&, llvm::Module&, bool) const"},
    {"_ZSt21__inplace_stable_sortIPPN4llvm14GlobalVariableEN12_GLOBAL__N_114ARMGlobalMerge9GlobalCmpEEvT_S7_T0_", "void std::__inplace_stable_sort<llvm::GlobalVariable**, (anonymous namespace)::ARMGlobalMerge::GlobalCmp>(llvm::GlobalVariable**, llvm::GlobalVariable**, (anonymous namespace)::ARMGlobalMerge::GlobalCmp)"},
    {"_ZSt22__stable_sort_adaptiveIPPN4llvm14GlobalVariableES3_lN12_GLOBAL__N_114ARMGlobalMerge9GlobalCmpEEvT_S7_T0_T1_T2_", "void std::__stable_sort_adaptive<llvm::GlobalVariable**, llvm::GlobalVariable**, long, (anonymous namespace)::ARMGlobalMerge::GlobalCmp>(llvm::GlobalVariable**, llvm::GlobalVariable**, llvm::GlobalVariable**, long, (anonymous namespace)::ARMGlobalMerge::GlobalCmp)"},
    {"_ZSt24__merge_sort_with_bufferIPPN4llvm14GlobalVariableES3_N12_GLOBAL__N_114ARMGlobalMerge9GlobalCmpEEvT_S7_T0_T1_", "void std::__merge_sort_with_buffer<llvm::GlobalVariable**, llvm::GlobalVariable**, (anonymous namespace)::ARMGlobalMerge::GlobalCmp>(llvm::GlobalVariable**, llvm::GlobalVariable**, llvm::GlobalVariable**, (anonymous namespace)::ARMGlobalMerge::GlobalCmp)"},
    {"_ZSt16__merge_adaptiveIPPN4llvm14GlobalVariableElS3_N12_GLOBAL__N_114ARMGlobalMerge9GlobalCmpEEvT_S7_S7_T0_S8_T1_S8_T2_", "void std::__merge_adaptive<llvm::GlobalVariable**, long, llvm::GlobalVariable**, (anonymous namespace)::ARMGlobalMerge::GlobalCmp>(llvm::GlobalVariable**, llvm::GlobalVariable**, llvm::GlobalVariable**, long, long, llvm::GlobalVariable**, long, (anonymous namespace)::ARMGlobalMerge::GlobalCmp)"},
    {"_ZSt16__insertion_sortIPPN4llvm14GlobalVariableEN12_GLOBAL__N_114ARMGlobalMerge9GlobalCmpEEvT_S7_T0_", "void std::__insertion_sort<llvm::GlobalVariable**, (anonymous namespace)::ARMGlobalMerge::GlobalCmp>(llvm::GlobalVariable**, llvm::GlobalVariable**, (anonymous namespace)::ARMGlobalMerge::GlobalCmp)"},
    {"_ZSt22__merge_without_bufferIPPN4llvm14GlobalVariableElN12_GLOBAL__N_114ARMGlobalMerge9GlobalCmpEEvT_S7_S7_T0_S8_T1_", "void std::__merge_without_buffer<llvm::GlobalVariable**, long, (anonymous namespace)::ARMGlobalMerge::GlobalCmp>(llvm::GlobalVariable**, llvm::GlobalVariable**, llvm::GlobalVariable**, long, long, (anonymous namespace)::ARMGlobalMerge::GlobalCmp)"},
    {"_ZSt8__rotateIPPN4llvm14GlobalVariableEEvT_S4_S4_St26random_access_iterator_tag", "void std::__rotate<llvm::GlobalVariable**>(llvm::GlobalVariable**, llvm::GlobalVariable**, llvm::GlobalVariable**, std::random_access_iterator_tag)"},
    {"_ZN4llvm19ARMHazardRecognizer13getHazardTypeEPNS_5SUnitEi", "llvm::ARMHazardRecognizer::getHazardType(llvm::SUnit*, int)"},
    {"_ZN4llvm19ARMHazardRecognizer5ResetEv", "llvm::ARMHazardRecognizer::Reset()"},
    {"_ZN4llvm19ARMHazardRecognizer15EmitInstructionEPNS_5SUnitE", "llvm::ARMHazardRecognizer::EmitInstruction(llvm::SUnit*)"},
    {"_ZN4llvm19ARMHazardRecognizer12AdvanceCycleEv", "llvm::ARMHazardRecognizer::AdvanceCycle()"},
    {"_ZN4llvm19ARMHazardRecognizer11RecedeCycleEv", "llvm::ARMHazardRecognizer::RecedeCycle()"},
    {"_ZN4llvm19ARMHazardRecognizerD1Ev", "llvm::ARMHazardRecognizer::~ARMHazardRecognizer()"},
    {"_ZN4llvm19ARMHazardRecognizerD0Ev", "llvm::ARMHazardRecognizer::~ARMHazardRecognizer()"},
    {"_ZN4llvm16createARMISelDagERNS_20ARMBaseTargetMachineENS_10CodeGenOpt5LevelE", "llvm::createARMISelDag(llvm::ARMBaseTargetMachine&, llvm::CodeGenOpt::Level)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISelD1Ev", "(anonymous namespace)::ARMDAGToDAGISel::~ARMDAGToDAGISel()"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISelD0Ev", "(anonymous namespace)::ARMDAGToDAGISel::~ARMDAGToDAGISel()"},
    {"_ZNK12_GLOBAL__N_115ARMDAGToDAGISel11getPassNameEv", "(anonymous namespace)::ARMDAGToDAGISel::getPassName() const"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel6SelectEPN4llvm6SDNodeE", "(anonymous namespace)::ARMDAGToDAGISel::Select(llvm::SDNode*)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel28SelectInlineAsmMemoryOperandERKN4llvm7SDValueEcRSt6vectorIS2_SaIS2_EE", "(anonymous namespace)::ARMDAGToDAGISel::SelectInlineAsmMemoryOperand(llvm::SDValue const&, char, std::vector<llvm::SDValue, std::allocator<llvm::SDValue>>&)"},
    {"_ZNK12_GLOBAL__N_115ARMDAGToDAGISel21CheckPatternPredicateEj", "(anonymous namespace)::ARMDAGToDAGISel::CheckPatternPredicate(unsigned int) const"},
    {"_ZNK12_GLOBAL__N_115ARMDAGToDAGISel18CheckNodePredicateEPN4llvm6SDNodeEj", "(anonymous namespace)::ARMDAGToDAGISel::CheckNodePredicate(llvm::SDNode*, unsigned int) const"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel19CheckComplexPatternEPN4llvm6SDNodeES3_NS1_7SDValueEjRNS1_15SmallVectorImplISt4pairIS4_S3_EEE", "(anonymous namespace)::ARMDAGToDAGISel::CheckComplexPattern(llvm::SDNode*, llvm::SDNode*, llvm::SDValue, unsigned int, llvm::SmallVectorImpl<std::pair<llvm::SDValue, llvm::SDNode*>>&)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel14RunSDNodeXFormEN4llvm7SDValueEj", "(anonymous namespace)::ARMDAGToDAGISel::RunSDNodeXForm(llvm::SDValue, unsigned int)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel23SelectShifterOperandRegEN4llvm7SDValueERS2_S3_S3_", "(anonymous namespace)::ARMDAGToDAGISel::SelectShifterOperandReg(llvm::SDValue, llvm::SDValue&, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel20SelectT2AddrModeImm8EN4llvm7SDValueERS2_S3_", "(anonymous namespace)::ARMDAGToDAGISel::SelectT2AddrModeImm8(llvm::SDValue, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel21SelectThumbAddrModeSPEN4llvm7SDValueERS2_S3_", "(anonymous namespace)::ARMDAGToDAGISel::SelectThumbAddrModeSP(llvm::SDValue, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel15SelectAddrMode6EPN4llvm6SDNodeENS1_7SDValueERS4_S5_", "(anonymous namespace)::ARMDAGToDAGISel::SelectAddrMode6(llvm::SDNode*, llvm::SDValue, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel21SelectAddrMode2OffsetEPN4llvm6SDNodeENS1_7SDValueERS4_S5_", "(anonymous namespace)::ARMDAGToDAGISel::SelectAddrMode2Offset(llvm::SDNode*, llvm::SDValue, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel21SelectAddrMode3OffsetEPN4llvm6SDNodeENS1_7SDValueERS4_S5_", "(anonymous namespace)::ARMDAGToDAGISel::SelectAddrMode3Offset(llvm::SDNode*, llvm::SDValue, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel26SelectT2AddrModeImm8OffsetEPN4llvm6SDNodeENS1_7SDValueERS4_", "(anonymous namespace)::ARMDAGToDAGISel::SelectT2AddrModeImm8Offset(llvm::SDNode*, llvm::SDValue, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel24SelectThumbAddrModeImm5SEN4llvm7SDValueEjRS2_S3_", "(anonymous namespace)::ARMDAGToDAGISel::SelectThumbAddrModeImm5S(llvm::SDValue, unsigned int, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel21SelectThumbAddrModeRIEN4llvm7SDValueERS2_S3_j", "(anonymous namespace)::ARMDAGToDAGISel::SelectThumbAddrModeRI(llvm::SDValue, llvm::SDValue&, llvm::SDValue&, unsigned int)"},
    {"_ZN4llvm6ARM_AM16decodeNEONModImmEjRj", "llvm::ARM_AM::decodeNEONModImm(unsigned int, unsigned int&)"},
    {"_ZNK12_GLOBAL__N_115ARMDAGToDAGISel18hasNoVMLxHazardUseEPN4llvm6SDNodeE", "(anonymous namespace)::ARMDAGToDAGISel::hasNoVMLxHazardUse(llvm::SDNode*) const"},
    {"_ZN4llvm6ARM_AM17isSOImmTwoPartValEj", "llvm::ARM_AM::isSOImmTwoPartVal(unsigned int)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel27SelectV6T2BitfieldExtractOpEPN4llvm6SDNodeEb", "(anonymous namespace)::ARMDAGToDAGISel::SelectV6T2BitfieldExtractOp(llvm::SDNode*, bool)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel12SelectVLDDupEPN4llvm6SDNodeEbjPj", "(anonymous namespace)::ARMDAGToDAGISel::SelectVLDDup(llvm::SDNode*, bool, unsigned int, unsigned int*)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel9SelectVLDEPN4llvm6SDNodeEbjPjS4_S4_", "(anonymous namespace)::ARMDAGToDAGISel::SelectVLD(llvm::SDNode*, bool, unsigned int, unsigned int*, unsigned int*, unsigned int*)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel15SelectVLDSTLaneEPN4llvm6SDNodeEbbjPjS4_", "(anonymous namespace)::ARMDAGToDAGISel::SelectVLDSTLane(llvm::SDNode*, bool, bool, unsigned int, unsigned int*, unsigned int*)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel9SelectVSTEPN4llvm6SDNodeEbjPjS4_S4_", "(anonymous namespace)::ARMDAGToDAGISel::SelectVST(llvm::SDNode*, bool, unsigned int, unsigned int*, unsigned int*, unsigned int*)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel10SelectVTBLEPN4llvm6SDNodeEbjj", "(anonymous namespace)::ARMDAGToDAGISel::SelectVTBL(llvm::SDNode*, bool, unsigned int, unsigned int)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel9QuadDRegsEN4llvm3EVTENS1_7SDValueES3_S3_S3_", "(anonymous namespace)::ARMDAGToDAGISel::QuadDRegs(llvm::EVT, llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::SDValue)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel9QuadQRegsEN4llvm3EVTENS1_7SDValueES3_S3_S3_", "(anonymous namespace)::ARMDAGToDAGISel::QuadQRegs(llvm::EVT, llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::SDValue)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel19SelectT2CMOVShiftOpEPN4llvm6SDNodeENS1_7SDValueES4_NS1_5ARMCC9CondCodesES4_S4_", "(anonymous namespace)::ARMDAGToDAGISel::SelectT2CMOVShiftOp(llvm::SDNode*, llvm::SDValue, llvm::SDValue, llvm::ARMCC::CondCodes, llvm::SDValue, llvm::SDValue)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel20SelectARMCMOVShiftOpEPN4llvm6SDNodeENS1_7SDValueES4_NS1_5ARMCC9CondCodesES4_S4_", "(anonymous namespace)::ARMDAGToDAGISel::SelectARMCMOVShiftOp(llvm::SDNode*, llvm::SDValue, llvm::SDValue, llvm::ARMCC::CondCodes, llvm::SDValue, llvm::SDValue)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel17SelectT2CMOVImmOpEPN4llvm6SDNodeENS1_7SDValueES4_NS1_5ARMCC9CondCodesES4_S4_", "(anonymous namespace)::ARMDAGToDAGISel::SelectT2CMOVImmOp(llvm::SDNode*, llvm::SDValue, llvm::SDValue, llvm::ARMCC::CondCodes, llvm::SDValue, llvm::SDValue)"},
    {"_ZN12_GLOBAL__N_115ARMDAGToDAGISel18SelectARMCMOVImmOpEPN4llvm6SDNodeENS1_7SDValueES4_NS1_5ARMCC9CondCodesES4_S4_", "(anonymous namespace)::ARMDAGToDAGISel::SelectARMCMOVImmOp(llvm::SDNode*, llvm::SDValue, llvm::SDValue, llvm::ARMCC::CondCodes, llvm::SDValue, llvm::SDValue)"},
    {"_ZN4llvm16SelectionDAGISel21EmitFunctionEntryCodeEv", "llvm::SelectionDAGISel::EmitFunctionEntryCode()"},
    {"_ZN4llvm16SelectionDAGISel17PreprocessISelDAGEv", "llvm::SelectionDAGISel::PreprocessISelDAG()"},
    {"_ZN4llvm16SelectionDAGISel18PostprocessISelDAGEv", "llvm::SelectionDAGISel::PostprocessISelDAG()"},
    {"_ZN4llvm15SmallVectorImplISt4pairINS_7SDValueEPNS_6SDNodeEEE6resizeEj", "llvm::SmallVectorImpl<std::pair<llvm::SDValue, llvm::SDNode*>>::resize(unsigned int)"},
    {"_ZN4llvm16SelectionDAGISel11ISelUpdaterD1Ev", "llvm::SelectionDAGISel::ISelUpdater::~ISelUpdater()"},
    {"_ZN4llvm16SelectionDAGISel11ISelUpdaterD0Ev", "llvm::SelectionDAGISel::ISelUpdater::~ISelUpdater()"},
    {"_ZN4llvm16SelectionDAGISel11ISelUpdater11NodeDeletedEPNS_6SDNodeES3_", "llvm::SelectionDAGISel::ISelUpdater::NodeDeleted(llvm::SDNode*, llvm::SDNode*)"},
    {"_ZN4llvm16SelectionDAGISel11ISelUpdater11NodeUpdatedEPNS_6SDNodeE", "llvm::SelectionDAGISel::ISelUpdater::NodeUpdated(llvm::SDNode*)"},
    {"_ZN4llvm17ARMTargetLowering14addTypeForNEONENS_3EVTES1_S1_", "llvm::ARMTargetLowering::addTypeForNEON(llvm::EVT, llvm::EVT, llvm::EVT)"},
    {"_ZN4llvm17ARMTargetLowering16addDRTypeForNEONENS_3EVTE", "llvm::ARMTargetLowering::addDRTypeForNEON(llvm::EVT)"},
    {"_ZN4llvm17ARMTargetLowering16addQRTypeForNEONENS_3EVTE", "llvm::ARMTargetLowering::addQRTypeForNEON(llvm::EVT)"},
    {"_ZN4llvm17ARMTargetLoweringC1ERNS_13TargetMachineE", "llvm::ARMTargetLowering::ARMTargetLowering(llvm::TargetMachine&)"},
    {"_ZN4llvm17ARMTargetLoweringC2ERNS_13TargetMachineE", "llvm::ARMTargetLowering::ARMTargetLowering(llvm::TargetMachine&)"},
    {"_ZNK4llvm17ARMTargetLowering23findRepresentativeClassENS_3EVTE", "llvm::ARMTargetLowering::findRepresentativeClass(llvm::EVT) const"},
    {"_ZNK4llvm17ARMTargetLowering17getTargetNodeNameEj", "llvm::ARMTargetLowering::getTargetNodeName(unsigned int) const"},
    {"_ZNK4llvm17ARMTargetLowering14getRegClassForENS_3EVTE", "llvm::ARMTargetLowering::getRegClassFor(llvm::EVT) const"},
    {"_ZNK4llvm17ARMTargetLowering14createFastISelERNS_20FunctionLoweringInfoE", "llvm::ARMTargetLowering::createFastISel(llvm::FunctionLoweringInfo&) const"},
    {"_ZNK4llvm17ARMTargetLowering20getFunctionAlignmentEPKNS_8FunctionE", "llvm::ARMTargetLowering::getFunctionAlignment(llvm::Function const*) const"},
    {"_ZNK4llvm17ARMTargetLowering22getMaximalGlobalOffsetEv", "llvm::ARMTargetLowering::getMaximalGlobalOffset() const"},
    {"_ZNK4llvm17ARMTargetLowering23getSchedulingPreferenceEPNS_6SDNodeE", "llvm::ARMTargetLowering::getSchedulingPreference(llvm::SDNode*) const"},
    {"_ZNK4llvm17ARMTargetLowering19getRegPressureLimitEPKNS_19TargetRegisterClassERNS_15MachineFunctionE", "llvm::ARMTargetLowering::getRegPressureLimit(llvm::TargetRegisterClass const*, llvm::MachineFunction&) const"},
    {"_ZNK4llvm17ARMTargetLowering17CCAssignFnForNodeENS_11CallingConv2IDEbb", "llvm::ARMTargetLowering::CCAssignFnForNode(llvm::CallingConv::ID, bool, bool) const"},
    {"_Z18RetFastCC_ARM_APCSjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetFastCC_ARM_APCS(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z15FastCC_ARM_APCSjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "FastCC_ARM_APCS(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z19RetCC_ARM_AAPCS_VFPjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_ARM_AAPCS_VFP(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z16CC_ARM_AAPCS_VFPjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_ARM_AAPCS_VFP(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z14RetCC_ARM_APCSjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_ARM_APCS(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z11CC_ARM_APCSjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_ARM_APCS(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z15RetCC_ARM_AAPCSjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_ARM_AAPCS(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_Z12CC_ARM_AAPCSjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_ARM_AAPCS(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZNK4llvm17ARMTargetLowering15LowerCallResultENS_7SDValueES1_NS_11CallingConv2IDEbRKNS_15SmallVectorImplINS_3ISD8InputArgEEENS_8DebugLocERNS_12SelectionDAGERNS4_IS1_EE", "llvm::ARMTargetLowering::LowerCallResult(llvm::SDValue, llvm::SDValue, llvm::CallingConv::ID, bool, llvm::SmallVectorImpl<llvm::ISD::InputArg> const&, llvm::DebugLoc, llvm::SelectionDAG&, llvm::SmallVectorImpl<llvm::SDValue>&) const"},
    {"_ZNK4llvm17ARMTargetLowering16LowerMemOpCallToENS_7SDValueES1_S1_NS_8DebugLocERNS_12SelectionDAGERKNS_11CCValAssignENS_3ISD10ArgFlagsTyE", "llvm::ARMTargetLowering::LowerMemOpCallTo(llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::DebugLoc, llvm::SelectionDAG&, llvm::CCValAssign const&, llvm::ISD::ArgFlagsTy) const"},
    {"_ZNK4llvm17ARMTargetLowering16PassF64ArgInRegsENS_8DebugLocERNS_12SelectionDAGENS_7SDValueERS4_RNS_11SmallVectorISt4pairIjS4_ELj8EEERNS_11CCValAssignESC_S5_RNS6_IS4_Lj8EEENS_3ISD10ArgFlagsTyE", "llvm::ARMTargetLowering::PassF64ArgInRegs(llvm::DebugLoc, llvm::SelectionDAG&, llvm::SDValue, llvm::SDValue&, llvm::SmallVector<std::pair<unsigned int, llvm::SDValue>, 8u>&, llvm::CCValAssign&, llvm::CCValAssign&, llvm::SDValue&, llvm::SmallVector<llvm::SDValue, 8u>&, llvm::ISD::ArgFlagsTy) const"},
    {"_ZNK4llvm17ARMTargetLowering9LowerCallENS_7SDValueES1_NS_11CallingConv2IDEbRbRKNS_15SmallVectorImplINS_3ISD9OutputArgEEERKNS5_IS1_EERKNS5_INS6_8InputArgEEENS_8DebugLocERNS_12SelectionDAGERSB_", "llvm::ARMTargetLowering::LowerCall(llvm::SDValue, llvm::SDValue, llvm::CallingConv::ID, bool, bool&, llvm::SmallVectorImpl<llvm::ISD::OutputArg> const&, llvm::SmallVectorImpl<llvm::SDValue> const&, llvm::SmallVectorImpl<llvm::ISD::InputArg> const&, llvm::DebugLoc, llvm::SelectionDAG&, llvm::SmallVectorImpl<llvm::SDValue>&) const"},
    {"_ZNK4llvm17ARMTargetLowering33IsEligibleForTailCallOptimizationENS_7SDValueENS_11CallingConv2IDEbbbRKNS_15SmallVectorImplINS_3ISD9OutputArgEEERKNS4_IS1_EERKNS4_INS5_8InputArgEEERNS_12SelectionDAGE", "llvm::ARMTargetLowering::IsEligibleForTailCallOptimization(llvm::SDValue, llvm::CallingConv::ID, bool, bool, bool, llvm::SmallVectorImpl<llvm::ISD::OutputArg> const&, llvm::SmallVectorImpl<llvm::SDValue> const&, llvm::SmallVectorImpl<llvm::ISD::InputArg> const&, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering11LowerReturnENS_7SDValueENS_11CallingConv2IDEbRKNS_15SmallVectorImplINS_3ISD9OutputArgEEERKNS4_IS1_EENS_8DebugLocERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerReturn(llvm::SDValue, llvm::CallingConv::ID, bool, llvm::SmallVectorImpl<llvm::ISD::OutputArg> const&, llvm::SmallVectorImpl<llvm::SDValue> const&, llvm::DebugLoc, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering18isUsedByReturnOnlyEPNS_6SDNodeE", "llvm::ARMTargetLowering::isUsedByReturnOnly(llvm::SDNode*) const"},
    {"_ZNK4llvm17ARMTargetLowering20getJumpTableEncodingEv", "llvm::ARMTargetLowering::getJumpTableEncoding() const"},
    {"_ZNK4llvm17ARMTargetLowering17LowerBlockAddressENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerBlockAddress(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering29LowerToTLSGeneralDynamicModelEPNS_19GlobalAddressSDNodeERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerToTLSGeneralDynamicModel(llvm::GlobalAddressSDNode*, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering20LowerToTLSExecModelsEPNS_19GlobalAddressSDNodeERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerToTLSExecModels(llvm::GlobalAddressSDNode*, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering21LowerGlobalTLSAddressENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerGlobalTLSAddress(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering21LowerGlobalAddressELFENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerGlobalAddressELF(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering24LowerGlobalAddressDarwinENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerGlobalAddressDarwin(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering24LowerGLOBAL_OFFSET_TABLEENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerGLOBAL_OFFSET_TABLE(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering26LowerEH_SJLJ_DISPATCHSETUPENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerEH_SJLJ_DISPATCHSETUP(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering19LowerEH_SJLJ_SETJMPENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerEH_SJLJ_SETJMP(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering20LowerEH_SJLJ_LONGJMPENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerEH_SJLJ_LONGJMP(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering23LowerINTRINSIC_WO_CHAINENS_7SDValueERNS_12SelectionDAGEPKNS_12ARMSubtargetE", "llvm::ARMTargetLowering::LowerINTRINSIC_WO_CHAIN(llvm::SDValue, llvm::SelectionDAG&, llvm::ARMSubtarget const*) const"},
    {"_ZNK4llvm17ARMTargetLowering20GetF64FormalArgumentERNS_11CCValAssignES2_RNS_7SDValueERNS_12SelectionDAGENS_8DebugLocE", "llvm::ARMTargetLowering::GetF64FormalArgument(llvm::CCValAssign&, llvm::CCValAssign&, llvm::SDValue&, llvm::SelectionDAG&, llvm::DebugLoc) const"},
    {"_ZNK4llvm17ARMTargetLowering20LowerFormalArgumentsENS_7SDValueENS_11CallingConv2IDEbRKNS_15SmallVectorImplINS_3ISD8InputArgEEENS_8DebugLocERNS_12SelectionDAGERNS4_IS1_EE", "llvm::ARMTargetLowering::LowerFormalArguments(llvm::SDValue, llvm::CallingConv::ID, bool, llvm::SmallVectorImpl<llvm::ISD::InputArg> const&, llvm::DebugLoc, llvm::SelectionDAG&, llvm::SmallVectorImpl<llvm::SDValue>&) const"},
    {"_ZNK4llvm17ARMTargetLowering9getARMCmpENS_7SDValueES1_NS_3ISD8CondCodeERS1_RNS_12SelectionDAGENS_8DebugLocE", "llvm::ARMTargetLowering::getARMCmp(llvm::SDValue, llvm::SDValue, llvm::ISD::CondCode, llvm::SDValue&, llvm::SelectionDAG&, llvm::DebugLoc) const"},
    {"_ZNK4llvm17ARMTargetLowering9getVFPCmpENS_7SDValueES1_RNS_12SelectionDAGENS_8DebugLocE", "llvm::ARMTargetLowering::getVFPCmp(llvm::SDValue, llvm::SDValue, llvm::SelectionDAG&, llvm::DebugLoc) const"},
    {"_ZNK4llvm17ARMTargetLowering11LowerSELECTENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerSELECT(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering14LowerSELECT_CCENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerSELECT_CC(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering17OptimizeVFPBrcondENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::OptimizeVFPBrcond(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_Z14canChangeToIntN4llvm7SDValueERbPKNS_12ARMSubtargetE", "canChangeToInt(llvm::SDValue, bool&, llvm::ARMSubtarget const*)"},
    {"_Z15bitcastf32Toi32N4llvm7SDValueERNS_12SelectionDAGE", "bitcastf32Toi32(llvm::SDValue, llvm::SelectionDAG&)"},
    {"_Z14expandf64Toi32N4llvm7SDValueERNS_12SelectionDAGERS0_S3_", "expandf64Toi32(llvm::SDValue, llvm::SelectionDAG&, llvm::SDValue&, llvm::SDValue&)"},
    {"_ZNK4llvm17ARMTargetLowering10LowerBR_CCENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerBR_CC(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering10LowerBR_JTENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerBR_JT(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering14LowerFCOPYSIGNENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerFCOPYSIGN(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering15LowerRETURNADDRENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerRETURNADDR(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering14LowerFRAMEADDRENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerFRAMEADDR(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering20LowerShiftRightPartsENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerShiftRightParts(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering19LowerShiftLeftPartsENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerShiftLeftParts(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering16LowerFLT_ROUNDS_ENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerFLT_ROUNDS_(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering17LowerBUILD_VECTORENS_7SDValueERNS_12SelectionDAGEPKNS_12ARMSubtargetE", "llvm::ARMTargetLowering::LowerBUILD_VECTOR(llvm::SDValue, llvm::SelectionDAG&, llvm::ARMSubtarget const*) const"},
    {"_Z17isNEONModifiedImmyyjRN4llvm12SelectionDAGERNS_3EVTEbNS_14NEONModImmTypeE", "isNEONModifiedImm(unsigned long long, unsigned long long, unsigned int, llvm::SelectionDAG&, llvm::EVT&, bool, llvm::NEONModImmType)"},
    {"_ZNK4llvm17ARMTargetLowering18ReconstructShuffleENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::ReconstructShuffle(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering18isShuffleMaskLegalERKNS_15SmallVectorImplIiEENS_3EVTE", "llvm::ARMTargetLowering::isShuffleMaskLegal(llvm::SmallVectorImpl<int> const&, llvm::EVT) const"},
    {"_Z10isVREVMaskRKN4llvm15SmallVectorImplIiEENS_3EVTEj", "isVREVMask(llvm::SmallVectorImpl<int> const&, llvm::EVT, unsigned int)"},
    {"_Z10isVTRNMaskRKN4llvm15SmallVectorImplIiEENS_3EVTERj", "isVTRNMask(llvm::SmallVectorImpl<int> const&, llvm::EVT, unsigned int&)"},
    {"_Z10isVUZPMaskRKN4llvm15SmallVectorImplIiEENS_3EVTERj", "isVUZPMask(llvm::SmallVectorImpl<int> const&, llvm::EVT, unsigned int&)"},
    {"_Z10isVZIPMaskRKN4llvm15SmallVectorImplIiEENS_3EVTERj", "isVZIPMask(llvm::SmallVectorImpl<int> const&, llvm::EVT, unsigned int&)"},
    {"_Z19isVTRN_v_undef_MaskRKN4llvm15SmallVectorImplIiEENS_3EVTERj", "isVTRN_v_undef_Mask(llvm::SmallVectorImpl<int> const&, llvm::EVT, unsigned int&)"},
    {"_Z19isVUZP_v_undef_MaskRKN4llvm15SmallVectorImplIiEENS_3EVTERj", "isVUZP_v_undef_Mask(llvm::SmallVectorImpl<int> const&, llvm::EVT, unsigned int&)"},
    {"_Z19isVZIP_v_undef_MaskRKN4llvm15SmallVectorImplIiEENS_3EVTERj", "isVZIP_v_undef_Mask(llvm::SmallVectorImpl<int> const&, llvm::EVT, unsigned int&)"},
    {"_ZNK4llvm17ARMTargetLowering14LowerOperationENS_7SDValueERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerOperation(llvm::SDValue, llvm::SelectionDAG&) const"},
    {"_Z13ExpandBITCASTPN4llvm6SDNodeERNS_12SelectionDAGE", "ExpandBITCAST(llvm::SDNode*, llvm::SelectionDAG&)"},
    {"_ZNK4llvm17ARMTargetLowering18ReplaceNodeResultsEPNS_6SDNodeERNS_15SmallVectorImplINS_7SDValueEEERNS_12SelectionDAGE", "llvm::ARMTargetLowering::ReplaceNodeResults(llvm::SDNode*, llvm::SmallVectorImpl<llvm::SDValue>&, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering17EmitAtomicCmpSwapEPNS_12MachineInstrEPNS_17MachineBasicBlockEj", "llvm::ARMTargetLowering::EmitAtomicCmpSwap(llvm::MachineInstr*, llvm::MachineBasicBlock*, unsigned int) const"},
    {"_ZNK4llvm17ARMTargetLowering16EmitAtomicBinaryEPNS_12MachineInstrEPNS_17MachineBasicBlockEjj", "llvm::ARMTargetLowering::EmitAtomicBinary(llvm::MachineInstr*, llvm::MachineBasicBlock*, unsigned int, unsigned int) const"},
    {"_ZNK4llvm17ARMTargetLowering27EmitInstrWithCustomInserterEPNS_12MachineInstrEPNS_17MachineBasicBlockE", "llvm::ARMTargetLowering::EmitInstrWithCustomInserter(llvm::MachineInstr*, llvm::MachineBasicBlock*) const"},
    {"_ZNK4llvm17ARMTargetLowering17PerformDAGCombineEPNS_6SDNodeERNS_14TargetLowering15DAGCombinerInfoE", "llvm::ARMTargetLowering::PerformDAGCombine(llvm::SDNode*, llvm::TargetLowering::DAGCombinerInfo&) const"},
    {"_Z21PerformVMOVDRRCombinePN4llvm6SDNodeERNS_12SelectionDAGE", "PerformVMOVDRRCombine(llvm::SDNode*, llvm::SelectionDAG&)"},
    {"_Z17CombineBaseUpdatePN4llvm6SDNodeERNS_14TargetLowering15DAGCombinerInfoE", "CombineBaseUpdate(llvm::SDNode*, llvm::TargetLowering::DAGCombinerInfo&)"},
    {"_ZNK4llvm17ARMTargetLowering33isDesirableToTransformToIntegerOpEjNS_3EVTE", "llvm::ARMTargetLowering::isDesirableToTransformToIntegerOp(unsigned int, llvm::EVT) const"},
    {"_ZNK4llvm17ARMTargetLowering29allowsUnalignedMemoryAccessesENS_3EVTE", "llvm::ARMTargetLowering::allowsUnalignedMemoryAccesses(llvm::EVT) const"},
    {"_ZNK4llvm17ARMTargetLowering29isLegalT2ScaledAddressingModeERKNS_14TargetLowering8AddrModeENS_3EVTE", "llvm::ARMTargetLowering::isLegalT2ScaledAddressingMode(llvm::TargetLowering::AddrMode const&, llvm::EVT) const"},
    {"_ZNK4llvm17ARMTargetLowering21isLegalAddressingModeERKNS_14TargetLowering8AddrModeEPKNS_4TypeE", "llvm::ARMTargetLowering::isLegalAddressingMode(llvm::TargetLowering::AddrMode const&, llvm::Type const*) const"},
    {"_ZNK4llvm17ARMTargetLowering20isLegalICmpImmediateEx", "llvm::ARMTargetLowering::isLegalICmpImmediate(long long) const"},
    {"_ZNK4llvm17ARMTargetLowering25getPreIndexedAddressPartsEPNS_6SDNodeERNS_7SDValueES4_RNS_3ISD14MemIndexedModeERNS_12SelectionDAGE", "llvm::ARMTargetLowering::getPreIndexedAddressParts(llvm::SDNode*, llvm::SDValue&, llvm::SDValue&, llvm::ISD::MemIndexedMode&, llvm::SelectionDAG&) const"},
    {"_Z24getT2IndexedAddressPartsPN4llvm6SDNodeENS_3EVTEbRNS_7SDValueES4_RbRNS_12SelectionDAGE", "getT2IndexedAddressParts(llvm::SDNode*, llvm::EVT, bool, llvm::SDValue&, llvm::SDValue&, bool&, llvm::SelectionDAG&)"},
    {"_Z25getARMIndexedAddressPartsPN4llvm6SDNodeENS_3EVTEbRNS_7SDValueES4_RbRNS_12SelectionDAGE", "getARMIndexedAddressParts(llvm::SDNode*, llvm::EVT, bool, llvm::SDValue&, llvm::SDValue&, bool&, llvm::SelectionDAG&)"},
    {"_ZNK4llvm17ARMTargetLowering26getPostIndexedAddressPartsEPNS_6SDNodeES2_RNS_7SDValueES4_RNS_3ISD14MemIndexedModeERNS_12SelectionDAGE", "llvm::ARMTargetLowering::getPostIndexedAddressParts(llvm::SDNode*, llvm::SDNode*, llvm::SDValue&, llvm::SDValue&, llvm::ISD::MemIndexedMode&, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering30computeMaskedBitsForTargetNodeENS_7SDValueERKNS_5APIntERS2_S5_RKNS_12SelectionDAGEj", "llvm::ARMTargetLowering::computeMaskedBitsForTargetNode(llvm::SDValue, llvm::APInt const&, llvm::APInt&, llvm::APInt&, llvm::SelectionDAG const&, unsigned int) const"},
    {"_ZNK4llvm17ARMTargetLowering15ExpandInlineAsmEPNS_8CallInstE", "llvm::ARMTargetLowering::ExpandInlineAsm(llvm::CallInst*) const"},
    {"_ZNK4llvm17ARMTargetLowering17getConstraintTypeERKSs", "llvm::ARMTargetLowering::getConstraintType(std::string const&) const"},
    {"_ZNK4llvm17ARMTargetLowering30getSingleConstraintMatchWeightERNS_14TargetLowering14AsmOperandInfoEPKc", "llvm::ARMTargetLowering::getSingleConstraintMatchWeight(llvm::TargetLowering::AsmOperandInfo&, char const*) const"},
    {"_ZNK4llvm17ARMTargetLowering28getRegForInlineAsmConstraintERKSsNS_3EVTE", "llvm::ARMTargetLowering::getRegForInlineAsmConstraint(std::string const&, llvm::EVT) const"},
    {"_ZNK4llvm17ARMTargetLowering33getRegClassForInlineAsmConstraintERKSsNS_3EVTE", "llvm::ARMTargetLowering::getRegClassForInlineAsmConstraint(std::string const&, llvm::EVT) const"},
    {"_ZNK4llvm17ARMTargetLowering28LowerAsmOperandForConstraintENS_7SDValueEcRSt6vectorIS1_SaIS1_EERNS_12SelectionDAGE", "llvm::ARMTargetLowering::LowerAsmOperandForConstraint(llvm::SDValue, char, std::vector<llvm::SDValue, std::allocator<llvm::SDValue>>&, llvm::SelectionDAG&) const"},
    {"_ZNK4llvm17ARMTargetLowering20isOffsetFoldingLegalEPKNS_19GlobalAddressSDNodeE", "llvm::ARMTargetLowering::isOffsetFoldingLegal(llvm::GlobalAddressSDNode const*) const"},
    {"_ZN4llvm3ARM12getVFPf32ImmERKNS_7APFloatE", "llvm::ARM::getVFPf32Imm(llvm::APFloat const&)"},
    {"_ZN4llvm3ARM12getVFPf64ImmERKNS_7APFloatE", "llvm::ARM::getVFPf64Imm(llvm::APFloat const&)"},
    {"_ZN4llvm3ARM22isBitFieldInvertedMaskEj", "llvm::ARM::isBitFieldInvertedMask(unsigned int)"},
    {"_ZNK4llvm17ARMTargetLowering12isFPImmLegalERKNS_7APFloatENS_3EVTE", "llvm::ARMTargetLowering::isFPImmLegal(llvm::APFloat const&, llvm::EVT) const"},
    {"_ZNK4llvm17ARMTargetLowering18getTgtMemIntrinsicERNS_14TargetLowering13IntrinsicInfoERKNS_8CallInstEj", "llvm::ARMTargetLowering::getTgtMemIntrinsic(llvm::TargetLowering::IntrinsicInfo&, llvm::CallInst const&, unsigned int) const"},
    {"_Z12getVShiftImmN4llvm7SDValueEjRx", "getVShiftImm(llvm::SDValue, unsigned int, long long&)"},
    {"_Z19combineSelectAndUsePN4llvm6SDNodeENS_7SDValueES2_RNS_14TargetLowering15DAGCombinerInfoE", "combineSelectAndUse(llvm::SDNode*, llvm::SDValue, llvm::SDValue, llvm::TargetLowering::DAGCombinerInfo&)"},
    {"_Z13SkipExtensionPN4llvm6SDNodeERNS_12SelectionDAGE", "SkipExtension(llvm::SDNode*, llvm::SelectionDAG&)"},
    {"_Z22isExtendedBUILD_VECTORPN4llvm6SDNodeERNS_12SelectionDAGEb", "isExtendedBUILD_VECTOR(llvm::SDNode*, llvm::SelectionDAG&, bool)"},
    {"_Z22GeneratePerfectShufflejN4llvm7SDValueES0_RNS_12SelectionDAGENS_8DebugLocE", "GeneratePerfectShuffle(unsigned int, llvm::SDValue, llvm::SDValue, llvm::SelectionDAG&, llvm::DebugLoc)"},
    {"_Z19CC_ARM_AAPCS_CommonjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "CC_ARM_AAPCS_Common(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZN4llvm14f64AssignAAPCSERjRNS_3MVTES2_RNS_11CCValAssign7LocInfoERNS_7CCStateEb", "llvm::f64AssignAAPCS(unsigned int&, llvm::MVT&, llvm::MVT&, llvm::CCValAssign::LocInfo&, llvm::CCState&, bool)"},
    {"_Z22RetCC_ARM_AAPCS_CommonjN4llvm3MVTES0_NS_11CCValAssign7LocInfoENS_3ISD10ArgFlagsTyERNS_7CCStateE", "RetCC_ARM_AAPCS_Common(unsigned int, llvm::MVT, llvm::MVT, llvm::CCValAssign::LocInfo, llvm::ISD::ArgFlagsTy, llvm::CCState&)"},
    {"_ZN4llvm12f64RetAssignERjRNS_3MVTES2_RNS_11CCValAssign7LocInfoERNS_7CCStateE", "llvm::f64RetAssign(unsigned int&, llvm::MVT&, llvm::MVT&, llvm::CCValAssign::LocInfo&, llvm::CCState&)"},
    {"_ZN4llvm13f64AssignAPCSERjRNS_3MVTES2_RNS_11CCValAssign7LocInfoERNS_7CCStateEb", "llvm::f64AssignAPCS(unsigned int&, llvm::MVT&, llvm::MVT&, llvm::CCValAssign::LocInfo&, llvm::CCState&, bool)"},
    {"_ZN4llvm12SelectionDAG14getCALLSEQ_ENDENS_7SDValueES1_S1_S1_", "llvm::SelectionDAG::getCALLSEQ_END(llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::SDValue)"},
    {"_ZN4llvm11make_vectorIjEESt6vectorIT_SaIS2_EES2_z", "std::vector<unsigned int, std::allocator<unsigned int>> llvm::make_vector<unsigned int>(unsigned int, ...)"},
    {"_ZNSt6vectorIN4llvm14TargetLowering12ArgListEntryESaIS2_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS2_S4_EERKS2_", "std::vector<llvm::TargetLowering::ArgListEntry, std::allocator<llvm::TargetLowering::ArgListEntry>>::_M_insert_aux(__gnu_cxx::__normal_iterator<llvm::TargetLowering::ArgListEntry*, std::vector<llvm::TargetLowering::ArgListEntry, std::allocator<llvm::TargetLowering::ArgListEntry>>>, llvm::TargetLowering::ArgListEntry const&)"},
    {"_ZN4llvm5APInt11flipAllBitsEv", "llvm::APInt::flipAllBits()"},
    {"_ZNK4llvm19ShuffleVectorSDNode7getMaskERNS_15SmallVectorImplIiEE", "llvm::ShuffleVectorSDNode::getMask(llvm::SmallVectorImpl<int>&) const"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_11CCValAssignELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::CCValAssign, false>::grow(unsigned long)"},
    {"_ZNK4llvm24TargetLoweringObjectFile26shouldEmitUsedDirectiveForEPKNS_11GlobalValueEPNS_7ManglerE", "llvm::TargetLoweringObjectFile::shouldEmitUsedDirectiveFor(llvm::GlobalValue const*, llvm::Mangler*) const"},
    {"_ZNK4llvm24TargetLoweringObjectFile29getSpecialCasedSectionGlobalsEPKNS_11GlobalValueEPNS_7ManglerENS_11SectionKindE", "llvm::TargetLoweringObjectFile::getSpecialCasedSectionGlobals(llvm::GlobalValue const*, llvm::Mangler*, llvm::SectionKind) const"},
    {"_ZNK4llvm22ARMElfTargetObjectFile20getAttributesSectionEv", "llvm::ARMElfTargetObjectFile::getAttributesSection() const"},
    {"_ZN4llvm27TargetLoweringObjectFileELFD1Ev", "llvm::TargetLoweringObjectFileELF::~TargetLoweringObjectFileELF()"},
    {"_ZN4llvm27TargetLoweringObjectFileELFD0Ev", "llvm::TargetLoweringObjectFileELF::~TargetLoweringObjectFileELF()"},
    {"_ZN4llvm29TargetLoweringObjectFileMachOD1Ev", "llvm::TargetLoweringObjectFileMachO::~TargetLoweringObjectFileMachO()"},
    {"_ZN4llvm29TargetLoweringObjectFileMachOD0Ev", "llvm::TargetLoweringObjectFileMachO::~TargetLoweringObjectFileMachO()"},
    {"_ZNSt6vectorISt4pairIN4llvm3EVTEPNS1_19TargetRegisterClassEESaIS5_EE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPS5_S7_EERKS5_", "std::vector<std::pair<llvm::EVT, llvm::TargetRegisterClass*>, std::allocator<std::pair<llvm::EVT, llvm::TargetRegisterClass*>>>::_M_insert_aux(__gnu_cxx::__normal_iterator<std::pair<llvm::EVT, llvm::TargetRegisterClass*>*, std::vector<std::pair<llvm::EVT, llvm::TargetRegisterClass*>, std::allocator<std::pair<llvm::EVT, llvm::TargetRegisterClass*>>>>, std::pair<llvm::EVT, llvm::TargetRegisterClass*> const&)"},
    {"_ZNSt8_Rb_treeISt4pairIjN4llvm3MVT15SimpleValueTypeEES0_IKS4_S3_ESt10_Select1stIS6_ESt4lessIS4_ESaIS6_EE16_M_insert_uniqueESt17_Rb_tree_iteratorIS6_ERKS6_", "std::_Rb_tree<std::pair<unsigned int, llvm::MVT::SimpleValueType>, std::pair<std::pair<unsigned int, llvm::MVT::SimpleValueType> const, llvm::MVT::SimpleValueType>, std::_Select1st<std::pair<std::pair<unsigned int, llvm::MVT::SimpleValueType> const, llvm::MVT::SimpleValueType>>, std::less<std::pair<unsigned int, llvm::MVT::SimpleValueType>>, std::allocator<std::pair<std::pair<unsigned int, llvm::MVT::SimpleValueType> const, llvm::MVT::SimpleValueType>>>::_M_insert_unique(std::_Rb_tree_iterator<std::pair<std::pair<unsigned int, llvm::MVT::SimpleValueType> const, llvm::MVT::SimpleValueType>>, std::pair<std::pair<unsigned int, llvm::MVT::SimpleValueType> const, llvm::MVT::SimpleValueType> const&)"},
    {"_ZNSt8_Rb_treeISt4pairIjN4llvm3MVT15SimpleValueTypeEES0_IKS4_S3_ESt10_Select1stIS6_ESt4lessIS4_ESaIS6_EE16_M_insert_uniqueERKS6_", "std::_Rb_tree<std::pair<unsigned int, llvm::MVT::SimpleValueType>, std::pair<std::pair<unsigned int, llvm::MVT::SimpleValueType> const, llvm::MVT::SimpleValueType>, std::_Select1st<std::pair<std::pair<unsigned int, llvm::MVT::SimpleValueType> const, llvm::MVT::SimpleValueType>>, std::less<std::pair<unsigned int, llvm::MVT::SimpleValueType>>, std::allocator<std::pair<std::pair<unsigned int, llvm::MVT::SimpleValueType> const, llvm::MVT::SimpleValueType>>>::_M_insert_unique(std::pair<std::pair<unsigned int, llvm::MVT::SimpleValueType> const, llvm::MVT::SimpleValueType> const&)"},
    {"_ZN4llvm12ARMInstrInfoC1ERKNS_12ARMSubtargetE", "llvm::ARMInstrInfo::ARMInstrInfo(llvm::ARMSubtarget const&)"},
    {"_ZN4llvm12ARMInstrInfoC2ERKNS_12ARMSubtargetE", "llvm::ARMInstrInfo::ARMInstrInfo(llvm::ARMSubtarget const&)"},
    {"_ZNK4llvm12ARMInstrInfo18getUnindexedOpcodeEj", "llvm::ARMInstrInfo::getUnindexedOpcode(unsigned int) const"},
    {"_ZN4llvm10ARMJITInfo29replaceMachineCodeForFunctionEPvS1_", "llvm::ARMJITInfo::replaceMachineCodeForFunction(void*, void*)"},
    {"_ZN4llvm10ARMJITInfo23getLazyResolverFunctionEPFPvS1_E", "llvm::ARMJITInfo::getLazyResolverFunction(void* (*)(void*))"},
    {"_ZN4llvm10ARMJITInfo26emitGlobalValueIndirectSymEPKNS_11GlobalValueEPvRNS_14JITCodeEmitterE", "llvm::ARMJITInfo::emitGlobalValueIndirectSym(llvm::GlobalValue const*, void*, llvm::JITCodeEmitter&)"},
    {"_ZN4llvm10ARMJITInfo13getStubLayoutEv", "llvm::ARMJITInfo::getStubLayout()"},
    {"_ZN4llvm10ARMJITInfo16emitFunctionStubEPKNS_8FunctionEPvRNS_14JITCodeEmitterE", "llvm::ARMJITInfo::emitFunctionStub(llvm::Function const*, void*, llvm::JITCodeEmitter&)"},
    {"_ZNK4llvm10ARMJITInfo20resolveRelocDestAddrEPNS_17MachineRelocationE", "llvm::ARMJITInfo::resolveRelocDestAddr(llvm::MachineRelocation*) const"},
    {"_ZN4llvm10ARMJITInfo8relocateEPvPNS_17MachineRelocationEjPh", "llvm::ARMJITInfo::relocate(void*, llvm::MachineRelocation*, unsigned int, unsigned char*)"},
    {"_ZN4llvm8DenseMapIPvlNS_12DenseMapInfoIS1_EENS2_IlEEE6insertERKSt4pairIS1_lE", "llvm::DenseMap<void*, long, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<long>>::insert(std::pair<void*, long> const&)"},
    {"_ZN4llvm8DenseMapIPvlNS_12DenseMapInfoIS1_EENS2_IlEEE16InsertIntoBucketERKS1_RKlPSt4pairIS1_lE", "llvm::DenseMap<void*, long, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<long>>::InsertIntoBucket(void* const&, long const&, std::pair<void*, long>*)"},
    {"_ZN4llvm8DenseMapIPvlNS_12DenseMapInfoIS1_EENS2_IlEEE4growEj", "llvm::DenseMap<void*, long, llvm::DenseMapInfo<void*>, llvm::DenseMapInfo<long>>::grow(unsigned int)"},
    {"_ZN4llvm6ARM_AM27getLoadStoreMultipleSubModeEi", "llvm::ARM_AM::getLoadStoreMultipleSubMode(int)"},
    {"_ZN4llvm34createARMLoadStoreOptimizationPassEb", "llvm::createARMLoadStoreOptimizationPass(bool)"},
    {"_ZN12_GLOBAL__N_115ARMLoadStoreOptD1Ev", "(anonymous namespace)::ARMLoadStoreOpt::~ARMLoadStoreOpt()"},
    {"_ZN12_GLOBAL__N_115ARMLoadStoreOptD0Ev", "(anonymous namespace)::ARMLoadStoreOpt::~ARMLoadStoreOpt()"},
    {"_ZNK12_GLOBAL__N_115ARMLoadStoreOpt11getPassNameEv", "(anonymous namespace)::ARMLoadStoreOpt::getPassName() const"},
    {"_ZN12_GLOBAL__N_115ARMLoadStoreOpt20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::ARMLoadStoreOpt::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_Z10isMemoryOpPKN4llvm12MachineInstrE", "isMemoryOp(llvm::MachineInstr const*)"},
    {"_ZN12_GLOBAL__N_115ARMLoadStoreOpt12MergeLDR_STRERN4llvm17MachineBasicBlockEjjijNS1_5ARMCC9CondCodesEjjRNS1_11SmallVectorINS0_15MemOpQueueEntryELj8EEERNS6_INS1_14ilist_iteratorINS1_12MachineInstrEEELj4EEE", "(anonymous namespace)::ARMLoadStoreOpt::MergeLDR_STR(llvm::MachineBasicBlock&, unsigned int, unsigned int, int, unsigned int, llvm::ARMCC::CondCodes, unsigned int, unsigned int, llvm::SmallVector<(anonymous namespace)::ARMLoadStoreOpt::MemOpQueueEntry, 8u>&, llvm::SmallVector<llvm::ilist_iterator<llvm::MachineInstr>, 4u>&)"},
    {"_ZN12_GLOBAL__N_115ARMLoadStoreOpt24MergeBaseUpdateLoadStoreERN4llvm17MachineBasicBlockENS1_14ilist_iteratorINS1_12MachineInstrEEEPKNS1_15TargetInstrInfoERbRS6_", "(anonymous namespace)::ARMLoadStoreOpt::MergeBaseUpdateLoadStore(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, llvm::TargetInstrInfo const*, bool&, llvm::ilist_iterator<llvm::MachineInstr>&)"},
    {"_ZN12_GLOBAL__N_115ARMLoadStoreOpt14MergeOpsUpdateERN4llvm17MachineBasicBlockERNS1_11SmallVectorINS0_15MemOpQueueEntryELj8EEEjjjijbiNS1_5ARMCC9CondCodesEjjNS1_8DebugLocERNS4_INS1_14ilist_iteratorINS1_12MachineInstrEEELj4EEE", "(anonymous namespace)::ARMLoadStoreOpt::MergeOpsUpdate(llvm::MachineBasicBlock&, llvm::SmallVector<(anonymous namespace)::ARMLoadStoreOpt::MemOpQueueEntry, 8u>&, unsigned int, unsigned int, unsigned int, int, unsigned int, bool, int, llvm::ARMCC::CondCodes, unsigned int, unsigned int, llvm::DebugLoc, llvm::SmallVector<llvm::ilist_iterator<llvm::MachineInstr>, 4u>&)"},
    {"_Z13InsertLDR_STRRN4llvm17MachineBasicBlockERNS_14ilist_iteratorINS_12MachineInstrEEEibNS_8DebugLocEjjbbjbbbbNS_5ARMCC9CondCodesEjPKNS_15TargetInstrInfoEb", "InsertLDR_STR(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>&, int, bool, llvm::DebugLoc, unsigned int, unsigned int, bool, bool, unsigned int, bool, bool, bool, bool, llvm::ARMCC::CondCodes, unsigned int, llvm::TargetInstrInfo const*, bool)"},
    {"_ZN12_GLOBAL__N_123ARMPreAllocLoadStoreOptD1Ev", "(anonymous namespace)::ARMPreAllocLoadStoreOpt::~ARMPreAllocLoadStoreOpt()"},
    {"_ZN12_GLOBAL__N_123ARMPreAllocLoadStoreOptD0Ev", "(anonymous namespace)::ARMPreAllocLoadStoreOpt::~ARMPreAllocLoadStoreOpt()"},
    {"_ZNK12_GLOBAL__N_123ARMPreAllocLoadStoreOpt11getPassNameEv", "(anonymous namespace)::ARMPreAllocLoadStoreOpt::getPassName() const"},
    {"_ZN12_GLOBAL__N_123ARMPreAllocLoadStoreOpt20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::ARMPreAllocLoadStoreOpt::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN12_GLOBAL__N_123ARMPreAllocLoadStoreOpt13RescheduleOpsEPN4llvm17MachineBasicBlockERNS1_11SmallVectorIPNS1_12MachineInstrELj4EEEjbRNS1_8DenseMapIS6_jNS1_12DenseMapInfoIS6_EENSA_IjEEEE", "(anonymous namespace)::ARMPreAllocLoadStoreOpt::RescheduleOps(llvm::MachineBasicBlock*, llvm::SmallVector<llvm::MachineInstr*, 4u>&, unsigned int, bool, llvm::DenseMap<llvm::MachineInstr*, unsigned int, llvm::DenseMapInfo<llvm::MachineInstr*>, llvm::DenseMapInfo<unsigned int>>&)"},
    {"_ZSt16__introsort_loopIPPN4llvm12MachineInstrElN12_GLOBAL__N_113OffsetCompareEEvT_S6_T0_T1_", "void std::__introsort_loop<llvm::MachineInstr**, long, (anonymous namespace)::OffsetCompare>(llvm::MachineInstr**, llvm::MachineInstr**, long, (anonymous namespace)::OffsetCompare)"},
    {"_ZNK12_GLOBAL__N_113OffsetCompareclEPKN4llvm12MachineInstrES4_", "(anonymous namespace)::OffsetCompare::operator()(llvm::MachineInstr const*, llvm::MachineInstr const*) const"},
    {"_ZSt13__adjust_heapIPPN4llvm12MachineInstrElS2_N12_GLOBAL__N_113OffsetCompareEEvT_T0_S7_T1_T2_", "void std::__adjust_heap<llvm::MachineInstr**, long, llvm::MachineInstr*, (anonymous namespace)::OffsetCompare>(llvm::MachineInstr**, long, long, llvm::MachineInstr*, (anonymous namespace)::OffsetCompare)"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_14ilist_iteratorINS_12MachineInstrEEELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::ilist_iterator<llvm::MachineInstr>, false>::grow(unsigned long)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIPNS_12MachineInstrELj4EEENS_12DenseMapInfoIjEENS5_IS4_EEE5clearEv", "llvm::DenseMap<unsigned int, llvm::SmallVector<llvm::MachineInstr*, 4u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<llvm::MachineInstr*, 4u>>>::clear()"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIPNS_12MachineInstrELj4EEENS_12DenseMapInfoIjEENS5_IS4_EEE16shrink_and_clearEv", "llvm::DenseMap<unsigned int, llvm::SmallVector<llvm::MachineInstr*, 4u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<llvm::MachineInstr*, 4u>>>::shrink_and_clear()"},
    {"_ZN4llvm15SmallVectorImplIPNS_12MachineInstrEEaSERKS3_", "llvm::SmallVectorImpl<llvm::MachineInstr*>::operator=(llvm::SmallVectorImpl<llvm::MachineInstr*> const&)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIPNS_12MachineInstrELj4EEENS_12DenseMapInfoIjEENS5_IS4_EEE16FindAndConstructERKj", "llvm::DenseMap<unsigned int, llvm::SmallVector<llvm::MachineInstr*, 4u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<llvm::MachineInstr*, 4u>>>::FindAndConstruct(unsigned int const&)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIPNS_12MachineInstrELj4EEENS_12DenseMapInfoIjEENS5_IS4_EEE16InsertIntoBucketERKjRKS4_PSt4pairIjS4_E", "llvm::DenseMap<unsigned int, llvm::SmallVector<llvm::MachineInstr*, 4u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<llvm::MachineInstr*, 4u>>>::InsertIntoBucket(unsigned int const&, llvm::SmallVector<llvm::MachineInstr*, 4u> const&, std::pair<unsigned int, llvm::SmallVector<llvm::MachineInstr*, 4u>>*)"},
    {"_ZN4llvm8DenseMapIjNS_11SmallVectorIPNS_12MachineInstrELj4EEENS_12DenseMapInfoIjEENS5_IS4_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::SmallVector<llvm::MachineInstr*, 4u>, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::SmallVector<llvm::MachineInstr*, 4u>>>::grow(unsigned int)"},
    {"_ZN4llvm8DenseMapIPNS_12MachineInstrEjNS_12DenseMapInfoIS2_EENS3_IjEEE16InsertIntoBucketERKS2_RKjPSt4pairIS2_jE", "llvm::DenseMap<llvm::MachineInstr*, unsigned int, llvm::DenseMapInfo<llvm::MachineInstr*>, llvm::DenseMapInfo<unsigned int>>::InsertIntoBucket(llvm::MachineInstr* const&, unsigned int const&, std::pair<llvm::MachineInstr*, unsigned int>*)"},
    {"_ZN4llvm8DenseMapIPNS_12MachineInstrEjNS_12DenseMapInfoIS2_EENS3_IjEEE4growEj", "llvm::DenseMap<llvm::MachineInstr*, unsigned int, llvm::DenseMapInfo<llvm::MachineInstr*>, llvm::DenseMapInfo<unsigned int>>::grow(unsigned int)"},
    {"_ZN4llvm18ARMMCAsmInfoDarwinC1Ev", "llvm::ARMMCAsmInfoDarwin::ARMMCAsmInfoDarwin()"},
    {"_ZN4llvm18ARMMCAsmInfoDarwinC2Ev", "llvm::ARMMCAsmInfoDarwin::ARMMCAsmInfoDarwin()"},
    {"_ZN4llvm15ARMELFMCAsmInfoC1Ev", "llvm::ARMELFMCAsmInfo::ARMELFMCAsmInfo()"},
    {"_ZN4llvm15ARMELFMCAsmInfoC2Ev", "llvm::ARMELFMCAsmInfo::ARMELFMCAsmInfo()"},
    {"_ZN4llvm15ARMELFMCAsmInfoD1Ev", "llvm::ARMELFMCAsmInfo::~ARMELFMCAsmInfo()"},
    {"_ZN4llvm15ARMELFMCAsmInfoD0Ev", "llvm::ARMELFMCAsmInfo::~ARMELFMCAsmInfo()"},
    {"_ZN4llvm18ARMMCAsmInfoDarwinD1Ev", "llvm::ARMMCAsmInfoDarwin::~ARMMCAsmInfoDarwin()"},
    {"_ZN4llvm18ARMMCAsmInfoDarwinD0Ev", "llvm::ARMMCAsmInfoDarwin::~ARMMCAsmInfoDarwin()"},
    {"_ZN4llvm22createARMMCCodeEmitterERKNS_6TargetERNS_13TargetMachineERNS_9MCContextE", "llvm::createARMMCCodeEmitter(llvm::Target const&, llvm::TargetMachine&, llvm::MCContext&)"},
    {"_ZN12_GLOBAL__N_116ARMMCCodeEmitterD1Ev", "(anonymous namespace)::ARMMCCodeEmitter::~ARMMCCodeEmitter()"},
    {"_ZN12_GLOBAL__N_116ARMMCCodeEmitterD0Ev", "(anonymous namespace)::ARMMCCodeEmitter::~ARMMCCodeEmitter()"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter17EncodeInstructionERKN4llvm6MCInstERNS1_11raw_ostreamERNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::EncodeInstruction(llvm::MCInst const&, llvm::raw_ostream&, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter21getBinaryCodeForInstrERKN4llvm6MCInstERNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getBinaryCodeForInstr(llvm::MCInst const&, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter17getMachineOpValueERKN4llvm6MCInstERKNS1_9MCOperandERNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getMachineOpValue(llvm::MCInst const&, llvm::MCOperand const&, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter15getSORegOpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getSORegOpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter17getT2SORegOpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getT2SORegOpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter17getT2SOImmOpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getT2SOImmOpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter19getHiLo16ImmOpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getHiLo16ImmOpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter22getRegisterListOpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getRegisterListOpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter23getAddrModeImm12OpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getAddrModeImm12OpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter25getT2AddrModeSORegOpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getT2AddrModeSORegOpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter25getARMBranchTargetOpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getARMBranchTargetOpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter19getAddrMode5OpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getAddrMode5OpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter19getLdStSORegOpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getLdStSORegOpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter19getAddrMode3OpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getAddrMode3OpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter25getAddrMode2OffsetOpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getAddrMode2OffsetOpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter25getAddrMode3OffsetOpValueERKN4llvm6MCInstEjRNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::getAddrMode3OffsetOpValue(llvm::MCInst const&, unsigned int, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZNK12_GLOBAL__N_116ARMMCCodeEmitter22EncodeAddrModeOpValuesERKN4llvm6MCInstEjRjS5_RNS1_15SmallVectorImplINS1_7MCFixupEEE", "(anonymous namespace)::ARMMCCodeEmitter::EncodeAddrModeOpValues(llvm::MCInst const&, unsigned int, unsigned int&, unsigned int&, llvm::SmallVectorImpl<llvm::MCFixup>&) const"},
    {"_ZN4llvm23SmallVectorTemplateBaseINS_7MCFixupELb0EE4growEm", "llvm::SmallVectorTemplateBase<llvm::MCFixup, false>::grow(unsigned long)"},
    {"_ZN4llvm9ARMMCExpr6CreateENS0_11VariantKindEPKNS_6MCExprERNS_9MCContextE", "llvm::ARMMCExpr::Create(llvm::ARMMCExpr::VariantKind, llvm::MCExpr const*, llvm::MCContext&)"},
    {"_ZNK4llvm9ARMMCExpr9PrintImplERNS_11raw_ostreamE", "llvm::ARMMCExpr::PrintImpl(llvm::raw_ostream&) const"},
    {"_ZNK4llvm9ARMMCExpr25EvaluateAsRelocatableImplERNS_7MCValueEPKNS_11MCAsmLayoutE", "llvm::ARMMCExpr::EvaluateAsRelocatableImpl(llvm::MCValue&, llvm::MCAsmLayout const*) const"},
    {"_ZNK4llvm9ARMMCExpr15AddValueSymbolsEPNS_11MCAssemblerE", "llvm::ARMMCExpr::AddValueSymbols(llvm::MCAssembler*) const"},
    {"_Z16AddValueSymbols_PKN4llvm6MCExprEPNS_11MCAssemblerE", "AddValueSymbols_(llvm::MCExpr const*, llvm::MCAssembler*)"},
    {"_ZN4llvm9ARMMCExprD1Ev", "llvm::ARMMCExpr::~ARMMCExpr()"},
    {"_ZN4llvm9ARMMCExprD0Ev", "llvm::ARMMCExpr::~ARMMCExpr()"},
    {"_ZN4llvm28LowerARMMachineInstrToMCInstEPKNS_12MachineInstrERNS_6MCInstERNS_13ARMAsmPrinterE", "llvm::LowerARMMachineInstrToMCInst(llvm::MachineInstr const*, llvm::MCInst&, llvm::ARMAsmPrinter&)"},
    {"_Z12GetSymbolRefRKN4llvm14MachineOperandEPKNS_8MCSymbolERNS_13ARMAsmPrinterE", "GetSymbolRef(llvm::MachineOperand const&, llvm::MCSymbol const*, llvm::ARMAsmPrinter&)"},
    {"_ZN4llvm15ARMRegisterInfoC1ERKNS_16ARMBaseInstrInfoERKNS_12ARMSubtargetE", "llvm::ARMRegisterInfo::ARMRegisterInfo(llvm::ARMBaseInstrInfo const&, llvm::ARMSubtarget const&)"},
    {"_ZN4llvm15ARMRegisterInfoC2ERKNS_16ARMBaseInstrInfoERKNS_12ARMSubtargetE", "llvm::ARMRegisterInfo::ARMRegisterInfo(llvm::ARMBaseInstrInfo const&, llvm::ARMSubtarget const&)"},
    {"_ZN4llvm19ARMSelectionDAGInfoC1ERKNS_13TargetMachineE", "llvm::ARMSelectionDAGInfo::ARMSelectionDAGInfo(llvm::TargetMachine const&)"},
    {"_ZN4llvm19ARMSelectionDAGInfoC2ERKNS_13TargetMachineE", "llvm::ARMSelectionDAGInfo::ARMSelectionDAGInfo(llvm::TargetMachine const&)"},
    {"_ZN4llvm19ARMSelectionDAGInfoD0Ev", "llvm::ARMSelectionDAGInfo::~ARMSelectionDAGInfo()"},
    {"_ZN4llvm19ARMSelectionDAGInfoD1Ev", "llvm::ARMSelectionDAGInfo::~ARMSelectionDAGInfo()"},
    {"_ZN4llvm19ARMSelectionDAGInfoD2Ev", "llvm::ARMSelectionDAGInfo::~ARMSelectionDAGInfo()"},
    {"_ZNK4llvm19ARMSelectionDAGInfo23EmitTargetCodeForMemcpyERNS_12SelectionDAGENS_8DebugLocENS_7SDValueES4_S4_S4_jbbNS_18MachinePointerInfoES5_", "llvm::ARMSelectionDAGInfo::EmitTargetCodeForMemcpy(llvm::SelectionDAG&, llvm::DebugLoc, llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::SDValue, unsigned int, bool, bool, llvm::MachinePointerInfo, llvm::MachinePointerInfo) const"},
    {"_ZNK4llvm22TargetSelectionDAGInfo24EmitTargetCodeForMemmoveERNS_12SelectionDAGENS_8DebugLocENS_7SDValueES4_S4_S4_jbNS_18MachinePointerInfoES5_", "llvm::TargetSelectionDAGInfo::EmitTargetCodeForMemmove(llvm::SelectionDAG&, llvm::DebugLoc, llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::SDValue, unsigned int, bool, llvm::MachinePointerInfo, llvm::MachinePointerInfo) const"},
    {"_ZNK4llvm22TargetSelectionDAGInfo23EmitTargetCodeForMemsetERNS_12SelectionDAGENS_8DebugLocENS_7SDValueES4_S4_S4_jbNS_18MachinePointerInfoE", "llvm::TargetSelectionDAGInfo::EmitTargetCodeForMemset(llvm::SelectionDAG&, llvm::DebugLoc, llvm::SDValue, llvm::SDValue, llvm::SDValue, llvm::SDValue, unsigned int, bool, llvm::MachinePointerInfo) const"},
    {"_ZN4llvm12ARMSubtarget22ParseSubtargetFeaturesERKSsS2_", "llvm::ARMSubtarget::ParseSubtargetFeatures(std::string const&, std::string const&)"},
    {"_ZN4llvm12ARMSubtargetC1ERKSsS2_b", "llvm::ARMSubtarget::ARMSubtarget(std::string const&, std::string const&, bool)"},
    {"_ZN4llvm12ARMSubtargetC2ERKSsS2_b", "llvm::ARMSubtarget::ARMSubtarget(std::string const&, std::string const&, bool)"},
    {"_ZN4llvm12ARMSubtarget17computeIssueWidthEv", "llvm::ARMSubtarget::computeIssueWidth()"},
    {"_ZNK4llvm12ARMSubtarget18GVIsIndirectSymbolEPKNS_11GlobalValueENS_5Reloc5ModelE", "llvm::ARMSubtarget::GVIsIndirectSymbol(llvm::GlobalValue const*, llvm::Reloc::Model) const"},
    {"_ZNK4llvm12ARMSubtarget23getMispredictionPenaltyEv", "llvm::ARMSubtarget::getMispredictionPenalty() const"},
    {"_ZNK4llvm12ARMSubtarget21enablePostRASchedulerENS_10CodeGenOpt5LevelERNS_15TargetSubtarget16AntiDepBreakModeERNS_15SmallVectorImplIPNS_19TargetRegisterClassEEE", "llvm::ARMSubtarget::enablePostRAScheduler(llvm::CodeGenOpt::Level, llvm::TargetSubtarget::AntiDepBreakMode&, llvm::SmallVectorImpl<llvm::TargetRegisterClass*>&) const"},
    {"_Z15createMCAsmInfoRKN4llvm6TargetENS_9StringRefE", "createMCAsmInfo(llvm::Target const&, llvm::StringRef)"},
    {"_Z16createMCStreamerRKN4llvm6TargetERKSsRNS_9MCContextERNS_16TargetAsmBackendERNS_11raw_ostreamEPNS_13MCCodeEmitterEbb", "createMCStreamer(llvm::Target const&, std::string const&, llvm::MCContext&, llvm::TargetAsmBackend&, llvm::raw_ostream&, llvm::MCCodeEmitter*, bool, bool)"},
    {"_ZN4llvm20ARMBaseTargetMachineC1ERKNS_6TargetERKSsS5_b", "llvm::ARMBaseTargetMachine::ARMBaseTargetMachine(llvm::Target const&, std::string const&, std::string const&, bool)"},
    {"_ZN4llvm20ARMBaseTargetMachineC2ERKNS_6TargetERKSsS5_b", "llvm::ARMBaseTargetMachine::ARMBaseTargetMachine(llvm::Target const&, std::string const&, std::string const&, bool)"},
    {"_ZN4llvm16ARMTargetMachineC1ERKNS_6TargetERKSsS5_", "llvm::ARMTargetMachine::ARMTargetMachine(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZN4llvm16ARMTargetMachineC2ERKNS_6TargetERKSsS5_", "llvm::ARMTargetMachine::ARMTargetMachine(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZN4llvm18ThumbTargetMachineC1ERKNS_6TargetERKSsS5_", "llvm::ThumbTargetMachine::ThumbTargetMachine(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZN4llvm18ThumbTargetMachineC2ERKNS_6TargetERKSsS5_", "llvm::ThumbTargetMachine::ThumbTargetMachine(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZN4llvm20ARMBaseTargetMachine10addPreISelERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::ARMBaseTargetMachine::addPreISel(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm20ARMBaseTargetMachine15addInstSelectorERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::ARMBaseTargetMachine::addInstSelector(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm20ARMBaseTargetMachine14addPreRegAllocERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::ARMBaseTargetMachine::addPreRegAlloc(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm20ARMBaseTargetMachine12addPreSched2ERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::ARMBaseTargetMachine::addPreSched2(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm20ARMBaseTargetMachine14addPreEmitPassERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::ARMBaseTargetMachine::addPreEmitPass(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm20ARMBaseTargetMachine14addCodeEmitterERNS_15PassManagerBaseENS_10CodeGenOpt5LevelERNS_14JITCodeEmitterE", "llvm::ARMBaseTargetMachine::addCodeEmitter(llvm::PassManagerBase&, llvm::CodeGenOpt::Level, llvm::JITCodeEmitter&)"},
    {"_ZNK4llvm20ARMBaseTargetMachine16getSubtargetImplEv", "llvm::ARMBaseTargetMachine::getSubtargetImpl() const"},
    {"_ZN4llvm20ARMBaseTargetMachineD1Ev", "llvm::ARMBaseTargetMachine::~ARMBaseTargetMachine()"},
    {"_ZN4llvm20ARMBaseTargetMachineD0Ev", "llvm::ARMBaseTargetMachine::~ARMBaseTargetMachine()"},
    {"_ZNK4llvm13TargetMachine12getInstrInfoEv", "llvm::TargetMachine::getInstrInfo() const"},
    {"_ZNK4llvm13TargetMachine16getFrameLoweringEv", "llvm::TargetMachine::getFrameLowering() const"},
    {"_ZNK4llvm13TargetMachine17getTargetLoweringEv", "llvm::TargetMachine::getTargetLowering() const"},
    {"_ZNK4llvm13TargetMachine19getSelectionDAGInfoEv", "llvm::TargetMachine::getSelectionDAGInfo() const"},
    {"_ZNK4llvm13TargetMachine13getDataLayoutEv", "llvm::TargetMachine::getDataLayout() const"},
    {"_ZNK4llvm13TargetMachine15getRegisterInfoEv", "llvm::TargetMachine::getRegisterInfo() const"},
    {"_ZNK4llvm13TargetMachine16getIntrinsicInfoEv", "llvm::TargetMachine::getIntrinsicInfo() const"},
    {"_ZN4llvm20ARMBaseTargetMachine10getJITInfoEv", "llvm::ARMBaseTargetMachine::getJITInfo()"},
    {"_ZNK4llvm20ARMBaseTargetMachine21getInstrItineraryDataEv", "llvm::ARMBaseTargetMachine::getInstrItineraryData() const"},
    {"_ZNK4llvm13TargetMachine16getELFWriterInfoEv", "llvm::TargetMachine::getELFWriterInfo() const"},
    {"_ZNK4llvm17LLVMTargetMachine25getEnableTailMergeDefaultEv", "llvm::LLVMTargetMachine::getEnableTailMergeDefault() const"},
    {"_ZN4llvm17LLVMTargetMachine15addPostRegAllocERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::LLVMTargetMachine::addPostRegAlloc(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm18ThumbTargetMachineD1Ev", "llvm::ThumbTargetMachine::~ThumbTargetMachine()"},
    {"_ZN4llvm18ThumbTargetMachineD0Ev", "llvm::ThumbTargetMachine::~ThumbTargetMachine()"},
    {"_ZNK4llvm18ThumbTargetMachine12getInstrInfoEv", "llvm::ThumbTargetMachine::getInstrInfo() const"},
    {"_ZNK4llvm18ThumbTargetMachine16getFrameLoweringEv", "llvm::ThumbTargetMachine::getFrameLowering() const"},
    {"_ZNK4llvm18ThumbTargetMachine17getTargetLoweringEv", "llvm::ThumbTargetMachine::getTargetLowering() const"},
    {"_ZNK4llvm18ThumbTargetMachine19getSelectionDAGInfoEv", "llvm::ThumbTargetMachine::getSelectionDAGInfo() const"},
    {"_ZNK4llvm18ThumbTargetMachine13getDataLayoutEv", "llvm::ThumbTargetMachine::getDataLayout() const"},
    {"_ZNK4llvm18ThumbTargetMachine15getRegisterInfoEv", "llvm::ThumbTargetMachine::getRegisterInfo() const"},
    {"_ZNK4llvm18ThumbTargetMachine16getELFWriterInfoEv", "llvm::ThumbTargetMachine::getELFWriterInfo() const"},
    {"_ZN4llvm16ARMTargetMachineD1Ev", "llvm::ARMTargetMachine::~ARMTargetMachine()"},
    {"_ZN4llvm16ARMTargetMachineD0Ev", "llvm::ARMTargetMachine::~ARMTargetMachine()"},
    {"_ZNK4llvm16ARMTargetMachine12getInstrInfoEv", "llvm::ARMTargetMachine::getInstrInfo() const"},
    {"_ZNK4llvm16ARMTargetMachine16getFrameLoweringEv", "llvm::ARMTargetMachine::getFrameLowering() const"},
    {"_ZNK4llvm16ARMTargetMachine17getTargetLoweringEv", "llvm::ARMTargetMachine::getTargetLowering() const"},
    {"_ZNK4llvm16ARMTargetMachine19getSelectionDAGInfoEv", "llvm::ARMTargetMachine::getSelectionDAGInfo() const"},
    {"_ZNK4llvm16ARMTargetMachine13getDataLayoutEv", "llvm::ARMTargetMachine::getDataLayout() const"},
    {"_ZNK4llvm16ARMTargetMachine15getRegisterInfoEv", "llvm::ARMTargetMachine::getRegisterInfo() const"},
    {"_ZNK4llvm16ARMTargetMachine16getELFWriterInfoEv", "llvm::ARMTargetMachine::getELFWriterInfo() const"},
    {"_ZN4llvm16ARMTargetMachineD2Ev", "llvm::ARMTargetMachine::~ARMTargetMachine()"},
    {"_ZN4llvm16ARMFrameLoweringD1Ev", "llvm::ARMFrameLowering::~ARMFrameLowering()"},
    {"_ZN4llvm17ARMTargetLoweringD1Ev", "llvm::ARMTargetLowering::~ARMTargetLowering()"},
    {"_ZN4llvm12ARMInstrInfoD1Ev", "llvm::ARMInstrInfo::~ARMInstrInfo()"},
    {"_ZN4llvm20ARMBaseTargetMachineD2Ev", "llvm::ARMBaseTargetMachine::~ARMBaseTargetMachine()"},
    {"_ZN4llvm10ARMJITInfoD1Ev", "llvm::ARMJITInfo::~ARMJITInfo()"},
    {"_ZN4llvm12ARMSubtargetD1Ev", "llvm::ARMSubtarget::~ARMSubtarget()"},
    {"_ZNK4llvm13TargetMachine16getSubtargetImplEv", "llvm::TargetMachine::getSubtargetImpl() const"},
    {"_ZN4llvm17LLVMTargetMachineD1Ev", "llvm::LLVMTargetMachine::~LLVMTargetMachine()"},
    {"_ZN4llvm17LLVMTargetMachineD0Ev", "llvm::LLVMTargetMachine::~LLVMTargetMachine()"},
    {"_ZN4llvm13TargetMachine10getJITInfoEv", "llvm::TargetMachine::getJITInfo()"},
    {"_ZNK4llvm13TargetMachine21getInstrItineraryDataEv", "llvm::TargetMachine::getInstrItineraryData() const"},
    {"_ZN4llvm17LLVMTargetMachine10addPreISelERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::LLVMTargetMachine::addPreISel(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm17LLVMTargetMachine15addInstSelectorERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::LLVMTargetMachine::addInstSelector(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm17LLVMTargetMachine14addPreRegAllocERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::LLVMTargetMachine::addPreRegAlloc(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm17LLVMTargetMachine12addPreSched2ERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::LLVMTargetMachine::addPreSched2(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm17LLVMTargetMachine14addPreEmitPassERNS_15PassManagerBaseENS_10CodeGenOpt5LevelE", "llvm::LLVMTargetMachine::addPreEmitPass(llvm::PassManagerBase&, llvm::CodeGenOpt::Level)"},
    {"_ZN4llvm17LLVMTargetMachine14addCodeEmitterERNS_15PassManagerBaseENS_10CodeGenOpt5LevelERNS_14JITCodeEmitterE", "llvm::LLVMTargetMachine::addCodeEmitter(llvm::PassManagerBase&, llvm::CodeGenOpt::Level, llvm::JITCodeEmitter&)"},
    {"_ZN4llvm12ARMSubtargetD0Ev", "llvm::ARMSubtarget::~ARMSubtarget()"},
    {"_ZNK4llvm15TargetSubtarget24getSpecialAddressLatencyEv", "llvm::TargetSubtarget::getSpecialAddressLatency() const"},
    {"_ZNK4llvm15TargetSubtarget21adjustSchedDependencyEPNS_5SUnitES2_RNS_4SDepE", "llvm::TargetSubtarget::adjustSchedDependency(llvm::SUnit*, llvm::SUnit*, llvm::SDep&) const"},
    {"_ZN4llvm10ARMJITInfoD0Ev", "llvm::ARMJITInfo::~ARMJITInfo()"},
    {"_ZN4llvm13TargetJITInfo20getPICJumpTableEntryEmm", "llvm::TargetJITInfo::getPICJumpTableEntry(unsigned long, unsigned long)"},
    {"_ZN4llvm13TargetJITInfo25allocateThreadLocalMemoryEm", "llvm::TargetJITInfo::allocateThreadLocalMemory(unsigned long)"},
    {"_ZNK4llvm10ARMJITInfo21hasCustomConstantPoolEv", "llvm::ARMJITInfo::hasCustomConstantPool() const"},
    {"_ZNK4llvm10ARMJITInfo19hasCustomJumpTablesEv", "llvm::ARMJITInfo::hasCustomJumpTables() const"},
    {"_ZNK4llvm10ARMJITInfo24allocateSeparateGVMemoryEv", "llvm::ARMJITInfo::allocateSeparateGVMemory() const"},
    {"_ZN4llvm13TargetJITInfoD1Ev", "llvm::TargetJITInfo::~TargetJITInfo()"},
    {"_ZN4llvm13TargetJITInfoD0Ev", "llvm::TargetJITInfo::~TargetJITInfo()"},
    {"_ZN4llvm13TargetJITInfo26emitGlobalValueIndirectSymEPKNS_11GlobalValueEPvRNS_14JITCodeEmitterE", "llvm::TargetJITInfo::emitGlobalValueIndirectSym(llvm::GlobalValue const*, void*, llvm::JITCodeEmitter&)"},
    {"_ZN4llvm13TargetJITInfo13getStubLayoutEv", "llvm::TargetJITInfo::getStubLayout()"},
    {"_ZN4llvm13TargetJITInfo16emitFunctionStubEPKNS_8FunctionEPvRNS_14JITCodeEmitterE", "llvm::TargetJITInfo::emitFunctionStub(llvm::Function const*, void*, llvm::JITCodeEmitter&)"},
    {"_ZN4llvm13TargetJITInfo23getLazyResolverFunctionEPFPvS1_E", "llvm::TargetJITInfo::getLazyResolverFunction(void* (*)(void*))"},
    {"_ZN4llvm13TargetJITInfo8relocateEPvPNS_17MachineRelocationEjPh", "llvm::TargetJITInfo::relocate(void*, llvm::MachineRelocation*, unsigned int, unsigned char*)"},
    {"_ZNK4llvm13TargetJITInfo21hasCustomConstantPoolEv", "llvm::TargetJITInfo::hasCustomConstantPool() const"},
    {"_ZNK4llvm13TargetJITInfo19hasCustomJumpTablesEv", "llvm::TargetJITInfo::hasCustomJumpTables() const"},
    {"_ZNK4llvm13TargetJITInfo24allocateSeparateGVMemoryEv", "llvm::TargetJITInfo::allocateSeparateGVMemory() const"},
    {"_ZN4llvm15ARMRegisterInfoD1Ev", "llvm::ARMRegisterInfo::~ARMRegisterInfo()"},
    {"_ZN4llvm12ARMInstrInfoD0Ev", "llvm::ARMInstrInfo::~ARMInstrInfo()"},
    {"_ZNK4llvm15TargetInstrInfo33isReallyTriviallyReMaterializableEPKNS_12MachineInstrEPNS_13AliasAnalysisE", "llvm::TargetInstrInfo::isReallyTriviallyReMaterializable(llvm::MachineInstr const*, llvm::AliasAnalysis*) const"},
    {"_ZNK4llvm15TargetInstrInfo21isCoalescableExtInstrERKNS_12MachineInstrERjS4_S4_", "llvm::TargetInstrInfo::isCoalescableExtInstr(llvm::MachineInstr const&, unsigned int&, unsigned int&, unsigned int&) const"},
    {"_ZNK4llvm15TargetInstrInfo25isLoadFromStackSlotPostFEEPKNS_12MachineInstrERi", "llvm::TargetInstrInfo::isLoadFromStackSlotPostFE(llvm::MachineInstr const*, int&) const"},
    {"_ZNK4llvm15TargetInstrInfo20hasLoadFromStackSlotEPKNS_12MachineInstrERPKNS_17MachineMemOperandERi", "llvm::TargetInstrInfo::hasLoadFromStackSlot(llvm::MachineInstr const*, llvm::MachineMemOperand const*&, int&) const"},
    {"_ZNK4llvm15TargetInstrInfo24isStoreToStackSlotPostFEEPKNS_12MachineInstrERi", "llvm::TargetInstrInfo::isStoreToStackSlotPostFE(llvm::MachineInstr const*, int&) const"},
    {"_ZNK4llvm15TargetInstrInfo19hasStoreToStackSlotEPKNS_12MachineInstrERPKNS_17MachineMemOperandERi", "llvm::TargetInstrInfo::hasStoreToStackSlot(llvm::MachineInstr const*, llvm::MachineMemOperand const*&, int&) const"},
    {"_ZNK4llvm15TargetInstrInfo21scheduleTwoAddrSourceEPNS_12MachineInstrES2_RKNS_18TargetRegisterInfoE", "llvm::TargetInstrInfo::scheduleTwoAddrSource(llvm::MachineInstr*, llvm::MachineInstr*, llvm::TargetRegisterInfo const&) const"},
    {"_ZNK4llvm15TargetInstrInfo19isLegalToSplitMBBAtERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEE", "llvm::TargetInstrInfo::isLegalToSplitMBBAt(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo25isProfitableToDupForIfCvtERNS_17MachineBasicBlockEjff", "llvm::ARMBaseInstrInfo::isProfitableToDupForIfCvt(llvm::MachineBasicBlock&, unsigned int, float, float) const"},
    {"_ZNK4llvm15TargetInstrInfo21foldMemoryOperandImplERNS_15MachineFunctionEPNS_12MachineInstrERKNS_15SmallVectorImplIjEEi", "llvm::TargetInstrInfo::foldMemoryOperandImpl(llvm::MachineFunction&, llvm::MachineInstr*, llvm::SmallVectorImpl<unsigned int> const&, int) const"},
    {"_ZNK4llvm15TargetInstrInfo21foldMemoryOperandImplERNS_15MachineFunctionEPNS_12MachineInstrERKNS_15SmallVectorImplIjEES4_", "llvm::TargetInstrInfo::foldMemoryOperandImpl(llvm::MachineFunction&, llvm::MachineInstr*, llvm::SmallVectorImpl<unsigned int> const&, llvm::MachineInstr*) const"},
    {"_ZNK4llvm15TargetInstrInfo19unfoldMemoryOperandERNS_15MachineFunctionEPNS_12MachineInstrEjbbRNS_15SmallVectorImplIS4_EE", "llvm::TargetInstrInfo::unfoldMemoryOperand(llvm::MachineFunction&, llvm::MachineInstr*, unsigned int, bool, bool, llvm::SmallVectorImpl<llvm::MachineInstr*>&) const"},
    {"_ZNK4llvm15TargetInstrInfo19unfoldMemoryOperandERNS_12SelectionDAGEPNS_6SDNodeERNS_15SmallVectorImplIS4_EE", "llvm::TargetInstrInfo::unfoldMemoryOperand(llvm::SelectionDAG&, llvm::SDNode*, llvm::SmallVectorImpl<llvm::SDNode*>&) const"},
    {"_ZNK4llvm15TargetInstrInfo26getOpcodeAfterMemoryUnfoldEjbbPj", "llvm::TargetInstrInfo::getOpcodeAfterMemoryUnfold(unsigned int, bool, bool, unsigned int*) const"},
    {"_ZNK4llvm15TargetInstrInfo21getNoopForMachoTargetERNS_6MCInstE", "llvm::TargetInstrInfo::getNoopForMachoTarget(llvm::MCInst&) const"},
    {"_ZNK4llvm16ARMBaseInstrInfo12isPredicatedEPKNS_12MachineInstrE", "llvm::ARMBaseInstrInfo::isPredicated(llvm::MachineInstr const*) const"},
    {"_ZNK4llvm15TargetInstrInfo24isSafeToMoveRegClassDefsEPKNS_19TargetRegisterClassE", "llvm::TargetInstrInfo::isSafeToMoveRegClassDefs(llvm::TargetRegisterClass const*) const"},
    {"_ZNK4llvm12ARMInstrInfo15getRegisterInfoEv", "llvm::ARMInstrInfo::getRegisterInfo() const"},
    {"_ZN4llvm16ARMBaseInstrInfoD1Ev", "llvm::ARMBaseInstrInfo::~ARMBaseInstrInfo()"},
    {"_ZN4llvm16ARMBaseInstrInfoD0Ev", "llvm::ARMBaseInstrInfo::~ARMBaseInstrInfo()"},
    {"_ZN4llvm19TargetInstrInfoImplD1Ev", "llvm::TargetInstrInfoImpl::~TargetInstrInfoImpl()"},
    {"_ZN4llvm19TargetInstrInfoImplD0Ev", "llvm::TargetInstrInfoImpl::~TargetInstrInfoImpl()"},
    {"_ZNK4llvm15TargetInstrInfo19isLoadFromStackSlotEPKNS_12MachineInstrERi", "llvm::TargetInstrInfo::isLoadFromStackSlot(llvm::MachineInstr const*, int&) const"},
    {"_ZNK4llvm15TargetInstrInfo18isStoreToStackSlotEPKNS_12MachineInstrERi", "llvm::TargetInstrInfo::isStoreToStackSlot(llvm::MachineInstr const*, int&) const"},
    {"_ZNK4llvm15TargetInstrInfo21convertToThreeAddressERNS_14ilist_iteratorINS_17MachineBasicBlockEEERNS1_INS_12MachineInstrEEEPNS_13LiveVariablesE", "llvm::TargetInstrInfo::convertToThreeAddress(llvm::ilist_iterator<llvm::MachineBasicBlock>&, llvm::ilist_iterator<llvm::MachineInstr>&, llvm::LiveVariables*) const"},
    {"_ZNK4llvm15TargetInstrInfo13analyzeBranchERNS_17MachineBasicBlockERPS1_S4_RNS_15SmallVectorImplINS_14MachineOperandEEEb", "llvm::TargetInstrInfo::analyzeBranch(llvm::MachineBasicBlock&, llvm::MachineBasicBlock*&, llvm::MachineBasicBlock*&, llvm::SmallVectorImpl<llvm::MachineOperand>&, bool) const"},
    {"_ZNK4llvm15TargetInstrInfo12removeBranchERNS_17MachineBasicBlockE", "llvm::TargetInstrInfo::removeBranch(llvm::MachineBasicBlock&) const"},
    {"_ZNK4llvm15TargetInstrInfo12insertBranchERNS_17MachineBasicBlockEPS1_S3_RKNS_15SmallVectorImplINS_14MachineOperandEEENS_8DebugLocE", "llvm::TargetInstrInfo::insertBranch(llvm::MachineBasicBlock&, llvm::MachineBasicBlock*, llvm::MachineBasicBlock*, llvm::SmallVectorImpl<llvm::MachineOperand> const&, llvm::DebugLoc) const"},
    {"_ZNK4llvm15TargetInstrInfo19isProfitableToIfCvtERNS_17MachineBasicBlockEjjff", "llvm::TargetInstrInfo::isProfitableToIfCvt(llvm::MachineBasicBlock&, unsigned int, unsigned int, float, float) const"},
    {"_ZNK4llvm15TargetInstrInfo19isProfitableToIfCvtERNS_17MachineBasicBlockEjjS2_jjff", "llvm::TargetInstrInfo::isProfitableToIfCvt(llvm::MachineBasicBlock&, unsigned int, unsigned int, llvm::MachineBasicBlock&, unsigned int, unsigned int, float, float) const"},
    {"_ZNK4llvm15TargetInstrInfo25isProfitableToDupForIfCvtERNS_17MachineBasicBlockEjff", "llvm::TargetInstrInfo::isProfitableToDupForIfCvt(llvm::MachineBasicBlock&, unsigned int, float, float) const"},
    {"_ZNK4llvm15TargetInstrInfo11copyPhysRegERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEENS_8DebugLocEjjb", "llvm::TargetInstrInfo::copyPhysReg(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, llvm::DebugLoc, unsigned int, unsigned int, bool) const"},
    {"_ZNK4llvm15TargetInstrInfo19storeRegToStackSlotERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEEjbiPKNS_19TargetRegisterClassEPKNS_18TargetRegisterInfoE", "llvm::TargetInstrInfo::storeRegToStackSlot(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, bool, int, llvm::TargetRegisterClass const*, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm15TargetInstrInfo20loadRegFromStackSlotERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEEjiPKNS_19TargetRegisterClassEPKNS_18TargetRegisterInfoE", "llvm::TargetInstrInfo::loadRegFromStackSlot(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, int, llvm::TargetRegisterClass const*, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm15TargetInstrInfo24emitFrameIndexDebugValueERNS_15MachineFunctionEiyPKNS_6MDNodeENS_8DebugLocE", "llvm::TargetInstrInfo::emitFrameIndexDebugValue(llvm::MachineFunction&, int, unsigned long long, llvm::MDNode const*, llvm::DebugLoc) const"},
    {"_ZNK4llvm15TargetInstrInfo23areLoadsFromSameBasePtrEPNS_6SDNodeES2_RxS3_", "llvm::TargetInstrInfo::areLoadsFromSameBasePtr(llvm::SDNode*, llvm::SDNode*, long long&, long long&) const"},
    {"_ZNK4llvm15TargetInstrInfo23shouldScheduleLoadsNearEPNS_6SDNodeES2_xxj", "llvm::TargetInstrInfo::shouldScheduleLoadsNear(llvm::SDNode*, llvm::SDNode*, long long, long long, unsigned int) const"},
    {"_ZNK4llvm15TargetInstrInfo22ReverseBranchConditionERNS_15SmallVectorImplINS_14MachineOperandEEE", "llvm::TargetInstrInfo::ReverseBranchCondition(llvm::SmallVectorImpl<llvm::MachineOperand>&) const"},
    {"_ZNK4llvm15TargetInstrInfo12isPredicatedEPKNS_12MachineInstrE", "llvm::TargetInstrInfo::isPredicated(llvm::MachineInstr const*) const"},
    {"_ZNK4llvm15TargetInstrInfo17SubsumesPredicateERKNS_15SmallVectorImplINS_14MachineOperandEEES5_", "llvm::TargetInstrInfo::SubsumesPredicate(llvm::SmallVectorImpl<llvm::MachineOperand> const&, llvm::SmallVectorImpl<llvm::MachineOperand> const&) const"},
    {"_ZNK4llvm15TargetInstrInfo16DefinesPredicateEPNS_12MachineInstrERSt6vectorINS_14MachineOperandESaIS4_EE", "llvm::TargetInstrInfo::DefinesPredicate(llvm::MachineInstr*, std::vector<llvm::MachineOperand, std::allocator<llvm::MachineOperand>>&) const"},
    {"_ZNK4llvm15TargetInstrInfo12isPredicableEPNS_12MachineInstrE", "llvm::TargetInstrInfo::isPredicable(llvm::MachineInstr*) const"},
    {"_ZNK4llvm15TargetInstrInfo14AnalyzeCompareEPKNS_12MachineInstrERjRiS5_", "llvm::TargetInstrInfo::AnalyzeCompare(llvm::MachineInstr const*, unsigned int&, int&, int&) const"},
    {"_ZNK4llvm15TargetInstrInfo20OptimizeCompareInstrEPNS_12MachineInstrEjiiPKNS_19MachineRegisterInfoE", "llvm::TargetInstrInfo::OptimizeCompareInstr(llvm::MachineInstr*, unsigned int, int, int, llvm::MachineRegisterInfo const*) const"},
    {"_ZNK4llvm15TargetInstrInfo13FoldImmediateEPNS_12MachineInstrES2_jPNS_19MachineRegisterInfoE", "llvm::TargetInstrInfo::FoldImmediate(llvm::MachineInstr*, llvm::MachineInstr*, unsigned int, llvm::MachineRegisterInfo*) const"},
    {"_ZNK4llvm15TargetInstrInfo21hasHighOperandLatencyEPKNS_18InstrItineraryDataEPKNS_19MachineRegisterInfoEPKNS_12MachineInstrEjS9_j", "llvm::TargetInstrInfo::hasHighOperandLatency(llvm::InstrItineraryData const*, llvm::MachineRegisterInfo const*, llvm::MachineInstr const*, unsigned int, llvm::MachineInstr const*, unsigned int) const"},
    {"_ZNSt8_Rb_treeIjjSt9_IdentityIjESt4lessIjESaIjEE8_M_eraseEPSt13_Rb_tree_nodeIjE", "std::_Rb_tree<unsigned int, unsigned int, std::_Identity<unsigned int>, std::less<unsigned int>, std::allocator<unsigned int>>::_M_erase(std::_Rb_tree_node<unsigned int>*)"},
    {"_ZN4llvm15ARMRegisterInfoD0Ev", "llvm::ARMRegisterInfo::~ARMRegisterInfo()"},
    {"_ZNK4llvm18TargetRegisterInfo20getCrossCopyRegClassEPKNS_19TargetRegisterClassE", "llvm::TargetRegisterInfo::getCrossCopyRegClass(llvm::TargetRegisterClass const*) const"},
    {"_ZNK4llvm18TargetRegisterInfo20hasReservedSpillSlotERKNS_15MachineFunctionEjRi", "llvm::TargetRegisterInfo::hasReservedSpillSlot(llvm::MachineFunction const&, unsigned int, int&) const"},
    {"_ZNK4llvm18TargetRegisterInfo21saveScavengerRegisterERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERS5_PKNS_19TargetRegisterClassEj", "llvm::TargetRegisterInfo::saveScavengerRegister(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, llvm::ilist_iterator<llvm::MachineInstr>&, llvm::TargetRegisterClass const*, unsigned int) const"},
    {"_ZN4llvm19ARMBaseRegisterInfoD1Ev", "llvm::ARMBaseRegisterInfo::~ARMBaseRegisterInfo()"},
    {"_ZN4llvm19ARMBaseRegisterInfoD0Ev", "llvm::ARMBaseRegisterInfo::~ARMBaseRegisterInfo()"},
    {"_ZN4llvm18ARMGenRegisterInfoD1Ev", "llvm::ARMGenRegisterInfo::~ARMGenRegisterInfo()"},
    {"_ZN4llvm18ARMGenRegisterInfoD0Ev", "llvm::ARMGenRegisterInfo::~ARMGenRegisterInfo()"},
    {"_ZNK4llvm18TargetRegisterInfo23canCombineSubRegIndicesEPKNS_19TargetRegisterClassERNS_15SmallVectorImplIjEERj", "llvm::TargetRegisterInfo::canCombineSubRegIndices(llvm::TargetRegisterClass const*, llvm::SmallVectorImpl<unsigned int>&, unsigned int&) const"},
    {"_ZNK4llvm18TargetRegisterInfo24getMatchingSuperRegClassEPKNS_19TargetRegisterClassES3_j", "llvm::TargetRegisterInfo::getMatchingSuperRegClass(llvm::TargetRegisterClass const*, llvm::TargetRegisterClass const*, unsigned int) const"},
    {"_ZNK4llvm18TargetRegisterInfo18getPointerRegClassEj", "llvm::TargetRegisterInfo::getPointerRegClass(unsigned int) const"},
    {"_ZNK4llvm18TargetRegisterInfo18getAllocationOrderEPKNS_19TargetRegisterClassEjjRKNS_15MachineFunctionE", "llvm::TargetRegisterInfo::getAllocationOrder(llvm::TargetRegisterClass const*, unsigned int, unsigned int, llvm::MachineFunction const&) const"},
    {"_ZNK4llvm18TargetRegisterInfo19ResolveRegAllocHintEjjRKNS_15MachineFunctionE", "llvm::TargetRegisterInfo::ResolveRegAllocHint(unsigned int, unsigned int, llvm::MachineFunction const&) const"},
    {"_ZNK4llvm18TargetRegisterInfo18UpdateRegAllocHintEjjRNS_15MachineFunctionE", "llvm::TargetRegisterInfo::UpdateRegAllocHint(unsigned int, unsigned int, llvm::MachineFunction&) const"},
    {"_ZNK4llvm18TargetRegisterInfo26requiresRegisterScavengingERKNS_15MachineFunctionE", "llvm::TargetRegisterInfo::requiresRegisterScavenging(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm18TargetRegisterInfo28requiresFrameIndexScavengingERKNS_15MachineFunctionE", "llvm::TargetRegisterInfo::requiresFrameIndexScavenging(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm18TargetRegisterInfo28requiresVirtualBaseRegistersERKNS_15MachineFunctionE", "llvm::TargetRegisterInfo::requiresVirtualBaseRegisters(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm18ARMGenRegisterInfo21needsStackRealignmentERKNS_15MachineFunctionE", "llvm::ARMGenRegisterInfo::needsStackRealignment(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm18TargetRegisterInfo24getFrameIndexInstrOffsetEPKNS_12MachineInstrEi", "llvm::TargetRegisterInfo::getFrameIndexInstrOffset(llvm::MachineInstr const*, int) const"},
    {"_ZNK4llvm18TargetRegisterInfo17needsFrameBaseRegEPNS_12MachineInstrEx", "llvm::TargetRegisterInfo::needsFrameBaseReg(llvm::MachineInstr*, long long) const"},
    {"_ZNK4llvm18TargetRegisterInfo28materializeFrameBaseRegisterEPNS_17MachineBasicBlockEjix", "llvm::TargetRegisterInfo::materializeFrameBaseRegister(llvm::MachineBasicBlock*, unsigned int, int, long long) const"},
    {"_ZNK4llvm18TargetRegisterInfo17resolveFrameIndexENS_14ilist_iteratorINS_12MachineInstrEEEjx", "llvm::TargetRegisterInfo::resolveFrameIndex(llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, long long) const"},
    {"_ZNK4llvm18TargetRegisterInfo18isFrameOffsetLegalEPKNS_12MachineInstrEx", "llvm::TargetRegisterInfo::isFrameOffsetLegal(llvm::MachineInstr const*, long long) const"},
    {"_ZNK4llvm18TargetRegisterInfo29eliminateCallFramePseudoInstrERNS_15MachineFunctionERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEE", "llvm::TargetRegisterInfo::eliminateCallFramePseudoInstr(llvm::MachineFunction&, llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>) const"},
    {"_ZN4llvm17ARMTargetLoweringD0Ev", "llvm::ARMTargetLowering::~ARMTargetLowering()"},
    {"_ZNK4llvm14TargetLowering17getRepRegClassForENS_3EVTE", "llvm::TargetLowering::getRepRegClassFor(llvm::EVT) const"},
    {"_ZNK4llvm14TargetLowering21getRepRegClassCostForENS_3EVTE", "llvm::TargetLowering::getRepRegClassCostFor(llvm::EVT) const"},
    {"_ZNK4llvm14TargetLowering22isVectorClearMaskLegalERKNS_15SmallVectorImplIiEENS_3EVTE", "llvm::TargetLowering::isVectorClearMaskLegal(llvm::SmallVectorImpl<int> const&, llvm::EVT) const"},
    {"_ZNK4llvm14TargetLowering22ShouldShrinkFPConstantENS_3EVTE", "llvm::TargetLowering::ShouldShrinkFPConstant(llvm::EVT) const"},
    {"_ZNK4llvm14TargetLowering19getOptimalMemOpTypeEyjjbbRNS_15MachineFunctionE", "llvm::TargetLowering::getOptimalMemOpType(unsigned long long, unsigned int, unsigned int, bool, bool, llvm::MachineFunction&) const"},
    {"_ZNK4llvm14TargetLowering25LowerCustomJumpTableEntryEPKNS_20MachineJumpTableInfoEPKNS_17MachineBasicBlockEjRNS_9MCContextE", "llvm::TargetLowering::LowerCustomJumpTableEntry(llvm::MachineJumpTableInfo const*, llvm::MachineBasicBlock const*, unsigned int, llvm::MCContext&) const"},
    {"_ZNK4llvm14TargetLowering22getStackCookieLocationERjS1_", "llvm::TargetLowering::getStackCookieLocation(unsigned int&, unsigned int&) const"},
    {"_ZNK4llvm14TargetLowering20isTypeDesirableForOpEjNS_3EVTE", "llvm::TargetLowering::isTypeDesirableForOp(unsigned int, llvm::EVT) const"},
    {"_ZNK4llvm14TargetLowering22IsDesirableToPromoteOpENS_7SDValueERNS_3EVTE", "llvm::TargetLowering::IsDesirableToPromoteOp(llvm::SDValue, llvm::EVT&) const"},
    {"_ZNK4llvm14TargetLowering14CanLowerReturnENS_11CallingConv2IDEbRKNS_15SmallVectorImplINS_3ISD9OutputArgEEERNS_11LLVMContextE", "llvm::TargetLowering::CanLowerReturn(llvm::CallingConv::ID, bool, llvm::SmallVectorImpl<llvm::ISD::OutputArg> const&, llvm::LLVMContext&) const"},
    {"_ZNK4llvm14TargetLowering14isTruncateFreeEPKNS_4TypeES3_", "llvm::TargetLowering::isTruncateFree(llvm::Type const*, llvm::Type const*) const"},
    {"_ZNK4llvm14TargetLowering14isTruncateFreeENS_3EVTES1_", "llvm::TargetLowering::isTruncateFree(llvm::EVT, llvm::EVT) const"},
    {"_ZNK4llvm14TargetLowering10isZExtFreeEPKNS_4TypeES3_", "llvm::TargetLowering::isZExtFree(llvm::Type const*, llvm::Type const*) const"},
    {"_ZNK4llvm14TargetLowering10isZExtFreeENS_3EVTES1_", "llvm::TargetLowering::isZExtFree(llvm::EVT, llvm::EVT) const"},
    {"_ZNK4llvm14TargetLowering21isNarrowingProfitableENS_3EVTES1_", "llvm::TargetLowering::isNarrowingProfitable(llvm::EVT, llvm::EVT) const"},
    {"_ZN4llvm16ARMFrameLoweringD0Ev", "llvm::ARMFrameLowering::~ARMFrameLowering()"},
    {"_ZNK4llvm19TargetFrameLowering24getCalleeSavedSpillSlotsERj", "llvm::TargetFrameLowering::getCalleeSavedSpillSlots(unsigned int&) const"},
    {"_ZNK4llvm19TargetFrameLowering31targetHandlesStackFrameRoundingEv", "llvm::TargetFrameLowering::targetHandlesStackFrameRounding() const"},
    {"_ZNK4llvm19TargetFrameLowering35processFunctionBeforeFrameFinalizedERNS_15MachineFunctionE", "llvm::TargetFrameLowering::processFunctionBeforeFrameFinalized(llvm::MachineFunction&) const"},
    {"_ZN4llvm21RegisterTargetMachineINS_18ThumbTargetMachineEE9AllocatorERKNS_6TargetERKSsS7_", "llvm::RegisterTargetMachine<llvm::ThumbTargetMachine>::Allocator(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZN4llvm21RegisterTargetMachineINS_16ARMTargetMachineEE9AllocatorERKNS_6TargetERKSsS7_", "llvm::RegisterTargetMachine<llvm::ARMTargetMachine>::Allocator(llvm::Target const&, std::string const&, std::string const&)"},
    {"_ZNK4llvm19TargetFrameLowering25spillCalleeSavedRegistersERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERKSt6vectorINS_15CalleeSavedInfoESaIS7_EEPKNS_18TargetRegisterInfoE", "llvm::TargetFrameLowering::spillCalleeSavedRegisters(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, std::vector<llvm::CalleeSavedInfo, std::allocator<llvm::CalleeSavedInfo>> const&, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm19TargetFrameLowering27restoreCalleeSavedRegistersERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERKSt6vectorINS_15CalleeSavedInfoESaIS7_EEPKNS_18TargetRegisterInfoE", "llvm::TargetFrameLowering::restoreCalleeSavedRegisters(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, std::vector<llvm::CalleeSavedInfo, std::allocator<llvm::CalleeSavedInfo>> const&, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm19TargetFrameLowering20hasReservedCallFrameERKNS_15MachineFunctionE", "llvm::TargetFrameLowering::hasReservedCallFrame(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19TargetFrameLowering27canSimplifyCallFramePseudosERKNS_15MachineFunctionE", "llvm::TargetFrameLowering::canSimplifyCallFramePseudos(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19TargetFrameLowering36processFunctionBeforeCalleeSavedScanERNS_15MachineFunctionEPNS_12RegScavengerE", "llvm::TargetFrameLowering::processFunctionBeforeCalleeSavedScan(llvm::MachineFunction&, llvm::RegScavenger*) const"},
    {"_ZN4llvm13ImmutablePass18getAsImmutablePassEv", "llvm::ImmutablePass::getAsImmutablePass()"},
    {"_ZN4llvm13ImmutablePass11runOnModuleERNS_6ModuleE", "llvm::ImmutablePass::runOnModule(llvm::Module&)"},
    {"_ZN4llvm10ARMJITInfoC2Ev", "llvm::ARMJITInfo::ARMJITInfo()"},
    {"_ZN4llvm22ARMElfTargetObjectFile10InitializeERNS_9MCContextERKNS_13TargetMachineE", "llvm::ARMElfTargetObjectFile::Initialize(llvm::MCContext&, llvm::TargetMachine const&)"},
    {"_ZN4llvm22ARMElfTargetObjectFileD1Ev", "llvm::ARMElfTargetObjectFile::~ARMElfTargetObjectFile()"},
    {"_ZN4llvm22ARMElfTargetObjectFileD0Ev", "llvm::ARMElfTargetObjectFile::~ARMElfTargetObjectFile()"},
    {"_ZN4llvm22createMLxExpansionPassEv", "llvm::createMLxExpansionPass()"},
    {"_ZN12_GLOBAL__N_112MLxExpansionD1Ev", "(anonymous namespace)::MLxExpansion::~MLxExpansion()"},
    {"_ZN12_GLOBAL__N_112MLxExpansionD0Ev", "(anonymous namespace)::MLxExpansion::~MLxExpansion()"},
    {"_ZNK12_GLOBAL__N_112MLxExpansion11getPassNameEv", "(anonymous namespace)::MLxExpansion::getPassName() const"},
    {"_ZN12_GLOBAL__N_112MLxExpansion20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::MLxExpansion::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN4llvm21createNEONMoveFixPassEv", "llvm::createNEONMoveFixPass()"},
    {"_ZN12_GLOBAL__N_115NEONMoveFixPassD1Ev", "(anonymous namespace)::NEONMoveFixPass::~NEONMoveFixPass()"},
    {"_ZN12_GLOBAL__N_115NEONMoveFixPassD0Ev", "(anonymous namespace)::NEONMoveFixPass::~NEONMoveFixPass()"},
    {"_ZNK12_GLOBAL__N_115NEONMoveFixPass11getPassNameEv", "(anonymous namespace)::NEONMoveFixPass::getPassName() const"},
    {"_ZN12_GLOBAL__N_115NEONMoveFixPass20runOnMachineFunctionERN4llvm15MachineFunctionE", "(anonymous namespace)::NEONMoveFixPass::runOnMachineFunction(llvm::MachineFunction&)"},
    {"_ZN4llvm8DenseMapIjPKNS_12MachineInstrENS_12DenseMapInfoIjEENS4_IS3_EEE16InsertIntoBucketERKjRKS3_PSt4pairIjS3_E", "llvm::DenseMap<unsigned int, llvm::MachineInstr const*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::MachineInstr const*>>::InsertIntoBucket(unsigned int const&, llvm::MachineInstr const* const&, std::pair<unsigned int, llvm::MachineInstr const*>*)"},
    {"_ZN4llvm8DenseMapIjPKNS_12MachineInstrENS_12DenseMapInfoIjEENS4_IS3_EEE4growEj", "llvm::DenseMap<unsigned int, llvm::MachineInstr const*, llvm::DenseMapInfo<unsigned int>, llvm::DenseMapInfo<llvm::MachineInstr const*>>::grow(unsigned int)"},
    {"_ZNK4llvm19Thumb1FrameLowering20hasReservedCallFrameERKNS_15MachineFunctionE", "llvm::Thumb1FrameLowering::hasReservedCallFrame(llvm::MachineFunction const&) const"},
    {"_ZNK4llvm19Thumb1FrameLowering12emitPrologueERNS_15MachineFunctionE", "llvm::Thumb1FrameLowering::emitPrologue(llvm::MachineFunction&) const"},
    {"_ZNK4llvm19Thumb1FrameLowering12emitEpilogueERNS_15MachineFunctionERNS_17MachineBasicBlockE", "llvm::Thumb1FrameLowering::emitEpilogue(llvm::MachineFunction&, llvm::MachineBasicBlock&) const"},
    {"_ZNK4llvm19Thumb1FrameLowering25spillCalleeSavedRegistersERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERKSt6vectorINS_15CalleeSavedInfoESaIS7_EEPKNS_18TargetRegisterInfoE", "llvm::Thumb1FrameLowering::spillCalleeSavedRegisters(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, std::vector<llvm::CalleeSavedInfo, std::allocator<llvm::CalleeSavedInfo>> const&, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm19Thumb1FrameLowering27restoreCalleeSavedRegistersERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEERKSt6vectorINS_15CalleeSavedInfoESaIS7_EEPKNS_18TargetRegisterInfoE", "llvm::Thumb1FrameLowering::restoreCalleeSavedRegisters(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, std::vector<llvm::CalleeSavedInfo, std::allocator<llvm::CalleeSavedInfo>> const&, llvm::TargetRegisterInfo const*) const"},
    {"_ZN4llvm19Thumb1FrameLoweringD1Ev", "llvm::Thumb1FrameLowering::~Thumb1FrameLowering()"},
    {"_ZN4llvm19Thumb1FrameLoweringD0Ev", "llvm::Thumb1FrameLowering::~Thumb1FrameLowering()"},
    {"_ZNSt6vectorIjSaIjEE13_M_insert_auxEN9__gnu_cxx17__normal_iteratorIPjS1_EERKj", "std::vector<unsigned int, std::allocator<unsigned int>>::_M_insert_aux(__gnu_cxx::__normal_iterator<unsigned int*, std::vector<unsigned int, std::allocator<unsigned int>>>, unsigned int const&)"},
    {"_ZN4llvm9BitVector6resizeEjb", "llvm::BitVector::resize(unsigned int, bool)"},
    {"_ZN4llvm15Thumb1InstrInfoC1ERKNS_12ARMSubtargetE", "llvm::Thumb1InstrInfo::Thumb1InstrInfo(llvm::ARMSubtarget const&)"},
    {"_ZN4llvm15Thumb1InstrInfoC2ERKNS_12ARMSubtargetE", "llvm::Thumb1InstrInfo::Thumb1InstrInfo(llvm::ARMSubtarget const&)"},
    {"_ZNK4llvm15Thumb1InstrInfo18getUnindexedOpcodeEj", "llvm::Thumb1InstrInfo::getUnindexedOpcode(unsigned int) const"},
    {"_ZNK4llvm15Thumb1InstrInfo11copyPhysRegERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEENS_8DebugLocEjjb", "llvm::Thumb1InstrInfo::copyPhysReg(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, llvm::DebugLoc, unsigned int, unsigned int, bool) const"},
    {"_ZNK4llvm15Thumb1InstrInfo19storeRegToStackSlotERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEEjbiPKNS_19TargetRegisterClassEPKNS_18TargetRegisterInfoE", "llvm::Thumb1InstrInfo::storeRegToStackSlot(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, bool, int, llvm::TargetRegisterClass const*, llvm::TargetRegisterInfo const*) const"},
    {"_ZNK4llvm15Thumb1InstrInfo20loadRegFromStackSlotERNS_17MachineBasicBlockENS_14ilist_iteratorINS_12MachineInstrEEEjiPKNS_19TargetRegisterClassEPKNS_18TargetRegisterInfoE", "llvm::Thumb1InstrInfo::loadRegFromStackSlot(llvm::MachineBasicBlock&, llvm::ilist_iterator<llvm::MachineInstr>, unsigned int, int, llvm::TargetRegisterClass const*, llvm::TargetRegisterInfo const*) const"},
    {"_ZN4llvm15Thumb1InstrInfoD1Ev", "llvm::Thumb1InstrInfo::~Thumb1InstrInfo()"},
    {"_ZN4llvm15Thumb1InstrInfoD0Ev", "llvm::Thumb1InstrInfo::~Thumb1InstrInfo()"},
    {"_ZNK4llvm15Thumb1InstrInfo15getRegisterInfoEv", "llvm::Thumb1InstrInfo::getRegisterInfo() const"},
    {"_ZN4llvm18Thumb1RegisterInfoD1Ev", "llvm::Thumb1RegisterInfo::~Thumb1RegisterInfo()"},
    {"_ZN4llvm18Thumb1RegisterInfoD0Ev", "llvm::Thumb1Register